# code for pulling down uniprot sequence for predictions

from getSequence.getsequence_exceptions import RetreiveSequenceError
import requests

def parse_input(user_input):
    '''
    function to parse out info that the user is trying
    to search and formats it for the uniprot query

    The idea was to make the Uniprot search API better by parsing
    user input to explicitely search specific organisms. Works alright (better than just
    tossing your hat in the ring).
    '''
    # first split the user input
    user_input=user_input.lower().split(' ')
    # list of vals to strip out of the name.
    strip_list = ['escherichia', 'coli', 'e.', 'coli', 'e', 'ecoli', 'saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's', 'budding', 'bakers', 'yeast', 'mus', 'musculus', 'm.', 'musculus', 'm', 'mouse', 'mouse', 'drosophila', 'melanogaster', 'd.', 'melanogaster', 'd', 'fruit', 'fly', 'drome', 'bacillus', 'subtilis', 'b.', 'subtilis', 'b', 'bacsu', 'rattus', 'norvegicus', 'r.', 'norvegicus', 'r', 'rat', 'rat', 'homo', 'sapiens', 'h.', 'sapiens', 'h', 'sapien', 'human', 'humans', 'human', 'arabidopsis', 'thaliana', 'a.', 'thaliana', 'a', 'arath', 'arath', 'bos', 'taurus', 'b.', 'taurus', 'b', 'bovin', 'danio', 'rerio', 'd.', 'rerio', 'd', 'zebrafish', 'zebra', 'fish', 'danre', 'caenorhabditis', 'elegans', 'c.', 'elegans', 'c', 'nematode', 'nematodes', 'worm', 'caeel', 'dictyostelium', 'discoideum', 'd.', 'discoideum', 'd', 'slime', 'mold', 'dictyo', 'dicdi', 'oryza', 'sativa', 'o.', 'sativa', 'o', 'rice', 'orysj', 'dugbe', 'virus', 'd.', 'virus', 'd', 'dugba', 'woodchuck', 'hepatitis', 'w.', 'hepatitis', 'w', 'whv5', 'equine', 'arteritis', 'e.', 'arteritis', 'e', 'eavbu', 'severe', 'acute', 's.', 'acute', 's', 'sars', 'breda', 'virus', 'b.', 'virus', 'b', 'brv1', 'poliovirus', 'type', 'p.', 'type', 'p', 'pol1m', 'avian', 'encephalomyelitis', 'a.', 'encephalomyelitis', 'a', 'aevca', 'yellow', 'fever', 'y.', 'fever', 'y', 'yefv1', 'turnip', 'yellow', 't.', 'yellow', 't', 'tymv', 'broad', 'bean', 'b.', 'bean', 'b', 'bbwvs', 'rabbit', 'hemorrhagic', 'r.', 'hemorrhagic', 'r', 'rhdvf', 'drosophila', 'x', 'd.', 'x', 'd', 'dxv96', 'hepatitis', 'c', 'h.', 'c', 'h', 'hcv77', 'potato', 'virus', 'p.', 'virus', 'p', 'pvyn', 'brome', 'streak', 'b.', 'streak', 'b', 'bstv1', 'tobacco', 'mosaic', 't.', 'mosaic', 't', 'tmv', 'ryegrass', 'mosaic', 'r.', 'mosaic', 'r', 'rgmvd', 'chikungunya', 'virus', 'c.', 'virus', 'c', 'chiks', 'semliki', 'forest', 's.', 'forest', 's', 'sfv', 'rubella', 'virus', 'r.', 'virus', 'r', 'rubvt', 'human', 'parechovirus', 'h.', 'parechovirus', 'h', 'hpe2w', 'seneca', 'valley', 's.', 'valley', 's', 'svv1', 'white', 'bream', 'w.', 'bream', 'w', 'wbv24', 'footandmouth', 'disease', 'f.', 'disease', 'f', 'fmdvp', 'norwalk', 'virus', 'n.', 'virus', 'n', 'nvn68', 'human', 'tcell', 'h.', 'tcell', 'h', 'htl1c', 'simian', 'foamy', 's.', 'foamy', 's', 'sfvcp', 'feline', 'calicivirus', 'f.', 'calicivirus', 'f', 'fcvur', 'porcine', 'transmissible', 'p.', 'transmissible', 'p', 'cvppu', 'human', 'astrovirus1', 'h.', 'astrovirus1', 'h', 'hasv1', 'barley', 'stripe', 'b.', 'stripe', 'b', 'bsmv', 'spiroplasma', 'virus', 's.', 'virus', 's', 'spv4', 'avian', 'leukosis', 'a.', 'leukosis', 'a', 'alva', 'xenotropic', 'mulvrelated', 'x.', 'mulvrelated', 'x', 'xmrv6', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1h2', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv2be', 'bovine', 'viral', 'b.', 'viral', 'b', 'bvdvn', 'encephalomyocarditis', 'virus', 'e.', 'virus', 'e', 'emcvr', 'vesicular', 'stomatitis', 'v.', 'stomatitis', 'v', 'vsiva', 'newcastle', 'disease', 'n.', 'disease', 'n', 'ndvb1', 'lassa', 'virus', 'l.', 'virus', 'l', 'lassj', 'lymphocytic', 'choriomeningitis', 'l.', 'choriomeningitis', 'l', 'lycva', 'bunyamwera', 'virus', 'b.', 'virus', 'b', 'bunyw', 'rift', 'valley', 'r.', 'valley', 'r', 'rvfvz', 'dengue', 'virus', 'd.', 'virus', 'd', 'den1w', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade05', 'acute', 'bee', 'a.', 'bee', 'a', 'abpvr', 'mouse', 'mammary', 'm.', 'mammary', 'm', 'mmtvc', 'bat', 'coronavirus', 'b.', 'coronavirus', 'b', 'bchk4', 'bat', 'coronavirus', 'b.', 'coronavirus', 'b', 'bchk9', 'human', 'parvovirus', 'h.', 'parvovirus', 'h', 'pavhv', 'moloney', 'murine', 'm.', 'murine', 'm', 'mlvms', 'tomato', 'spotted', 't.', 'spotted', 't', 'tswv1', 'hepatitis', 'delta', 'h.', 'delta', 'h', 'hdvd3', 'porcine', 'reproductive', 'p.', 'reproductive', 'p', 'prrsl', 'blackberry', 'virus', 'b.', 'virus', 'b', 'bvy3', 'barley', 'yellow', 'b.', 'yellow', 'b', 'baymy', 'sindbis', 'virus', 's.', 'virus', 's', 'sindv', 'human', 'coronavirus', 'h.', 'coronavirus', 'h', 'cvh22', 'avian', 'infectious', 'a.', 'infectious', 'a', 'ibvb', 'potato', 'leafroll', 'p.', 'leafroll', 'p', 'plrv1', 'human', 'hepatitis', 'h.', 'hepatitis', 'h', 'havhm', 'soybean', 'mosaic', 's.', 'mosaic', 's', 'sbmvn', 'human', 'rhinovirus', 'h.', 'rhinovirus', 'h', 'hrv8a', 'sweet', 'potato', 's.', 'potato', 's', 'spmmv', 'rice', 'tungro', 'r.', 'tungro', 'r', 'rtsva', 'parsnip', 'yellow', 'p.', 'yellow', 'p', 'pyfv1', 'rubella', 'virus', 'r.', 'virus', 'r', 'rubvm', 'murine', 'coronavirus', 'm.', 'coronavirus', 'm', 'cvma5', 'murine', 'coronavirus', 'm.', 'coronavirus', 'm', 'cvmjh', 'duck', 'hepatitis', 'd.', 'hepatitis', 'd', 'dhbv1', 'reston', 'ebolavirus', 'r.', 'ebolavirus', 'r', 'eborr', 'zaire', 'ebolavirus', 'z.', 'ebolavirus', 'z', 'ebozm', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivm1', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivsp', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivtn', 'cryphonectria', 'hypovirus', 'c.', 'hypovirus', 'c', 'chpve', 'tomato', 'golden', 't.', 'golden', 't', 'tgmvy', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1vi', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1yf', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv2eh', 'avian', 'infectious', 'a.', 'infectious', 'a', 'ibdvb', 'bat', 'coronavirus', 'b.', 'coronavirus', 'b', 'bc133', 'bat', 'coronavirus', 'b.', 'coronavirus', 'b', 'bchk5', 'bovine', 'respiratory', 'b.', 'respiratory', 'b', 'brsva', 'avian', 'infectious', 'a.', 'infectious', 'a', 'ibvm', 'human', 'tcell', 'h.', 'tcell', 'h', 'htl1a', 'human', 'tcell', 'h.', 'tcell', 'h', 'htl3p', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv190', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1a2', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1an', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1b9', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1br', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1el', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1jr', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1ma', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1rh', 'simian', 'virus', 's.', 'virus', 's', 'sv40', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv2st', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1yb', 'borna', 'disease', 'b.', 'disease', 'b', 'bdvv', 'hepatitis', 'b', 'h.', 'b', 'h', 'hbvc1', 'hepatitis', 'b', 'h.', 'b', 'h', 'hbvd2', 'hepatitis', 'b', 'h.', 'b', 'h', 'hbvd3', 'tacaribe', 'virus', 't.', 'virus', 't', 'tacvf', 'human', 'tcell', 'h.', 'tcell', 'h', 'htl32', 'duck', 'hepatitis', 'd.', 'hepatitis', 'd', 'hpbdc', 'influenza', 'b', 'i.', 'b', 'i', 'inble', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade02', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivs4', 'triticum', 'mosaic', 't.', 'mosaic', 't', 'trmvu', 'rubella', 'virus', 'r.', 'virus', 'r', 'rubvv', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivek', 'cowpea', 'mosaic', 'c.', 'mosaic', 'c', 'cpmvs', 'cricket', 'paralysis', 'c.', 'paralysis', 'c', 'crpvc', 'hepatitis', 'b', 'h.', 'b', 'h', 'hbvcj', 'uukuniemi', 'virus', 'u.', 'virus', 'u', 'uuks', 'hantaan', 'virus', 'h.', 'virus', 'h', 'hantv', 'crimeancongo', 'hemorrhagic', 'c.', 'hemorrhagic', 'c', 'cchfi', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'sivmb', 'ground', 'squirrel', 'g.', 'squirrel', 'g', 'gshv', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv16', 'human', 'tcell', 'h.', 'tcell', 'h', 'htlv2', 'influenza', 'a', 'i.', 'a', 'i', 'i34a1', 'latino', 'mammarenavirus', 'l.', 'mammarenavirus', 'l', 'latvb', 'machupo', 'virus', 'm.', 'virus', 'm', 'machu', 'salivirus', 'a', 's.', 'a', 's', 'salva', 'cosavirus', 'a', 'c.', 'a', 'c', 'cosaa', 'pegivirus', 'a', 'p.', 'a', 'p', 'pegia', 'blueberry', 'scorch', 'b.', 'scorch', 'b', 'bbscv', 'zika', 'virus', 'z.', 'virus', 'z', 'zikv', 'aichi', 'virus', 'a.', 'virus', 'a', 'aiva8', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv1u4', 'human', 'spumaretrovirus', 'h.', 'spumaretrovirus', 'h', 'foamv', 'middle', 'east', 'm.', 'east', 'm', 'mers1', 'influenza', 'a', 'i.', 'a', 'i', 'i72a2', 'human', 'coronavirus', 'h.', 'coronavirus', 'h', 'cvhoc', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', '9hiv1', 'lake', 'victoria', 'l.', 'victoria', 'l', 'mabvm', 'sendai', 'virus', 's.', 'virus', 's', 'sendz', 'borna', 'disease', 'b.', 'disease', 'b', 'bdv1', 'turnip', 'mosaic', 't.', 'mosaic', 't', 'tumvj', 'sfts', 'phlebovirus', 's.', 'phlebovirus', 's', 'sftsv', 'dobravabelgrade', 'orthohantavirus', 'd.', 'orthohantavirus', 'd', 'dobv', 'toscana', 'virus', 't.', 'virus', 't', 'tosv', 'solenopsis', 'invicta', 's.', 'invicta', 's', 'sinv3', 'mouse', 'mammary', 'm.', 'mammary', 'm', 'mmtvb', 'tula', 'orthohantavirus', 't.', 'orthohantavirus', 't', 'tulv', 'severe', 'acute', 's.', 'acute', 's', 'sars2', 'beet', 'yellows', 'b.', 'yellows', 'b', 'byvu', 'apple', 'stem', 'a.', 'stem', 'a', 'asgvp', 'equine', 'rhinitis', 'e.', 'rhinitis', 'e', 'erbv1', 'porcine', 'sapelovirus', 'p.', 'sapelovirus', 'p', 'psv13', 'tomato', 'ringspot', 't.', 'ringspot', 't', 'torvr', 'human', 'parainfluenza', 'h.', 'parainfluenza', 'h', 'pi2ht', 'bovine', 'enteric', 'b.', 'enteric', 'b', 'becn1', 'satsuma', 'dwarf', 's.', 'dwarf', 's', 'sdvs5', 'turkey', 'astrovirus', 't.', 'astrovirus', 't', 'tasv1', 'feline', 'coronavirus', 'f.', 'coronavirus', 'f', 'fipv', 'rotavirus', 'a', 'r.', 'a', 'r', 'rotsh', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpph2', 'human', 'metapneumovirus', 'h.', 'metapneumovirus', 'h', 'hmpvc', 'tomato', 'mosaic', 't.', 'mosaic', 't', 'toml', 'brome', 'mosaic', 'b.', 'mosaic', 'b', 'bmv', 'southern', 'bean', 's.', 'bean', 's', 'sbmva', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpms2', 'petunia', 'vein', 'p.', 'vein', 'p', 'pvcv1', 'mumps', 'virus', 'm.', 'virus', 'm', 'mumpm', 'human', 'respiratory', 'h.', 'respiratory', 'h', 'hrsvb', 'schizosaccharomyces', 'pombe', 's.', 'pombe', 's', 'fission', 'schpo', 'cucumber', 'mosaic', 'c.', 'mosaic', 'c', 'cmvfn', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpphs', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv1', 'potato', 'moptop', 'p.', 'moptop', 'p', 'pmtvs', 'mokola', 'virus', 'm.', 'virus', 'm', 'mokv', 'abutilon', 'mosaic', 'a.', 'mosaic', 'a', 'abmvw', 'cherry', 'rasp', 'c.', 'rasp', 'c', 'crlvp', 'australian', 'bat', 'a.', 'bat', 'a', 'ablvb', 'mastomys', 'natalensis', 'm.', 'natalensis', 'm', 'mnpva', 'sapporo', 'virus', 's.', 'virus', 's', 'svsap', 'walleye', 'dermal', 'w.', 'dermal', 'w', 'wdsv', 'rotavirus', 'a', 'r.', 'a', 'r', 'rots1', 'european', 'bat', 'e.', 'bat', 'e', 'eblv2', 'simian', 'foamy', 's.', 'foamy', 's', 'sfv3l', 'sunnhemp', 'mosaic', 's.', 'mosaic', 's', 'shmv', 'sugarcane', 'streak', 's.', 'streak', 's', 'ssvn', 'parainfluenza', 'virus', 'p.', 'virus', 'p', 'piv5', 'infectious', 'pancreatic', 'i.', 'pancreatic', 'i', 'ipnvj', 'avian', 'infectious', 'a.', 'infectious', 'a', 'ibdvu', 'blotched', 'snakehead', 'b.', 'snakehead', 'b', 'bsnv', 'reovirus', 'type', 'r.', 'type', 'r', 'reovl', 'human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h', 'hv2ro', 'bean', 'yellow', 'b.', 'yellow', 'b', 'beydv', 'spring', 'viremia', 's.', 'viremia', 's', 'svcv', 'turnip', 'yellows', 't.', 'yellows', 't', 'tyyvf', 'canary', 'circovirus', 'c.', 'circovirus', 'c', 'cacv', 'vesicular', 'stomatitis', 'v.', 'stomatitis', 'v', 'vsnjo', 'panicum', 'streak', 'p.', 'streak', 'p', 'pasvk', 'southern', 'cowpea', 's.', 'cowpea', 's', 'scpmv', 'hepatitis', 'delta', 'h.', 'delta', 'h', 'hdvp1', 'influenza', 'c', 'i.', 'c', 'i', 'incaa', 'cauliflower', 'mosaic', 'c.', 'mosaic', 'c', 'camvc', 'cryphonectria', 'hypovirus', 'c.', 'hypovirus', 'c', 'chpvu', 'aleutian', 'mink', 'a.', 'mink', 'a', 'advg', 'bk', 'polyomavirus', 'b.', 'polyomavirus', 'b', 'povbk', 'murine', 'polyomavirus', 'm.', 'polyomavirus', 'm', 'povma', 'rabies', 'virus', 'r.', 'virus', 'r', 'rabvp', 'measles', 'virus', 'm.', 'virus', 'm', 'measc', 'feline', 'foamy', 'f.', 'foamy', 'f', 'ffv', 'bunyavirus', 'la', 'b.', 'la', 'b', 'bunl8', 'hendra', 'virus', 'h.', 'virus', 'h', 'hendh', 'maize', 'streak', 'm.', 'streak', 'm', 'msvk', 'maize', 'streak', 'm.', 'streak', 'm', 'msvse', 'european', 'bat', 'e.', 'bat', 'e', 'eblv1', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv18', 'squash', 'leaf', 's.', 'leaf', 's', 'slcv', 'parana', 'mammarenavirus', 'p.', 'mammarenavirus', 'p', 'parvp', 'pirital', 'mammarenavirus', 'p.', 'mammarenavirus', 'p', 'pirvv', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv11', 'rosavirus', 'a2', 'r.', 'a2', 'r', 'rosv2', 'passerivirus', 'a1', 'p.', 'a1', 'p', 'pasva', 'oscivirus', 'a1', 'o.', 'a1', 'o', 'oscv1', 'megrivirus', 'a', 'm.', 'a', 'm', 'megr1', 'avisivirus', 'a', 'a.', 'a', 'a', 'avisv', 'sicinivirus', 'a', 's.', 'a', 's', 'siva1', 'wu', 'polyomavirus', 'w.', 'polyomavirus', 'w', 'povwu', 'influenza', 'a', 'i.', 'a', 'i', 'i96a0', 'squirrel', 'monkey', 's.', 'monkey', 's', 'povsm', 'murine', 'coronavirus', 'm.', 'coronavirus', 'm', 'cvm2', 'primate', 'bocaparvovirus', 'p.', 'bocaparvovirus', 'p', 'hboc1', 'human', 'coronavirus', 'h.', 'coronavirus', 'h', 'cvhk1', 'rift', 'valley', 'r.', 'valley', 'r', 'rvfv', 'rubella', 'virus', 'r.', 'virus', 'r', 'rubv', 'influenza', 'a', 'i.', 'a', 'i', 'i88a4', 'hazara', 'virus', 'h.', 'virus', 'h', 'hazvj', 'tamiami', 'mammarenavirus', 't.', 'mammarenavirus', 't', 'tamvu', 'porcine', 'circovirus', 'p.', 'circovirus', 'p', 'pcv1', 'bovine', 'papillomavirus', 'b.', 'papillomavirus', 'b', 'bpv5', 'pichinde', 'mammarenavirus', 'p.', 'mammarenavirus', 'p', 'piarv', 'caprine', 'arthritis', 'c.', 'arthritis', 'c', 'caevc', 'chloris', 'striate', 'c.', 'striate', 'c', 'csmv', 'feline', 'immunodeficiency', 'f.', 'immunodeficiency', 'f', 'fivpe', 'saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's', 'scvm1', 'tobacco', 'mosaic', 't.', 'mosaic', 't', 'tmvom', 'tobacco', 'mild', 't.', 'mild', 't', 'tmgmv', 'vaccinia', 'virus', 'v.', 'virus', 'v', 'vaccw', 'giardia', 'lamblia', 'g.', 'lamblia', 'g', 'glvwb', 'saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's', 'scvla', 'alfalfa', 'mosaic', 'a.', 'mosaic', 'a', 'amvle', 'salmonella', 'phage', 's.', 'phage', 's', 'bpike', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpi22', 'indian', 'citrus', 'i.', 'citrus', 'i', 'icrsv', 'sclerotinia', 'sclerotiorum', 's.', 'sclerotiorum', 's', 'ssdrv', 'apple', 'chlorotic', 'a.', 'chlorotic', 'a', 'aclsa', 'botrytis', 'virus', 'b.', 'virus', 'b', 'botvf', 'maize', 'rayado', 'm.', 'rayado', 'm', 'mrfvc', 'heterosigma', 'akashiwo', 'h.', 'akashiwo', 'h', 'harna', 'duck', 'hepatitis', 'd.', 'hepatitis', 'd', 'dhav', 'porcine', 'teschovirus', 'p.', 'teschovirus', 'p', 'ptv1f', 'pelargonium', 'zonate', 'p.', 'zonate', 'p', 'pzsvt', 'pygmy', 'chimpanzee', 'p.', 'chimpanzee', 'p', 'pcpv1', 'porcine', 'circovirus', 'p.', 'circovirus', 'p', 'pcv2', 'papaya', 'mosaic', 'p.', 'mosaic', 'p', 'pmv', 'moranella', 'endobia', 'm.', 'endobia', 'm', 'morep', 'pea', 'enation', 'p.', 'enation', 'p', 'pemvw', 'candida', 'albicans', 'c.', 'albicans', 'c', 'canal', 'wigglesworthia', 'glossinidia', 'w.', 'glossinidia', 'w', 'wigbr', 'haemophilus', 'influenzae', 'h.', 'influenzae', 'h', 'haein', 'saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's', 'shv21', 'buchnera', 'aphidicola', 'b.', 'aphidicola', 'b', 'bucbp', 'african', 'swine', 'a.', 'swine', 'a', 'asfb7', 'buchnera', 'aphidicola', 'b.', 'aphidicola', 'b', 'buccc', 'potato', 'virus', 'p.', 'virus', 'p', 'pvmr', 'apple', 'stem', 'a.', 'stem', 'a', 'aspvp', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpsp', 'mycoplasma', 'genitalium', 'm.', 'genitalium', 'm', 'mycge', 'tomato', 'torrado', 't.', 'torrado', 't', 'totv', 'nudaurelia', 'capensis', 'n.', 'capensis', 'n', 'ncbvs', 'measles', 'virus', 'm.', 'virus', 'm', 'mease', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpt7', 'human', 'cytomegalovirus', 'h.', 'cytomegalovirus', 'h', 'hcmvm', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv8p', 'lettuce', 'infectious', 'l.', 'infectious', 'l', 'liyv9', 'beet', 'necrotic', 'b.', 'necrotic', 'b', 'bnyvs', 'saccharomyces', '2s', 's.', '2s', 's', 'scv20', 'cryphonectria', 'parasitica', 'c.', 'parasitica', 'c', 'cpmv1', 'equine', 'herpesvirus', 'e.', 'herpesvirus', 'e', 'ehv1b', 'cocksfoot', 'mottle', 'c.', 'mottle', 'c', 'cfmvn', 'branchiostoma', 'floridae', 'b.', 'floridae', 'b', 'brafl', 'mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm', 'myctu', 'shallot', 'virus', 's.', 'virus', 's', 'shvx', 'tomato', 'bushy', 't.', 'bushy', 't', 'tbsvc', 'peanut', 'clump', 'p.', 'clump', 'p', 'pcv87', 'tobacco', 'rattle', 't.', 'rattle', 't', 'trvpp', 'poinsettia', 'latent', 'p.', 'latent', 'p', 'pnlv', 'aquareovirus', 'g', 'a.', 'g', 'a', 'aqrvg', 'escherichia', 'phage', 'e.', 'phage', 'e', 'lambd', 'buchnera', 'aphidicola', 'b.', 'aphidicola', 'b', 'bucai', 'qbeta', 'virus', 'q.', 'virus', 'q', 'bpmx1', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpif1', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpfd', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv2h', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpm13', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpphk', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpal3', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpprd', 'rice', 'dwarf', 'r.', 'dwarf', 'r', 'rdvf', 'rice', 'tungro', 'r.', 'tungro', 'r', 'rtbvp', 'pepper', 'huasteco', 'p.', 'huasteco', 'p', 'phuv', 'tomato', 'yellow', 't.', 'yellow', 't', 'tycsv', 'rice', 'yellow', 'r.', 'yellow', 'r', 'rysv', 'sonchus', 'yellow', 's.', 'yellow', 's', 'synv', 'banana', 'bunchy', 'b.', 'bunchy', 'b', 'bbtva', 'baumannia', 'cicadellinicola', 'b.', 'cicadellinicola', 'b', 'bauch', 'avian', 'metapneumovirus', 'a.', 'metapneumovirus', 'a', 'ampv1', 'cauliflower', 'mosaic', 'c.', 'mosaic', 'c', 'camvs', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpfr', 'varicellazoster', 'virus', 'v.', 'virus', 'v', 'vzvd', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpph6', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpmu', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv41', 'maize', 'streak', 'm.', 'streak', 'm', 'msvs', 'beet', 'curly', 'b.', 'curly', 'b', 'bctvc', 'subterranean', 'clover', 's.', 'clover', 's', 'scsvf', 'bean', 'golden', 'b.', 'golden', 'b', 'bgymv', 'european', 'mountain', 'e.', 'mountain', 'e', 'emarv', 'rice', 'stripe', 'r.', 'stripe', 'r', 'rsvt', 'hepatitis', 'e', 'h.', 'e', 'h', 'hevch', 'carnation', 'mottle', 'c.', 'mottle', 'c', 'carms', 'helicoverpa', 'armigera', 'h.', 'armigera', 'h', 'hasv', 'barley', 'yellow', 'b.', 'yellow', 'b', 'bydvp', 'psittacid', 'herpesvirus', 'p.', 'herpesvirus', 'p', 'pshv1', 'citrus', 'leaf', 'c.', 'leaf', 'c', 'clbvs', 'murine', 'minute', 'm.', 'minute', 'm', 'mumip', 'bovine', 'parvovirus', 'b.', 'parvovirus', 'b', 'pavbp', 'apple', 'chlorotic', 'a.', 'chlorotic', 'a', 'aclsp', 'tomato', 'pseudocurly', 't.', 'pseudocurly', 't', 'tpctv', 'rotavirus', 'a', 'r.', 'a', 'r', 'rotrf', 'indian', 'cassava', 'i.', 'cassava', 'i', 'icmv', 'infectious', 'hematopoietic', 'i.', 'hematopoietic', 'i', 'ihnvw', 'snakehead', 'rhabdovirus', 's.', 'rhabdovirus', 's', 'shrv', 'strawberry', 'mild', 's.', 'mild', 's', 'smyea', 'human', 'picobirnavirus', 'h.', 'picobirnavirus', 'h', 'hpbvh', 'sendai', 'virus', 's.', 'virus', 's', 'sendo', 'tomato', 'aspermy', 't.', 'aspermy', 't', 'tav', 'turnip', 'crinkle', 't.', 'crinkle', 't', 'tcv', 'chicken', 'anemia', 'c.', 'anemia', 'c', 'cavc1', 'taro', 'vein', 't.', 'vein', 't', 'tavcv', 'tomato', 'yellow', 't.', 'yellow', 't', 'tylci', 'xanthomonas', 'phage', 'x.', 'phage', 'x', 'bpphl', 'white', 'clover', 'w.', 'clover', 'w', 'wcmvm', 'wheat', 'dwarf', 'w.', 'dwarf', 'w', 'wdvs', 'epsteinbarr', 'virus', 'e.', 'virus', 'e', 'ebva8', 'vesicular', 'exanthema', 'v.', 'exanthema', 'v', 'vesva', 'bluetongue', 'virus', 'b.', 'virus', 'b', 'btv10', 'rotavirus', 'x', 'r.', 'x', 'r', 'rotj1', 'rotavirus', 'c', 'r.', 'c', 'r', 'rothc', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv56', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv57', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv5b', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv61', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv63', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv66', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv69', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv35', 'maize', 'streak', 'm.', 'streak', 'm', 'msvpa', 'maize', 'streak', 'm.', 'streak', 'm', 'msvra', 'mungbean', 'yellow', 'm.', 'yellow', 'm', 'mymvv', 'blochmannia', 'pennsylvanicus', 'b.', 'pennsylvanicus', 'b', 'blopb', 'tobacco', 'streak', 't.', 'streak', 't', 'tobsv', 'macaca', 'mulata', 'm.', 'mulata', 'm', 'mmpv1', 'rotavirus', 'c', 'r.', 'c', 'r', 'rotpc', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv11', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv15', 'milk', 'vetch', 'm.', 'vetch', 'm', 'mdv1', 'tomato', 'leaf', 't.', 'leaf', 't', 'tlcva', 'tomato', 'yellow', 't.', 'yellow', 't', 'tylcc', 'autographa', 'californica', 'a.', 'californica', 'a', 'npvac', 'junonia', 'coenia', 'j.', 'coenia', 'j', 'jdnvp', 'chicken', 'anemia', 'c.', 'anemia', 'c', 'cavci', 'cowpea', 'chlorotic', 'c.', 'chlorotic', 'c', 'ccmv', 'carnation', 'etched', 'c.', 'etched', 'c', 'cerv', 'cucumber', 'green', 'c.', 'green', 'c', 'cgmvs', 'chandipura', 'virus', 'c.', 'virus', 'c', 'chav', 'african', 'cassava', 'a.', 'cassava', 'a', 'clvn', 'cucumber', 'mosaic', 'c.', 'mosaic', 'c', 'cmvq', 'aedes', 'albopictus', 'a.', 'albopictus', 'a', 'aadnv', 'bovine', 'polyomavirus', 'b.', 'polyomavirus', 'b', 'povbo', 'hamster', 'polyomavirus', 'h.', 'polyomavirus', 'h', 'povha', 'influenza', 'a', 'i.', 'a', 'i', 'i97a1', 'lettuce', 'necrotic', 'l.', 'necrotic', 'l', 'lnyv3', 'maize', 'mosaic', 'm.', 'mosaic', 'm', 'mmvr', 'youcai', 'mosaic', 'y.', 'mosaic', 'y', 'yomv', 'potato', 'virus', 'p.', 'virus', 'p', 'pvxcp', 'foxtail', 'mosaic', 'f.', 'mosaic', 'f', 'fxmv', 'red', 'clover', 'r.', 'clover', 'r', 'rcnmv', 'rinderpest', 'virus', 'r.', 'virus', 'r', 'rindr', 'faba', 'bean', 'f.', 'bean', 'f', 'fbny1', 'potato', 'virus', 'p.', 'virus', 'p', 'pvxx3', 'lolium', 'latent', 'l.', 'latent', 'l', 'lolv', 'bean', 'golden', 'b.', 'golden', 'b', 'bgymj', 'infectious', 'salmon', 'i.', 'salmon', 'i', 'isav8', 'murid', 'herpesvirus', 'm.', 'herpesvirus', 'm', 'muhvs', 'cottontail', 'rabbit', 'c.', 'rabbit', 'c', 'crpvk', 'canine', 'oral', 'c.', 'oral', 'c', 'copv6', 'phocoena', 'spinipinnis', 'p.', 'spinipinnis', 'p', 'pspvp', 'equus', 'caballus', 'e.', 'caballus', 'e', 'ecpvo', 'narcissus', 'mosaic', 'n.', 'mosaic', 'n', 'nmv', 'miscanthus', 'streak', 'm.', 'streak', 'm', 'misv9', 'thogoto', 'virus', 't.', 'virus', 't', 'thogv', 'human', 'cytomegalovirus', 'h.', 'cytomegalovirus', 'h', 'hcmva', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpt4', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppf3', 'duck', 'hepatitis', 'd.', 'hepatitis', 'd', 'dhbvq', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv09', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv13', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv14', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv22', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv23', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv29', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv31', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv40', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv42', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv53', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv30', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv28', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv21', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv38', 'plantago', 'asiatica', 'p.', 'asiatica', 'p', 'p1amv', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv05', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv04', 'soilborne', 'wheat', 's.', 'wheat', 's', 'sbwmn', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv6u', 'pasivirus', 'a1', 'p.', 'a1', 'p', 'pasi1', 'mosavirus', 'a2', 'm.', 'a2', 'm', 'mova2', 'mischivirus', 'a', 'm.', 'a', 'm', 'misv1', 'hunnivirus', 'a', 'h.', 'a', 'h', 'hunvo', 'gallivirus', 'a', 'g.', 'a', 'g', 'galiv', 'aquamavirus', 'a', 'a.', 'a', 'a', 'aquav', 'drosophila', 'melanogaster', 'd.', 'melanogaster', 'd', 'dmsva', 'tibrogargan', 'virus', 't.', 'virus', 't', 'tibvc', 'tupaia', 'virus', 't.', 'virus', 't', 'tupvt', 'buchnera', 'aphidicola', 'b.', 'aphidicola', 'b', 'bucsc', 'west', 'caucasian', 'w.', 'caucasian', 'w', 'wcbv', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade17', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv62', 'influenza', 'a', 'i.', 'a', 'i', 'i83a6', 'avian', 'infectious', 'a.', 'infectious', 'a', 'ibdv', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv32', 'simian', 'virus', 's.', 'virus', 's', 'sv41', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv54', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv48', 'human', 'respiratory', 'h.', 'respiratory', 'h', 'hrss2', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv43', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv60', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv59', 'influenza', 'b', 'i.', 'b', 'i', 'inbyb', 'murine', 'pneumonia', 'm.', 'pneumonia', 'm', 'mpv15', 'budgerigar', 'fledgling', 'b.', 'fledgling', 'b', 'bfpyv', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv52', 'alethinophid', '1', 'a.', '1', 'a', 'gogv', 'tupaia', 'paramyxovirus', 't.', 'paramyxovirus', 't', 'tpmv', 'snake', 'adenovirus', 's.', 'adenovirus', 's', 'ades1', 'influenza', 'a', 'i.', 'a', 'i', 'i09a8', 'influenza', 'c', 'i.', 'c', 'i', 'incjh', 'bos', 'taurus', 'b.', 'taurus', 'b', 'bpv6', 'simian', 'foamy', 's.', 'foamy', 's', 'sfv1', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv82', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv58', 'micromys', 'minutus', 'm.', 'minutus', 'm', 'mmpv', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv55', 'epsteinbarr', 'virus', 'e.', 'virus', 'e', 'ebvb9', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv34', 'rattus', 'norvegicus', 'r.', 'norvegicus', 'r', 'rnpv1', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv24', 'woolly', 'monkey', 'w.', 'monkey', 'w', 'wmhbv', 'nodamura', 'virus', 'n.', 'virus', 'n', 'nodam', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv50', 'middle', 'east', 'm.', 'east', 'm', 'mers', 'pigeon', 'circovirus', 'p.', 'circovirus', 'p', 'picv', 'adenoassociated', 'virus', 'a.', 'virus', 'a', 'aav2s', 'pestedespetitsruminants', 'virus', 'p.', 'virus', 'p', 'pprv', 'bovine', 'papillomavirus', 'b.', 'papillomavirus', 'b', 'bpv3', 'goose', 'circovirus', 'g.', 'circovirus', 'g', 'gocv', 'impatiens', 'necrotic', 'i.', 'necrotic', 'i', 'insv', 'melon', 'necrotic', 'm.', 'necrotic', 'm', 'mnsv', 'bhanja', 'virus', 'b.', 'virus', 'b', 'bhav', 'isfahan', 'virus', 'i.', 'virus', 'i', 'isfv', 'saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's', 'scvlb', 'satellite', 'tobacco', 's.', 'tobacco', 's', 'stnv1', 'punta', 'toro', 'p.', 'toro', 'p', 'ptpv', 'bunyavirus', 'la', 'b.', 'la', 'b', 'bunlc', 'ipomoea', 'nil', 'i.', 'nil', 'i', 'iponi', 'human', 'papillomavirus', 'h.', 'papillomavirus', 'h', 'hpv73', 'jembrana', 'disease', 'j.', 'disease', 'j', 'jembr', 'monkeypox', 'virus', 'm.', 'virus', 'm', 'monpv', 'phaseolus', 'vulgaris', 'p.', 'vulgaris', 'p', 'phavu', 'polynucleobacter', 'asymbioticus', 'p.', 'asymbioticus', 'p', 'polaq', 'stutzerimonas', 'stutzeri', 's.', 'stutzeri', 's', 'stus1', 'salinispora', 'tropica', 's.', 'tropica', 's', 'salto', 'hahella', 'chejuensis', 'h.', 'chejuensis', 'h', 'hahch', 'chromohalobacter', 'salexigens', 'c.', 'salexigens', 'c', 'chrsd', 'metallosphaera', 'sedula', 'm.', 'sedula', 'm', 'mets5', 'acidiphilium', 'cryptum', 'a.', 'cryptum', 'a', 'acicj', 'vesicomyosocius', 'okutanii', 'v.', 'okutanii', 'v', 'vesoh', 'dichelobacter', 'nodosus', 'd.', 'nodosus', 'd', 'dicnv', 'staphylothermus', 'marinus', 's.', 'marinus', 's', 'stamf', 'cronobacter', 'sakazakii', 'c.', 'sakazakii', 'c', 'cros8', 'ignicoccus', 'hospitalis', 'i.', 'hospitalis', 'i', 'ignh4', 'vanderwaltozyma', 'polyspora', 'v.', 'polyspora', 'v', 'vanpo', 'acaryochloris', 'marina', 'a.', 'marina', 'a', 'acam1', 'alkaliphilus', 'oremlandii', 'a.', 'oremlandii', 'a', 'alkoo', 'azorhizobium', 'caulinodans', 'a.', 'caulinodans', 'a', 'azoc5', 'thermosediminibacter', 'oceani', 't.', 'oceani', 't', 'theoj', 'corynebacterium', 'pseudotuberculosis', 'c.', 'pseudotuberculosis', 'c', 'corp2', 'drosophila', 'simulans', 'd.', 'simulans', 'd', 'drosi', 'daphnia', 'pulex', 'd.', 'pulex', 'd', 'dappu', 'pseudopedobacter', 'saltans', 'p.', 'saltans', 'p', 'psesl', 'camponotus', 'floridanus', 'c.', 'floridanus', 'c', 'camfo', 'komagataella', 'phaffii', 'k.', 'phaffii', 'k', 'kompg', 'aurantimonas', 'manganoxydans', 'a.', 'manganoxydans', 'a', 'aurms', 'sanguibacter', 'keddieii', 's.', 'keddieii', 's', 'sanks', 'thermobaculum', 'terrenum', 't.', 'terrenum', 't', 'thet1', 'herbaspirillum', 'seropedicae', 'h.', 'seropedicae', 'h', 'herss', 'brachyspira', 'pilosicoli', 'b.', 'pilosicoli', 'b', 'brap9', 'olsenella', 'uli', 'o.', 'uli', 'o', 'olsuv', 'granulicella', 'tundricola', 'g.', 'tundricola', 'g', 'gratm', 'acidilobus', 'saccharovorans', 'a.', 'saccharovorans', 'a', 'acis3', 'rice', 'ragged', 'r.', 'ragged', 'r', 'rrsvt', 'micromonas', 'pusilla', 'm.', 'pusilla', 'm', 'mprvn', 'helminthosporium', 'victoriae', 'h.', 'victoriae', 'h', 'hv19s', 'paracoccus', 'denitrificans', 'p.', 'denitrificans', 'p', 'pardp', 'methylibium', 'petroleiphilum', 'm.', 'petroleiphilum', 'm', 'metpp', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bp186', 'lachnoclostridium', 'phytofermentans', 'l.', 'phytofermentans', 'l', 'lacp7', 'verminephrobacter', 'eiseniae', 'v.', 'eiseniae', 'v', 'verei', 'arcanobacterium', 'haemolyticum', 'a.', 'haemolyticum', 'a', 'archd', 'streptomyces', 'bingchenggensis', 's.', 'bingchenggensis', 's', 'strbb', 'syntrophothermus', 'lipocalidus', 's.', 'lipocalidus', 's', 'synlt', 'truepera', 'radiovictrix', 't.', 'radiovictrix', 't', 'trurr', 'methylotenera', 'versatilis', 'm.', 'versatilis', 'm', 'metv0', 'methanohalobium', 'evestigatum', 'm.', 'evestigatum', 'm', 'metez', 'grapevine', 'fleck', 'g.', 'fleck', 'g', 'gfkvm', 'gillassociated', 'virus', 'g.', 'virus', 'g', 'gavau', 'olive', 'latent', 'o.', 'latent', 'o', 'olv2i', 'striped', 'jack', 's.', 'jack', 's', 'sjnnv', 'symbiobacterium', 'thermophilum', 's.', 'thermophilum', 's', 'symth', 'wolinella', 'succinogenes', 'w.', 'succinogenes', 'w', 'wolsu', 'ureaplasma', 'parvum', 'u.', 'parvum', 'u', 'urepa', 'neisseria', 'meningitidis', 'n.', 'meningitidis', 'n', 'neimb', 'streptomyces', 'avermitilis', 's.', 'avermitilis', 's', 'straw', 'helicobacter', 'pylori', 'h.', 'pylori', 'h', 'helpy', 'acinetobacter', 'baylyi', 'a.', 'baylyi', 'a', 'aciad', 'chlamydia', 'trachomatis', 'c.', 'trachomatis', 'c', 'chltr', 'lactiplantibacillus', 'plantarum', 'l.', 'plantarum', 'l', 'lacpl', 'picrophilus', 'torridus', 'p.', 'torridus', 'p', 'picto', 'bifidobacterium', 'longum', 'b.', 'longum', 'b', 'biflo', 'thermosynechococcus', 'vestitus', 't.', 'vestitus', 't', 'thevb', 'desulforapulum', 'autotrophicum', 'd.', 'autotrophicum', 'd', 'desah', 'streptococcus', 'uberis', 's.', 'uberis', 's', 'stru0', 'simiduia', 'agarivorans', 's.', 'agarivorans', 's', 'simas', 'thermacetogenium', 'phaeum', 't.', 'phaeum', 't', 'theps', 'desulfobacca', 'acetoxidans', 'd.', 'acetoxidans', 'd', 'desar', 'cellulomonas', 'gilvus', 'c.', 'gilvus', 'c', 'celga', 'corynebacterium', 'resistens', 'c.', 'resistens', 'c', 'corrg', 'runella', 'slithyformis', 'r.', 'slithyformis', 'r', 'runsl', 'hyphomicrobium', 'sp', 'h.', 'sp', 'h', 'hypsm', 'parachlamydia', 'acanthamoebae', 'p.', 'acanthamoebae', 'p', 'parav', 'simkania', 'negevensis', 's.', 'negevensis', 's', 'simnz', 'gracilinema', 'caldarium', 'g.', 'caldarium', 'g', 'grac1', 'acidianus', 'bottleshaped', 'a.', 'bottleshaped', 'a', 'abvp', 'acidianus', 'filamentous', 'a.', 'filamentous', 'a', 'afv1y', 'lymphocystis', 'disease', 'l.', 'disease', 'l', 'lcdv1', 'mycoplasmopsis', 'pulmonis', 'm.', 'pulmonis', 'm', 'mycpu', 'protochlamydia', 'amoebophila', 'p.', 'amoebophila', 'p', 'paruw', 'staphylococcus', 'epidermidis', 's.', 'epidermidis', 's', 'staeq', 'thermus', 'thermophilus', 't.', 'thermophilus', 't', 'thet8', 'neisseria', 'gonorrhoeae', 'n.', 'gonorrhoeae', 'n', 'neig1', 'thermococcus', 'kodakarensis', 't.', 'kodakarensis', 't', 'theko', 'aliivibrio', 'fischeri', 'a.', 'fischeri', 'a', 'alif1', 'gallus', 'gallus', 'g.', 'gallus', 'g', 'chick', 'leishmania', 'major', 'l.', 'major', 'l', 'leima', 'staphylococcus', 'haemolyticus', 's.', 'haemolyticus', 's', 'stahj', 'corynebacterium', 'jeikeium', 'c.', 'jeikeium', 'c', 'corjk', 'psychrobacter', 'arcticus', 'p.', 'arcticus', 'p', 'psya2', 'mycoplasmopsis', 'synoviae', 'm.', 'synoviae', 'm', 'mycs5', 'halobacterium', 'salinarum', 'h.', 'salinarum', 'h', 'halsa', 'caldanaerobacter', 'subterraneus', 'c.', 'subterraneus', 'c', 'cals4', 'pseudomonas', 'putida', 'p.', 'putida', 'p', 'psepk', 'gloeobacter', 'violaceus', 'g.', 'violaceus', 'g', 'glovi', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco57', 'emericella', 'nidulans', 'e.', 'nidulans', 'e', 'emeni', 'ustilago', 'maydis', 'u.', 'maydis', 'u', 'ustma', 'parabacteroides', 'distasonis', 'p.', 'distasonis', 'p', 'pard8', 'pothos', 'latent', 'p.', 'latent', 'p', 'polvp', 'oat', 'chlorotic', 'o.', 'chlorotic', 'o', 'ocsvu', 'carnation', 'ringspot', 'c.', 'ringspot', 'c', 'crsvl', 'tobacco', 'necrosis', 't.', 'necrosis', 't', 'tnva', 'geobacter', 'sulfurreducens', 'g.', 'sulfurreducens', 'g', 'geosl', 'nanoarchaeum', 'equitans', 'n.', 'equitans', 'n', 'naneq', 'mycolicibacterium', 'paratuberculosis', 'm.', 'paratuberculosis', 'm', 'mycpa', 'lactobacillus', 'johnsonii', 'l.', 'johnsonii', 'l', 'lacjo', 'corynebacterium', 'glutamicum', 'c.', 'glutamicum', 'c', 'corgl', 'vibrio', 'cholerae', 'v.', 'cholerae', 'v', 'vibch', 'streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's', 'strpn', 'streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's', 'strr6', 'porphyromonas', 'gingivalis', 'p.', 'gingivalis', 'p', 'porgi', 'methanococcus', 'maripaludis', 'm.', 'maripaludis', 'm', 'metmp', 'ashbya', 'gossypii', 'a.', 'gossypii', 'a', 'ashgo', 'photobacterium', 'profundum', 'p.', 'profundum', 'p', 'phopr', 'bacillus', 'anthracis', 'b.', 'anthracis', 'b', 'bacan', 'kluyveromyces', 'lactis', 'k.', 'lactis', 'k', 'klula', 'debaryomyces', 'hansenii', 'd.', 'hansenii', 'd', 'debha', 'desulfotalea', 'psychrophila', 'd.', 'psychrophila', 'd', 'desps', 'burkholderia', 'pseudomallei', 'b.', 'pseudomallei', 'b', 'burps', 'bacillus', 'licheniformis', 'b.', 'licheniformis', 'b', 'bacld', 'legionella', 'pneumophila', 'l.', 'pneumophila', 'l', 'legph', 'jonesia', 'denitrificans', 'j.', 'denitrificans', 'j', 'jondd', 'ruegeria', 'sp', 'r.', 'sp', 'r', 'ruest', 'psychromonas', 'ingrahamii', 'p.', 'ingrahamii', 'p', 'psyin', 'nocardioides', 'sp', 'n.', 'sp', 'n', 'nocsj', 'thermofilum', 'pendens', 't.', 'pendens', 't', 'thepd', 'bartonella', 'bacilliformis', 'b.', 'bacilliformis', 'b', 'barbk', 'polaromonas', 'naphthalenivorans', 'p.', 'naphthalenivorans', 'p', 'polna', 'halorhodospira', 'halophila', 'h.', 'halophila', 'h', 'halhl', 'frankia', 'alni', 'f.', 'alni', 'f', 'fraaa', 'methanocella', 'arvoryzae', 'm.', 'arvoryzae', 'm', 'metar', 'anopheles', 'darlingi', 'a.', 'darlingi', 'a', 'anoda', 'methanothrix', 'thermoacetophila', 'm.', 'thermoacetophila', 'm', 'mettp', 'grapevine', 'virus', 'g.', 'virus', 'g', 'gvais', 'infectious', 'flacherie', 'i.', 'flacherie', 'i', 'ifvs', 'shewanella', 'frigidimarina', 's.', 'frigidimarina', 's', 'shefn', 'pseudomonas', 'fulva', 'p.', 'fulva', 'p', 'psef1', 'naumovozyma', 'dairenensis', 'n.', 'dairenensis', 'n', 'naudc', 'ketogulonicigenium', 'vulgare', 'k.', 'vulgare', 'k', 'ketvw', 'candida', 'tenuis', 'c.', 'tenuis', 'c', 'cantc', 'spathaspora', 'passalidarum', 's.', 'passalidarum', 's', 'spapn', 'mustela', 'putorius', 'm.', 'putorius', 'm', 'muspf', 'thermodesulfovibrio', 'yellowstonii', 't.', 'yellowstonii', 't', 'theyd', 'halothermothrix', 'orenii', 'h.', 'orenii', 'h', 'haloh', 'azobacteroides', 'pseudotrichonymphae', 'a.', 'pseudotrichonymphae', 'a', 'azopc', 'penicillium', 'rubens', 'p.', 'rubens', 'p', 'penrw', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bphk6', 'lyngbya', 'sp', 'l.', 'sp', 'l', 'lynsp', 'micrococcus', 'luteus', 'm.', 'luteus', 'm', 'miclc', 'desulfatibacillum', 'aliphaticivorans', 'd.', 'aliphaticivorans', 'd', 'desal', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpnf', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco55', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco45', 'streptococcus', 'pyogenes', 's.', 'pyogenes', 's', 'strp1', 'arthrobacter', 'sp', 'a.', 'sp', 'a', 'arts2', 'aeromonas', 'hydrophila', 'a.', 'hydrophila', 'a', 'aerhh', 'mycolicibacterium', 'smegmatis', 'm.', 'smegmatis', 'm', 'mycs2', 'cenarchaeum', 'symbiosum', 'c.', 'symbiosum', 'c', 'censy', 'phaeodactylum', 'tricornutum', 'p.', 'tricornutum', 'p', 'phatc', 'campylobacter', 'fetus', 'c.', 'fetus', 'c', 'camff', 'sorghum', 'bicolor', 's.', 'bicolor', 's', 'sorbi', 'acidimicrobium', 'ferrooxidans', 'a.', 'ferrooxidans', 'a', 'acifd', 'oenococcus', 'oeni', 'o.', 'oeni', 'o', 'oenob', 'delftia', 'acidovorans', 'd.', 'acidovorans', 'd', 'delas', 'prochlorococcus', 'marinus', 'p.', 'marinus', 'p', 'prom4', 'nitrosopumilus', 'maritimus', 'n.', 'maritimus', 'n', 'nitms', 'aquifex', 'aeolicus', 'a.', 'aeolicus', 'a', 'aquae', 'campylobacter', 'jejuni', 'c.', 'jejuni', 'c', 'camje', 'methanocaldococcus', 'jannaschii', 'm.', 'jannaschii', 'm', 'metja', 'mycobacterium', 'leprae', 'm.', 'leprae', 'm', 'mycle', 'mycoplasma', 'pneumoniae', 'm.', 'pneumoniae', 'm', 'mycpn', 'pasteurella', 'multocida', 'p.', 'multocida', 'p', 'pasmu', 'treponema', 'pallidum', 't.', 'pallidum', 't', 'trepa', 'agrobacterium', 'fabrum', 'a.', 'fabrum', 'a', 'agrfc', 'clostridium', 'acetobutylicum', 'c.', 'acetobutylicum', 'c', 'cloab', 'yersinia', 'pestis', 'y.', 'pestis', 'y', 'yerpe', 'listeria', 'monocytogenes', 'l.', 'monocytogenes', 'l', 'lismo', 'clostridium', 'perfringens', 'c.', 'perfringens', 'c', 'clope', 'encephalitozoon', 'cuniculi', 'e.', 'cuniculi', 'e', 'enccu', 'streptococcus', 'agalactiae', 's.', 'agalactiae', 's', 'stra5', 'oceanobacillus', 'iheyensis', 'o.', 'iheyensis', 'o', 'oceih', 'banna', 'virus', 'b.', 'virus', 'b', 'bavjk', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bplsk', 'saccharomonospora', 'viridis', 's.', 'viridis', 's', 'sacvd', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpkmv', 'stackebrandtia', 'nassauensis', 's.', 'nassauensis', 's', 'stanl', 'sebaldella', 'termitidis', 's.', 'termitidis', 's', 'sebte', 'cellulomonas', 'flavigena', 'c.', 'flavigena', 'c', 'celfn', 'catenulispora', 'acidiphila', 'c.', 'acidiphila', 'c', 'catad', 'pedobacter', 'heparinus', 'p.', 'heparinus', 'p', 'pedhd', 'acyrthosiphon', 'pisum', 'a.', 'pisum', 'a', 'bpaps', 'sulfolobus', 'spindleshape', 's.', 'spindleshape', 's', 'ssv1', 'deerpox', 'virus', 'd.', 'virus', 'd', 'dpv83', 'myxoma', 'virus', 'm.', 'virus', 'm', 'myxvl', 'rabbit', 'fibroma', 'r.', 'fibroma', 'r', 'rfvka', 'molluscum', 'contagiosum', 'm.', 'contagiosum', 'm', 'mcv1', 'orf', 'virus', 'o.', 'virus', 'o', 'orfsa', 'swinepox', 'virus', 's.', 'virus', 's', 'swpv1', 'coraliomargarita', 'akajimensis', 'c.', 'akajimensis', 'c', 'corad', 'prevotella', 'ruminicola', 'p.', 'ruminicola', 'p', 'prer2', 'moraxella', 'catarrhalis', 'm.', 'catarrhalis', 'm', 'morcb', 'priestia', 'megaterium', 'p.', 'megaterium', 'p', 'prim1', 'propionibacterium', 'freudenreichii', 'p.', 'freudenreichii', 'p', 'profc', 'arcobacter', 'nitrofigilis', 'a.', 'nitrofigilis', 'a', 'arcnc', 'alcelaphine', 'herpesvirus', 'a.', 'herpesvirus', 'a', 'alhv1', 'cryptobacterium', 'curtum', 'c.', 'curtum', 'c', 'crycd', 'lancefieldella', 'parvula', 'l.', 'parvula', 'l', 'lanp1', 'shigella', 'flexneri', 's.', 'flexneri', 's', 'shifl', 'chlorobaculum', 'tepidum', 'c.', 'tepidum', 'c', 'chlte', 'xanthomonas', 'campestris', 'x.', 'campestris', 'x', 'xancp', 'pyrococcus', 'furiosus', 'p.', 'furiosus', 'p', 'pyrfu', 'salmonella', 'typhimurium', 's.', 'typhimurium', 's', 'salty', 'sulfurisphaera', 'tokodaii', 's.', 'tokodaii', 's', 'sulto', 'mycoplasma', 'mycoides', 'm.', 'mycoides', 'm', 'mycms', 'sulfolobus', 'acidocaldarius', 's.', 'acidocaldarius', 's', 'sulac', 'mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm', 'mycto', 'haemophilus', 'ducreyi', 'h.', 'ducreyi', 'h', 'haedu', 'ruegeria', 'pomeroyi', 'r.', 'pomeroyi', 'r', 'ruepo', 'thermoplasma', 'acidophilum', 't.', 'acidophilum', 't', 'theac', 'rhodopirellula', 'baltica', 'r.', 'baltica', 'r', 'rhoba', 'elusimicrobium', 'minutum', 'e.', 'minutum', 'e', 'elump', 'shigella', 'boydii', 's.', 'boydii', 's', 'shib3', 'akkermansia', 'muciniphila', 'a.', 'muciniphila', 'a', 'akkm8', 'cellvibrio', 'japonicus', 'c.', 'japonicus', 'c', 'celju', 'pyrolobus', 'fumarii', 'p.', 'fumarii', 'p', 'pyrf1', 'oryzias', 'latipes', 'o.', 'latipes', 'o', 'oryla', 'desulfohalobium', 'retbaense', 'd.', 'retbaense', 'd', 'desrd', 'sinorhizobium', 'fredii', 's.', 'fredii', 's', 'sinfn', 'phaeosphaeria', 'nodorum', 'p.', 'nodorum', 'p', 'phano', 'chaetomium', 'globosum', 'c.', 'globosum', 'c', 'chagb', 'methanohalophilus', 'mahii', 'm.', 'mahii', 'm', 'metms', 'marinomonas', 'mediterranea', 'm.', 'mediterranea', 'm', 'marm1', 'dictyostelium', 'purpureum', 'd.', 'purpureum', 'd', 'dicpu', 'soybean', 'chlorotic', 's.', 'chlorotic', 's', 'socmv', 'pyrenophora', 'teres', 'p.', 'teres', 'p', 'pyrtt', 'desulfurococcus', 'mucosus', 'd.', 'mucosus', 'd', 'desm0', 'drosophila', 'grimshawi', 'd.', 'grimshawi', 'd', 'drogr', 'melampsora', 'laricipopulina', 'm.', 'laricipopulina', 'm', 'mellp', 'nomascus', 'leucogenys', 'n.', 'leucogenys', 'n', 'nomle', 'myotis', 'lucifugus', 'm.', 'lucifugus', 'm', 'myolu', 'cricetulus', 'griseus', 'c.', 'griseus', 'c', 'crigr', 'citrus', 'leprosis', 'c.', 'leprosis', 'c', 'cilvc', 'raspberry', 'bushy', 'r.', 'bushy', 'r', 'rbdvr', 'ourmia', 'melon', 'o.', 'melon', 'o', 'oumvv', 'actinobacillus', 'succinogenes', 'a.', 'succinogenes', 'a', 'actsz', 'synechococcus', 'sp', 's.', 'sp', 's', 'synr3', 'kineococcus', 'radiotolerans', 'k.', 'radiotolerans', 'k', 'kinrd', 'nitratiruptor', 'sp', 'n.', 'sp', 'n', 'nitsb', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco24', 'escherichia', 'coli', 'e.', 'coli', 'e', 'ecohs', 'streptococcus', 'gordonii', 's.', 'gordonii', 's', 'strgc', 'acanthamoeba', 'polyphaga', 'a.', 'polyphaga', 'a', 'mimiv', 'aliarcobacter', 'butzleri', 'a.', 'butzleri', 'a', 'alib4', 'caldivirga', 'maquilingensis', 'c.', 'maquilingensis', 'c', 'calmq', 'alkalihalobacillus', 'clausii', 'a.', 'clausii', 'a', 'alkck', 'haloarcula', 'marismortui', 'h.', 'marismortui', 'h', 'halma', 'streptococcus', 'thermophilus', 's.', 'thermophilus', 's', 'strt2', 'idiomarina', 'loihiensis', 'i.', 'loihiensis', 'i', 'idilo', 'geobacillus', 'kaustophilus', 'g.', 'kaustophilus', 'g', 'geoka', 'zymomonas', 'mobilis', 'z.', 'mobilis', 'z', 'zymmo', 'francisella', 'tularensis', 'f.', 'tularensis', 'f', 'fratt', 'synechococcus', 'sp', 's.', 'sp', 's', 'synp6', 'gluconacetobacter', 'diazotrophicus', 'g.', 'diazotrophicus', 'g', 'gluda', 'mycobacterium', 'marinum', 'm.', 'marinum', 'm', 'mycmm', 'nostoc', 'punctiforme', 'n.', 'punctiforme', 'n', 'nosp7', 'paraburkholderia', 'phymatum', 'p.', 'phymatum', 'p', 'parp8', 'podospora', 'anserina', 'p.', 'anserina', 'p', 'podan', 'crocosphaera', 'subtropica', 'c.', 'subtropica', 'c', 'cros5', 'chloroherpeton', 'thalassium', 'c.', 'thalassium', 'c', 'chlt3', 'tsukamurella', 'paurometabola', 't.', 'paurometabola', 't', 'tsupd', 'gordonia', 'bronchialis', 'g.', 'bronchialis', 'g', 'gorb4', 'amoebophilus', 'asiaticus', 'a.', 'asiaticus', 'a', 'amoa5', 'kangiella', 'koreensis', 'k.', 'koreensis', 'k', 'kankd', 'gallionella', 'capsiferriformans', 'g.', 'capsiferriformans', 'g', 'galcs', 'spiroplasma', 'virus', 's.', 'virus', 's', 'spv1r', 'halalkalibacterium', 'halodurans', 'h.', 'halodurans', 'h', 'halh5', 'lactobacillus', 'delbrueckii', 'l.', 'delbrueckii', 'l', 'lacda', 'coccidioides', 'immitis', 'c.', 'immitis', 'c', 'cocim', 'pseudogulbenkiania', 'sp', 'p.', 'sp', 'p', 'pseul', 'sphingobium', 'sp', 's.', 'sp', 's', 'sphsk', 'ligilactobacillus', 'ruminis', 'l.', 'ruminis', 'l', 'ligr2', 'fructilactobacillus', 'sanfranciscensis', 'f.', 'sanfranciscensis', 'f', 'frust', 'drosophila', 'sechellia', 'd.', 'sechellia', 'd', 'drose', 'talaromyces', 'marneffei', 't.', 'marneffei', 't', 'talmq', 'torque', 'teno', 't.', 'teno', 't', 'ttvt1', 'butyrivibrio', 'proteoclasticus', 'b.', 'proteoclasticus', 'b', 'butpb', 'yarrowia', 'lipolytica', 'y.', 'lipolytica', 'y', 'yarli', 'parvularcula', 'bermudensis', 'p.', 'bermudensis', 'p', 'parbh', 'zinderia', 'insecticola', 'z.', 'insecticola', 'z', 'zinic', 'ignisphaera', 'aggregans', 'i.', 'aggregans', 'i', 'ignaa', 'leifsonia', 'xyli', 'l.', 'xyli', 'l', 'leixx', 'oikopleura', 'dioica', 'o.', 'dioica', 'o', 'oikdi', 'sclerotinia', 'sclerotiorum', 's.', 'sclerotiorum', 's', 'scls1', 'finegoldia', 'magna', 'f.', 'magna', 'f', 'finm2', 'ruminiclostridium', 'cellulolyticum', 'r.', 'cellulolyticum', 'r', 'rumch', 'monosiga', 'brevicollis', 'm.', 'brevicollis', 'm', 'monbe', 'invertebrate', 'iridescent', 'i.', 'iridescent', 'i', 'iiv3', 'acidithiobacillus', 'ferrooxidans', 'a.', 'ferrooxidans', 'a', 'acif2', 'caulobacter', 'vibrioides', 'c.', 'vibrioides', 'c', 'cauvn', 'persephonella', 'marina', 'p.', 'marina', 'p', 'permh', 'sulfurihydrogenibium', 'azorense', 's.', 'azorense', 's', 'sulaa', 'eggerthella', 'lenta', 'e.', 'lenta', 'e', 'eggle', 'geodermatophilus', 'obscurus', 'g.', 'obscurus', 'g', 'geoog', 'macrococcus', 'caseolyticus', 'm.', 'caseolyticus', 'm', 'maccj', 'heterostelium', 'pallidum', 'h.', 'pallidum', 'h', 'hetp5', 'streptomyces', 'sp', 's.', 'sp', 's', 'strek', 'rhodomicrobium', 'vannielii', 'r.', 'vannielii', 'r', 'rhovt', 'aciduliprofundum', 'boonei', 'a.', 'boonei', 'a', 'acib4', 'evansella', 'cellulosilytica', 'e.', 'cellulosilytica', 'e', 'evac2', 'atelocyanobacterium', 'thalassa', 'a.', 'thalassa', 'a', 'ateth', 'leptospira', 'interrogans', 'l.', 'interrogans', 'l', 'lepin', 'corynebacterium', 'efficiens', 'c.', 'efficiens', 'c', 'coref', 'escherichia', 'coli', 'e.', 'coli', 'e', 'ecol6', 'clostridium', 'tetani', 'c.', 'tetani', 'c', 'clote', 'bacteroides', 'thetaiotaomicron', 'b.', 'thetaiotaomicron', 'b', 'bactn', 'enterococcus', 'faecalis', 'e.', 'faecalis', 'e', 'entfa', 'nitrosomonas', 'europaea', 'n.', 'europaea', 'n', 'niteu', 'bacillus', 'cereus', 'b.', 'cereus', 'b', 'baccr', 'mycoplasmoides', 'gallisepticum', 'm.', 'gallisepticum', 'm', 'mycga', 'mycobacterium', 'bovis', 'm.', 'bovis', 'm', 'mycbo', 'prochlorococcus', 'marinus', 'p.', 'marinus', 'p', 'proma', 'parasynechococcus', 'marenigrum', 'p.', 'marenigrum', 'p', 'parmw', 'prochlorococcus', 'marinus', 'p.', 'marinus', 'p', 'promm', 'chromobacterium', 'violaceum', 'c.', 'violaceum', 'c', 'chrvo', 'synechocystis', 'sp', 's.', 'sp', 's', 'syny3', 'rhodopseudomonas', 'palustris', 'r.', 'palustris', 'r', 'rhopa', 'actinobacillus', 'pleuropneumoniae', 'a.', 'pleuropneumoniae', 'a', 'actp2', 'allochromatium', 'vinosum', 'a.', 'vinosum', 'a', 'allvd', 'streptomyces', 'scabiei', 's.', 'scabiei', 's', 'strsw', 'thalassiosira', 'pseudonana', 't.', 'pseudonana', 't', 'thaps', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'plaf7', 'streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's', 'strp2', 'cryptosporidium', 'muris', 'c.', 'muris', 'c', 'crymr', 'pyrenophora', 'triticirepentis', 'p.', 'triticirepentis', 'p', 'pyrtr', 'corynebacterium', 'kroppenstedtii', 'c.', 'kroppenstedtii', 'c', 'cork4', 'lachnospira', 'eligens', 'l.', 'eligens', 'l', 'lace2', 'mesomycoplasma', 'conjunctivae', 'm.', 'conjunctivae', 'm', 'mesch', 'waddlia', 'chondrophila', 'w.', 'chondrophila', 'w', 'wadcw', 'desulfurivibrio', 'alkaliphilus', 'd.', 'alkaliphilus', 'd', 'desat', 'nostoc', 'azollae', 'n.', 'azollae', 'n', 'nosa0', 'flavobacteriaceae', 'bacterium', 'f.', 'bacterium', 'f', 'flab3', 'selaginella', 'moellendorffii', 's.', 'moellendorffii', 's', 'selml', 'gorilla', 'gorilla', 'g.', 'gorilla', 'g', 'gorgo', 'deferribacter', 'desulfuricans', 'd.', 'desulfuricans', 'd', 'defds', 'helicobacter', 'mustelae', 'h.', 'mustelae', 'h', 'helm1', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpk1f', 'alkalihalophilus', 'pseudofirmus', 'a.', 'pseudofirmus', 'a', 'alkpo', 'giardia', 'intestinalis', 'g.', 'intestinalis', 'g', 'giaic', 'ethanoligenens', 'harbinense', 'e.', 'harbinense', 'e', 'ethhy', 'ixodes', 'scapularis', 'i.', 'scapularis', 'i', 'ixosc', 'desulforamulus', 'reducens', 'd.', 'reducens', 'd', 'desrm', 'shewanella', 'loihica', 's.', 'loihica', 's', 'shelp', 'clavibacter', 'michiganensis', 'c.', 'michiganensis', 'c', 'clam3', 'orientia', 'tsutsugamushi', 'o.', 'tsutsugamushi', 'o', 'oritb', 'synechococcus', 'sp', 's.', 'sp', 's', 'synpw', 'ostreococcus', 'lucimarinus', 'o.', 'lucimarinus', 'o', 'ostlu', 'alkaliphilus', 'metalliredigens', 'a.', 'metalliredigens', 'a', 'alkmq', 'acholeplasma', 'phage', 'a.', 'phage', 'a', 'bpl2', 'prochlorococcus', 'marinus', 'p.', 'marinus', 'p', 'prom5', 'rhodospirillum', 'centenum', 'r.', 'centenum', 'r', 'rhocs', 'nematostella', 'vectensis', 'n.', 'vectensis', 'n', 'nemve', 'fowl', 'adenovirus', 'f.', 'adenovirus', 'f', 'adeg1', 'pongo', 'abelii', 'p.', 'abelii', 'p', 'ponab', 'agrobacterium', 'vitis', 'a.', 'vitis', 'a', 'agrvs', 'leeuwenhoekiella', 'blandensis', 'l.', 'blandensis', 'l', 'leebm', 'maribacter', 'sp', 'm.', 'sp', 'm', 'marsh', 'cordyceps', 'militaris', 'c.', 'militaris', 'c', 'cormm', 'verticillium', 'dahliae', 'v.', 'dahliae', 'v', 'verdv', 'sideroxydans', 'lithotrophicus', 's.', 'lithotrophicus', 's', 'sidle', 'thermoanaerobacterium', 'thermosaccharolyticum', 't.', 'thermosaccharolyticum', 't', 'thetc', 'paracoccidioides', 'brasiliensis', 'p.', 'brasiliensis', 'p', 'parbd', 'ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a', 'ajecg', 'cyclobacterium', 'marinum', 'c.', 'marinum', 'c', 'cycms', 'arthromitus', 'sp', 'a.', 'sp', 'a', 'artss', 'naumovozyma', 'castellii', 'n.', 'castellii', 'n', 'naucc', 'meleagris', 'gallopavo', 'm.', 'gallopavo', 'm', 'melga', 'anolis', 'carolinensis', 'a.', 'carolinensis', 'a', 'anoca', 'lacticaseibacillus', 'paracasei', 'l.', 'paracasei', 'l', 'lacp3', 'levilactobacillus', 'brevis', 'l.', 'brevis', 'l', 'levba', 'acetohalobium', 'arabaticum', 'a.', 'arabaticum', 'a', 'aceaz', 'lacrimispora', 'saccharolytica', 'l.', 'saccharolytica', 'l', 'lacsw', 'botrytis', 'virus', 'b.', 'virus', 'b', 'botvx', 'panicum', 'mosaic', 'p.', 'mosaic', 'p', 'pmvk', 'white', 'clover', 'w.', 'clover', 'w', 'wccvb', 'atkinsonella', 'hypoxylon', 'a.', 'hypoxylon', 'a', 'ahv2h', 'colorado', 'tick', 'c.', 'tick', 'c', 'ctfvl', 'aedes', 'pseudoscutellaris', 'a.', 'pseudoscutellaris', 'a', 'aprvf', 'fiji', 'disease', 'f.', 'disease', 'f', 'fdvs', 'exiguobacterium', 'sibiricum', 'e.', 'sibiricum', 'e', 'exis2', 'natranaerobius', 'thermophilus', 'n.', 'thermophilus', 'n', 'nattj', 'korarchaeum', 'cryptofilum', 'k.', 'cryptofilum', 'k', 'korco', 'synechococcus', 'sp', 's.', 'sp', 's', 'synp2', 'leptothrix', 'cholodnii', 'l.', 'cholodnii', 'l', 'lepcp', 'beijerinckia', 'indica', 'b.', 'indica', 'b', 'beii9', 'pantoea', 'ananatis', 'p.', 'ananatis', 'p', 'panam', 'haemophilus', 'phage', 'h.', 'phage', 'h', 'bphc1', 'erwinia', 'tasmaniensis', 'e.', 'tasmaniensis', 'e', 'erwt9', 'corynebacterium', 'urealyticum', 'c.', 'urealyticum', 'c', 'coru7', 'coprothermobacter', 'proteolyticus', 'c.', 'proteolyticus', 'c', 'coppd', 'schizosaccharomyces', 'japonicus', 's.', 'japonicus', 's', 'schjy', 'talaromyces', 'stipitatus', 't.', 'stipitatus', 't', 'talsn', 'halomicrobium', 'mukohataei', 'h.', 'mukohataei', 'h', 'halmd', 'spiroplasma', 'virus', 's.', 'virus', 's', 'spv1c', 'syntrophobacter', 'fumaroxidans', 's.', 'fumaroxidans', 's', 'synfm', 'salmonella', 'phage', 's.', 'phage', 's', 'bpp22', 'botryotinia', 'fuckeliana', 'b.', 'fuckeliana', 'b', 'botfb', 'neurospora', 'crassa', 'n.', 'crassa', 'n', 'neucr', 'borreliella', 'burgdorferi', 'b.', 'burgdorferi', 'b', 'borbu', 'oryctolagus', 'cuniculus', 'o.', 'cuniculus', 'o', 'rabit', 'variola', 'virus', 'v.', 'virus', 'v', 'varv', 'caulobacter', 'vibrioides', 'c.', 'vibrioides', 'c', 'cauvc', 'paraburkholderia', 'xenovorans', 'p.', 'xenovorans', 'p', 'parxl', 'drosophila', 'pseudoobscura', 'd.', 'pseudoobscura', 'd', 'drops', 'cytophaga', 'hutchinsonii', 'c.', 'hutchinsonii', 'c', 'cyth3', 'methanopyrus', 'kandleri', 'm.', 'kandleri', 'm', 'metka', 'nitrosococcus', 'halophilus', 'n.', 'halophilus', 'n', 'nithn', 'mycoplasma', 'crocodyli', 'm.', 'crocodyli', 'm', 'myccm', 'leptospira', 'biflexa', 'l.', 'biflexa', 'l', 'lepbp', 'coprinopsis', 'cinerea', 'c.', 'cinerea', 'c', 'copc7', 'sputnik', 'virophage', 's.', 'virophage', 's', 'sptnk', 'phenylobacterium', 'zucineum', 'p.', 'zucineum', 'p', 'phezh', 'micromonas', 'pusilla', 'm.', 'pusilla', 'm', 'micpc', 'brevibacillus', 'brevis', 'b.', 'brevis', 'b', 'brebn', 'natrialba', 'magadii', 'n.', 'magadii', 'n', 'natmm', 'haliangium', 'ochraceum', 'h.', 'ochraceum', 'h', 'halo1', 'sordaria', 'macrospora', 's.', 'macrospora', 's', 'sormk', 'rothia', 'mucilaginosa', 'r.', 'mucilaginosa', 'r', 'rotmd', 'pirellula', 'staleyi', 'p.', 'staleyi', 'p', 'pirsd', 'citrobacter', 'rodentium', 'c.', 'rodentium', 'c', 'citri', 'xanthomonas', 'albilineans', 'x.', 'albilineans', 'x', 'xanap', 'archaeoglobus', 'profundus', 'a.', 'profundus', 'a', 'arcpa', 'acidaminococcus', 'fermentans', 'a.', 'fermentans', 'a', 'acifv', 'micromonospora', 'aurantiaca', 'm.', 'aurantiaca', 'm', 'micai', 'meiothermus', 'silvanus', 'm.', 'silvanus', 'm', 'meisd', 'alicyclobacillus', 'acidocaldarius', 'a.', 'acidocaldarius', 'a', 'aliad', 'thermomonospora', 'curvata', 't.', 'curvata', 't', 'thecd', 'brachybacterium', 'faecium', 'b.', 'faecium', 'b', 'brafd', 'entamoeba', 'histolytica', 'e.', 'histolytica', 'e', 'enth1', 'rhodospirillum', 'rubrum', 'r.', 'rubrum', 'r', 'rhort', 'methanosphaera', 'stadtmanae', 'm.', 'stadtmanae', 'm', 'metst', 'syntrophus', 'aciditrophicus', 's.', 'aciditrophicus', 's', 'synas', 'anaeromyxobacter', 'dehalogenans', 'a.', 'dehalogenans', 'a', 'anade', 'rhizobium', 'etli', 'r.', 'etli', 'r', 'rhiec', 'frankia', 'casuarinae', 'f.', 'casuarinae', 'f', 'fracc', 'synechococcus', 'sp', 's.', 'sp', 's', 'synjb', 'methanospirillum', 'hungatei', 'm.', 'hungatei', 'm', 'methj', 'desulfitobacterium', 'hafniense', 'd.', 'hafniense', 'd', 'deshy', 'saccharophagus', 'degradans', 's.', 'degradans', 's', 'sacd2', 'theileria', 'annulata', 't.', 'annulata', 't', 'thean', 'nitrobacter', 'hamburgensis', 'n.', 'hamburgensis', 'n', 'nithx', 'shimwellia', 'blattae', 's.', 'blattae', 's', 'shibc', 'hyphomonas', 'neptunium', 'h.', 'neptunium', 'h', 'hypna', 'synechococcus', 'sp', 's.', 'sp', 's', 'syns3', 'alkalilimnicola', 'ehrlichii', 'a.', 'ehrlichii', 'a', 'alkeh', 'granulibacter', 'bethesdensis', 'g.', 'bethesdensis', 'g', 'grabc', 'maricaulis', 'maris', 'm.', 'maris', 'm', 'marmm', 'syntrophomonas', 'wolfei', 's.', 'wolfei', 's', 'synww', 'streptomyces', 'coelicolor', 's.', 'coelicolor', 's', 'strco', 'saccharolobus', 'solfataricus', 's.', 'solfataricus', 's', 'sacs2', 'haloquadratum', 'walsbyi', 'h.', 'walsbyi', 'h', 'halwd', 'rhizobium', 'meliloti', 'r.', 'meliloti', 'r', 'rhime', 'bordetella', 'avium', 'b.', 'avium', 'b', 'bora1', 'clostridioides', 'difficile', 'c.', 'difficile', 'c', 'clod6', 'shewanella', 'denitrificans', 's.', 'denitrificans', 's', 'shedo', 'polaromonas', 'sp', 'p.', 'sp', 'p', 'polsj', 'clostridium', 'botulinum', 'c.', 'botulinum', 'c', 'clobh', 'mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm', 'mycta', 'limosilactobacillus', 'reuteri', 'l.', 'reuteri', 'l', 'limrd', 'bradyrhizobium', 'sp', 'b.', 'sp', 'b', 'braso', 'lodderomyces', 'elongisporus', 'l.', 'elongisporus', 'l', 'lodel', 'meyerozyma', 'guilliermondii', 'm.', 'guilliermondii', 'm', 'picgu', 'renibacterium', 'salmoninarum', 'r.', 'salmoninarum', 'r', 'rensm', 'chloroflexus', 'aurantiacus', 'c.', 'aurantiacus', 'c', 'chlaa', 'micromonas', 'commoda', 'm.', 'commoda', 'm', 'miccc', 'laribacter', 'hongkongensis', 'l.', 'hongkongensis', 'l', 'larhh', 'dyadobacter', 'fermentans', 'd.', 'fermentans', 'd', 'dyafd', 'denitrovibrio', 'acetiphilus', 'd.', 'acetiphilus', 'd', 'dena2', 'shewanella', 'sediminis', 's.', 'sediminis', 's', 'shesh', 'pseudothermotoga', 'lettingae', 'p.', 'lettingae', 'p', 'pselt', 'cloacimonas', 'acidaminovorans', 'c.', 'acidaminovorans', 'c', 'cloai', 'phytoplasma', 'mali', 'p.', 'mali', 'p', 'phymt', 'slackia', 'heliotrinireducens', 's.', 'heliotrinireducens', 's', 'slahd', 'sphaerobacter', 'thermophilus', 's.', 'thermophilus', 's', 'sphtd', 'streptosporangium', 'roseum', 's.', 'roseum', 's', 'strrd', 'thermanaerovibrio', 'acidaminovorans', 't.', 'acidaminovorans', 't', 'theas', 'escherichia', 'coli', 'e.', 'coli', 'e', 'ecobd', 'hyphomicrobium', 'denitrificans', 'h.', 'denitrificans', 'h', 'hypda', 'arthroderma', 'otae', 'a.', 'otae', 'a', 'artoc', 'lachancea', 'thermotolerans', 'l.', 'thermotolerans', 'l', 'lactc', 'candida', 'tropicalis', 'c.', 'tropicalis', 'c', 'cantt', 'blastomyces', 'gilchristii', 'b.', 'gilchristii', 'b', 'blags', 'thermocrinis', 'albus', 't.', 'albus', 't', 'theah', 'medicago', 'truncatula', 'm.', 'truncatula', 'm', 'medtr', 'uncinocarpus', 'reesii', 'u.', 'reesii', 'u', 'uncre', 'paracoccidioides', 'lutzii', 'p.', 'lutzii', 'p', 'parba', 'variola', 'virus', 'v.', 'virus', 'v', 'var67', 'streptobacillus', 'moniliformis', 's.', 'moniliformis', 's', 'strm9', 'corynebacterium', 'aurimucosum', 'c.', 'aurimucosum', 'c', 'cora7', 'salmonella', 'arizonae', 's.', 'arizonae', 's', 'salar', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpt3', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpt5', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppf1', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpml5', 'chlamydia', 'phage', 'c.', 'phage', 'c', 'bpchp', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpga', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmd2', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpn15', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bp933', 'pseudoalteromonas', 'phage', 'p.', 'phage', 'p', 'bppm2', 'sorangium', 'cellulosum', 's.', 'cellulosum', 's', 'sorc5', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpg4', 'acetivibrio', 'thermocellus', 'a.', 'thermocellus', 'a', 'acet2', 'streptococcus', 'sanguinis', 's.', 'sanguinis', 's', 'strsv', 'cryptococcus', 'neoformans', 'c.', 'neoformans', 'c', 'crynj', 'acidianus', 'twotailed', 'a.', 'twotailed', 'a', 'atv', 'thermoanaerobacter', 'pseudethanolicus', 't.', 'pseudethanolicus', 't', 'thep3', 'neptuniibacter', 'caesariensis', 'n.', 'caesariensis', 'n', 'nepce', 'flavobacteria', 'bacterium', 'f.', 'bacterium', 'f', 'flabb', 'babesia', 'bovis', 'b.', 'bovis', 'b', 'babbo', 'thauera', 'sp', 't.', 'sp', 't', 'thasp', 'burkholderia', 'glumae', 'b.', 'glumae', 'b', 'burgb', 'desulfovibrio', 'vulgaris', 'd.', 'vulgaris', 'd', 'desvh', 'lactococcus', 'lactis', 'l.', 'lactis', 'l', 'lacla', 'corynebacterium', 'diphtheriae', 'c.', 'diphtheriae', 'c', 'cordi', 'archaeoglobus', 'fulgidus', 'a.', 'fulgidus', 'a', 'arcfu', 'tropheryma', 'whipplei', 't.', 'whipplei', 't', 'trowt', 'acidobacterium', 'capsulatum', 'a.', 'capsulatum', 'a', 'acic5', 'deinococcus', 'deserti', 'd.', 'deserti', 'd', 'deidv', 'gemmatimonas', 'aurantiaca', 'g.', 'aurantiaca', 'g', 'gemat', 'actinosynnema', 'mirum', 'a.', 'mirum', 'a', 'actmd', 'desulfomicrobium', 'baculatum', 'd.', 'baculatum', 'd', 'desbd', 'desulfofarcimen', 'acetoxidans', 'd.', 'acetoxidans', 'd', 'desas', 'nakamurella', 'multipartita', 'n.', 'multipartita', 'n', 'nakmy', 'nocardiopsis', 'dassonvillei', 'n.', 'dassonvillei', 'n', 'nocdd', 'planctopirus', 'limnophila', 'p.', 'limnophila', 'p', 'plal2', 'sulfurospirillum', 'deleyianum', 's.', 'deleyianum', 's', 'suld5', 'toxoplasma', 'gondii', 't.', 'gondii', 't', 'toxgv', 'karelsulcia', 'muelleri', 'k.', 'muelleri', 'k', 'karmc', 'commelina', 'yellow', 'c.', 'yellow', 'c', 'coymv', 'cassava', 'vein', 'c.', 'vein', 'c', 'csvmv', 'canis', 'lupus', 'c.', 'lupus', 'c', 'canlf', 'xylanimonas', 'cellulosilytica', 'x.', 'cellulosilytica', 'x', 'xylcx', 'methylocella', 'silvestris', 'm.', 'silvestris', 'm', 'metsb', 'scheffersomyces', 'stipitis', 's.', 'stipitis', 's', 'picst', 'sulfolobus', 'islandicus', 's.', 'islandicus', 's', 'sirv1', 'pan', 'troglodytes', 'p.', 'troglodytes', 'p', 'pantr', 'ornithorhynchus', 'anatinus', 'o.', 'anatinus', 'o', 'ornan', 'monodelphis', 'domestica', 'm.', 'domestica', 'm', 'mondo', 'equus', 'caballus', 'e.', 'caballus', 'e', 'horse', 'burkholderia', 'vietnamiensis', 'b.', 'vietnamiensis', 'b', 'burvg', 'trypanosoma', 'cruzi', 't.', 'cruzi', 't', 'trycc', 'croceibacter', 'atlanticus', 'c.', 'atlanticus', 'c', 'croah', 'brucella', 'anthropi', 'b.', 'anthropi', 'b', 'brua4', 'methanothermus', 'fervidus', 'm.', 'fervidus', 'm', 'metfv', 'sediminispirochaeta', 'smaragdinae', 's.', 'smaragdinae', 's', 'sedss', 'culex', 'quinquefasciatus', 'c.', 'quinquefasciatus', 'c', 'culqu', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bplp2', 'shewanella', 'violacea', 's.', 'violacea', 's', 'shevd', 'ovis', 'aries', 'o.', 'aries', 'o', 'sheep', 'streptomyces', 'clavuligerus', 's.', 'clavuligerus', 's', 'strcl', 'nasonia', 'vitripennis', 'n.', 'vitripennis', 'n', 'nasvi', 'rhodobacter', 'capsulatus', 'r.', 'capsulatus', 'r', 'rhocb', 'aminobacterium', 'colombiense', 'a.', 'colombiense', 'a', 'amicl', 'thiomonas', 'arsenitoxydans', 't.', 'arsenitoxydans', 't', 'thia3', 'thermosphaera', 'aggregans', 't.', 'aggregans', 't', 'theam', 'thermincola', 'potens', 't.', 'potens', 't', 'thepj', 'kosmotoga', 'olearia', 'k.', 'olearia', 'k', 'kosot', 'thioalkalivibrio', 'sulfidiphilus', 't.', 'sulfidiphilus', 't', 'thish', 'gloeothece', 'citriformis', 'g.', 'citriformis', 'g', 'gloc7', 'myxococcus', 'xanthus', 'm.', 'xanthus', 'm', 'myxxd', 'campylobacter', 'hominis', 'c.', 'hominis', 'c', 'camhc', 'methanoregula', 'boonei', 'm.', 'boonei', 'm', 'metb6', 'clostridium', 'kluyveri', 'c.', 'kluyveri', 'c', 'clok5', 'fervidobacterium', 'nodosum', 'f.', 'nodosum', 'f', 'fernb', 'xanthobacter', 'autotrophicus', 'x.', 'autotrophicus', 'x', 'xanp2', 'bdellovibrio', 'phage', 'b.', 'phage', 'b', 'bpphm', 'trichlorobacter', 'lovleyi', 't.', 'lovleyi', 't', 'tril1', 'candida', 'glabrata', 'c.', 'glabrata', 'c', 'canga', 'cupriavidus', 'metallidurans', 'c.', 'metallidurans', 'c', 'cupmc', 'lawsonia', 'intracellularis', 'l.', 'intracellularis', 'l', 'lawip', 'deinococcus', 'geothermalis', 'd.', 'geothermalis', 'd', 'deigd', 'koribacter', 'versatilis', 'k.', 'versatilis', 'k', 'korve', 'toxoplasma', 'gondii', 't.', 'gondii', 't', 'toxgo', 'pseudomonas', 'aeruginosa', 'p.', 'aeruginosa', 'p', 'pseae', 'pyrobaculum', 'aerophilum', 'p.', 'aerophilum', 'p', 'pyrae', 'methylobacillus', 'flagellatus', 'm.', 'flagellatus', 'm', 'metfk', 'bifidobacterium', 'animalis', 'b.', 'animalis', 'b', 'bifa0', 'methanosphaerula', 'palustris', 'm.', 'palustris', 'm', 'metpe', 'rickettsia', 'prowazekii', 'r.', 'prowazekii', 'r', 'ricpr', 'acidovorax', 'avenae', 'a.', 'avenae', 'a', 'aciap', 'nostoc', 'sp', 'n.', 'sp', 'n', 'noss1', 'frankia', 'inefficax', 'f.', 'inefficax', 'f', 'fraie', 'methanosarcina', 'acetivorans', 'm.', 'acetivorans', 'm', 'metac', 'fusarium', 'oxysporum', 'f.', 'oxysporum', 'f', 'fusof', 'vibrio', 'parahaemolyticus', 'v.', 'parahaemolyticus', 'v', 'vibpa', 'helicobacter', 'hepaticus', 'h.', 'hepaticus', 'h', 'helhp', 'coccidioides', 'posadasii', 'c.', 'posadasii', 'c', 'cocps', 'metarhizium', 'acridum', 'm.', 'acridum', 'm', 'metaq', 'dehalococcoides', 'mccartyi', 'd.', 'mccartyi', 'd', 'dehmv', 'streptococcus', 'mutans', 's.', 'mutans', 's', 'strmu', 'photorhabdus', 'laumondii', 'p.', 'laumondii', 'p', 'pholl', 'pseudomonas', 'syringae', 'p.', 'syringae', 'p', 'psesm', 'xylella', 'fastidiosa', 'x.', 'fastidiosa', 'x', 'xylft', 'aeropyrum', 'pernix', 'a.', 'pernix', 'a', 'aerpe', 'fusobacterium', 'nucleatum', 'f.', 'nucleatum', 'f', 'fusnn', 'malacoplasma', 'penetrans', 'm.', 'penetrans', 'm', 'malp2', 'deinococcus', 'radiodurans', 'd.', 'radiodurans', 'd', 'deira', 'bradyrhizobium', 'diazoefficiens', 'b.', 'diazoefficiens', 'b', 'bradu', 'pelagibacter', 'ubique', 'p.', 'ubique', 'p', 'pelub', 'shigella', 'sonnei', 's.', 'sonnei', 's', 'shiss', 'aspergillus', 'fumigatus', 'a.', 'fumigatus', 'a', 'aspfu', 'nitrobacter', 'winogradskyi', 'n.', 'winogradskyi', 'n', 'nitwn', 'syntrophotalea', 'carbinolica', 's.', 'carbinolica', 's', 'sync1', 'prochlorococcus', 'marinus', 'p.', 'marinus', 'p', 'promt', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpspp', 'desulfurispirillum', 'indicum', 'd.', 'indicum', 'd', 'desis', 'hydrogenobacter', 'thermophilus', 'h.', 'thermophilus', 'h', 'hydtt', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bphk7', 'magnetococcus', 'marinus', 'm.', 'marinus', 'm', 'magmm', 'azoarcus', 'sp', 'a.', 'sp', 'a', 'azosb', 'hyperthermus', 'butylicus', 'h.', 'butylicus', 'h', 'hypbu', 'maridesulfovibrio', 'salexigens', 'm.', 'salexigens', 'm', 'marsd', 'shewanella', 'pealeana', 's.', 'pealeana', 's', 'shepa', 'ferroglobus', 'placidus', 'f.', 'placidus', 'f', 'ferpa', 'ammonifex', 'degensii', 'a.', 'degensii', 'a', 'ammdk', 'ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a', 'ajech', 'ectocarpus', 'siliculosus', 'e.', 'siliculosus', 'e', 'ectsi', 'metamycoplasma', 'hominis', 'm.', 'hominis', 'm', 'meth1', 'phytophthora', 'sojae', 'p.', 'sojae', 'p', 'physp', 'thermoproteus', 'tenax', 't.', 'tenax', 't', 'thetk', 'tetragenococcus', 'halophilus', 't.', 'halophilus', 't', 'tethn', 'leptosphaeria', 'maculans', 'l.', 'maculans', 'l', 'lepmj', 'arthroderma', 'gypseum', 'a.', 'gypseum', 'a', 'artgp', 'coxiella', 'burnetii', 'c.', 'burnetii', 'c', 'coxbu', 'bordetella', 'pertussis', 'b.', 'pertussis', 'b', 'borpe', 'brevundimonas', 'subvibrioides', 'b.', 'subvibrioides', 'b', 'bresc', 'natronomonas', 'pharaonis', 'n.', 'pharaonis', 'n', 'natpd', 'cereibacter', 'sphaeroides', 'c.', 'sphaeroides', 'c', 'cers4', 'carboxydothermus', 'hydrogenoformans', 'c.', 'hydrogenoformans', 'c', 'carhz', 'latilactobacillus', 'sakei', 'l.', 'sakei', 'l', 'latss', 'chlorobium', 'luteolum', 'c.', 'luteolum', 'c', 'chll3', 'oleidesulfovibrio', 'alaskensis', 'o.', 'alaskensis', 'o', 'olea2', 'sulfurimonas', 'denitrificans', 's.', 'denitrificans', 's', 'suldn', 'shigella', 'dysenteriae', 's.', 'dysenteriae', 's', 'shids', 'nitrosospira', 'multiformis', 'n.', 'multiformis', 'n', 'nitmu', 'brucella', 'abortus', 'b.', 'abortus', 'b', 'brua2', 'pelodictyon', 'phaeoclathratiforme', 'p.', 'phaeoclathratiforme', 'p', 'pelpb', 'prosthecochloris', 'aestuarii', 'p.', 'aestuarii', 'p', 'proa2', 'aureococcus', 'anophagefferens', 'a.', 'anophagefferens', 'a', 'auran', 'clostridium', 'cellulovorans', 'c.', 'cellulovorans', 'c', 'cloc7', 'methylotenera', 'mobilis', 'm.', 'mobilis', 'm', 'metml', 'methylovorus', 'glucosetrophus', 'm.', 'glucosetrophus', 'm', 'metgs', 'hirschia', 'baltica', 'h.', 'baltica', 'h', 'hirbi', 'saccharomyces', 'kudriavzevii', 's.', 'kudriavzevii', 's', 'sack1', 'beauveria', 'bassiana', 'b.', 'bassiana', 'b', 'beab2', 'streptomyces', 'pristinaespiralis', 's.', 'pristinaespiralis', 's', 'stre2', 'xiphophorus', 'maculatus', 'x.', 'maculatus', 'x', 'xipma', 'phocaeicola', 'vulgatus', 'p.', 'vulgatus', 'p', 'phov8', 'tetrapisispora', 'blattae', 't.', 'blattae', 't', 'tetbl', 'nematocida', 'parisii', 'n.', 'parisii', 'n', 'nemp3', 'enterococcus', 'hirae', 'e.', 'hirae', 'e', 'entha', 'babesia', 'microti', 'b.', 'microti', 'b', 'babmr', 'yersinia', 'phage', 'y.', 'phage', 'y', 'bppr1', 'roseobacter', 'sp', 'r.', 'sp', 'r', 'ross0', 'peptacetobacter', 'hiranonis', 'p.', 'hiranonis', 'p', 'pepht', 'oceanicola', 'granulosus', 'o.', 'granulosus', 'o', 'ocegh', 'pedosphaera', 'parvula', 'p.', 'parvula', 'p', 'pedpl', 'lentilactobacillus', 'hilgardii', 'l.', 'hilgardii', 'l', 'lenh9', 'aerococcus', 'viridans', 'a.', 'viridans', 'a', 'aervm', 'nocardiopsis', 'alba', 'n.', 'alba', 'n', 'nocaa', 'gillisia', 'limnaea', 'g.', 'limnaea', 'g', 'gillr', 'streptomyces', 'viridochromogenes', 's.', 'viridochromogenes', 's', 'strvt', 'hoeflea', 'phototrophica', 'h.', 'phototrophica', 'h', 'hoepd', 'porphyromonas', 'endodontalis', 'p.', 'endodontalis', 'p', 'porea', 'pseudooceanicola', 'batsensis', 'p.', 'batsensis', 'p', 'psebh', 'faecalibacterium', 'prausnitzii', 'f.', 'prausnitzii', 'f', 'faepa', 'methylobacter', 'tundripaludum', 'm.', 'tundripaludum', 'm', 'mettv', 'caldisericum', 'exile', 'c.', 'exile', 'c', 'calea', 'segniliparus', 'rugosus', 's.', 'rugosus', 's', 'segrc', 'methylacidiphilum', 'fumariolicum', 'm.', 'fumariolicum', 'm', 'metfb', 'cardiobacterium', 'hominis', 'c.', 'hominis', 'c', 'carh6', 'mycolicibacterium', 'thermoresistibile', 'm.', 'thermoresistibile', 'm', 'myct3', 'solanum', 'lycopersicum', 's.', 'lycopersicum', 's', 'sollc', 'setaria', 'italica', 's.', 'italica', 's', 'setit', 'methyloversatilis', 'universalis', 'm.', 'universalis', 'm', 'metuf', 'paraburkholderia', 'graminis', 'p.', 'graminis', 'p', 'parg4', 'apis', 'mellifera', 'a.', 'mellifera', 'a', 'apime', 'bombyx', 'mori', 'b.', 'mori', 'b', 'bommo', 'atta', 'cephalotes', 'a.', 'cephalotes', 'a', 'attce', 'fusarium', 'vanettenii', 'f.', 'vanettenii', 'f', 'fusv7', 'oreochromis', 'niloticus', 'o.', 'niloticus', 'o', 'oreni', 'ictidomys', 'tridecemlineatus', 'i.', 'tridecemlineatus', 'i', 'icttr', 'kazachstania', 'africana', 'k.', 'africana', 'k', 'kazaf', 'candida', 'parapsilosis', 'c.', 'parapsilosis', 'c', 'canpc', 'pichia', 'sorbitophila', 'p.', 'sorbitophila', 'p', 'picso', 'methanothermobacter', 'thermautotrophicus', 'm.', 'thermautotrophicus', 'm', 'metth', 'otolemur', 'garnettii', 'o.', 'garnettii', 'o', 'otoga', 'takifugu', 'rubripes', 't.', 'rubripes', 't', 'takru', 'methanocella', 'conradii', 'm.', 'conradii', 'm', 'metcz', 'frateuria', 'aurantia', 'f.', 'aurantia', 'f', 'fraad', 'phytophthora', 'ramorum', 'p.', 'ramorum', 'p', 'phyrm', 'pristionchus', 'pacificus', 'p.', 'pacificus', 'p', 'pripa', 'puccinia', 'triticina', 'p.', 'triticina', 'p', 'puct1', 'wallemia', 'mellicola', 'w.', 'mellicola', 'w', 'walmc', 'tistrella', 'mobilis', 't.', 'mobilis', 't', 'tismk', 'thermogladius', 'calderae', 't.', 'calderae', 't', 'thec1', 'thiothrix', 'nivea', 't.', 'nivea', 't', 'thinj', 'sphingomonas', 'sp', 's.', 'sp', 's', 'sphss', 'crassostrea', 'gigas', 'c.', 'gigas', 'c', 'cragi', 'hypocrea', 'atroviridis', 'h.', 'atroviridis', 'h', 'hypai', 'acetivibrio', 'clariflavus', 'a.', 'clariflavus', 'a', 'acece', 'tannerella', 'forsythia', 't.', 'forsythia', 't', 'tanfa', 'sulfobacillus', 'acidophilus', 's.', 'acidophilus', 's', 'sulad', 'actinoplanes', 'sp', 'a.', 'sp', 'a', 'acts5', 'mycolicibacterium', 'rhodesiae', 'm.', 'rhodesiae', 'm', 'mycrn', 'pediococcus', 'claussenii', 'p.', 'claussenii', 'p', 'pedcp', 'glarea', 'lozoyensis', 'g.', 'lozoyensis', 'g', 'glal7', 'cavia', 'porcellus', 'c.', 'porcellus', 'c', 'cavpo', 'nematocida', 'ausubeli', 'n.', 'ausubeli', 'n', 'nema1', 'simian', 'immunodeficiency', 's.', 'immunodeficiency', 's', 'siv', 'torulaspora', 'delbrueckii', 't.', 'delbrueckii', 't', 'torde', 'owenweeksia', 'hongkongensis', 'o.', 'hongkongensis', 'o', 'owehd', 'sphaerochaeta', 'pleomorpha', 's.', 'pleomorpha', 's', 'sphpg', 'flavobacterium', 'columnare', 'f.', 'columnare', 'f', 'flaca', 'tetrapisispora', 'phaffii', 't.', 'phaffii', 't', 'tetph', 'azospirillum', 'lipoferum', 'a.', 'lipoferum', 'a', 'azol4', 'desulfuromonas', 'acetoxidans', 'd.', 'acetoxidans', 'd', 'desa6', 'synechococcus', 'sp', 's.', 'sp', 's', 'syns7', 'thermovirga', 'lienii', 't.', 'lienii', 't', 'theld', 'pseudoxanthomonas', 'spadix', 'p.', 'spadix', 'p', 'pseup', 'methanothrix', 'harundinacea', 'm.', 'harundinacea', 'm', 'meth6', 'ralstonia', 'solanacearum', 'r.', 'solanacearum', 'r', 'ralsu', 'roseovarius', 'nubinhibens', 'r.', 'nubinhibens', 'r', 'rosni', 'slackia', 'exigua', 's.', 'exigua', 's', 'slaes', 'bilophila', 'wadsworthia', 'b.', 'wadsworthia', 'b', 'bilw3', 'oryza', 'brachyantha', 'o.', 'brachyantha', 'o', 'orybr', 'gaeumannomyces', 'tritici', 'g.', 'tritici', 'g', 'gaet3', 'turneriella', 'parva', 't.', 'parva', 't', 'turpd', 'belliella', 'baltica', 'b.', 'baltica', 'b', 'belbd', 'ornithobacterium', 'rhinotracheale', 'o.', 'rhinotracheale', 'o', 'ornrl', 'bernardetia', 'litoralis', 'b.', 'litoralis', 'b', 'berls', 'desulfomonile', 'tiedjei', 'd.', 'tiedjei', 'd', 'desta', 'terriglobus', 'roseus', 't.', 'roseus', 't', 'terrk', 'mycolicibacterium', 'chubuense', 'm.', 'chubuense', 'm', 'myccn', 'acetomicrobium', 'mobile', 'a.', 'mobile', 'a', 'acemn', 'thiocystis', 'violascens', 't.', 'violascens', 't', 'thiv6', 'indibacter', 'alkaliphilus', 'i.', 'alkaliphilus', 'i', 'indal', 'gottschalkia', 'acidurici', 'g.', 'acidurici', 'g', 'gota9', 'acidithiobacillus', 'caldus', 'a.', 'caldus', 'a', 'acics', 'amycolatopsis', 'mediterranei', 'a.', 'mediterranei', 'a', 'amyms', 'rhodosporidium', 'toruloides', 'r.', 'toruloides', 'r', 'rhot2', 'ustilago', 'hordei', 'u.', 'hordei', 'u', 'ustho', 'salipiger', 'bermudensis', 's.', 'bermudensis', 's', 'salbh', 'mycolicibacterium', 'hassiacum', 'm.', 'hassiacum', 'm', 'mychd', 'saccharothrix', 'espanaensis', 's.', 'espanaensis', 's', 'saces', 'cycloclasticus', 'sp', 'c.', 'sp', 'c', 'cycsp', 'alcanivorax', 'dieselolei', 'a.', 'dieselolei', 'a', 'alcdb', 'amphibacillus', 'xylanus', 'a.', 'xylanus', 'a', 'ampxn', 'leuconostoc', 'carnosum', 'l.', 'carnosum', 'l', 'leucj', 'kazachstania', 'naganishii', 'k.', 'naganishii', 'k', 'kazna', 'plasmodium', 'cynomolgi', 'p.', 'cynomolgi', 'p', 'placd', 'desulfosporosinus', 'orientis', 'd.', 'orientis', 'd', 'desod', 'desulfobulbus', 'propionicus', 'd.', 'propionicus', 'd', 'despd', 'staphylococcus', 'saprophyticus', 's.', 'saprophyticus', 's', 'stas1', 'gluconobacter', 'oxydans', 'g.', 'oxydans', 'g', 'gluox', 'parvibaculum', 'lavamentivorans', 'p.', 'lavamentivorans', 'p', 'parl1', 'sulfurovum', 'sp', 's.', 'sp', 's', 'sulnb', 'campylobacter', 'curvus', 'c.', 'curvus', 'c', 'camc5', 'lactobacillus', 'acidophilus', 'l.', 'acidophilus', 'l', 'lacac', 'anaeromyxobacter', 'sp', 'a.', 'sp', 'a', 'anadf', 'janthinobacterium', 'sp', 'j.', 'sp', 'j', 'janma', 'flavobacterium', 'psychrophilum', 'f.', 'psychrophilum', 'f', 'flapj', 'sulfurimonas', 'gotlandica', 's.', 'gotlandica', 's', 'sulgg', 'porphyromonas', 'asaccharolytica', 'p.', 'asaccharolytica', 'p', 'porad', 'treponema', 'brennaborense', 't.', 'brennaborense', 't', 'trebd', 'aromatoleum', 'aromaticum', 'a.', 'aromaticum', 'a', 'aroae', 'roseiflexus', 'sp', 'r.', 'sp', 'r', 'ross1', 'pelotomaculum', 'thermopropionicum', 'p.', 'thermopropionicum', 'p', 'pelts', 'ligilactobacillus', 'salivarius', 'l.', 'salivarius', 'l', 'ligs1', 'aspergillus', 'oryzae', 'a.', 'oryzae', 'a', 'aspor', 'methanolacinia', 'petrolearia', 'm.', 'petrolearia', 'm', 'metp4', 'sphingopyxis', 'alaskensis', 's.', 'alaskensis', 's', 'sphal', 'thermodesulfobacterium', 'geofontis', 't.', 'geofontis', 't', 'thegp', 'methylobacterium', 'radiotolerans', 'm.', 'radiotolerans', 'm', 'metrj', 'oryza', 'nivara', 'o.', 'nivara', 'o', 'oryni', 'flexistipes', 'sinusarabici', 'f.', 'sinusarabici', 'f', 'flesm', 'methanosalsum', 'zhilinae', 'm.', 'zhilinae', 'm', 'metzd', 'starkeya', 'novella', 's.', 'novella', 's', 'stand', 'torque', 'teno', 't.', 'teno', 't', 'ttvd1', 'rubrobacter', 'xylanophilus', 'r.', 'xylanophilus', 'r', 'rubxd', 'midichloria', 'mitochondrii', 'm.', 'mitochondrii', 'm', 'midmi', 'thermobispora', 'bispora', 't.', 'bispora', 't', 'thebd', 'phytophthora', 'infestans', 'p.', 'infestans', 'p', 'phyit', 'mesoplasma', 'florum', 'm.', 'florum', 'm', 'mesfl', 'capnocytophaga', 'ochracea', 'c.', 'ochracea', 'c', 'capod', 'odoribacter', 'splanchnicus', 'o.', 'splanchnicus', 'o', 'odosd', 'halogeometricum', 'borinquense', 'h.', 'borinquense', 'h', 'halbp', 'brugia', 'malayi', 'b.', 'malayi', 'b', 'bruma', 'vulcanisaeta', 'distributa', 'v.', 'distributa', 'v', 'vuldi', 'ferrimonas', 'balearica', 'f.', 'balearica', 'f', 'ferbd', 'solibacillus', 'silvestris', 's.', 'silvestris', 's', 'solss', 'geotalea', 'uraniireducens', 'g.', 'uraniireducens', 'g', 'geour', 'herminiimonas', 'arsenicoxydans', 'h.', 'arsenicoxydans', 'h', 'herar', 'aspergillus', 'clavatus', 'a.', 'clavatus', 'a', 'aspcl', 'neosartorya', 'fischeri', 'n.', 'fischeri', 'n', 'neofi', 'aspergillus', 'niger', 'a.', 'niger', 'a', 'aspnc', 'grapevine', 'leafrollassociated', 'g.', 'leafrollassociated', 'g', 'glrv3', 'lymantria', 'dispar', 'l.', 'dispar', 'l', 'ldcpr', 'aquareovirus', 'c', 'a.', 'c', 'a', 'aqrvc', 'penicillium', 'chrysogenum', 'p.', 'chrysogenum', 'p', 'pcvc', 'macaca', 'mulatta', 'm.', 'mulatta', 'm', 'macmu', 'cryphonectria', 'parasitica', 'c.', 'parasitica', 'c', 'myrv9', 'rice', 'gall', 'r.', 'gall', 'r', 'rgdv', 'leishmania', 'rna', 'l.', 'rna', 'l', 'lrvlg', 'cryptosporidium', 'parvum', 'c.', 'parvum', 'c', 'crypi', 'physcomitrium', 'patens', 'p.', 'patens', 'p', 'phypa', 'saccharopolyspora', 'erythraea', 's.', 'erythraea', 's', 'sacen', 'populus', 'trichocarpa', 'p.', 'trichocarpa', 'p', 'poptr', 'bacteroides', 'fragilis', 'b.', 'fragilis', 'b', 'bacfn', 'pelobacter', 'propionicus', 'p.', 'propionicus', 'p', 'pelpd', 'xanthomonas', 'oryzae', 'x.', 'oryzae', 'x', 'xanor', 'mobiluncus', 'curtisii', 'm.', 'curtisii', 'm', 'mobcv', 'glaesserella', 'parasuis', 'g.', 'parasuis', 'g', 'glap5', 'marssonina', 'brunnea', 'm.', 'brunnea', 'm', 'marbu', 'trichosporon', 'asahii', 't.', 'asahii', 't', 'triac', 'eremothecium', 'cymbalariae', 'e.', 'cymbalariae', 'e', 'erecy', 'chloracidobacterium', 'thermophilum', 'c.', 'thermophilum', 'c', 'chltf', 'thermodesulfatator', 'indicus', 't.', 'indicus', 't', 'theid', 'halopiger', 'xanaduensis', 'h.', 'xanaduensis', 'h', 'halxs', 'mycoplasmopsis', 'fermentans', 'm.', 'fermentans', 'm', 'mycfp', 'heterocephalus', 'glaber', 'h.', 'glaber', 'h', 'hetga', 'nocardia', 'farcinica', 'n.', 'farcinica', 'n', 'nocfa', 'methylococcus', 'capsulatus', 'm.', 'capsulatus', 'm', 'metca', 'mushroom', 'bacilliform', 'm.', 'bacilliform', 'm', 'mbvlf', 'dinoroseobacter', 'shibae', 'd.', 'shibae', 'd', 'dinsh', 'nitrosococcus', 'oceani', 'n.', 'oceani', 'n', 'nitoc', 'pseudoalteromonas', 'translucida', 'p.', 'translucida', 'p', 'pset1', 'terriglobus', 'saanensis', 't.', 'saanensis', 't', 'terss', 'coriobacterium', 'glomerans', 'c.', 'glomerans', 'c', 'corgp', 'treponema', 'succinifaciens', 't.', 'succinifaciens', 't', 'tres6', 'streptomyces', 'venezuelae', 's.', 'venezuelae', 's', 'strvp', 'dickeya', 'dadantii', 'd.', 'dadantii', 'd', 'dicd3', 'rubinisphaera', 'brasiliensis', 'r.', 'brasiliensis', 'r', 'rubbr', 'halanaerobium', 'praevalens', 'h.', 'praevalens', 'h', 'halpg', 'paenibacillus', 'polymyxa', 'p.', 'polymyxa', 'p', 'paeps', 'enterobacter', 'lignolyticus', 'e.', 'lignolyticus', 'e', 'entls', 'ilyobacter', 'polytropus', 'i.', 'polytropus', 'i', 'ilypc', 'glutamicibacter', 'arilaitensis', 'g.', 'arilaitensis', 'g', 'gluar', 'prunus', 'persica', 'p.', 'persica', 'p', 'prupe', 'caldicellulosiruptor', 'owensensis', 'c.', 'owensensis', 'c', 'calow', 'chlamydomonas', 'reinhardtii', 'c.', 'reinhardtii', 'c', 'chlre', 'tuber', 'melanosporum', 't.', 'melanosporum', 't', 'tubmm', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpf1', 'cryptosporidium', 'parvum', 'c.', 'parvum', 'c', 'cpvks', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv6z', 'saccharomyces', 'arboricola', 's.', 'arboricola', 's', 'sacar', 'opitutus', 'terrae', 'o.', 'terrae', 'o', 'opitp', 'cyanidioschyzon', 'merolae', 'c.', 'merolae', 'c', 'cyam1', 'oryza', 'sativa', 'o.', 'sativa', 'o', 'orysi', 'sulfolobus', 'islandicus', 's.', 'islandicus', 's', 'sifvh', 'ostreid', 'herpesvirus', 'o.', 'herpesvirus', 'o', 'oshvf', 'his1', 'virus', 'h.', 'virus', 'h', 'his1i', 'roseobacter', 'denitrificans', 'r.', 'denitrificans', 'r', 'rosdo', 'marinithermus', 'hydrothermalis', 'm.', 'hydrothermalis', 'm', 'marht', 'calditerrivibrio', 'nitroreducens', 'c.', 'nitroreducens', 'c', 'calny', 'acetoanaerobium', 'sticklandii', 'a.', 'sticklandii', 'a', 'acesd', 'ruminococcus', 'champanellensis', 'r.', 'champanellensis', 'r', 'rumc1', 'magnetospirillum', 'magneticum', 'm.', 'magneticum', 'm', 'magsa', 'anopheles', 'gambiae', 'a.', 'gambiae', 'a', 'anoga', 'mycoplasmopsis', 'agalactiae', 'm.', 'agalactiae', 'm', 'mycap', 'maize', 'chlorotic', 'm.', 'chlorotic', 'm', 'mcmvk', 'geobacter', 'metallireducens', 'g.', 'metallireducens', 'g', 'geomg', 'kitasatospora', 'setae', 'k.', 'setae', 'k', 'kitsk', 'torque', 'teno', 't.', 'teno', 't', 'ttvg1', 'torque', 'teno', 't.', 'teno', 't', 'ttvi1', 'torque', 'teno', 't.', 'teno', 't', 'ttvz1', 'equine', 'herpesvirus', 'e.', 'herpesvirus', 'e', 'ehv2', 'oryza', 'sativa', 'o.', 'sativa', 'o', 'osevj', 'acidaminococcus', 'intestini', 'a.', 'intestini', 'a', 'aciir', 'desulfurobacterium', 'thermolithotrophum', 'd.', 'thermolithotrophum', 'd', 'destd', 'strongylocentrotus', 'purpuratus', 's.', 'purpuratus', 's', 'strpu', 'granulicella', 'mallensis', 'g.', 'mallensis', 'g', 'gramm', 'hypocrea', 'virens', 'h.', 'virens', 'h', 'hypvg', 'macrophomina', 'phaseolina', 'm.', 'phaseolina', 'm', 'macph', 'serendipita', 'indica', 's.', 'indica', 's', 'serid', 'marinitoga', 'piezophila', 'm.', 'piezophila', 'm', 'marpk', 'streptomyces', 'hygroscopicus', 's.', 'hygroscopicus', 's', 'strhj', 'acetobacterium', 'woodii', 'a.', 'woodii', 'a', 'acewd', 'batrachochytrium', 'dendrobatidis', 'b.', 'dendrobatidis', 'b', 'batdj', 'spirochaeta', 'thermophila', 's.', 'thermophila', 's', 'spitz', 'leishmania', 'braziliensis', 'l.', 'braziliensis', 'l', 'leibr', 'coccomyxa', 'subellipsoidea', 'c.', 'subellipsoidea', 'c', 'cocsc', 'tribolium', 'castaneum', 't.', 'castaneum', 't', 'trica', 'pelodiscus', 'sinensis', 'p.', 'sinensis', 'p', 'pelsi', 'tetraodon', 'nigroviridis', 't.', 'nigroviridis', 't', 'tetng', 'exophiala', 'dermatitidis', 'e.', 'dermatitidis', 'e', 'exodn', 'zea', 'mays', 'z.', 'mays', 'z', 'maize', 'corn', 'maize', 'anaplasma', 'marginale', 'a.', 'marginale', 'a', 'anamf', 'myceliophthora', 'thermophila', 'm.', 'thermophila', 'm', 'myctt', 'desulfobacula', 'toluolica', 'd.', 'toluolica', 'd', 'destt', 'leptospirillum', 'ferrooxidans', 'l.', 'ferrooxidans', 'l', 'lepfc', 'spirochaeta', 'africana', 's.', 'africana', 's', 'spiaz', 'fervidicoccus', 'fontis', 'f.', 'fontis', 'f', 'ferfk', 'ignavibacterium', 'album', 'i.', 'album', 'i', 'ignaj', 'halobacillus', 'halophilus', 'h.', 'halophilus', 'h', 'halh3', 'schizophyllum', 'commune', 's.', 'commune', 's', 'schcm', 'halanaerobium', 'hydrogeniformans', 'h.', 'hydrogeniformans', 'h', 'halhg', 'leadbetterella', 'byssophila', 'l.', 'byssophila', 'l', 'leab4', 'puniceispirillum', 'marinum', 'p.', 'marinum', 'p', 'punmi', 'fluviicola', 'taffensis', 'f.', 'taffensis', 'f', 'flutr', 'filifactor', 'alocis', 'f.', 'alocis', 'f', 'filad', 'acinetobacter', 'calcoaceticus', 'a.', 'calcoaceticus', 'a', 'acicp', 'mycoplasma', 'suis', 'm.', 'suis', 'm', 'mycsl', 'cellulophaga', 'lytica', 'c.', 'lytica', 'c', 'cellc', 'syntrophobotulus', 'glycolicus', 's.', 'glycolicus', 's', 'syngf', 'methanobacterium', 'lacus', 'm.', 'lacus', 'm', 'metla', 'neospora', 'caninum', 'n.', 'caninum', 'n', 'neocl', 'blastococcus', 'saxobsidens', 'b.', 'saxobsidens', 'b', 'blasd', 'saprospira', 'grandis', 's.', 'grandis', 's', 'sapgl', 'torque', 'teno', 't.', 'teno', 't', 'ttvvg', 'torque', 'teno', 't.', 'teno', 't', 'ttvv6', 'torque', 'teno', 't.', 'teno', 't', 'ttvv8', 'mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm', 'mycte', 'corallococcus', 'coralloides', 'c.', 'coralloides', 'c', 'corcm', 'solitalea', 'canadensis', 's.', 'canadensis', 's', 'solcm', 'flavobacterium', 'indicum', 'f.', 'indicum', 'f', 'flaig', 'gasterosteus', 'aculeatus', 'g.', 'aculeatus', 'g', 'gasac', 'ictalurid', 'herpesvirus', 'i.', 'herpesvirus', 'i', 'ichva', 'loxodonta', 'africana', 'l.', 'africana', 'l', 'loxaf', 'sarcophilus', 'harrisii', 's.', 'harrisii', 's', 'sarha', 'clavispora', 'lusitaniae', 'c.', 'lusitaniae', 'c', 'clal4', 'deinococcus', 'proteolyticus', 'd.', 'proteolyticus', 'd', 'deipm', 'dictyoglomus', 'turgidum', 'd.', 'turgidum', 'd', 'dictd', 'geotalea', 'daltonii', 'g.', 'daltonii', 'g', 'geodf', 'methanococcus', 'voltae', 'm.', 'voltae', 'm', 'metv3', 'afipia', 'carboxidovorans', 'a.', 'carboxidovorans', 'a', 'afic5', 'oceanimonas', 'sp', 'o.', 'sp', 'o', 'ocesg', 'sphingobium', 'indicum', 's.', 'indicum', 's', 'sphiu', 'taeniopygia', 'guttata', 't.', 'guttata', 't', 'taegu', 'acromyrmex', 'echinatior', 'a.', 'echinatior', 'a', 'acrec', 'cestrum', 'yellow', 'c.', 'yellow', 'c', 'cylcv', 'northern', 'cereal', 'n.', 'cereal', 'n', 'ncmv', 'grosmannia', 'clavigera', 'g.', 'clavigera', 'g', 'grocl', 'cavenderia', 'fasciculata', 'c.', 'fasciculata', 'c', 'cacfs', 'drosophila', 'willistoni', 'd.', 'willistoni', 'd', 'drowi', 'salpingoeca', 'rosetta', 's.', 'rosetta', 's', 'salr5', 'drosophila', 'ananassae', 'd.', 'ananassae', 'd', 'droan', 'sulfurimonas', 'autotrophica', 's.', 'autotrophica', 's', 'sulao', 'methanothrix', 'soehngenii', 'm.', 'soehngenii', 'm', 'metsg', 'pseudonocardia', 'dioxanivorans', 'p.', 'dioxanivorans', 'p', 'pseux', 'acyrthosiphon', 'pisum', 'a.', 'pisum', 'a', 'acypi', 'klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k', 'kleph', 'streptantibioticus', 'cattleyicolor', 's.', 'cattleyicolor', 's', 'stren', 'ciona', 'savignyi', 'c.', 'savignyi', 'c', 'ciosa', 'amphimedon', 'queenslandica', 'a.', 'queenslandica', 'a', 'ampqe', 'caldilinea', 'aerophila', 'c.', 'aerophila', 'c', 'calas', 'phycisphaera', 'mikurensis', 'p.', 'mikurensis', 'p', 'phymf', 'actinoplanes', 'missouriensis', 'a.', 'missouriensis', 'a', 'actm4', 'rubrivivax', 'gelatinosus', 'r.', 'gelatinosus', 'r', 'rubgi', 'alicycliphilus', 'denitrificans', 'a.', 'denitrificans', 'a', 'alidk', 'sphaerochaeta', 'coccoides', 's.', 'coccoides', 's', 'sphcd', 'streptococcus', 'pasteurianus', 's.', 'pasteurianus', 's', 'strpx', 'microlunatus', 'phosphovorus', 'm.', 'phosphovorus', 'm', 'micpn', 'beutenbergia', 'cavernae', 'b.', 'cavernae', 'b', 'beuc1', 'aspergillus', 'terreus', 'a.', 'terreus', 'a', 'asptn', 'pectobacterium', 'atrosepticum', 'p.', 'atrosepticum', 'p', 'pecas', 'kribbella', 'flavida', 'k.', 'flavida', 'k', 'krifd', 'rickettsia', 'amblyommatis', 'r.', 'amblyommatis', 'r', 'ricag', 'oryza', 'rufipogon', 'o.', 'rufipogon', 'o', 'oryru', 'sheeppox', 'virus', 's.', 'virus', 's', 'shevt', 'streptomyces', 'davaonensis', 's.', 'davaonensis', 's', 'strdj', 'zymoseptoria', 'tritici', 'z.', 'tritici', 'z', 'zymti', 'serpula', 'lacrymans', 's.', 'lacrymans', 's', 'serl3', 'chaetomium', 'thermophilum', 'c.', 'thermophilum', 'c', 'chatd', 'caenorhabditis', 'brenneri', 'c.', 'brenneri', 'c', 'caebe', 'gallid', 'herpesvirus', 'g.', 'herpesvirus', 'g', 'gahvm', 'xenorhabdus', 'nematophila', 'x.', 'nematophila', 'x', 'xenna', 'bdellovibrio', 'bacteriovorus', 'b.', 'bacteriovorus', 'b', 'bdeba', 'ovine', 'adenovirus', 'o.', 'adenovirus', 'o', 'adeo7', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpp1', 'aerococcus', 'urinae', 'a.', 'urinae', 'a', 'aerua', 'polymorphum', 'gilvum', 'p.', 'gilvum', 'p', 'polgs', 'archaeoglobus', 'veneficus', 'a.', 'veneficus', 'a', 'arcvs', 'hippea', 'maritima', 'h.', 'maritima', 'h', 'hipma', 'chlorella', 'variabilis', 'c.', 'variabilis', 'c', 'chlva', 'ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a', 'ajec8', 'xenopus', 'tropicalis', 'x.', 'tropicalis', 'x', 'xentr', 'ciona', 'intestinalis', 'c.', 'intestinalis', 'c', 'cioin', 'citrobacter', 'koseri', 'c.', 'koseri', 'c', 'citk8', 'lettuce', 'bigvein', 'l.', 'bigvein', 'l', 'lbvav', 'microplitis', 'demolitor', 'm.', 'demolitor', 'm', 'mdbvw', 'roseburia', 'hominis', 'r.', 'hominis', 'r', 'rosha', 'thermothielavioides', 'terrestris', 't.', 'terrestris', 't', 'thett', 'thermotoga', 'maritima', 't.', 'maritima', 't', 'thema', 'shewanella', 'oneidensis', 's.', 'oneidensis', 's', 'sheon', 'nocardia', 'cyriacigeorgica', 'n.', 'cyriacigeorgica', 'n', 'noccg', 'rippkaea', 'orientalis', 'r.', 'orientalis', 'r', 'ripo1', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco27', 'gloeothece', 'verrucosa', 'g.', 'verrucosa', 'g', 'glov7', 'methylobacterium', 'nodulans', 'm.', 'nodulans', 'm', 'metno', 'cupriavidus', 'necator', 'c.', 'necator', 'c', 'cupnh', 'treponema', 'denticola', 't.', 'denticola', 't', 'trede', 'escherichia', 'coli', 'e.', 'coli', 'e', 'ecok1', 'clostridium', 'novyi', 'c.', 'novyi', 'c', 'clonn', 'acidothermus', 'cellulolyticus', 'a.', 'cellulolyticus', 'a', 'acic1', 'callithrix', 'jacchus', 'c.', 'jacchus', 'c', 'calja', 'sus', 'scrofa', 's.', 'scrofa', 's', 'pig', 'conexibacter', 'woesei', 'c.', 'woesei', 'c', 'conwi', 'mageeibacillus', 'indolicus', 'm.', 'indolicus', 'm', 'magiu', 'harpegnathos', 'saltator', 'h.', 'saltator', 'h', 'harsa', 'haloferax', 'volcanii', 'h.', 'volcanii', 'h', 'halvd', 'torque', 'teno', 't.', 'teno', 't', 'ttvv2', 'torque', 'teno', 't.', 'teno', 't', 'ttvv3', 'torque', 'teno', 't.', 'teno', 't', 'ttvv4', 'torque', 'teno', 't.', 'teno', 't', 'ttvv5', 'torque', 'teno', 't.', 'teno', 't', 'ttvv7', 'torque', 'teno', 't.', 'teno', 't', 'ttvv9', 'caenorhabditis', 'remanei', 'c.', 'remanei', 'c', 'caere', 'rat', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r', 'rcmvm', 'dokdonia', 'sp', 'd.', 'sp', 'd', 'doks4', 'thiobacillus', 'denitrificans', 't.', 'denitrificans', 't', 'thida', 'lacinutrix', 'sp', 'l.', 'sp', 'l', 'lacs5', 'carnobacterium', 'sp', 'c.', 'sp', 'c', 'cars1', 'micromonospora', 'maris', 'm.', 'maris', 'm', 'micm1', 'ricinus', 'communis', 'r.', 'communis', 'r', 'ricco', 'blastocystis', 'hominis', 'b.', 'hominis', 'b', 'blaho', 'methylotuvimicrobium', 'alcaliphilum', 'm.', 'alcaliphilum', 'm', 'meta2', 'ehrlichia', 'chaffeensis', 'e.', 'chaffeensis', 'e', 'ehrcr', 'phytoplasma', 'australiense', 'p.', 'australiense', 'p', 'phyas', 'jannaschia', 'sp', 'j.', 'sp', 'j', 'jansc', 'albidiferax', 'ferrireducens', 'a.', 'ferrireducens', 'a', 'albft', 'plasmodium', 'vivax', 'p.', 'vivax', 'p', 'plavs', 'phanerochaete', 'carnosa', 'p.', 'carnosa', 'p', 'phacs', 'ramlibacter', 'tataouinensis', 'r.', 'tataouinensis', 'r', 'ramtt', 'collimonas', 'fungivorans', 'c.', 'fungivorans', 'c', 'colft', 'cauliflower', 'mosaic', 'c.', 'mosaic', 'c', 'camvd', 'melissococcus', 'plutonius', 'm.', 'plutonius', 'm', 'melpt', 'mahella', 'australiensis', 'm.', 'australiensis', 'm', 'maha5', 'cellulomonas', 'fimi', 'c.', 'fimi', 'c', 'celfa', 'haliscomenobacter', 'hydrossis', 'h.', 'hydrossis', 'h', 'halh1', 'sphaerochaeta', 'globosa', 's.', 'globosa', 's', 'sphgb', 'cellulosilyticum', 'lentocellum', 'c.', 'lentocellum', 'c', 'celld', 'agaricus', 'bisporus', 'a.', 'bisporus', 'a', 'agabu', 'neurospora', 'tetrasperma', 'n.', 'tetrasperma', 'n', 'neut9', 'lactococcus', 'garvieae', 'l.', 'garvieae', 'l', 'lacgl', 'trypanosoma', 'brucei', 't.', 'brucei', 't', 'tryb2', 'desulforudis', 'audaxviator', 'd.', 'audaxviator', 'd', 'desap', 'caenorhabditis', 'briggsae', 'c.', 'briggsae', 'c', 'caebr', 'heliobacterium', 'modesticaldum', 'h.', 'modesticaldum', 'h', 'helmi', 'acholeplasma', 'laidlawii', 'a.', 'laidlawii', 'a', 'achli', 'desulfosudis', 'oleivorans', 'd.', 'oleivorans', 'd', 'desoh', 'cucumber', 'necrosis', 'c.', 'necrosis', 'c', 'cnv', 'cymbidium', 'ringspot', 'c.', 'ringspot', 'c', 'crv', 'bovine', 'ephemeral', 'b.', 'ephemeral', 'b', 'befvb', 'yaba', 'monkey', 'y.', 'monkey', 'y', 'ymtv5', 'fowlpox', 'virus', 'f.', 'virus', 'f', 'fowpn', 'escherichia', 'coli', 'e.', 'coli', 'e', 'eco8n', 'figwort', 'mosaic', 'f.', 'mosaic', 'f', 'fmvd', 'bacteroides', 'helcogenes', 'b.', 'helcogenes', 'b', 'bact6', 'isosphaera', 'pallida', 'i.', 'pallida', 'i', 'isopi', 'pseudoxanthomonas', 'suwonensis', 'p.', 'suwonensis', 'p', 'pseuu', 'nitratifractor', 'salsuginis', 'n.', 'salsuginis', 'n', 'nitse', 'deinococcus', 'maricopensis', 'd.', 'maricopensis', 'd', 'deiml', 'weeksella', 'virosa', 'w.', 'virosa', 'w', 'weevc', 'latimeria', 'chalumnae', 'l.', 'chalumnae', 'l', 'latch', 'ogataea', 'parapolymorpha', 'o.', 'parapolymorpha', 'o', 'ogapd', 'salinibacter', 'ruber', 's.', 'ruber', 's', 'salrd', 'methanobrevibacter', 'ruminantium', 'm.', 'ruminantium', 'm', 'metrm', 'arabidopsis', 'lyrata', 'a.', 'lyrata', 'a', 'arall', 'verticillium', 'alfalfae', 'v.', 'alfalfae', 'v', 'vera1', 'chlorobium', 'phaeobacteroides', 'c.', 'phaeobacteroides', 'c', 'chlpd', 'bifidobacterium', 'adolescentis', 'b.', 'adolescentis', 'b', 'bifaa', 'paludibacter', 'propionicigenes', 'p.', 'propionicigenes', 'p', 'palpw', 'marivirga', 'tractuosa', 'm.', 'tractuosa', 'm', 'marth', 'sulfuricurvum', 'kujiense', 's.', 'kujiense', 's', 'sulky', 'oceanithermus', 'profundus', 'o.', 'profundus', 'o', 'ocep5', 'capsaspora', 'owczarzaki', 'c.', 'owczarzaki', 'c', 'capo3', 'drosophila', 'persimilis', 'd.', 'persimilis', 'd', 'drope', 'frog', 'virus', 'f.', 'virus', 'f', 'frg3g', 'torque', 'teno', 't.', 'teno', 't', 'ttva1', 'torque', 'teno', 't.', 'teno', 't', 'ttvb1', 'torque', 'teno', 't.', 'teno', 't', 'ttve1', 'torque', 'teno', 't.', 'teno', 't', 'ttvf1', 'colletotrichum', 'graminicola', 'c.', 'graminicola', 'c', 'colgm', 'puccinia', 'graminis', 'p.', 'graminis', 'p', 'pucgt', 'arthrobotrys', 'oligospora', 'a.', 'oligospora', 'a', 'artoa', 'fringilla', 'coelebs', 'f.', 'coelebs', 'f', 'fcpvn', 'psittacus', 'erithacus', 'p.', 'erithacus', 'p', 'pepva', 'drosophila', 'virilis', 'd.', 'virilis', 'd', 'drovi', 'erwinia', 'billingiae', 'e.', 'billingiae', 'e', 'erwbe', 'erythrobacter', 'litoralis', 'e.', 'litoralis', 'e', 'erylh', 'brachypodium', 'distachyon', 'b.', 'distachyon', 'b', 'bradi', 'metamycoplasma', 'arthritidis', 'm.', 'arthritidis', 'm', 'meta1', 'burkholderia', 'multivorans', 'b.', 'multivorans', 'b', 'burm1', 'staphylococcus', 'aureus', 's.', 'aureus', 's', 'staa8', 'aedes', 'aegypti', 'a.', 'aegypti', 'a', 'aedae', 'citrifermentans', 'bemidjiense', 'c.', 'bemidjiense', 'c', 'citbb', 'glycine', 'max', 'g.', 'max', 'g', 'soy', 'soybean', 'bean', 'soybn', 'malassezia', 'globosa', 'm.', 'globosa', 'm', 'malgo', 'kocuria', 'rhizophila', 'k.', 'rhizophila', 'k', 'kocrd', 'stenotrophomonas', 'maltophilia', 's.', 'maltophilia', 's', 'strmk', 'chlorobium', 'limicola', 'c.', 'limicola', 'c', 'chll2', 'pelagibacterium', 'halotolerans', 'p.', 'halotolerans', 'p', 'pelhb', 'schistosoma', 'mansoni', 's.', 'mansoni', 's', 'schma', 'trichophyton', 'rubrum', 't.', 'rubrum', 't', 'trirc', 'arthroderma', 'benhamiae', 'a.', 'benhamiae', 'a', 'artbc', 'alcanivorax', 'borkumensis', 'a.', 'borkumensis', 'a', 'alcbs', 'methylomonas', 'methanica', 'm.', 'methanica', 'm', 'metmm', 'capnocytophaga', 'canimorsus', 'c.', 'canimorsus', 'c', 'capcc', 'zobellia', 'galactanivorans', 'z.', 'galactanivorans', 'z', 'zobga', 'muricauda', 'ruestringensis', 'm.', 'ruestringensis', 'm', 'murrd', 'ailuropoda', 'melanoleuca', 'a.', 'melanoleuca', 'a', 'ailme', 'intrasporangium', 'calvum', 'i.', 'calvum', 'i', 'intc7', 'thermaerobacter', 'marianensis', 't.', 'marianensis', 't', 'them7', 'variovorax', 'paradoxus', 'v.', 'paradoxus', 'v', 'varpe', 'anaerolinea', 'thermophila', 'a.', 'thermophila', 'a', 'anatu', 'groundnut', 'rosette', 'g.', 'rosette', 'g', 'grvmc', 'eggerthella', 'sp', 'e.', 'sp', 'e', 'eegsy', 'clostridium', 'sp', 'c.', 'sp', 'c', 'closs', 'anaerostipes', 'hadrus', 'a.', 'hadrus', 'a', 'anaha', 'halobacteriovorax', 'marinus', 'h.', 'marinus', 'h', 'halms', 'ichthyophthirius', 'multifiliis', 'i.', 'multifiliis', 'i', 'ichmu', 'hypocrea', 'jecorina', 'h.', 'jecorina', 'h', 'hypjq', 'mycoplasma', 'wenyonii', 'm.', 'wenyonii', 'm', 'mycwm', 'methanoculleus', 'bourgensis', 'm.', 'bourgensis', 'm', 'metbm', 'rahnella', 'aquatilis', 'r.', 'aquatilis', 'r', 'rahac', 'melioribacter', 'roseus', 'm.', 'roseus', 'm', 'melrp', 'trichoplax', 'adhaerens', 't.', 'adhaerens', 't', 'triad', 'pediculus', 'humanus', 'p.', 'humanus', 'p', 'pedhc', 'desulfarculus', 'baarsii', 'd.', 'baarsii', 'd', 'desb2', 'robiginitalea', 'biformata', 'r.', 'biformata', 'r', 'robbh', 'magnaporthe', 'oryzae', 'm.', 'oryzae', 'm', 'mago7', 'european', 'elk', 'e.', 'elk', 'e', 'papve', 'shigella', 'phage', 's.', 'phage', 's', 'bpsf5', 'mesomycoplasma', 'mobile', 'm.', 'mobile', 'm', 'mesm1', 'tolumonas', 'auensis', 't.', 'auensis', 't', 'tolat', 'streptococcus', 'suis', 's.', 'suis', 's', 'strs4', 'thermococcus', 'sibiricus', 't.', 'sibiricus', 't', 'thesm', 'teredinibacter', 'turnerae', 't.', 'turnerae', 't', 'tertt', 'methylorubrum', 'extorquens', 'm.', 'extorquens', 'm', 'metea', 'nosema', 'ceranae', 'n.', 'ceranae', 'n', 'nosce', 'streptococcus', 'phage', 's.', 'phage', 's', 'bpcp1', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpspb', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpp2', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpp4', 'gibberella', 'moniliformis', 'g.', 'moniliformis', 'g', 'gibm7', 'halothiobacillus', 'neapolitanus', 'h.', 'neapolitanus', 'h', 'halnc', 'mixia', 'osmundae', 'm.', 'osmundae', 'm', 'mixos', 'novosphingobium', 'aromaticivorans', 'n.', 'aromaticivorans', 'n', 'novad', 'mycoplasma', 'haemocanis', 'm.', 'haemocanis', 'm', 'mychn', 'rhizopus', 'delemar', 'r.', 'delemar', 'r', 'rhio9', 'methylophaga', 'frappieri', 'm.', 'frappieri', 'm', 'metfj', 'gordonia', 'polyisoprenivorans', 'g.', 'polyisoprenivorans', 'g', 'gorpv', 'ostreococcus', 'tauri', 'o.', 'tauri', 'o', 'ostta', 'heterosigma', 'akashiwo', 'h.', 'akashiwo', 'h', 'hav01', 'shewanella', 'amazonensis', 's.', 'amazonensis', 's', 'sheam', 'pelagibacter', 'sp', 'p.', 'sp', 'p', 'pelsm', 'vitis', 'vinifera', 'v.', 'vinifera', 'v', 'vitvi', 'flavobacterium', 'branchiophilum', 'f.', 'branchiophilum', 'f', 'flabf', 'drosophila', 'mojavensis', 'd.', 'mojavensis', 'd', 'dromo', 'leadbettera', 'azotonutricia', 'l.', 'azotonutricia', 'l', 'leaaz', 'treponema', 'primitia', 't.', 'primitia', 't', 'trepz', 'mycolicibacter', 'sinensis', 'm.', 'sinensis', 'm', 'mycsd', 'desulfotomaculum', 'nigrificans', 'd.', 'nigrificans', 'd', 'descc', 'methanotorris', 'igneus', 'm.', 'igneus', 'm', 'metik', 'thiomicrospira', 'cyclica', 't.', 'cyclica', 't', 'thica', 'desulforamulus', 'ruminis', 'd.', 'ruminis', 'd', 'desrl', 'hoyosella', 'subflava', 'h.', 'subflava', 'h', 'hoysd', 'isoptericola', 'variabilis', 'i.', 'variabilis', 'i', 'isov2', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv7j', 'frog', 'adenovirus', 'f.', 'adenovirus', 'f', 'adef1', 'citrus', 'psorosis', 'c.', 'psorosis', 'c', 'cpsvp', 'glaciecola', 'nitratireducens', 'g.', 'nitratireducens', 'g', 'glanf', 'taylorella', 'asinigenitalis', 't.', 'asinigenitalis', 't', 'tayam', 'micavibrio', 'aeruginosavorus', 'm.', 'aeruginosavorus', 'm', 'micaa', 'ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a', 'ajecn', 'wickerhamomyces', 'ciferrii', 'w.', 'ciferrii', 'w', 'wiccf', 'halorubrum', 'pleomorphic', 'h.', 'pleomorphic', 'h', 'hapv1', 'penicillium', 'digitatum', 'p.', 'digitatum', 'p', 'pend2', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpm', 'enterococcus', 'italicus', 'e.', 'italicus', 'e', 'enti1', 'micromonospora', 'sp', 'm.', 'sp', 'm', 'mics3', 'chamaesiphon', 'minutus', 'c.', 'minutus', 'c', 'chap6', 'nostoc', 'sp', 'n.', 'sp', 'n', 'noss7', 'synechococcus', 'sp', 's.', 'sp', 's', 'synp3', 'chroococcidiopsis', 'thermalis', 'c.', 'thermalis', 'c', 'chrtp', 'pneumocystis', 'jirovecii', 'p.', 'jirovecii', 'p', 'pneji', 'mycoplasmopsis', 'cynos', 'm.', 'cynos', 'm', 'mycc1', 'deinococcus', 'peraridilitoris', 'd.', 'peraridilitoris', 'd', 'deipd', 'natronobacterium', 'gregoryi', 'n.', 'gregoryi', 'n', 'natgs', 'caldisphaera', 'lagunensis', 'c.', 'lagunensis', 'c', 'calld', 'stanieria', 'cyanosphaera', 's.', 'cyanosphaera', 's', 'stac7', 'cyanobacterium', 'aponinum', 'c.', 'aponinum', 'c', 'cyaap', 'halothece', 'sp', 'h.', 'sp', 'h', 'halp7', 'cyanobacterium', 'stanieri', 'c.', 'stanieri', 'c', 'cyasc', 'pteropus', 'alecto', 'p.', 'alecto', 'p', 'pteal', 'myotis', 'davidii', 'm.', 'davidii', 'm', 'myods', 'caldalkalibacillus', 'thermarum', 'c.', 'thermarum', 'c', 'caltt', 'thermobacillus', 'composti', 't.', 'composti', 't', 'theck', 'echinicola', 'vietnamensis', 'e.', 'vietnamensis', 'e', 'echvk', 'desulfitobacterium', 'dichloroeliminans', 'd.', 'dichloroeliminans', 'd', 'desdl', 'singulisphaera', 'acidiphila', 's.', 'acidiphila', 's', 'sinad', 'liberibacter', 'crescens', 'l.', 'crescens', 'l', 'libcb', 'tepidanaerobacter', 'acetatoxydans', 't.', 'acetatoxydans', 't', 'tepae', 'methanoregula', 'formicica', 'm.', 'formicica', 'm', 'metfs', 'natrinema', 'pellirubrum', 'n.', 'pellirubrum', 'n', 'natp1', 'halovivax', 'ruber', 'h.', 'ruber', 'h', 'halrx', 'prevotella', 'dentalis', 'p.', 'dentalis', 'p', 'predd', 'methanomethylovorans', 'hollandica', 'm.', 'hollandica', 'm', 'methd', 'halobacteroides', 'halobius', 'h.', 'halobius', 'h', 'halhc', 'mesorhizobium', 'australicum', 'm.', 'australicum', 'm', 'mesaw', 'enterobacteriaceae', 'bacterium', 'e.', 'bacterium', 'e', 'entbf', 'pseudogymnoascus', 'destructans', 'p.', 'destructans', 'p', 'psed2', 'vavraia', 'culicis', 'v.', 'culicis', 'v', 'vavcu', 'vittaforma', 'corneae', 'v.', 'corneae', 'v', 'vitco', 'guillardia', 'theta', 'g.', 'theta', 'g', 'guitc', 'colletotrichum', 'fructicola', 'c.', 'fructicola', 'c', 'colfn', 'solanum', 'tuberosum', 's.', 'tuberosum', 's', 'soltu', 'hordeum', 'vulgare', 'h.', 'vulgare', 'h', 'horvv', 'selenomonas', 'sputigena', 's.', 'sputigena', 's', 'sels3', 'thermoclostridium', 'stercorarium', 't.', 'stercorarium', 't', 'thes1', 'atlantic', 'salmon', 'a.', 'salmon', 'a', 'aspvr', 'ferdelance', 'paramyxovirus', 'f.', 'paramyxovirus', 'f', 'fdlv8', 'rhizosolenia', 'setigera', 'r.', 'setigera', 'r', 'rset1', 'aurantiochytrium', 'singlestranded', 'a.', 'singlestranded', 'a', 'aurn1', 'potato', 'virus', 'p.', 'virus', 'p', 'pvt92', 'heterocapsa', 'circularisquama', 'h.', 'circularisquama', 'h', 'hcrna', 'tobacco', 'vein', 't.', 'vein', 't', 'tvcvl', 'providence', 'virus', 'p.', 'virus', 'p', 'prvfl', 'trichomonas', 'vaginalis', 't.', 'vaginalis', 't', 'ttv1', 'rosellinia', 'necatrix', 'r.', 'necatrix', 'r', 'rmbv1', 'natrinema', 'altunense', 'n.', 'altunense', 'n', 'nata2', 'tupaia', 'chinensis', 't.', 'chinensis', 't', 'tupch', 'natrialba', 'asiatica', 'n.', 'asiatica', 'n', 'nata1', 'nitrospina', 'gracilis', 'n.', 'gracilis', 'n', 'nitg3', 'felis', 'catus', 'f.', 'catus', 'f', 'felca', 'hyaloperonospora', 'arabidopsidis', 'h.', 'arabidopsidis', 'h', 'hyaae', 'magnaporthiopsis', 'poae', 'm.', 'poae', 'm', 'magp6', 'desulfocapsa', 'sulfexigens', 'd.', 'sulfexigens', 'd', 'dessd', 'pseudodesulfovibrio', 'piezophilus', 'p.', 'piezophilus', 'p', 'psep2', 'brassica', 'rapa', 'b.', 'rapa', 'b', 'brarp', 'baudoinia', 'panamericana', 'b.', 'panamericana', 'b', 'baupa', 'candida', 'maltosa', 'c.', 'maltosa', 'c', 'canmx', 'thrush', 'coronavirus', 't.', 'coronavirus', 't', 'thcov', 'ilumatobacter', 'coccineus', 'i.', 'coccineus', 'i', 'ilucy', 'natronomonas', 'moolapensis', 'n.', 'moolapensis', 'n', 'natm8', 'pneumocystis', 'murina', 'p.', 'murina', 'p', 'pnemu', 'pseudozyma', 'antarctica', 'p.', 'antarctica', 'p', 'psea3', 'chondrus', 'crispus', 'c.', 'crispus', 'c', 'chocr', 'thermoplasmatales', 'archaeon', 't.', 'archaeon', 't', 'thexx', 'eutypa', 'lata', 'e.', 'lata', 'e', 'eutla', 'methanomethylophilus', 'alvus', 'm.', 'alvus', 'm', 'metax', 'musa', 'acuminata', 'm.', 'acuminata', 'm', 'musam', 'thauera', 'linaloolentis', 't.', 'linaloolentis', 't', 'thal4', 'botryosphaeria', 'parva', 'b.', 'parva', 'b', 'botpv', 'taphrina', 'deformans', 't.', 'deformans', 't', 'tapde', 'emiliania', 'huxleyi', 'e.', 'huxleyi', 'e', 'emihu', 'wallemia', 'ichthyophaga', 'w.', 'ichthyophaga', 'w', 'wali9', 'methanomassiliicoccus', 'intestinalis', 'm.', 'intestinalis', 'm', 'metii', 'pseudozyma', 'hubeiensis', 'p.', 'hubeiensis', 'p', 'psehs', 'phaeoacremonium', 'minimum', 'p.', 'minimum', 'p', 'pham7', 'chthonomonas', 'calidirosea', 'c.', 'calidirosea', 'c', 'chtct', 'mucor', 'circinelloides', 'm.', 'circinelloides', 'm', 'mucc1', 'halomonas', 'anticariensis', 'h.', 'anticariensis', 'h', 'halaf', 'colletotrichum', 'orbiculare', 'c.', 'orbiculare', 'c', 'color', 'strigamia', 'maritima', 's.', 'maritima', 's', 'strmm', 'capitella', 'teleta', 'c.', 'teleta', 'c', 'capte', 'dactylellina', 'haptotyla', 'd.', 'haptotyla', 'd', 'dacha', 'helobdella', 'robusta', 'h.', 'robusta', 'h', 'helro', 'megaselia', 'scalaris', 'm.', 'scalaris', 'm', 'megsc', 'rhodnius', 'prolixus', 'r.', 'prolixus', 'r', 'rhopr', 'tetranychus', 'urticae', 't.', 'urticae', 't', 'tetur', 'aegilops', 'tauschii', 'a.', 'tauschii', 'a', 'aegts', 'triticum', 'urartu', 't.', 'urartu', 't', 'triua', 'fomitopsis', 'pinicola', 'f.', 'pinicola', 'f', 'fompi', 'streptomyces', 'collinus', 's.', 'collinus', 's', 'strc3', 'blumeria', 'graminis', 'b.', 'graminis', 'b', 'blug1', 'schizosaccharomyces', 'cryophilus', 's.', 'cryophilus', 's', 'schcr', 'colletotrichum', 'gloeosporioides', 'c.', 'gloeosporioides', 'c', 'colgc', 'sulfuricella', 'denitrificans', 's.', 'denitrificans', 's', 'sulds', 'formosa', 'agariphila', 'f.', 'agariphila', 'f', 'forag', 'pseudomonas', 'alcaligenes', 'p.', 'alcaligenes', 'p', 'psea4', 'megalodesulfovibrio', 'gigas', 'm.', 'gigas', 'm', 'megg1', 'ficedula', 'albicollis', 'f.', 'albicollis', 'f', 'fical', 'anas', 'platyrhynchos', 'a.', 'platyrhynchos', 'a', 'anapp', 'gibberella', 'fujikuroi', 'g.', 'fujikuroi', 'g', 'gibf5', 'claviceps', 'purpurea', 'c.', 'purpurea', 'c', 'clap2', 'glarea', 'lozoyensis', 'g.', 'lozoyensis', 'g', 'glal2', 'ophiostoma', 'piceae', 'o.', 'piceae', 'o', 'ophp1', 'coniosporium', 'apollinis', 'c.', 'apollinis', 'c', 'cona1', 'fusarium', 'oxysporum', 'f.', 'oxysporum', 'f', 'fusc1', 'fusarium', 'oxysporum', 'f.', 'oxysporum', 'f', 'fusc4', 'ceriporiopsis', 'subvermispora', 'c.', 'subvermispora', 'c', 'cers8', 'sphaerulina', 'musiva', 's.', 'musiva', 's', 'sphms', 'pseudocercospora', 'fijiensis', 'p.', 'fijiensis', 'p', 'psefd', 'dothistroma', 'septosporum', 'd.', 'septosporum', 'd', 'dotsn', 'cochliobolus', 'sativus', 'c.', 'sativus', 'c', 'cocsn', 'exserohilum', 'turcicum', 'e.', 'turcicum', 'e', 'exst2', 'cochliobolus', 'heterostrophus', 'c.', 'heterostrophus', 'c', 'coch5', 'microbotryum', 'lychnidisdioicae', 'm.', 'lychnidisdioicae', 'm', 'ustv1', 'moniliophthora', 'roreri', 'm.', 'roreri', 'm', 'monro', 'serratia', 'sp', 's.', 'sp', 's', 'sers3', 'amborella', 'trichopoda', 'a.', 'trichopoda', 'a', 'ambtc', 'byssochlamys', 'spectabilis', 'b.', 'spectabilis', 'b', 'byssn', 'sporothrix', 'schenckii', 's.', 'schenckii', 's', 'spos1', 'succinatimonas', 'hippei', 's.', 'hippei', 's', 'suchy', 'astyanax', 'mexicanus', 'a.', 'mexicanus', 'a', 'astmx', 'lepisosteus', 'oculatus', 'l.', 'oculatus', 'l', 'lepoc', 'phytophthora', 'parasitica', 'p.', 'parasitica', 'p', 'phypn', 'alkalihalobacillus', 'akibai', 'a.', 'akibai', 'a', 'alka3', 'magnetospirillum', 'gryphiswaldense', 'm.', 'gryphiswaldense', 'm', 'maggm', 'ophiophagus', 'hannah', 'o.', 'hannah', 'o', 'ophha', 'advenella', 'mimigardefordensis', 'a.', 'mimigardefordensis', 'a', 'advmd', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'plafp', 'triticum', 'aestivum', 't.', 'aestivum', 't', 'wheat', 'globisporangium', 'ultimum', 'g.', 'ultimum', 'g', 'gloud', 'echinococcus', 'granulosus', 'e.', 'granulosus', 'e', 'echgr', 'endocarpon', 'pusillum', 'e.', 'pusillum', 'e', 'endpu', 'ophiocordyceps', 'sinensis', 'o.', 'sinensis', 'o', 'ophsc', 'penicillium', 'oxalicum', 'p.', 'oxalicum', 'p', 'peno1', 'kalmanozyma', 'brasiliensis', 'k.', 'brasiliensis', 'k', 'kalbg', 'sclerotinia', 'borealis', 's.', 'borealis', 's', 'sclbf', 'aspergillus', 'ruber', 'a.', 'ruber', 'a', 'asprc', 'accumulibacter', 'regalis', 'a.', 'regalis', 'a', 'accre', 'sphingobium', 'herbicidovorans', 's.', 'herbicidovorans', 's', 'sphhm', 'onchocerca', 'volvulus', 'o.', 'volvulus', 'o', 'oncvo', 'trichophyton', 'interdigitale', 't.', 'interdigitale', 't', 'triim', 'pseudomonas', 'knackmussii', 'p.', 'knackmussii', 'p', 'psekb', 'theobroma', 'cacao', 't.', 'cacao', 't', 'thecc', 'streptomyces', 'noursei', 's.', 'noursei', 's', 'strnr', 'oryza', 'punctata', 'o.', 'punctata', 'o', 'orypu', 'ustilaginoidea', 'virens', 'u.', 'virens', 'u', 'ustvr', 'citrus', 'sinensis', 'c.', 'sinensis', 'c', 'citsi', 'zootermopsis', 'nevadensis', 'z.', 'nevadensis', 'z', 'zoone', 'jatropha', 'curcas', 'j.', 'curcas', 'j', 'jatcu', 'galerina', 'marginata', 'g.', 'marginata', 'g', 'galm3', 'colletotrichum', 'sublineola', 'c.', 'sublineola', 'c', 'colsu', 'hydrogenovibrio', 'marinus', 'h.', 'marinus', 'h', 'hydmr', 'tilletiaria', 'anomala', 't.', 'anomala', 't', 'tilau', 'bacillus', 'methanolicus', 'b.', 'methanolicus', 'b', 'bacmm', 'erythrobacter', 'longus', 'e.', 'longus', 'e', 'erylo', 'salinisphaera', 'hydrothermalis', 's.', 'hydrothermalis', 's', 'salhc', 'streptomyces', 'toyocaensis', 's.', 'toyocaensis', 's', 'strto', 'stachybotrys', 'chlorohalonata', 's.', 'chlorohalonata', 's', 'stac4', 'pseudallescheria', 'apiosperma', 'p.', 'apiosperma', 'p', 'pseda', 'metabacillus', 'indicus', 'm.', 'indicus', 'm', 'metid', 'chryseobacterium', 'sp', 'c.', 'sp', 'c', 'chrp1', 'poecilia', 'formosa', 'p.', 'formosa', 'p', 'poefo', 'papio', 'anubis', 'p.', 'anubis', 'p', 'papan', 'mycolicibacterium', 'cosmeticum', 'm.', 'cosmeticum', 'm', 'mycco', 'auxenochlorella', 'protothecoides', 'a.', 'protothecoides', 'a', 'auxpr', 'fukomys', 'damarensis', 'f.', 'damarensis', 'f', 'fukda', 'brassica', 'napus', 'b.', 'napus', 'b', 'brana', 'arabis', 'alpina', 'a.', 'alpina', 'a', 'araal', 'paenibacillus', 'macerans', 'p.', 'macerans', 'p', 'paema', 'streptomyces', 'glaucescens', 's.', 'glaucescens', 's', 'strga', 'pycnoporus', 'cinnabarinus', 'p.', 'cinnabarinus', 'p', 'pycci', 'alphamesonivirus', '1', 'a.', '1', 'a', 'amv79', 'cadicivirus', 'a', 'c.', 'a', 'c', 'cadiv', 'furcraea', 'necrotic', 'f.', 'necrotic', 'f', 'fnsvc', 'maize', 'necrotic', 'm.', 'necrotic', 'm', 'mnesv', 'nyamanini', 'virus', 'n.', 'virus', 'n', 'nymvt', 'galinsoga', 'mosaic', 'g.', 'mosaic', 'g', 'gamv', 'perch', 'rhabdovirus', 'p.', 'rhabdovirus', 'p', 'prvf', 'spring', 'viraemia', 's.', 'viraemia', 's', 'svcva', 'beet', 'curly', 'b.', 'curly', 'b', 'bctiv', 'eragrostis', 'curvula', 'e.', 'curvula', 'e', 'ecsvg', 'turnip', 'curly', 't.', 'curly', 't', 'tctvb', 'lloviu', 'cuevavirus', 'l.', 'cuevavirus', 'l', 'llova', 'southern', 'tomato', 's.', 'tomato', 's', 'stv', 'quaranfil', 'virus', 'q.', 'virus', 'q', 'qrfve', 'acremonium', 'chrysogenum', 'a.', 'chrysogenum', 'a', 'acrc1', 'chlorocebus', 'sabaeus', 'c.', 'sabaeus', 'c', 'chlsb', 'cucumis', 'sativus', 'c.', 'sativus', 'c', 'cucsa', 'penicillium', 'italicum', 'p.', 'italicum', 'p', 'penit', 'porphyromonas', 'cangingivalis', 'p.', 'cangingivalis', 'p', 'porcn', 'penicillium', 'expansum', 'p.', 'expansum', 'p', 'penen', 'nocardioides', 'simplex', 'n.', 'simplex', 'n', 'nocsi', 'aureobasidium', 'subglaciale', 'a.', 'subglaciale', 'a', 'aurse', 'weissella', 'oryzae', 'w.', 'oryzae', 'w', 'weios', 'pestalotiopsis', 'fici', 'p.', 'fici', 'p', 'pesfw', 'dacryopinax', 'primogenitus', 'd.', 'primogenitus', 'd', 'dacpd', 'gloeophyllum', 'trabeum', 'g.', 'trabeum', 'g', 'glota', 'heterobasidion', 'irregulare', 'h.', 'irregulare', 'h', 'hetit', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'malaria', 'plafo', 'galdieria', 'sulphuraria', 'g.', 'sulphuraria', 'g', 'galsu', 'camelus', 'ferus', 'c.', 'ferus', 'c', 'camfr', 'citrus', 'clementina', 'c.', 'clementina', 'c', 'citcl', 'eutrema', 'salsugineum', 'e.', 'salsugineum', 'e', 'eutsa', 'fonticula', 'alba', 'f.', 'alba', 'f', 'fonal', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'plafc', 'eucalyptus', 'grandis', 'e.', 'grandis', 'e', 'eucgr', 'dendroctonus', 'ponderosae', 'd.', 'ponderosae', 'd', 'denpd', 'saprolegnia', 'parasitica', 's.', 'parasitica', 's', 'sappc', 'lottia', 'gigantea', 'l.', 'gigantea', 'l', 'lotgi', 'erythranthe', 'guttata', 'e.', 'guttata', 'e', 'erygu', 'rozella', 'allomycis', 'r.', 'allomycis', 'r', 'rozac', 'saprolegnia', 'diclina', 's.', 'diclina', 's', 'sapdv', 'anopheles', 'sinensis', 'a.', 'sinensis', 'a', 'anosi', 'metarhizium', 'album', 'm.', 'album', 'm', 'metas', 'uncinula', 'necator', 'u.', 'necator', 'u', 'uncne', 'solemya', 'velum', 's.', 'velum', 's', 'sovgs', 'frischella', 'perrara', 'f.', 'perrara', 'f', 'fripe', 'toxocara', 'canis', 't.', 'canis', 't', 'toxca', 'chelonia', 'mydas', 'c.', 'mydas', 'c', 'chemy', 'brevibacterium', 'linens', 'b.', 'linens', 'b', 'breln', 'plasmodium', 'knowlesi', 'p.', 'knowlesi', 'p', 'plakh', 'chaetura', 'pelagica', 'c.', 'pelagica', 'c', 'chape', 'streptomyces', 'albus', 's.', 'albus', 's', 'stra4', 'bacillus', 'thermotolerans', 'b.', 'thermotolerans', 'b', 'bactr', 'bacillus', 'sp', 'b.', 'sp', 'b', 'bacsx', 'burkholderia', 'plantarii', 'b.', 'plantarii', 'b', 'burpl', 'bacillus', 'badius', 'b.', 'badius', 'b', 'bacba', 'kitasatospora', 'griseola', 'k.', 'griseola', 'k', 'kitgr', 'gossypium', 'raimondii', 'g.', 'raimondii', 'g', 'gosra', 'rhodococcus', 'sp', 'r.', 'sp', 'r', 'rhosx', 'tatlockia', 'micdadei', 't.', 'micdadei', 't', 'tatmi', 'rhodopseudomonas', 'palustris', 'r.', 'palustris', 'r', 'rhopl', 'martelella', 'endophytica', 'm.', 'endophytica', 'm', 'maren', 'magnetospira', 'sp', 'm.', 'sp', 'm', 'magsq', 'alteracholeplasma', 'palmae', 'a.', 'palmae', 'a', 'altpj', 'defluviitoga', 'tunisiensis', 'd.', 'tunisiensis', 'd', 'deftu', 'clostridium', 'scatologenes', 'c.', 'scatologenes', 'c', 'closl', 'saitoella', 'complicata', 's.', 'complicata', 's', 'saicn', 'babesia', 'bigemina', 'b.', 'bigemina', 'b', 'babbi', 'lentzea', 'aerocolonigenes', 'l.', 'aerocolonigenes', 'l', 'lenae', 'aspergillus', 'parasiticus', 'a.', 'parasiticus', 'a', 'asppu', 'streptomyces', 'rubellomurinus', 's.', 'rubellomurinus', 's', 'strr3', 'trichoderma', 'harzianum', 't.', 'harzianum', 't', 'triha', 'serratia', 'fonticola', 's.', 'fonticola', 's', 'serfo', 'scleropages', 'formosus', 's.', 'formosus', 's', 'sclfo', 'ceratocystis', 'fimbriata', 'c.', 'fimbriata', 'c', 'cerfi', 'variovorax', 'paradoxus', 'v.', 'paradoxus', 'v', 'varpd', 'strongyloides', 'venezuelensis', 's.', 'venezuelensis', 's', 'strvs', 'strongyloides', 'stercoralis', 's.', 'stercoralis', 's', 'strer', 'strongyloides', 'ratti', 's.', 'ratti', 's', 'strrb', 'beta', 'vulgaris', 'b.', 'vulgaris', 'b', 'betvv', 'niallia', 'circulans', 'n.', 'circulans', 'n', 'niaci', 'mycolicibacterium', 'chubuense', 'm.', 'chubuense', 'm', 'myccu', 'pluralibacter', 'gergoviae', 'p.', 'gergoviae', 'p', 'pluge', 'virgibacillus', 'pantothenticus', 'v.', 'pantothenticus', 'v', 'virpa', 'tolypocladium', 'ophioglossoides', 't.', 'ophioglossoides', 't', 'toloc', 'zostera', 'marina', 'z.', 'marina', 'z', 'zosmr', 'lucilia', 'cuprina', 'l.', 'cuprina', 'l', 'luccu', 'ophiocordyceps', 'unilateralis', 'o.', 'unilateralis', 'o', 'ophun', 'gottschalkia', 'purinilytica', 'g.', 'purinilytica', 'g', 'gotpu', 'aneurinibacillus', 'migulanus', 'a.', 'migulanus', 'a', 'anemi', 'kitasatospora', 'aureofaciens', 'k.', 'aureofaciens', 'k', 'kitau', 'vibrio', 'nereis', 'v.', 'nereis', 'v', 'vibne', 'ideonella', 'sakaiensis', 'i.', 'sakaiensis', 'i', 'idesa', 'fusarium', 'langsethiae', 'f.', 'langsethiae', 'f', 'fusla', 'plasmodiophora', 'brassicae', 'p.', 'brassicae', 'p', 'plabs', 'stylonychia', 'lemnae', 's.', 'lemnae', 's', 'style', 'vitrella', 'brassicaformis', 'v.', 'brassicaformis', 'v', 'vitbc', 'treponema', 'phagedenis', 't.', 'phagedenis', 't', 'treph', 'penicillium', 'brasilianum', 'p.', 'brasilianum', 'p', 'penbi', 'alligator', 'mississippiensis', 'a.', 'mississippiensis', 'a', 'allmi', 'wenjunlia', 'vitaminophila', 'w.', 'vitaminophila', 'w', 'wenvi', 'vibrio', 'furnissii', 'v.', 'furnissii', 'v', 'vibfu', 'thalassobius', 'gelatinovorus', 't.', 'gelatinovorus', 't', 'thage', 'amazona', 'aestiva', 'a.', 'aestiva', 'a', 'amaae', 'weissella', 'viridescens', 'w.', 'viridescens', 'w', 'weivi', 'caloramator', 'mitchellensis', 'c.', 'mitchellensis', 'c', 'calmk', 'chaetoceros', 'protobacilladnavirus', 'c.', 'protobacilladnavirus', 'c', 'cpbdv', 'phytophthora', 'nicotianae', 'p.', 'nicotianae', 'p', 'phyni', 'merops', 'nubicus', 'm.', 'nubicus', 'm', 'mernu', 'corvus', 'brachyrhynchos', 'c.', 'brachyrhynchos', 'c', 'corbr', 'myotis', 'brandtii', 'm.', 'brandtii', 'm', 'myobr', 'leptosomus', 'discolor', 'l.', 'discolor', 'l', 'lepdc', 'ooceraea', 'biroi', 'o.', 'biroi', 'o', 'oocbi', 'egretta', 'garzetta', 'e.', 'garzetta', 'e', 'egrga', 'phaseolus', 'angularis', 'p.', 'angularis', 'p', 'phaan', 'spizellomyces', 'punctatus', 's.', 'punctatus', 's', 'spipd', 'phalacrocorax', 'carbo', 'p.', 'carbo', 'p', 'phaca', 'papilio', 'machaon', 'p.', 'machaon', 'p', 'papma', 'papilio', 'xuthus', 'p.', 'xuthus', 'p', 'papxu', 'nanobsidianus', 'stetteri', 'n.', 'stetteri', 'n', 'nanst', 'nipponia', 'nippon', 'n.', 'nippon', 'n', 'nipni', 'aptenodytes', 'forsteri', 'a.', 'forsteri', 'a', 'aptfo', 'dichomitus', 'squalens', 'd.', 'squalens', 'd', 'dicsq', 'pyrodictium', 'occultum', 'p.', 'occultum', 'p', 'pyroc', 'pneumocystis', 'jirovecii', 'p.', 'jirovecii', 'p', 'pnej7', 'octopus', 'bimaculoides', 'o.', 'bimaculoides', 'o', 'octbm', 'aspergillus', 'ustus', 'a.', 'ustus', 'a', 'asput', 'coniophora', 'puteana', 'c.', 'puteana', 'c', 'conpw', 'opisthocomus', 'hoazin', 'o.', 'hoazin', 'o', 'opiho', 'colius', 'striatus', 'c.', 'striatus', 'c', 'colst', 'antrostomus', 'carolinensis', 'a.', 'carolinensis', 'a', 'antcr', 'phaethon', 'lepturus', 'p.', 'lepturus', 'p', 'phalp', 'tinamus', 'guttatus', 't.', 'guttatus', 't', 'tingu', 'tauraco', 'erythrolophus', 't.', 'erythrolophus', 't', 'tauer', 'necator', 'americanus', 'n.', 'americanus', 'n', 'necam', 'cathartes', 'aura', 'c.', 'aura', 'c', 'catau', 'pseudozyma', 'antarctica', 'p.', 'antarctica', 'p', 'psea2', 'dictyocaulus', 'viviparus', 'd.', 'viviparus', 'd', 'dicvi', 'fulmarus', 'glacialis', 'f.', 'glacialis', 'f', 'fulga', 'nestor', 'notabilis', 'n.', 'notabilis', 'n', 'nesno', 'podiceps', 'cristatus', 'p.', 'cristatus', 'p', 'podcr', 'charadrius', 'vociferus', 'c.', 'vociferus', 'c', 'chavo', 'columba', 'livia', 'c.', 'livia', 'c', 'colli', 'dryobates', 'pubescens', 'd.', 'pubescens', 'd', 'drypu', 'rhodotorula', 'graminis', 'r.', 'graminis', 'r', 'rhogw', 'pygoscelis', 'adeliae', 'p.', 'adeliae', 'p', 'pygad', 'spinacia', 'oleracea', 's.', 'oleracea', 's', 'spiol', 'cariama', 'cristata', 'c.', 'cristata', 'c', 'caric', 'pelecanus', 'crispus', 'p.', 'crispus', 'p', 'pelcr', 'tyto', 'alba', 't.', 'alba', 't', 'tytal', 'punctularia', 'strigosozonata', 'p.', 'strigosozonata', 'p', 'punst', 'eurypyga', 'helias', 'e.', 'helias', 'e', 'eurhl', 'apaloderma', 'vittatum', 'a.', 'vittatum', 'a', 'apavi', 'hypholoma', 'sublateritium', 'h.', 'sublateritium', 'h', 'hypsf', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'plaf4', 'plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'plafx', 'exophiala', 'mesophila', 'e.', 'mesophila', 'e', 'exome', 'calypte', 'anna', 'c.', 'anna', 'c', 'calan', 'gavia', 'stellata', 'g.', 'stellata', 'g', 'gavst', 'allomyces', 'macrogynus', 'a.', 'macrogynus', 'a', 'allm3', 'fungal', 'sp', 'f.', 'sp', 'f', 'blob1', 'haliaeetus', 'albicilla', 'h.', 'albicilla', 'h', 'halal', 'talaromyces', 'islandicus', 't.', 'islandicus', 't', 'talis', 'rosellinia', 'necatrix', 'r.', 'necatrix', 'r', 'rosne', 'actinoplanes', 'utahensis', 'a.', 'utahensis', 'a', 'actut', 'tremella', 'mesenterica', 't.', 'mesenterica', 't', 'trems', 'klebsormidium', 'nitens', 'k.', 'nitens', 'k', 'kleni', 'trichinella', 'britovi', 't.', 'britovi', 't', 'tribr', 'aspergillus', 'calidoustus', 'a.', 'calidoustus', 'a', 'aspci', 'trichinella', 'spiralis', 't.', 'spiralis', 't', 'trisp', 'trichinella', 'pseudospiralis', 't.', 'pseudospiralis', 't', 'trips', 'legionella', 'spiritensis', 'l.', 'spiritensis', 'l', 'legsp', 'pseudocohnilembus', 'persalinus', 'p.', 'persalinus', 'p', 'psepj', 'anaplasma', 'phagocytophilum', 'a.', 'phagocytophilum', 'a', 'anaph', 'bacteroides', 'stercoris', 'b.', 'stercoris', 'b', 'bacse', 'mycolicibacterium', 'fortuitum', 'm.', 'fortuitum', 'm', 'mycfo', 'sphingopyxis', 'macrogoltabida', 's.', 'macrogoltabida', 's', 'sphmc', 'thermoplasmatales', 'archaeon', 't.', 'archaeon', 't', 'thex5', 'hyphomicrobium', 'sulfonivorans', 'h.', 'sulfonivorans', 'h', 'hypsl', 'thanatephorus', 'cucumeris', 't.', 'cucumeris', 't', 'thacb', 'alcaligenes', 'xylosoxydans', 'a.', 'xylosoxydans', 'a', 'alcxx', 'lysobacter', 'antibioticus', 'l.', 'antibioticus', 'l', 'lysan', 'streptomyces', 'ambofaciens', 's.', 'ambofaciens', 's', 'stra7', 'sphingopyxis', 'sp', 's.', 'sp', 's', 'sphs1', 'lysobacter', 'enzymogenes', 'l.', 'enzymogenes', 'l', 'lysen', 'eubacterium', 'limosum', 'e.', 'limosum', 'e', 'eubli', 'pseudomonas', 'agarici', 'p.', 'agarici', 'p', 'pseaa', 'thermosulfidibacter', 'takaii', 't.', 'takaii', 't', 'thet7', 'thiobacillus', 'denitrificans', 't.', 'denitrificans', 't', 'thide', 'blastochloris', 'viridis', 'b.', 'viridis', 'b', 'blavi', 'limnochorda', 'pilosa', 'l.', 'pilosa', 'l', 'limpi', 'chondromyces', 'crocatus', 'c.', 'crocatus', 'c', 'choco', 'nitrospira', 'moscoviensis', 'n.', 'moscoviensis', 'n', 'nitmo', 'penicillium', 'patulum', 'p.', 'patulum', 'p', 'penpa', 'steroidobacter', 'denitrificans', 's.', 'denitrificans', 's', 'stede', 'sarcoptes', 'scabiei', 's.', 'scabiei', 's', 'sarsc', 'conidiobolus', 'coronatus', 'c.', 'coronatus', 'c', 'conc2', 'gonapodya', 'prolifera', 'g.', 'prolifera', 'g', 'gonpj', 'gibberella', 'zeae', 'g.', 'zeae', 'g', 'gibze', 'streptococcus', 'suis', 's.', 'suis', 's', 'strsu', 'plasmodium', 'berghei', 'p.', 'berghei', 'p', 'plaba', 'tremblaya', 'princeps', 't.', 'princeps', 't', 'trepr', 'bdellovibrio', 'bacteriovorus', 'b.', 'bacteriovorus', 'b', 'bdebc', 'roseivirga', 'ehrenbergii', 'r.', 'ehrenbergii', 'r', 'rosek', 'gonium', 'pectorale', 'g.', 'pectorale', 'g', 'gonpe', 'rhodococcus', 'fascians', 'r.', 'fascians', 'r', 'rhofa', 'tieghemostelium', 'lacteum', 't.', 'lacteum', 't', 'tiela', 'luteitalea', 'pratensis', 'l.', 'pratensis', 'l', 'lutpr', 'hypsizygus', 'marmoreus', 'h.', 'marmoreus', 'h', 'hypma', 'anaerosporomusa', 'subterranea', 'a.', 'subterranea', 'a', 'anasb', 'anopheles', 'stephensi', 'a.', 'stephensi', 'a', 'anost', 'dufourea', 'novaeangliae', 'd.', 'novaeangliae', 'd', 'dufno', 'xylona', 'heveae', 'x.', 'heveae', 'x', 'xylht', 'calocera', 'viscosa', 'c.', 'viscosa', 'c', 'calvf', 'cordyceps', 'fumosorosea', 'c.', 'fumosorosea', 'c', 'corfa', 'didymella', 'rabiei', 'd.', 'rabiei', 'd', 'didra', 'batrachochytrium', 'dendrobatidis', 'b.', 'dendrobatidis', 'b', 'batdl', 'alternaria', 'alternata', 'a.', 'alternata', 'a', 'altal', 'phycomyces', 'blakesleeanus', 'p.', 'blakesleeanus', 'p', 'phyb8', 'methylomonas', 'sp', 'm.', 'sp', 'm', 'metsd', 'daucus', 'carota', 'd.', 'carota', 'd', 'daucs', 'purpureocillium', 'lilacinum', 'p.', 'lilacinum', 'p', 'purli', 'blastocystis', 'sp', 'b.', 'sp', 'b', 'blahn', 'sinorhizobium', 'saheli', 's.', 'saheli', 's', 'sinsa', 'enterococcus', 'thailandicus', 'e.', 'thailandicus', 'e', 'entth', 'absidia', 'glauca', 'a.', 'glauca', 'a', 'absgl', 'diaphorina', 'citri', 'd.', 'citri', 'd', 'diaci', 'erinaceus', 'europaeus', 'e.', 'europaeus', 'e', 'erieu', 'dipodomys', 'ordii', 'd.', 'ordii', 'd', 'dipor', 'nicotiana', 'tabacum', 'n.', 'tabacum', 'n', 'tobac', 'lingula', 'unguis', 'l.', 'unguis', 'l', 'linun', 'cicer', 'arietinum', 'c.', 'arietinum', 'c', 'cicar', 'salmo', 'salar', 's.', 'salar', 's', 'salsa', 'vigna', 'radiata', 'v.', 'radiata', 'v', 'vigrr', 'cucumis', 'melo', 'c.', 'melo', 'c', 'cucme', 'fusarium', 'poae', 'f.', 'poae', 'f', 'fuspo', 'neotoma', 'lepida', 'n.', 'lepida', 'n', 'neole', 'streptomyces', 'lincolnensis', 's.', 'lincolnensis', 's', 'strln', 'ananas', 'comosus', 'a.', 'comosus', 'a', 'anaco', 'moraxella', 'nonliquefaciens', 'm.', 'nonliquefaciens', 'm', 'morno', 'grifola', 'frondosa', 'g.', 'frondosa', 'g', 'grifr', 'mycobacterium', 'asiaticum', 'm.', 'asiaticum', 'm', 'mycas', 'wickerhamomyces', 'anomalus', 'w.', 'anomalus', 'w', 'wicaa', 'cyberlindnera', 'jadinii', 'c.', 'jadinii', 'c', 'cybjn', 'orchesella', 'cincta', 'o.', 'cincta', 'o', 'orcci', 'aspergillus', 'cristatus', 'a.', 'cristatus', 'a', 'aspcr', 'limosilactobacillus', 'fermentum', 'l.', 'fermentum', 'l', 'limfe', 'mycobacterium', 'intermedium', 'm.', 'intermedium', 'm', 'mycie', 'endomicrobium', 'trichonymphae', 'e.', 'trichonymphae', 'e', 'endtx', 'loa', 'loa', 'l.', 'loa', 'l', 'loalo', 'hanseniaspora', 'uvarum', 'h.', 'uvarum', 'h', 'hanuv', 'sarcina', 'ventriculi', 's.', 'ventriculi', 's', 'sarve', 'murid', 'herpesvirus', 'm.', 'herpesvirus', 'm', 'mhv68', 'simian', 'hemorrhagic', 's.', 'hemorrhagic', 's', 'shfv', 'camelpox', 'virus', 'c.', 'virus', 'c', 'camps', 'bovine', 'herpesvirus', 'b.', 'herpesvirus', 'b', 'bhv4', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade31', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv1', 'cercopithecine', 'herpesvirus', 'c.', 'herpesvirus', 'c', 'chv1', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade08', 'rotavirus', 'b', 'r.', 'b', 'r', 'rotga', 'porcine', 'reproductive', 'p.', 'reproductive', 'p', 'prrsv', 'simian', 'cytomegalovirus', 's.', 'cytomegalovirus', 's', 'scmvc', 'canine', 'adenovirus', 'c.', 'adenovirus', 'c', 'adec2', 'murid', 'herpesvirus', 'm.', 'herpesvirus', 'm', 'muhv1', 'beluga', 'whale', 'b.', 'whale', 'b', 'bwcov', 'saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's', 'shv1', 'rat', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r', 'rcmve', 'elephantid', 'herpesvirus', 'e.', 'herpesvirus', 'e', 'elhv1', 'orf', 'virus', 'o.', 'virus', 'o', 'orfv', 'tupaiid', 'herpesvirus', 't.', 'herpesvirus', 't', 'tuhv1', 'equine', 'adenovirus', 'e.', 'adenovirus', 'e', 'adee1', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade18', 'dabie', 'bandavirus', 'd.', 'bandavirus', 'd', 'sfts', 'infectious', 'laryngotracheitis', 'i.', 'laryngotracheitis', 'i', 'iltv', 'adelaide', 'river', 'a.', 'river', 'a', 'arv', 'feline', 'herpesvirus', 'f.', 'herpesvirus', 'f', 'fhv1', 'caprine', 'arthritis', 'c.', 'arthritis', 'c', 'caev', 'cercopithecine', 'herpesvirus', 'c.', 'herpesvirus', 'c', 'chv9d', 'vaccinia', 'virus', 'v.', 'virus', 'v', 'vacct', 'saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's', 'shv2', 'human', 'adenovirus', 'h.', 'adenovirus', 'h', 'ade04', 'bovine', 'herpesvirus', 'b.', 'herpesvirus', 'b', 'bhv1k', 'lactate', 'dehydrogenaseelevating', 'l.', 'dehydrogenaseelevating', 'l', 'ldv', 'meleagrid', 'herpesvirus', 'm.', 'herpesvirus', 'm', 'mehv1', 'wolbachia', 'pipientis', 'w.', 'pipientis', 'w', 'wolpi', 'flammeovirga', 'pacifica', 'f.', 'pacifica', 'f', 'flapc', 'psittacus', 'erithacus', 'p.', 'erithacus', 'p', 'pepv', 'syntrophotalea', 'acetylenica', 's.', 'acetylenica', 's', 'synac', 'stigmatella', 'aurantiaca', 's.', 'aurantiaca', 's', 'stiau', 'moorella', 'thermoacetica', 'm.', 'thermoacetica', 'm', 'mooth', 'selenomonas', 'ruminantium', 's.', 'ruminantium', 's', 'selru', 'magnetospirillum', 'fulvum', 'm.', 'fulvum', 'm', 'magfu', 'streptacidiphilus', 'jiangxiensis', 's.', 'jiangxiensis', 's', 'strji', 'allokutzneria', 'albata', 'a.', 'albata', 'a', 'allab', 'salegentibacter', 'echinorum', 's.', 'echinorum', 's', 'salec', 'aspergillus', 'luchuensis', 'a.', 'luchuensis', 'a', 'asplc', 'trametes', 'pubescens', 't.', 'pubescens', 't', 'trapu', 'pseudonocardia', 'thermophila', 'p.', 'thermophila', 'p', 'pseth', 'aspergillus', 'brasiliensis', 'a.', 'brasiliensis', 'a', 'aspbc', 'streptoalloteichus', 'hindustanus', 's.', 'hindustanus', 's', 'strhi', 'aspergillus', 'aculeatus', 'a.', 'aculeatus', 'a', 'aspa1', 'corynebacterium', 'flavescens', 'c.', 'flavescens', 'c', 'corfl', 'malassezia', 'sympodialis', 'm.', 'sympodialis', 'm', 'mals4', 'acidiphilium', 'rubrum', 'a.', 'rubrum', 'a', 'aciru', 'streptococcus', 'acidominimus', 's.', 'acidominimus', 's', 'strai', 'neolecta', 'irregularis', 'n.', 'irregularis', 'n', 'neoid', 'xenopus', 'laevis', 'x.', 'laevis', 'x', 'xenla', 'ramazzottius', 'varieornatus', 'r.', 'varieornatus', 'r', 'ramva', 'nicotiana', 'attenuata', 'n.', 'attenuata', 'n', 'nicat', 'corchorus', 'capsularis', 'c.', 'capsularis', 'c', 'cocap', 'aspergillus', 'carbonarius', 'a.', 'carbonarius', 'a', 'aspc5', 'lupinus', 'angustifolius', 'l.', 'angustifolius', 'l', 'lupan', 'lentinula', 'edodes', 'l.', 'edodes', 'l', 'lened', 'acetobacter', 'aceti', 'a.', 'aceti', 'a', 'aceac', 'elizabethkingia', 'meningoseptica', 'e.', 'meningoseptica', 'e', 'elime', 'cyberlindnera', 'fabianii', 'c.', 'fabianii', 'c', 'cybfa', 'nicotiana', 'sylvestris', 'n.', 'sylvestris', 'n', 'nicsy', 'gossypium', 'hirsutum', 'g.', 'hirsutum', 'g', 'goshi', 'nelumbo', 'nucifera', 'n.', 'nucifera', 'n', 'nelnu', 'carlito', 'syrichta', 'c.', 'syrichta', 'c', 'carsf', 'alligator', 'sinensis', 'a.', 'sinensis', 'a', 'allsi', 'mesocricetus', 'auratus', 'm.', 'auratus', 'm', 'mesau', 'oceanospirillum', 'linum', 'o.', 'linum', 'o', 'oceli', 'aspergillus', 'oryzae', 'a.', 'oryzae', 'a', 'aspoz', 'treponema', 'porcinum', 't.', 'porcinum', 't', 'trepo', 'rhodoferax', 'fermentans', 'r.', 'fermentans', 'r', 'rhofe', 'lachancea', 'fermentati', 'l.', 'fermentati', 'l', 'lacfm', 'penicillium', 'polonicum', 'p.', 'polonicum', 'p', 'penpo', 'penicillium', 'decumbens', 'p.', 'decumbens', 'p', 'pendc', 'ruminiclostridium', 'hungatei', 'r.', 'hungatei', 'r', 'rumhu', 'penicillium', 'nalgiovense', 'p.', 'nalgiovense', 'p', 'penna', 'austrofundulus', 'limnaeus', 'a.', 'limnaeus', 'a', 'ausli', 'agrilus', 'planipennis', 'a.', 'planipennis', 'a', 'agrpl', 'reichenbachiella', 'faecimaris', 'r.', 'faecimaris', 'r', 'reifa', 'mycobacterium', 'heidelbergense', 'm.', 'heidelbergense', 'm', 'myche', 'saccharomonospora', 'piscinae', 's.', 'piscinae', 's', 'sacpi', 'sulfobacillus', 'thermosulfidooxidans', 's.', 'thermosulfidooxidans', 's', 'sulta', 'kibdelosporangium', 'aridum', 'k.', 'aridum', 'k', 'kibar', 'trinickia', 'caryophylli', 't.', 'caryophylli', 't', 'tricw', 'epicoccum', 'nigrum', 'e.', 'nigrum', 'e', 'eping', 'oncorhynchus', 'mykiss', 'o.', 'mykiss', 'o', 'oncmy', 'mycolicibacterium', 'fallax', 'm.', 'fallax', 'm', 'mycfa', 'protomyces', 'lactucaedebilis', 'p.', 'lactucaedebilis', 'p', 'prolt', 'mycobacterium', 'celatum', 'm.', 'celatum', 'm', 'mycce', 'mycobacterium', 'bohemicum', 'm.', 'bohemicum', 'm', 'mycbe', 'pseudonocardia', 'autotrophica', 'p.', 'autotrophica', 'p', 'pseah', 'pseudoalteromonas', 'ulvae', 'p.', 'ulvae', 'p', 'psedv', 'clavibacter', 'michiganensis', 'c.', 'michiganensis', 'c', 'clamm', 'plasmodium', 'gonderi', 'p.', 'gonderi', 'p', 'plago', 'piromyces', 'sp', 'p.', 'sp', 'p', 'pirse', 'micromonospora', 'echinofusca', 'm.', 'echinofusca', 'm', 'miceh', 'folsomia', 'candida', 'f.', 'candida', 'f', 'folca', 'callipepla', 'squamata', 'c.', 'squamata', 'c', 'calsu', 'ekhidna', 'lutea', 'e.', 'lutea', 'e', 'ekhlu', 'halorubrum', 'vacuolatum', 'h.', 'vacuolatum', 'h', 'halvu', 'fistulifera', 'solaris', 'f.', 'solaris', 'f', 'fisso', 'rhodoblastus', 'acidophilus', 'r.', 'acidophilus', 'r', 'rhoac', 'colinus', 'virginianus', 'c.', 'virginianus', 'c', 'colvi', 'aquimarina', 'amphilecti', 'a.', 'amphilecti', 'a', 'aquam', 'allochromatium', 'warmingii', 'a.', 'warmingii', 'a', 'allwa', 'niabella', 'drilacis', 'n.', 'drilacis', 'n', 'niade', 'alkalimonas', 'amylolytica', 'a.', 'amylolytica', 'a', 'alkam', 'bizionia', 'paragorgiae', 'b.', 'paragorgiae', 'b', 'bizpa', 'pseudonocardia', 'oroxyli', 'p.', 'oroxyli', 'p', 'pseor', 'peptococcus', 'niger', 'p.', 'niger', 'p', 'pepni', 'rhodosporidium', 'toruloides', 'r.', 'toruloides', 'r', 'rhoto', 'eubacterium', 'oxidoreducens', 'e.', 'oxidoreducens', 'e', 'eubox', 'thalassotalea', 'agarivorans', 't.', 'agarivorans', 't', 'thasx', 'ectothiorhodospira', 'mobilis', 'e.', 'mobilis', 'e', 'ectmo', 'pseudonocardia', 'ammonioxydans', 'p.', 'ammonioxydans', 'p', 'psuam', 'vitreoscilla', 'filiformis', 'v.', 'filiformis', 'v', 'vitfi', 'lily', 'virus', 'l.', 'virus', 'l', 'lvx', 'pea', 'early', 'p.', 'early', 'p', 'pebv', 'carnation', 'mottle', 'c.', 'mottle', 'c', 'carmv', 'potato', 'aucuba', 'p.', 'aucuba', 'p', 'pamv', 'maize', 'white', 'm.', 'white', 'm', 'mwlmv', 'artichoke', 'mottled', 'a.', 'mottled', 'a', 'amcv', 'simbu', 'virus', 's.', 'virus', 's', 'simbu', 'bovine', 'leukemia', 'b.', 'leukemia', 'b', 'blv', 'chrysanthemum', 'virus', 'c.', 'virus', 'c', 'cvb', 'barley', 'yellow', 'b.', 'yellow', 'b', 'bydv1', 'tobacco', 'necrosis', 't.', 'necrosis', 't', 'tnvd', 'dahlia', 'mosaic', 'd.', 'mosaic', 'd', 'dmv', 'thiomonas', 'delicata', 't.', 'delicata', 't', 'thidl', 'paenibacillus', 'xerothermodurans', 'p.', 'xerothermodurans', 'p', 'paexe', 'streptomyces', 'laurentii', 's.', 'laurentii', 's', 'strlu', 'porphyra', 'umbilicalis', 'p.', 'umbilicalis', 'p', 'porum', 'heliothis', 'virescens', 'h.', 'virescens', 'h', 'helvi', 'wolfiporia', 'cocos', 'w.', 'cocos', 'w', 'wolco', 'halorhodospira', 'halochloris', 'h.', 'halochloris', 'h', 'halhr', 'armillaria', 'ostoyae', 'a.', 'ostoyae', 'a', 'armos', 'natronoarchaeum', 'philippinense', 'n.', 'philippinense', 'n', 'natpi', 'plasmodium', 'malariae', 'p.', 'malariae', 'p', 'plama', 'plasmodium', 'relictum', 'p.', 'relictum', 'p', 'plarl', 'comamonas', 'terrigena', 'c.', 'terrigena', 'c', 'comtr', 'mycolicibacterium', 'agri', 'm.', 'agri', 'm', 'mycag', 'kuenenia', 'stuttgartiensis', 'k.', 'stuttgartiensis', 'k', 'kuest', 'thermoleophilum', 'album', 't.', 'album', 't', 'theal', 'streptomyces', 'cinnamoneus', 's.', 'cinnamoneus', 's', 'strcj', 'capsicum', 'annuum', 'c.', 'annuum', 'c', 'capan', 'chloroflexi', 'bacterium', 'c.', 'bacterium', 'c', 'chlb2', 'flavilitoribacter', 'nigricans', 'f.', 'nigricans', 'f', 'flan2', 'capsicum', 'chinense', 'c.', 'chinense', 'c', 'capch', 'capsicum', 'baccatum', 'c.', 'baccatum', 'c', 'capba', 'stylophora', 'pistillata', 's.', 'pistillata', 's', 'stypi', 'phoenix', 'dactylifera', 'p.', 'dactylifera', 'p', 'phodc', 'fasciola', 'hepatica', 'f.', 'hepatica', 'f', 'fashe', 'aquilegia', 'coerulea', 'a.', 'coerulea', 'a', 'aquca', 'candida', 'auris', 'c.', 'auris', 'c', 'canar', 'stichopus', 'japonicus', 's.', 'japonicus', 's', 'stija', 'pea', 'enation', 'p.', 'enation', 'p', 'pemv1', 'heterocapsa', 'circularisquama', 'h.', 'circularisquama', 'h', 'hcv01', 'piry', 'virus', 'p.', 'virus', 'p', 'piryv', 'aotus', 'nancymaae', 'a.', 'nancymaae', 'a', 'aotna', 'cebus', 'imitator', 'c.', 'imitator', 'c', 'cebim', 'cercocebus', 'atys', 'c.', 'atys', 'c', 'cerat', 'colobus', 'angolensis', 'c.', 'angolensis', 'c', 'colap', 'macaca', 'fascicularis', 'm.', 'fascicularis', 'm', 'macfa', 'macaca', 'nemestrina', 'm.', 'nemestrina', 'm', 'macne', 'mandrillus', 'leucophaeus', 'm.', 'leucophaeus', 'm', 'manle', 'propithecus', 'coquereli', 'p.', 'coquereli', 'p', 'proco', 'rhinopithecus', 'bieti', 'r.', 'bieti', 'r', 'rhibe', 'rhinopithecus', 'roxellana', 'r.', 'roxellana', 'r', 'rhiro', 'saimiri', 'boliviensis', 's.', 'boliviensis', 's', 'saibb', 'aspergillus', 'novofumigatus', 'a.', 'novofumigatus', 'a', 'aspn1', 'aspergillus', 'candidus', 'a.', 'candidus', 'a', 'aspcn', 'lactuca', 'sativa', 'l.', 'sativa', 'l', 'lacsa', 'juglans', 'regia', 'j.', 'regia', 'j', 'jugre', 'bacteriovorax', 'stolpii', 'b.', 'stolpii', 'b', 'bactc', 'beauveria', 'bassiana', 'b.', 'bassiana', 'b', 'beaba', 'vibrio', 'diazotrophicus', 'v.', 'diazotrophicus', 'v', 'vibdi', 'herbinix', 'hemicellulosilytica', 'h.', 'hemicellulosilytica', 'h', 'herhm', 'streptomyces', 'malaysiensis', 's.', 'malaysiensis', 's', 'strmq', 'laceyella', 'sacchari', 'l.', 'sacchari', 'l', 'lacsh', 'citrus', 'unshiu', 'c.', 'unshiu', 'c', 'citun', 'gibberella', 'nygamai', 'g.', 'nygamai', 'g', 'gibny', 'arthrobacter', 'glacialis', 'a.', 'glacialis', 'a', 'artgl', 'bambusicola', 'thoracicus', 'b.', 'thoracicus', 'b', 'bamth', 'lysinibacillus', 'sphaericus', 'l.', 'sphaericus', 'l', 'lyssh', 'rosa', 'chinensis', 'r.', 'chinensis', 'r', 'rosch', 'vitreoscilla', 'sp', 'v.', 'sp', 'v', 'vits1', 'actinopolyspora', 'mortivallis', 'a.', 'mortivallis', 'a', 'actmo', 'rhodopila', 'globiformis', 'r.', 'globiformis', 'r', 'rhogl', 'gossypium', 'barbadense', 'g.', 'barbadense', 'g', 'gosba', 'chlorella', 'sorokiniana', 'c.', 'sorokiniana', 'c', 'chlso', 'brevinema', 'andersonii', 'b.', 'andersonii', 'b', 'bread', 'pan', 'paniscus', 'p.', 'paniscus', 'p', 'panpa', 'vitiosangium', 'sp', 'v.', 'sp', 'v', 'vitxg', 'chitinophaga', 'niastensis', 'c.', 'niastensis', 'c', 'china', 'mycoplana', 'dimorpha', 'm.', 'dimorpha', 'm', 'mycdi', 'actinidia', 'chinensis', 'a.', 'chinensis', 'a', 'actcc', 'fusarium', 'culmorum', 'f.', 'culmorum', 'f', 'fuscu', 'syncephalastrum', 'racemosum', 's.', 'racemosum', 's', 'synra', 'mizuhopecten', 'yessoensis', 'm.', 'yessoensis', 'm', 'mizye', 'rhizopus', 'microsporus', 'r.', 'microsporus', 'r', 'rhizd', 'cervus', 'elaphus', 'c.', 'elaphus', 'c', 'cereh', 'helicobasidium', 'mompa', 'h.', 'mompa', 'h', 'hmev', 'apis', 'cerana', 'a.', 'cerana', 'a', 'apicc', 'coemansia', 'reversa', 'c.', 'reversa', 'c', 'coern', 'vicia', 'faba', 'v.', 'faba', 'v', 'vfev', 'poecilia', 'reticulata', 'p.', 'reticulata', 'p', 'poere', 'trifolium', 'subterraneum', 't.', 'subterraneum', 't', 'trisu', 'bean', 'leafroll', 'b.', 'leafroll', 'b', 'blrv', 'trichophyton', 'rubrum', 't.', 'rubrum', 't', 'triru', 'hydrogenibacillus', 'schlegelii', 'h.', 'schlegelii', 'h', 'hydsh', 'cordyceps', 'confragosa', 'c.', 'confragosa', 'c', 'cordf', 'eschrichtius', 'robustus', 'e.', 'robustus', 'e', 'escro', 'asparagus', 'officinalis', 'a.', 'officinalis', 'a', 'aspof', 'phytophthora', 'endornavirus', 'p.', 'endornavirus', 'p', 'phev1', 'metarhizium', 'rileyi', 'm.', 'rileyi', 'm', 'metrr', 'herpesvirus', 'ateles', 'h.', 'ateles', 'h', 'hsva1', 'brochothrix', 'thermosphacta', 'b.', 'thermosphacta', 'b', 'broth', 'buchnera', 'aphidicola', 'b.', 'aphidicola', 'b', 'buctt', 'cynara', 'cardunculus', 'c.', 'cardunculus', 'c', 'cyncs', 'marchantia', 'polymorpha', 'm.', 'polymorpha', 'm', 'marpo', 'tuber', 'borchii', 't.', 'borchii', 't', 'tubbo', 'pomacea', 'canaliculata', 'p.', 'canaliculata', 'p', 'pomca', 'methylosinus', 'sporium', 'm.', 'sporium', 'm', 'metsr', 'artemisia', 'annua', 'a.', 'annua', 'a', 'artan', 'petromyzon', 'marinus', 'p.', 'marinus', 'p', 'petma', 'tursiops', 'truncatus', 't.', 'truncatus', 't', 'turtr', 'odobenus', 'rosmarus', 'o.', 'rosmarus', 'o', 'odoro', 'leptonychotes', 'weddellii', 'l.', 'weddellii', 'l', 'lepwe', 'acidibacillus', 'sulfuroxidans', 'a.', 'sulfuroxidans', 'a', 'acis4', 'pseudaminobacter', 'salicylatoxidans', 'p.', 'salicylatoxidans', 'p', 'psese', 'butyrivibrio', 'fibrisolvens', 'b.', 'fibrisolvens', 'b', 'butfi', 'sediminitomix', 'flava', 's.', 'flava', 's', 'sedfl', 'scophthalmus', 'maximus', 's.', 'maximus', 's', 'scomx', 'banana', 'bunchy', 'b.', 'bunchy', 'b', 'bbtv', 'deltaproteobacteria', 'bacterium', 'd.', 'bacterium', 'd', 'uncde', 'glaciecola', 'sp', 'g.', 'sp', 'g', 'glask', 'streptomyces', 'actuosus', 's.', 'actuosus', 's', 'stras', 'aspergillus', 'sclerotiicarbonarius', 'a.', 'sclerotiicarbonarius', 'a', 'aspsb', 'delphinapterus', 'leucas', 'd.', 'leucas', 'd', 'delle', 'physeter', 'macrocephalus', 'p.', 'macrocephalus', 'p', 'phymc', 'larkinella', 'arboricola', 'l.', 'arboricola', 'l', 'larab', 'thermosporothrix', 'hazakensis', 't.', 'hazakensis', 't', 'theha', 'aspergillus', 'homomorphus', 'a.', 'homomorphus', 'a', 'asphc', 'lederbergia', 'lenta', 'l.', 'lenta', 'l', 'ledle', 'pichia', 'kudriavzevii', 'p.', 'kudriavzevii', 'p', 'picku', 'aspergillus', 'violaceofuscus', 'a.', 'violaceofuscus', 'a', 'aspv1', 'aedes', 'albopictus', 'a.', 'albopictus', 'a', 'aedal', 'gambusia', 'affinis', 'g.', 'affinis', 'g', 'gamaf', 'balneicella', 'halophila', 'b.', 'halophila', 'b', 'balha', 'mycobacterium', 'shimoidei', 'm.', 'shimoidei', 'm', 'mycsh', 'rhizopus', 'azygosporus', 'r.', 'azygosporus', 'r', 'rhiaz', 'rhizopus', 'stolonifer', 'r.', 'stolonifer', 'r', 'rhist', 'sporosarcina', 'pasteurii', 's.', 'pasteurii', 's', 'spopa', 'enterobacter', 'agglomerans', 'e.', 'agglomerans', 'e', 'entag', 'bergeriella', 'denitrificans', 'b.', 'denitrificans', 'b', 'berde', 'klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k', 'klepr', 'yersinia', 'ruckeri', 'y.', 'ruckeri', 'y', 'yerru', 'moraxella', 'osloensis', 'm.', 'osloensis', 'm', 'moros', 'klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k', 'klepo', 'thermasporomyces', 'composti', 't.', 'composti', 't', 'thecx', 'tetradesmus', 'obliquus', 't.', 'obliquus', 't', 'tetob', 'amphiprion', 'ocellaris', 'a.', 'ocellaris', 'a', 'ampoc', 'scytalidium', 'lignicola', 's.', 'lignicola', 's', 'scyli', 'neolamprologus', 'brichardi', 'n.', 'brichardi', 'n', 'neobr', 'mola', 'mola', 'm.', 'mola', 'm', 'molml', 'ursus', 'maritimus', 'u.', 'maritimus', 'u', 'ursma', 'balaenoptera', 'acutorostrata', 'b.', 'acutorostrata', 'b', 'balas', 'hydrogenophilus', 'thermoluteolus', 'h.', 'thermoluteolus', 'h', 'hydte', 'streptomyces', 'inhibens', 's.', 'inhibens', 's', 'strih', 'brassica', 'campestris', 'b.', 'campestris', 'b', 'bracm', 'kryptolebias', 'marmoratus', 'k.', 'marmoratus', 'k', 'kryma', 'haplochromis', 'burtoni', 'h.', 'burtoni', 'h', 'hapbu', 'cyprinodon', 'variegatus', 'c.', 'variegatus', 'c', 'cypva', 'anabas', 'testudineus', 'a.', 'testudineus', 'a', 'anate', 'amphiprion', 'percula', 'a.', 'percula', 'a', 'amppe', 'cynoglossus', 'semilaevis', 'c.', 'semilaevis', 'c', 'cynse', 'esox', 'lucius', 'e.', 'lucius', 'e', 'esolu', 'lipotes', 'vexillifer', 'l.', 'vexillifer', 'l', 'lipve', 'chara', 'braunii', 'c.', 'braunii', 'c', 'chabu', 'cephus', 'cinctus', 'c.', 'cinctus', 'c', 'cepcn', 'fusarium', 'sporotrichioides', 'f.', 'sporotrichioides', 'f', 'fussp', 'trichoderma', 'arundinaceum', 't.', 'arundinaceum', 't', 'triar', 'angiostrongylus', 'costaricensis', 'a.', 'costaricensis', 'a', 'angcs', 'mesocestoides', 'corti', 'm.', 'corti', 'm', 'mesco', 'streptomyces', 'luteoverticillatus', 's.', 'luteoverticillatus', 's', 'strlt', 'avibacterium', 'volantium', 'a.', 'volantium', 'a', 'avivo', 'drosophila', 'guanche', 'd.', 'guanche', 'd', 'drogu', 'actinobacillus', 'equuli', 'a.', 'equuli', 'a', 'acteu', 'streptococcus', 'iniae', 's.', 'iniae', 's', 'strin', 'wuchereria', 'bancrofti', 'w.', 'bancrofti', 'w', 'wucba', 'human', 'herpesvirus', 'h.', 'herpesvirus', 'h', 'hhv2', 'onchocerca', 'ochengi', 'o.', 'ochengi', 'o', 'oncoc', 'mannheimia', 'haemolytica', 'm.', 'haemolytica', 'm', 'manha', 'streptomyces', 'griseoviridis', 's.', 'griseoviridis', 's', 'strgd', 'elysia', 'chlorotica', 'e.', 'chlorotica', 'e', 'elych', 'salmonella', 'bongori', 's.', 'bongori', 's', 'salbn', 'ziziphus', 'jujuba', 'z.', 'jujuba', 'z', 'zizju', 'enterobius', 'vermicularis', 'e.', 'vermicularis', 'e', 'entve', 'hydatigena', 'taeniaeformis', 'h.', 'taeniaeformis', 'h', 'hydta', 'hymenolepis', 'diminuta', 'h.', 'diminuta', 'h', 'hymdi', 'dracunculus', 'medinensis', 'd.', 'medinensis', 'd', 'drame', 'panicum', 'miliaceum', 'p.', 'miliaceum', 'p', 'panmi', 'pocillopora', 'damicornis', 'p.', 'damicornis', 'p', 'pocda', 'blumeria', 'hordei', 'b.', 'hordei', 'b', 'bluho', 'sphingomonas', 'paeninsulae', 's.', 'paeninsulae', 's', 'sphpe', 'thelazia', 'callipaeda', 't.', 'callipaeda', 't', 'thecl', 'chloebia', 'gouldiae', 'c.', 'gouldiae', 'c', 'chlgu', 'hortaea', 'werneckii', 'h.', 'werneckii', 'h', 'horwe', 'acanthocheilonema', 'viteae', 'a.', 'viteae', 'a', 'acavi', 'litomosoides', 'sigmodontis', 'l.', 'sigmodontis', 'l', 'litsi', 'rosellinia', 'necatrix', 'r.', 'necatrix', 'r', 'rnqv1', 'brugia', 'pahangi', 'b.', 'pahangi', 'b', 'brupa', 'pseudomonas', 'azotoformans', 'p.', 'azotoformans', 'p', 'pseaz', 'rodentolepis', 'nana', 'r.', 'nana', 'r', 'rodna', 'mycolicibacterium', 'aurum', 'm.', 'aurum', 'm', 'mycau', 'anabarilius', 'grahami', 'a.', 'grahami', 'a', 'anaga', 'pasteurella', 'aerogenes', 'p.', 'aerogenes', 'p', 'pasae', 'serratia', 'plymuthica', 's.', 'plymuthica', 's', 'serpl', 'mycolicibacterium', 'chitae', 'm.', 'chitae', 'm', 'mycci', 'taenia', 'asiatica', 't.', 'asiatica', 't', 'taeas', 'chilo', 'suppressalis', 'c.', 'suppressalis', 'c', 'chisp', 'oryzias', 'javanicus', 'o.', 'javanicus', 'o', 'oryja', 'psilocybe', 'cyanescens', 'p.', 'cyanescens', 'p', 'psicy', 'penaeus', 'vannamei', 'p.', 'vannamei', 'p', 'penva', 'trypanosoma', 'rangeli', 't.', 'rangeli', 't', 'tryra', 'byssochlamys', 'spectabilis', 'b.', 'spectabilis', 'b', 'byssp', 'vulpes', 'vulpes', 'v.', 'vulpes', 'v', 'vulvu', 'callorhinus', 'ursinus', 'c.', 'ursinus', 'c', 'calur', 'aspergillus', 'awamori', 'a.', 'awamori', 'a', 'aspaw', 'beak', 'and', 'b.', 'and', 'b', 'bfdv', 'scyliorhinus', 'torazame', 's.', 'torazame', 's', 'scyto', 'tremella', 'mesenterica', 't.', 'mesenterica', 't', 'treme', 'glycine', 'soja', 'g.', 'soja', 'g', 'glyso', 'arachis', 'hypogaea', 'a.', 'hypogaea', 'a', 'arahy', 'haploplasma', 'axanthum', 'h.', 'axanthum', 'h', 'hapax', 'acipenser', 'ruthenus', 'a.', 'ruthenus', 'a', 'acirt', 'malus', 'domestica', 'm.', 'domestica', 'm', 'maldo', 'streptomyces', 'netropsis', 's.', 'netropsis', 's', 'strne', 'ktedonosporobacter', 'rubrisoli', 'k.', 'rubrisoli', 'k', 'kteru', 'labeo', 'rohita', 'l.', 'rohita', 'l', 'labro', 'schistosoma', 'bovis', 's.', 'bovis', 's', 'schbo', 'brettanomyces', 'naardenensis', 'b.', 'naardenensis', 'b', 'brena', 'sphingobium', 'xenophagum', 's.', 'xenophagum', 's', 'sphxe', 'capra', 'hircus', 'c.', 'hircus', 'c', 'caphi', 'ursus', 'americanus', 'u.', 'americanus', 'u', 'ursam', 'laodelphax', 'striatellus', 'l.', 'striatellus', 'l', 'laost', 'chloroflexi', 'bacterium', 'c.', 'bacterium', 'c', 'uncch', 'pseudonocardia', 'sediminis', 'p.', 'sediminis', 'p', 'psest', 'myxococcales', 'bacterium', 'm.', 'bacterium', 'm', 'uncmy', 'propioniciclava', 'tarda', 'p.', 'tarda', 'p', 'protd', 'streptomyces', 'kasugaensis', 's.', 'kasugaensis', 's', 'strka', 'streptomyces', 'seoulensis', 's.', 'seoulensis', 's', 'strso', 'methylocella', 'tundrae', 'm.', 'tundrae', 'm', 'mettu', 'hydrogenispora', 'ethanolica', 'h.', 'ethanolica', 'h', 'hydet', 'perca', 'flavescens', 'p.', 'flavescens', 'p', 'perfv', 'nocardia', 'ignorata', 'n.', 'ignorata', 'n', 'nocig', 'pelomonas', 'saccharophila', 'p.', 'saccharophila', 'p', 'pelsc', 'drosophila', 'navojoa', 'd.', 'navojoa', 'd', 'drona', 'coffea', 'canephora', 'c.', 'canephora', 'c', 'cofca', 'sousa', 'chinensis', 's.', 'chinensis', 's', 'souch', 'paucimonas', 'lemoignei', 'p.', 'lemoignei', 'p', 'paule', 'labedaea', 'rhizosphaerae', 'l.', 'rhizosphaerae', 'l', 'labrh', 'pseudonocardia', 'endophytica', 'p.', 'endophytica', 'p', 'pseen', 'colletotrichum', 'trifolii', 'c.', 'trifolii', 'c', 'coltr', 'rhodovulum', 'adriaticum', 'r.', 'adriaticum', 'r', 'rhoad', 'anas', 'platyrhynchos', 'a.', 'platyrhynchos', 'a', 'anapl', 'salvia', 'splendens', 's.', 'splendens', 's', 'salsn', 'setaria', 'viridis', 's.', 'viridis', 's', 'setvi', 'steinernema', 'carpocapsae', 's.', 'carpocapsae', 's', 'stecr', 'collichthys', 'lucidus', 'c.', 'lucidus', 'c', 'collu', 'camelus', 'dromedarius', 'c.', 'dromedarius', 'c', 'camdr', 'opisthorchis', 'felineus', 'o.', 'felineus', 'o', 'opife', 'monodon', 'monoceros', 'm.', 'monoceros', 'm', 'monmo', 'hathewaya', 'histolytica', 'h.', 'histolytica', 'h', 'hathi', 'populus', 'alba', 'p.', 'alba', 'p', 'popal', 'wallemia', 'ichthyophaga', 'w.', 'ichthyophaga', 'w', 'walic', 'lates', 'calcarifer', 'l.', 'calcarifer', 'l', 'latca', 'bos', 'indicus', 'b.', 'indicus', 'b', 'bobox', 'electrophorus', 'electricus', 'e.', 'electricus', 'e', 'eleel', 'callorhinchus', 'milii', 'c.', 'milii', 'c', 'calmi', 'vombatus', 'ursinus', 'v.', 'ursinus', 'v', 'vomur', 'malus', 'baccata', 'm.', 'baccata', 'm', 'malba', 'rarobacter', 'faecitabidus', 'r.', 'faecitabidus', 'r', 'rarfa', 'persicimonas', 'caeni', 'p.', 'caeni', 'p', 'perce', 'flavobacterium', 'sp', 'f.', 'sp', 'f', 'flasp', 'glutamicibacter', 'uratoxydans', 'g.', 'uratoxydans', 'g', 'gluur', 'papaver', 'somniferum', 'p.', 'somniferum', 'p', 'papso', 'fasciola', 'gigantica', 'f.', 'gigantica', 'f', 'fasgi', 'chitinophaga', 'japonensis', 'c.', 'japonensis', 'c', 'chija', 'musa', 'balbisiana', 'm.', 'balbisiana', 'm', 'musba', 'paenarthrobacter', 'aurescens', 'p.', 'aurescens', 'p', 'paeau', 'chlorobium', 'sp', 'c.', 'sp', 'c', 'chlsq', 'shewanella', 'hanedai', 's.', 'hanedai', 's', 'sheha', 'zoogloea', 'ramigera', 'z.', 'ramigera', 'z', 'zoora', 'tigriopus', 'californicus', 't.', 'californicus', 't', 'tigca', 'saccharicrinis', 'carchari', 's.', 'carchari', 's', 'saccc', 'streptomyces', 'cacaoi', 's.', 'cacaoi', 's', 'strci', 'acinetobacter', 'sp', 'a.', 'sp', 'a', 'acisp', 'monascus', 'purpureus', 'm.', 'purpureus', 'm', 'monpu', 'bagarius', 'yarrelli', 'b.', 'yarrelli', 'b', 'bagya', 'micromonospora', 'olivasterospora', 'm.', 'olivasterospora', 'm', 'micol', 'actinoplanes', 'teichomyceticus', 'a.', 'teichomyceticus', 'a', 'actti', 'molluscum', 'contagiosum', 'm.', 'contagiosum', 'm', 'mcv2', 'amycolatopsis', 'cihanbeyliensis', 'a.', 'cihanbeyliensis', 'a', 'amyci', 'deinococcus', 'cellulosilyticus', 'd.', 'cellulosilyticus', 'd', 'deic1', 'bacillus', 'dafuensis', 'b.', 'dafuensis', 'b', 'bacda', 'leuconostoc', 'lactis', 'l.', 'lactis', 'l', 'leula', 'trichoplusia', 'ni', 't.', 'ni', 't', 'trini', 'monilinia', 'fructicola', 'm.', 'fructicola', 'm', 'monfr', 'cafeteria', 'roenbergensis', 'c.', 'roenbergensis', 'c', 'cafro', 'gossypium', 'mustelinum', 'g.', 'mustelinum', 'g', 'gosmu', 'sheeppox', 'virus', 's.', 'virus', 's', 'shev', 'porphyridium', 'purpureum', 'p.', 'purpureum', 'p', 'porpp', 'bacillus', 'safensis', 'b.', 'safensis', 'b', 'bacia', 'striga', 'asiatica', 's.', 'asiatica', 's', 'straf', 'neisseria', 'animalis', 'n.', 'animalis', 'n', 'neian', 'aspergillus', 'pseudotamarii', 'a.', 'pseudotamarii', 'a', 'aspps', 'saccharothrix', 'syringae', 's.', 'syringae', 's', 'sacsy', 'streptomyces', 'galilaeus', 's.', 'galilaeus', 's', 'strgj', 'muntiacus', 'reevesi', 'm.', 'reevesi', 'm', 'munre', 'aspergillus', 'parasiticus', 'a.', 'parasiticus', 'a', 'asppa', 'monilinia', 'laxa', 'm.', 'laxa', 'm', 'monla', 'petromyces', 'alliaceus', 'p.', 'alliaceus', 'p', 'petaa', 'photinus', 'pyralis', 'p.', 'pyralis', 'p', 'phopy', 'prunus', 'dulcis', 'p.', 'dulcis', 'p', 'prudu', 'pangasianodon', 'hypophthalmus', 'p.', 'hypophthalmus', 'p', 'panhp', 'marmota', 'monax', 'm.', 'monax', 'm', 'marmo', 'pontiella', 'desulfatans', 'p.', 'desulfatans', 'p', 'ponde', 'lynx', 'pardinus', 'l.', 'pardinus', 'l', 'lynpa', 'kluyvera', 'cryocrescens', 'k.', 'cryocrescens', 'k', 'klucr', 'callosobruchus', 'maculatus', 'c.', 'maculatus', 'c', 'calms', 'streptomyces', 'jumonjinensis', 's.', 'jumonjinensis', 's', 'strju', 'larimichthys', 'crocea', 'l.', 'crocea', 'l', 'larcr', 'ideonella', 'dechloratans', 'i.', 'dechloratans', 'i', 'idede', 'mycolicibacterium', 'vanbaalenii', 'm.', 'vanbaalenii', 'm', 'mycvn', 'heliobacterium', 'mobile', 'h.', 'mobile', 'h', 'helmo', 'venturia', 'inaequalis', 'v.', 'inaequalis', 'v', 'venin', 'hibiscus', 'syriacus', 'h.', 'syriacus', 'h', 'hibsy', 'balaenoptera', 'physalus', 'b.', 'physalus', 'b', 'balph', 'amphibalanus', 'amphitrite', 'a.', 'amphitrite', 'a', 'ampam', 'naegleria', 'fowleri', 'n.', 'fowleri', 'n', 'naefo', 'diutina', 'rugosa', 'd.', 'rugosa', 'd', 'diuru', 'aspergillus', 'terreus', 'a.', 'terreus', 'a', 'aspte', 'lupinus', 'albus', 'l.', 'albus', 'l', 'lupal', 'perca', 'fluviatilis', 'p.', 'fluviatilis', 'p', 'perfl', 'apolygus', 'lucorum', 'a.', 'lucorum', 'a', 'apolu', 'cyclocybe', 'aegerita', 'c.', 'aegerita', 'c', 'cycae', 'hevea', 'brasiliensis', 'h.', 'brasiliensis', 'h', 'hevbr', 'dissulfurirhabdus', 'thermomarina', 'd.', 'thermomarina', 'd', 'disth', 'vibrio', 'cholerae', 'v.', 'cholerae', 'v', 'vibcl', 'rhinolophus', 'ferrumequinum', 'r.', 'ferrumequinum', 'r', 'rhife', 'lynx', 'canadensis', 'l.', 'canadensis', 'l', 'lynca', 'phasianus', 'colchicus', 'p.', 'colchicus', 'p', 'phacc', 'sinocyclocheilus', 'grahami', 's.', 'grahami', 's', 'singr', 'echeneis', 'naucrates', 'e.', 'naucrates', 'e', 'echna', 'sparus', 'aurata', 's.', 'aurata', 's', 'spaau', 'strigops', 'habroptila', 's.', 'habroptila', 's', 'strhb', 'salarias', 'fasciatus', 's.', 'fasciatus', 's', 'salfa', 'suricata', 'suricatta', 's.', 'suricatta', 's', 'sursu', 'athene', 'cunicularia', 'a.', 'cunicularia', 'a', 'athcn', 'podarcis', 'muralis', 'p.', 'muralis', 'p', 'podmu', 'pseudonaja', 'textilis', 'p.', 'textilis', 'p', 'psete', 'oreochromis', 'aureus', 'o.', 'aureus', 'o', 'oreau', 'salmo', 'trutta', 's.', 'trutta', 's', 'saltr', 'crocuta', 'crocuta', 'c.', 'crocuta', 'c', 'crocr', 'aphis', 'glycines', 'a.', 'glycines', 'a', 'aphgl', 'dekkera', 'bruxellensis', 'd.', 'bruxellensis', 'd', 'dekbr', 'panagrellus', 'redivivus', 'p.', 'redivivus', 'p', 'panre', 'cimex', 'lectularius', 'c.', 'lectularius', 'c', 'cimle', 'arctia', 'plantaginis', 'a.', 'plantaginis', 'a', 'arcpl', 'drosophila', 'busckii', 'd.', 'busckii', 'd', 'drobs', 'coptotermes', 'formosanus', 'c.', 'formosanus', 'c', 'copfo', 'peromyscus', 'maniculatus', 'p.', 'maniculatus', 'p', 'permb', 'geospiza', 'fortis', 'g.', 'fortis', 'g', 'geofo', 'momordica', 'charantia', 'm.', 'charantia', 'm', 'momch', 'sesamum', 'indicum', 's.', 'indicum', 's', 'sesin', 'vicugna', 'pacos', 'v.', 'pacos', 'v', 'vicpa', 'elaeis', 'guineensis', 'e.', 'guineensis', 'e', 'elagv', 'cucurbita', 'maxima', 'c.', 'maxima', 'c', 'cucma', 'raphanus', 'sativus', 'r.', 'sativus', 'r', 'rapsa', 'galleria', 'mellonella', 'g.', 'mellonella', 'g', 'galme', 'bactrocera', 'dorsalis', 'b.', 'dorsalis', 'b', 'bacdo', 'bicyclus', 'anynana', 'b.', 'anynana', 'b', 'bican', 'neodiprion', 'lecontei', 'n.', 'lecontei', 'n', 'neolc', 'acinonyx', 'jubatus', 'a.', 'jubatus', 'a', 'acijb', 'cottoperca', 'gobio', 'c.', 'gobio', 'c', 'cotgo', 'chanos', 'chanos', 'c.', 'chanos', 'c', 'chacn', 'drosophila', 'lebanonensis', 'd.', 'lebanonensis', 'd', 'drole', 'sitophilus', 'oryzae', 's.', 'oryzae', 's', 'sitor', 'aythya', 'fuligula', 'a.', 'fuligula', 'a', 'aytfu', 'sapajus', 'apella', 's.', 'apella', 's', 'sapap', 'prunus', 'armeniaca', 'p.', 'armeniaca', 'p', 'pruar', 'frog', 'virus', 'f.', 'virus', 'f', 'frg3v', 'zygotorulaspora', 'mrakii', 'z.', 'mrakii', 'z', 'zygmr', 'spirochaetes', 'bacterium', 's.', 'bacterium', 's', 'uncsp', 'durio', 'zibethinus', 'd.', 'zibethinus', 'd', 'durzi', 'prunus', 'avium', 'p.', 'avium', 'p', 'pruav', 'carassius', 'auratus', 'c.', 'auratus', 'c', 'carau', 'puma', 'concolor', 'p.', 'concolor', 'p', 'pumco', 'bos', 'indicus', 'b.', 'indicus', 'b', 'bosin', 'branchiostoma', 'belcheri', 'b.', 'belcheri', 'b', 'brabe', 'phascolarctos', 'cinereus', 'p.', 'cinereus', 'p', 'phaci', 'dermatophagoides', 'pteronyssinus', 'd.', 'pteronyssinus', 'd', 'derpt', 'coffea', 'arabica', 'c.', 'arabica', 'c', 'cofar', 'magnaporthe', 'grisea', 'm.', 'grisea', 'm', 'maggr', 'octopus', 'vulgaris', 'o.', 'vulgaris', 'o', 'octvu', 'pantherophis', 'guttatus', 'p.', 'guttatus', 'p', 'pangu', 'thrips', 'palmi', 't.', 'palmi', 't', 'thrpl', 'geotrypetes', 'seraphini', 'g.', 'seraphini', 'g', 'geosa', 'gymnodraco', 'acuticeps', 'g.', 'acuticeps', 'g', 'gymac', 'actinia', 'tenebrosa', 'a.', 'tenebrosa', 'a', 'actte', 'drosophila', 'kikkawai', 'd.', 'kikkawai', 'd', 'droki', 'pteropus', 'vampyrus', 'p.', 'vampyrus', 'p', 'pteva', 'octodon', 'degus', 'o.', 'degus', 'o', 'octde', 'dinoponera', 'quadriceps', 'd.', 'quadriceps', 'd', 'dinqu', 'drosophila', 'rhopaloa', 'd.', 'rhopaloa', 'd', 'drorh', 'ziziphus', 'jujuba', 'z.', 'jujuba', 'z', 'zizjj', 'thermanaerosceptrum', 'fracticalcis', 't.', 'fracticalcis', 't', 'thefr', 'alkalicella', 'caledoniensis', 'a.', 'caledoniensis', 'a', 'alkca', 'mycobacterium', 'kansasii', 'm.', 'kansasii', 'm', 'mycka', 'steatornis', 'caripensis', 's.', 'caripensis', 's', 'steca', 'dissostichus', 'mawsoni', 'd.', 'mawsoni', 'd', 'disma', 'desulfuromonadales', 'bacterium', 'd.', 'bacterium', 'd', 'desbx', 'pluvianellus', 'socialis', 'p.', 'socialis', 'p', 'pluso', 'catharus', 'fuscescens', 'c.', 'fuscescens', 'c', 'catfu', 'armatimonas', 'rosea', 'a.', 'rosea', 'a', 'armro', 'piprites', 'chloris', 'p.', 'chloris', 'p', 'pipcl', 'leucopsar', 'rothschildi', 'l.', 'rothschildi', 'l', 'leuro', 'toxostoma', 'redivivum', 't.', 'redivivum', 't', 'toxre', 'leiothrix', 'lutea', 'l.', 'lutea', 'l', 'leilu', 'chroicocephalus', 'maculipennis', 'c.', 'maculipennis', 'c', 'chrmc', 'smutsornis', 'africanus', 's.', 'africanus', 's', 'smuaf', 'cochlearius', 'cochlearius', 'c.', 'cochlearius', 'c', 'cocco', 'rynchops', 'niger', 'r.', 'niger', 'r', 'rynni', 'orthonyx', 'spaldingii', 'o.', 'spaldingii', 'o', 'ortsp', 'corythaixoides', 'concolor', 'c.', 'concolor', 'c', 'corcn', 'oceanodroma', 'tethys', 'o.', 'tethys', 'o', 'ocete', 'myotis', 'myotis', 'm.', 'myotis', 'm', 'myomy', 'balaeniceps', 'rex', 'b.', 'rex', 'b', 'balrx', 'regulus', 'satrapa', 'r.', 'satrapa', 'r', 'regsa', 'erithacus', 'rubecula', 'e.', 'rubecula', 'e', 'eriru', 'columbina', 'picui', 'c.', 'picui', 'c', 'colpi', 'irena', 'cyanogastra', 'i.', 'cyanogastra', 'i', 'irecy', 'geococcyx', 'californianus', 'g.', 'californianus', 'g', 'geoca', 'motacilla', 'alba', 'm.', 'alba', 'm', 'motal', 'bombycilla', 'garrulus', 'b.', 'garrulus', 'b', 'bomga', 'stercorarius', 'parasiticus', 's.', 'parasiticus', 's', 'stepr', 'eudromia', 'elegans', 'e.', 'elegans', 'e', 'eudel', 'oriolus', 'oriolus', 'o.', 'oriolus', 'o', 'orior', 'pycnonotus', 'jocosus', 'p.', 'jocosus', 'p', 'pycjo', 'alca', 'torda', 'a.', 'torda', 'a', 'alcto', 'candida', 'albicans', 'c.', 'albicans', 'c', 'canax', 'chauna', 'torquata', 'c.', 'torquata', 'c', 'chato', 'tyrannus', 'savana', 't.', 'savana', 't', 'tyrsa', 'sylvia', 'borin', 's.', 'borin', 's', 'sylbo', 'scopus', 'umbretta', 's.', 'umbretta', 's', 'scoum', 'sagittarius', 'serpentarius', 's.', 'serpentarius', 's', 'sagse', 'poecile', 'atricapillus', 'p.', 'atricapillus', 'p', 'poeat', 'rissa', 'tridactyla', 'r.', 'tridactyla', 'r', 'ristr', 'kitasatospora', 'kifunensis', 'k.', 'kifunensis', 'k', 'kitki', 'aspergillus', 'burnettii', 'a.', 'burnettii', 'a', 'aspbu', 'arenaria', 'interpres', 'a.', 'interpres', 'a', 'arein', 'dromaius', 'novaehollandiae', 'd.', 'novaehollandiae', 'd', 'drono', 'cephalopterus', 'ornatus', 'c.', 'ornatus', 'c', 'cepor', 'upupa', 'epops', 'u.', 'epops', 'u', 'upuep', 'novispirillum', 'itersonii', 'n.', 'itersonii', 'n', 'novit', 'panurus', 'biarmicus', 'p.', 'biarmicus', 'p', 'panbi', 'caloenas', 'nicobarica', 'c.', 'nicobarica', 'c', 'calni', 'lanius', 'ludovicianus', 'l.', 'ludovicianus', 'l', 'lanlu', 'gibberella', 'subglutinans', 'g.', 'subglutinans', 'g', 'gibsu', 'azomonas', 'macrocytogenes', 'a.', 'macrocytogenes', 'a', 'azoma', 'crotophaga', 'sulcirostris', 'c.', 'sulcirostris', 'c', 'crosl', 'acrocephalus', 'arundinaceus', 'a.', 'arundinaceus', 'a', 'acrar', 'setophaga', 'kirtlandii', 's.', 'kirtlandii', 's', 'setkr', 'jacana', 'jacana', 'j.', 'jacana', 'j', 'jacjc', 'onychorhynchus', 'coronatus', 'o.', 'coronatus', 'o', 'onyco', 'trogon', 'melanurus', 't.', 'melanurus', 't', 'troml', 'molossus', 'molossus', 'm.', 'molossus', 'm', 'molmo', 'bucorvus', 'abyssinicus', 'b.', 'abyssinicus', 'b', 'bucab', 'diceros', 'bicornis', 'd.', 'bicornis', 'd', 'dicbm', 'quiscalus', 'mexicanus', 'q.', 'mexicanus', 'q', 'quime', 'molothrus', 'ater', 'm.', 'ater', 'm', 'molat', 'anthoscopus', 'minutus', 'a.', 'minutus', 'a', 'antmn', 'podilymbus', 'podiceps', 'p.', 'podiceps', 'p', 'podpo', 'pelecanoides', 'urinatrix', 'p.', 'urinatrix', 'p', 'pelur', 'herpetotheres', 'cachinnans', 'h.', 'cachinnans', 'h', 'herca', 'nitrospirae', 'bacterium', 'n.', 'bacterium', 'n', 'uncnt', 'thalassarche', 'chlororhynchos', 't.', 'chlororhynchos', 't', 'thach', 'chionis', 'minor', 'c.', 'minor', 'c', 'chimn', 'pipistrellus', 'kuhlii', 'p.', 'kuhlii', 'p', 'pipku', 'thryothorus', 'ludovicianus', 't.', 'ludovicianus', 't', 'thrlu', 'fusarium', 'oxysporum', 'f.', 'oxysporum', 'f', 'fusox', 'melospiza', 'melodia', 'm.', 'melodia', 'm', 'melmo', 'cellulomonas', 'fimi', 'c.', 'fimi', 'c', 'celfi', 'alectura', 'lathami', 'a.', 'lathami', 'a', 'alela', 'planomonospora', 'venezuelensis', 'p.', 'venezuelensis', 'p', 'plave', 'probosciger', 'aterrimus', 'p.', 'aterrimus', 'p', 'proar', 'fregetta', 'grallaria', 'f.', 'grallaria', 'f', 'frega', 'loxia', 'curvirostra', 'l.', 'curvirostra', 'l', 'loxcu', 'pedionomus', 'torquatus', 'p.', 'torquatus', 'p', 'pedto', 'paenibacillus', 'lemnae', 'p.', 'lemnae', 'p', 'paele', 'oenanthe', 'oenanthe', 'o.', 'oenanthe', 'o', 'oenon', 'rhinopomastus', 'cyanomelas', 'r.', 'cyanomelas', 'r', 'rhicy', 'aramus', 'guarauna', 'a.', 'guarauna', 'a', 'araga', 'nyctibius', 'grandis', 'n.', 'grandis', 'n', 'nycgr', 'anseranas', 'semipalmata', 'a.', 'semipalmata', 'a', 'ansse', 'fusarium', 'heterosporum', 'f.', 'heterosporum', 'f', 'fushe', 'chordeiles', 'acutipennis', 'c.', 'acutipennis', 'c', 'choac', 'oceanites', 'oceanicus', 'o.', 'oceanicus', 'o', 'oceoc', 'himantopus', 'himantopus', 'h.', 'himantopus', 'h', 'himhi', 'actinomadura', 'namibiensis', 'a.', 'namibiensis', 'a', 'actnm', 'polioptila', 'caerulea', 'p.', 'caerulea', 'p', 'polce', 'aphelocoma', 'coerulescens', 'a.', 'coerulescens', 'a', 'aphce', 'pheucticus', 'melanocephalus', 'p.', 'melanocephalus', 'p', 'pheme', 'baryphthengus', 'martii', 'b.', 'martii', 'b', 'barma', 'phainopepla', 'nitens', 'p.', 'nitens', 'p', 'phani', 'gymnorhina', 'tibicen', 'g.', 'tibicen', 'g', 'gymti', 'pandion', 'haliaetus', 'p.', 'haliaetus', 'p', 'panha', 'glareola', 'pratincola', 'g.', 'pratincola', 'g', 'glapt', 'pomatostomus', 'ruficeps', 'p.', 'ruficeps', 'p', 'pomru', 'cardinalis', 'cardinalis', 'c.', 'cardinalis', 'c', 'carcd', 'sitta', 'europaea', 's.', 'europaea', 's', 'siteu', 'cannabis', 'sativa', 'c.', 'sativa', 'c', 'cansa', 'podargus', 'strigoides', 'p.', 'strigoides', 'p', 'podst', 'citrobacter', 'freundii', 'c.', 'freundii', 'c', 'citfr', 'ptilonorhynchus', 'violaceus', 'p.', 'violaceus', 'p', 'ptivi', 'hirundo', 'rustica', 'h.', 'rustica', 'h', 'hirru', 'nitrospinae', 'bacterium', 'n.', 'bacterium', 'n', 'uncni', 'rhodocyclus', 'tenuis', 'r.', 'tenuis', 'r', 'rhote', 'streptomyces', 'morookaense', 's.', 'morookaense', 's', 'strmo', 'vireo', 'altiloquus', 'v.', 'altiloquus', 'v', 'viral', 'cinclus', 'mexicanus', 'c.', 'mexicanus', 'c', 'cinmu', 'glaucidium', 'brasilianum', 'g.', 'brasilianum', 'g', 'glabr', 'perkinsus', 'chesapeaki', 'p.', 'chesapeaki', 'p', 'perch', 'planctomycetota', 'bacterium', 'p.', 'bacterium', 'p', 'uncpl', 'gossypium', 'davidsonii', 'g.', 'davidsonii', 'g', 'gosdv', 'tripterygium', 'wilfordii', 't.', 'wilfordii', 't', 'triwf', 'apium', 'graveolens', 'a.', 'graveolens', 'a', 'apigr', 'camellia', 'sinensis', 'c.', 'sinensis', 'c', 'camsi', 'ameiurus', 'melas', 'a.', 'melas', 'a', 'ameme', 'rousettus', 'aegyptiacus', 'r.', 'aegyptiacus', 'r', 'rouae', 'gossypium', 'schwendimanii', 'g.', 'schwendimanii', 'g', 'gossc', 'gossypium', 'aridum', 'g.', 'aridum', 'g', 'gosai', 'gossypium', 'gossypioides', 'g.', 'gossypioides', 'g', 'gosgo', 'streptomyces', 'chromofuscus', 's.', 'chromofuscus', 's', 'strcw', 'african', 'swine', 'a.', 'swine', 'a', 'asf', 'crocodylus', 'porosus', 'c.', 'porosus', 'c', 'cropo', 'varroa', 'destructor', 'v.', 'destructor', 'v', 'varde', 'quercus', 'lobata', 'q.', 'lobata', 'q', 'quelo', 'kalanchoe', 'fedtschenkoi', 'k.', 'fedtschenkoi', 'k', 'kalfe', 'epichloe', 'festucae', 'e.', 'festucae', 'e', 'epiff', 'hermetia', 'illucens', 'h.', 'illucens', 'h', 'heril', 'atribacter', 'laminatus', 'a.', 'laminatus', 'a', 'atrlm', 'bovine', 'adenovirus', 'b.', 'adenovirus', 'b', 'adeb7', 'chenopodium', 'quinoa', 'c.', 'quinoa', 'c', 'cheqi', 'mytilus', 'galloprovincialis', 'm.', 'galloprovincialis', 'm', 'mytga', 'vespula', 'pensylvanica', 'v.', 'pensylvanica', 'v', 'vespe', 'calcarius', 'ornatus', 'c.', 'ornatus', 'c', 'calor', 'corvus', 'moneduloides', 'c.', 'moneduloides', 'c', 'cormo', 'silurus', 'meridionalis', 's.', 'meridionalis', 's', 'silme', 'certhia', 'familiaris', 'c.', 'familiaris', 'c', 'cerfa', 'colletotrichum', 'gloeosporioides', 'c.', 'gloeosporioides', 'c', 'colgl', 'mycena', 'chlorophos', 'm.', 'chlorophos', 'm', 'myccl', 'vespula', 'vulgaris', 'v.', 'vulgaris', 'v', 'vesvu', 'bionectria', 'ochroleuca', 'b.', 'ochroleuca', 'b', 'biooc', 'vespula', 'germanica', 'v.', 'germanica', 'v', 'vesge', 'spizella', 'passerina', 's.', 'passerina', 's', 'spipa', 'sula', 'dactylatra', 's.', 'dactylatra', 's', 'sulda', 'corythaeola', 'cristata', 'c.', 'cristata', 'c', 'corcr', 'pleurotus', 'ostreatus', 'p.', 'ostreatus', 'p', 'pleos', 'cochliobolus', 'sativus', 'c.', 'sativus', 'c', 'cocsa', 'passerina', 'amoena', 'p.', 'amoena', 'p', 'pasaf', 'rhynchophorus', 'ferrugineus', 'r.', 'ferrugineus', 'r', 'rhyfe', 'rhododendron', 'simsii', 'r.', 'simsii', 'r', 'rhoss', 'aegithalos', 'caudatus', 'a.', 'caudatus', 'a', 'aegca', 'peucedramus', 'taeniatus', 'p.', 'taeniatus', 'p', 'peuta', 'picathartes', 'gymnocephalus', 'p.', 'gymnocephalus', 'p', 'picgy', 'tychaedon', 'coryphoeus', 't.', 'coryphoeus', 't', 'tycco', 'fregata', 'magnificens', 'f.', 'magnificens', 'f', 'frema', 'pitta', 'sordida', 'p.', 'sordida', 'p', 'pitso', 'vidua', 'chalybeata', 'v.', 'chalybeata', 'v', 'vidch', 'vanilla', 'planifolia', 'v.', 'planifolia', 'v', 'vanpl', 'aspergillus', 'chevalieri', 'a.', 'chevalieri', 'a', 'aspch', 'eolophus', 'roseicapilla', 'e.', 'roseicapilla', 'e', 'eolro', 'grus', 'americana', 'g.', 'americana', 'g', 'gruam', 'calyptomena', 'viridis', 'c.', 'viridis', 'c', 'calvr', 'nyctereutes', 'procyonoides', 'n.', 'procyonoides', 'n', 'nycpr', 'oryzias', 'melastigma', 'o.', 'melastigma', 'o', 'oryme', 'spodoptera', 'exigua', 's.', 'exigua', 's', 'spoex', 'chlamydomonas', 'incerta', 'c.', 'incerta', 'c', 'chlin', 'piaya', 'cayana', 'p.', 'cayana', 'p', 'piaca', 'plutella', 'xylostella', 'p.', 'xylostella', 'p', 'pluxy', 'mortierella', 'isabellina', 'm.', 'isabellina', 'm', 'moris', 'urocolius', 'indicus', 'u.', 'indicus', 'u', 'uroin', 'planobispora', 'rosea', 'p.', 'rosea', 'p', 'plaro', 'vidua', 'macroura', 'v.', 'macroura', 'v', 'vidma', 'anhinga', 'anhinga', 'a.', 'anhinga', 'a', 'anhan', 'bursaphelenchus', 'xylophilus', 'b.', 'xylophilus', 'b', 'burxy', 'todus', 'mexicanus', 't.', 'mexicanus', 't', 'todme', 'aspergillus', 'kawachii', 'a.', 'kawachii', 'a', 'aspka', 'eeniella', 'nana', 'e.', 'nana', 'e', 'eenna', 'fusarium', 'pseudograminearum', 'f.', 'pseudograminearum', 'f', 'fusps', 'spirodela', 'intermedia', 's.', 'intermedia', 's', 'spiin', 'adineta', 'ricciae', 'a.', 'ricciae', 'a', 'adiri', 'sulfidibacter', 'corallicola', 's.', 'corallicola', 's', 'sulco', 'psilocybe', 'cubensis', 'p.', 'cubensis', 'p', 'psicu', 'ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a', 'ajeca', 'panthera', 'tigris', 'p.', 'tigris', 'p', 'panta', 'subterranean', 'clover', 's.', 'clover', 's', 'scsv', 'chrysemys', 'picta', 'c.', 'picta', 'c', 'chrpi', 'nannospalax', 'galili', 'n.', 'galili', 'n', 'nanga', 'geospiza', 'parvula', 'g.', 'parvula', 'g', 'geopr', 'cyprinus', 'carpio', 'c.', 'carpio', 'c', 'cypca', 'jaculus', 'jaculus', 'j.', 'jaculus', 'j', 'jacja', 'eptatretus', 'burgeri', 'e.', 'burgeri', 'e', 'eptbu', 'dicentrarchus', 'labrax', 'd.', 'labrax', 'd', 'dicla', 'sphenodon', 'punctatus', 's.', 'punctatus', 's', 'sphpu', 'microcebus', 'murinus', 'm.', 'murinus', 'm', 'micmu', 'chinchilla', 'lanigera', 'c.', 'lanigera', 'c', 'chila', 'panthera', 'leo', 'p.', 'leo', 'p', 'panle', 'oncorhynchus', 'tshawytscha', 'o.', 'tshawytscha', 'o', 'oncts', 'chelydra', 'serpentina', 'c.', 'serpentina', 'c', 'chese', 'chelonoidis', 'abingdonii', 'c.', 'abingdonii', 'c', 'cheab', 'melopsittacus', 'undulatus', 'm.', 'undulatus', 'm', 'melud', 'laticauda', 'laticaudata', 'l.', 'laticaudata', 'l', 'latla', 'marmota', 'marmota', 'm.', 'marmota', 'm', 'marma', 'junco', 'hyemalis', 'j.', 'hyemalis', 'j', 'junhy', 'serinus', 'canaria', 's.', 'canaria', 's', 'serca', 'cyanistes', 'caeruleus', 'c.', 'caeruleus', 'c', 'cyacu', 'theropithecus', 'gelada', 't.', 'gelada', 't', 'thege', 'coturnix', 'japonica', 'c.', 'japonica', 'c', 'cotja', 'zonotrichia', 'albicollis', 'z.', 'albicollis', 'z', 'zonal', 'prolemur', 'simus', 'p.', 'simus', 'p', 'pross', 'mus', 'spicilegus', 'm.', 'spicilegus', 'm', 'mussi', 'urocitellus', 'parryii', 'u.', 'parryii', 'u', 'uropr', 'nothoprocta', 'perdicaria', 'n.', 'perdicaria', 'n', 'notpe', 'salvator', 'merianae', 's.', 'merianae', 's', 'salmn', 'spermophilus', 'dauricus', 's.', 'dauricus', 's', 'speda', 'apteryx', 'owenii', 'a.', 'owenii', 'a', 'aptow', 'neovison', 'vison', 'n.', 'vison', 'n', 'neovi', 'pavo', 'cristatus', 'p.', 'cristatus', 'p', 'pavcr', 'bos', 'mutus', 'b.', 'mutus', 'b', 'bosmu', 'anser', 'cygnoides', 'a.', 'cygnoides', 'a', 'anscy', 'chrysolophus', 'pictus', 'c.', 'pictus', 'c', 'chrpc', 'moschus', 'moschiferus', 'm.', 'moschiferus', 'm', 'mosmo', 'varanus', 'komodoensis', 'v.', 'komodoensis', 'v', 'varko', 'gadus', 'morhua', 'g.', 'morhua', 'g', 'gadmo', 'nothobranchius', 'furzeri', 'n.', 'furzeri', 'n', 'notfu', 'phocoena', 'sinus', 'p.', 'sinus', 'p', 'phoss', 'oncorhynchus', 'kisutch', 'o.', 'kisutch', 'o', 'oncki', 'naja', 'naja', 'n.', 'naja', 'n', 'najna', 'falco', 'tinnunculus', 'f.', 'tinnunculus', 'f', 'falti', 'catharus', 'ustulatus', 'c.', 'ustulatus', 'c', 'catus', 'sciurus', 'vulgaris', 's.', 'vulgaris', 's', 'scivu', 'cyclopterus', 'lumpus', 'c.', 'lumpus', 'c', 'cyclu', 'bubo', 'bubo', 'b.', 'bubo', 'b', 'bubbb', 'sander', 'lucioperca', 's.', 'lucioperca', 's', 'sanlu', 'erpetoichthys', 'calabaricus', 'e.', 'calabaricus', 'e', 'erpca', 'hydra', 'vulgaris', 'h.', 'vulgaris', 'h', 'hydvu', 'hyalella', 'azteca', 'h.', 'azteca', 'h', 'hyaaz', 'crassostrea', 'virginica', 'c.', 'virginica', 'c', 'cravi', 'acanthaster', 'planci', 'a.', 'planci', 'a', 'acapl', 'vanessa', 'tameamea', 'v.', 'tameamea', 'v', 'vanta', 'hipposideros', 'armiger', 'h.', 'armiger', 'h', 'hipar', 'castor', 'canadensis', 'c.', 'canadensis', 'c', 'cascn', 'abrus', 'precatorius', 'a.', 'precatorius', 'a', 'abrpr', 'balaenoptera', 'musculus', 'b.', 'musculus', 'b', 'balmu', 'galemys', 'pyrenaicus', 'g.', 'pyrenaicus', 'g', 'galpy', 'microtus', 'ochrogaster', 'm.', 'ochrogaster', 'm', 'micoh', 'eudyptes', 'chrysocome', 'e.', 'chrysocome', 'e', 'eudch', 'tenebrio', 'molitor', 't.', 'molitor', 't', 'tenmo', 'clarias', 'magur', 'c.', 'magur', 'c', 'clamg', 'zizania', 'palustris', 'z.', 'palustris', 'z', 'zizpa', 'zingiber', 'officinale', 'z.', 'officinale', 'z', 'zinof', 'atractosteus', 'spatula', 'a.', 'spatula', 'a', 'atrsp', 'owenia', 'fusiformis', 'o.', 'fusiformis', 'o', 'owefu', 'aptenodytes', 'patagonicus', 'a.', 'patagonicus', 'a', 'aptpa', 'diacronema', 'lutheri', 'd.', 'lutheri', 'd', 'dialt', 'eleutherodactylus', 'coqui', 'e.', 'coqui', 'e', 'elecq', 'eudyptula', 'minor', 'e.', 'minor', 'e', 'eudmi', 'cotesia', 'congregata', 'c.', 'congregata', 'c', 'cotcn', 'ladona', 'fulva', 'l.', 'fulva', 'l', 'ladfu', 'pythium', 'oligandrum', 'p.', 'oligandrum', 'p', 'pytol', 'cocos', 'nucifera', 'c.', 'nucifera', 'c', 'cocnu', 'andalucia', 'godoyi', 'a.', 'godoyi', 'a', 'andgo', 'populus', 'deltoides', 'p.', 'deltoides', 'p', 'popde', 'argiope', 'bruennichi', 'a.', 'bruennichi', 'a', 'argbr', 'salvelinus', 'namaycush', 's.', 'namaycush', 's', 'salnm', 'carya', 'illinoinensis', 'c.', 'illinoinensis', 'c', 'caril', 'ceratodon', 'purpureus', 'c.', 'purpureus', 'c', 'cerpu', 'panicum', 'virgatum', 'p.', 'virgatum', 'p', 'panvg', 'ceratopteris', 'richardii', 'c.', 'richardii', 'c', 'cerri', 'dendrobium', 'nobile', 'd.', 'nobile', 'd', 'denno', 'branchiostoma', 'lanceolatum', 'b.', 'lanceolatum', 'b', 'brala', 'brassica', 'carinata', 'b.', 'carinata', 'b', 'braci', 'polypterus', 'senegalus', 'p.', 'senegalus', 'p', 'polse', 'populus', 'tomentosa', 'p.', 'tomentosa', 'p', 'popto', 'synechococcus', 'elongatus', 's.', 'elongatus', 's', 'syne7', 'enterobacter', 'sp', 'e.', 'sp', 'e', 'ent38', 'white', 'spot', 'w.', 'spot', 'w', 'wssvs', 'salmonella', 'phage', 's.', 'phage', 's', 'bpsav', 'streptococcus', 'phage', 's.', 'phage', 's', 'bpo12', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpkpp', 'paramecium', 'tetraurelia', 'p.', 'tetraurelia', 'p', 'parte', 'acidovorax', 'sp', 'a.', 'sp', 'a', 'acisj', 'trypanosoma', 'congolense', 't.', 'congolense', 't', 'tryci', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmb2', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmbz', 'sulfolobus', 'viruslike', 's.', 'viruslike', 's', 'ssv2', 'moniliophthora', 'perniciosa', 'm.', 'perniciosa', 'm', 'monpe', 'shigella', 'phage', 's.', 'phage', 's', 'bpsfv', 'paramecium', 'bursaria', 'p.', 'bursaria', 'p', 'pbcv1', 'emiliania', 'huxleyi', 'e.', 'huxleyi', 'e', 'ehv8u', 'ectocarpus', 'siliculosus', 'e.', 'siliculosus', 'e', 'esv1k', 'amsacta', 'moorei', 'a.', 'moorei', 'a', 'amepv', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpd31', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpr69', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bprb4', 'synechococcus', 'phage', 's.', 'phage', 's', 'bpsys', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bplp0', 'prochlorococcus', 'phage', 'p.', 'phage', 'p', 'bpprs', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmom', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmco', 'prochlorococcus', 'phage', 'p.', 'phage', 'p', 'bpprm', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppaj', 'thermus', 'virus', 't.', 'virus', 't', 'bp234', 'enterococcus', 'phage', 'e.', 'phage', 'e', 'bpphe', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpt1', 'salmonella', 'phage', 's.', 'phage', 's', 'bpst6', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bpr1t', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bpmr1', 'halomonas', 'phage', 'h.', 'phage', 'h', 'bpha1', 'laccaria', 'bicolor', 'l.', 'bicolor', 'l', 'lacbs', 'clostridium', 'botulinum', 'c.', 'botulinum', 'c', 'cbcp', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bppgk', 'trichoplusia', 'ni', 't.', 'ni', 't', 'tnavc', 'heliothis', 'virescens', 'h.', 'virescens', 'h', 'hvave', 'invertebrate', 'iridescent', 'i.', 'iridescent', 'i', 'iiv6', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bptwo', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bptu2', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpsp1', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpsp6', 'rhizobium', 'phage', 'r.', 'phage', 'r', 'bp163', 'enterocytozoon', 'bieneusi', 'e.', 'bieneusi', 'e', 'entbh', 'postia', 'placenta', 'p.', 'placenta', 'p', 'pospm', 'bordetella', 'phage', 'b.', 'phage', 'b', 'bpbpp', 'salmonella', 'phage', 's.', 'phage', 's', 'bpe15', 'vibrio', 'phage', 'v.', 'phage', 'v', 'bpkvm', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpn4', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bplc2', 'lactococcus', 'phage', 'l.', 'phage', 'l', 'bpllh', 'theileria', 'parva', 't.', 'parva', 't', 'thepa', 'pseudoalteromonas', 'atlantica', 'p.', 'atlantica', 'p', 'psea6', 'rhizorhabdus', 'wittichii', 'r.', 'wittichii', 'r', 'rhiwr', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpe32', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpluz', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppyu', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpdpk', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bpphd', 'streptomyces', 'phage', 's.', 'phage', 's', 'bpphc', 'mycobacterium', 'phage', 'm.', 'phage', 'm', 'bpmt4', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppp7', 'his', '2', 'h.', '2', 'h', 'his2v', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bp201', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bpmr2', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bp35c', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpga1', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpvt2', 'listeria', 'phage', 'l.', 'phage', 'l', 'bpa18', 'helicobacter', 'pylori', 'h.', 'pylori', 'h', 'bpkhp', 'edhazardia', 'aedis', 'e.', 'aedis', 'e', 'edhae', 'haloredivivus', 'sp', 'h.', 'sp', 'h', 'halsg', 'vibrio', 'phage', 'v.', 'phage', 'v', 'bpcpt', 'caenorhabditis', 'japonica', 'c.', 'japonica', 'c', 'caeja', 'acidianus', 'filamentous', 'a.', 'filamentous', 'a', 'afv2p', 'mycoplasma', 'haemolamae', 'm.', 'haemolamae', 'm', 'mycha', 'auricularia', 'subglabra', 'a.', 'subglabra', 'a', 'aurst', 'campoletis', 'sonorensis', 'c.', 'sonorensis', 'c', 'csivt', 'culex', 'nigripalpus', 'c.', 'nigripalpus', 'c', 'npvco', 'clostridium', 'phage', 'c.', 'phage', 'c', 'bppcd', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpprr', 'naegleria', 'gruberi', 'n.', 'gruberi', 'n', 'naegr', 'periplaneta', 'fuliginosa', 'p.', 'fuliginosa', 'p', 'pfdng', 'rachiplusia', 'ou', 'r.', 'ou', 'r', 'npvr1', 'shigella', 'phage', 's.', 'phage', 's', 'bpsp8', 'bombyx', 'mori', 'b.', 'mori', 'b', 'bmdns', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bp44a', 'perkinsus', 'marinus', 'p.', 'marinus', 'p', 'perm5', 'spodoptera', 'frugiperda', 's.', 'frugiperda', 's', 'sfava', 'nitrososphaera', 'gargensis', 'n.', 'gargensis', 'n', 'nitgg', 'caldiarchaeum', 'subterraneum', 'c.', 'subterraneum', 'c', 'cals0', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpppb', 'listeria', 'phage', 'l.', 'phage', 'l', 'bpa50', 'leishmania', 'infantum', 'l.', 'infantum', 'l', 'leiin', 'botryotinia', 'fuckeliana', 'b.', 'fuckeliana', 'b', 'botf4', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpph1', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppa3', 'plasmodium', 'yoelii', 'p.', 'yoelii', 'p', 'playo', 'acinetobacter', 'phage', 'a.', 'phage', 'a', 'bpac4', 'infectious', 'spleen', 'i.', 'spleen', 'i', 'isknn', 'neodiprion', 'lecontei', 'n.', 'lecontei', 'n', 'npvnc', 'pyrobaculum', 'spherical', 'p.', 'spherical', 'p', 'psvy', 'vibrio', 'phage', 'v.', 'phage', 'v', 'bpvc8', 'clonorchis', 'sinensis', 'c.', 'sinensis', 'c', 'closi', 'aeropyrum', 'pernix', 'a.', 'pernix', 'a', 'apov1', 'pneumococcus', 'phage', 'p.', 'phage', 'p', 'bpdp1', 'bombyx', 'mori', 'b.', 'mori', 'b', 'bmdnd', 'delftia', 'phage', 'd.', 'phage', 'd', 'bpw14', 'trypanosoma', 'vivax', 't.', 'vivax', 't', 'tryvy', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bppkt', 'salmonella', 'phage', 's.', 'phage', 's', 'bpfo1', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpd3', 'fusarium', 'oxysporum', 'f.', 'oxysporum', 'f', 'fuso4', 'tetrahymena', 'thermophila', 't.', 'thermophila', 't', 'tetts', 'cydia', 'pomonella', 'c.', 'pomonella', 'c', 'gvcpm', 'thermoproteus', 'tenax', 't.', 'tenax', 't', 'ttv1k', 'nannochloropsis', 'gaditana', 'n.', 'gaditana', 'n', 'nangc', 'nanosalina', 'sp', 'n.', 'sp', 'n', 'nans0', 'nanosalinarum', 'sp', 'n.', 'sp', 'n', 'nansj', 'trachipleistophora', 'hominis', 't.', 'hominis', 't', 'traho', 'burkholderia', 'phage', 'b.', 'phage', 'b', 'bpb78', 'burkholderia', 'phage', 'b.', 'phage', 'b', 'bpbmu', 'ranid', 'herpesvirus', 'r.', 'herpesvirus', 'r', 'rahv1', 'anguillid', 'herpesvirus', 'a.', 'herpesvirus', 'a', 'anhv1', 'torque', 'teno', 't.', 'teno', 't', 'ttvk2', 'euprosterna', 'elaeasa', 'e.', 'elaeasa', 'e', 'eevz', 'aeropyrum', 'pernix', 'a.', 'pernix', 'a', 'apbv1', 'musca', 'hytrovirusisolate', 'm.', 'hytrovirusisolate', 'm', 'mhvb', 'torque', 'teno', 't.', 'teno', 't', 'zcttv', 'salmonella', 'phage', 's.', 'phage', 's', 'bps16', 'nile', 'crocodilepox', 'n.', 'crocodilepox', 'n', 'cprvz', 'glossina', 'hytrovirus', 'g.', 'hytrovirus', 'g', 'ghvs', 'thanatephorus', 'cucumeris', 't.', 'cucumeris', 't', 'thaca', 'oryctes', 'rhinoceros', 'o.', 'rhinoceros', 'o', 'ornvm', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpph8', 'spraguea', 'lophii', 's.', 'lophii', 's', 'sprlo', 'shigella', 'phage', 's.', 'phage', 's', 'bpsf2', 'paeniclostridium', 'sordellii', 'p.', 'sordellii', 'p', 'paes9', 'nosema', 'bombycis', 'n.', 'bombycis', 'n', 'nosb1', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpgra', 'rhizophagus', 'irregularis', 'r.', 'irregularis', 'r', 'rhiid', 'gregarina', 'niphandrodes', 'g.', 'niphandrodes', 'g', 'greni', 'rhizophagus', 'irregularis', 'r.', 'irregularis', 'r', 'rhiiw', 'reticulomyxa', 'filosa', 'r.', 'filosa', 'r', 'retfi', 'streptococcus', 'phage', 's.', 'phage', 's', 'bpcp7', 'grapevine', 'leafrollassociated', 'g.', 'leafrollassociated', 'g', 'glrv7', 'hibiscus', 'green', 'h.', 'green', 'h', 'hgsv2', 'fenneropenaeus', 'chinensis', 'f.', 'chinensis', 'f', 'fcdnv', 'infectious', 'hypodermal', 'i.', 'hypodermal', 'i', 'ihhnv', 'galliform', 'aveparvovirus', 'g.', 'aveparvovirus', 'g', 'chpv1', 'eidolon', 'helvum', 'e.', 'helvum', 'e', 'btpv1', 'abalone', 'herpesvirus', 'a.', 'herpesvirus', 'a', 'abhv', 'helicoverpa', 'zea', 'h.', 'zea', 'h', 'hznv2', 'marseillevirus', 'marseillevirus', 'm.', 'marseillevirus', 'm', 'gbmv', 'cafeteria', 'roenbergensis', 'c.', 'roenbergensis', 'c', 'crovb', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpr27', 'rosellinia', 'necatrix', 'r.', 'necatrix', 'r', 'rnqvw', 'streptococcus', 'pyogenes', 's.', 'pyogenes', 's', 'bpt12', 'thelohanellus', 'kitauei', 't.', 'kitauei', 't', 'thekt', 'gossypium', 'arboreum', 'g.', 'arboreum', 'g', 'gosar', 'angiostrongylus', 'cantonensis', 'a.', 'cantonensis', 'a', 'angca', 'lasius', 'niger', 'l.', 'niger', 'l', 'lasni', 'operophtera', 'brumata', 'o.', 'brumata', 'o', 'opebr', 'leptomonas', 'pyrrhocoris', 'l.', 'pyrrhocoris', 'l', 'leppy', 'chlamydia', 'trachomatis', 'c.', 'trachomatis', 'c', 'chlth', 'bodo', 'saltans', 'b.', 'saltans', 'b', 'bodsa', 'fomitiporia', 'mediterranea', 'f.', 'mediterranea', 'f', 'fomme', 'oesophagostomum', 'dentatum', 'o.', 'dentatum', 'o', 'oesde', 'stereum', 'hirsutum', 's.', 'hirsutum', 's', 'stehr', 'piloderma', 'croceum', 'p.', 'croceum', 'p', 'pilcf', 'sphaerobolus', 'stellatus', 's.', 'stellatus', 's', 'sphs4', 'trametes', 'versicolor', 't.', 'versicolor', 't', 'travs', 'stegodyphus', 'mimosarum', 's.', 'mimosarum', 's', 'stemi', 'amanita', 'muscaria', 'a.', 'muscaria', 'a', 'amamk', 'plasmopara', 'halstedii', 'p.', 'halstedii', 'p', 'plahl', 'cajanus', 'cajan', 'c.', 'cajan', 'c', 'cajca', 'manihot', 'esculenta', 'm.', 'esculenta', 'm', 'manes', 'wiseana', 'iridescent', 'w.', 'iridescent', 'w', 'irv9', 'rice', 'black', 'r.', 'black', 'r', 'rbsdv', 'maize', 'rough', 'm.', 'rough', 'm', 'mrdv', 'rosellinia', 'necatrix', 'r.', 'necatrix', 'r', 'myrvw', 'orgyia', 'pseudotsugata', 'o.', 'pseudotsugata', 'o', 'cpvop', 'rhesus', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r', 'rhcm6', 'canarypox', 'virus', 'c.', 'virus', 'c', 'cnpv', 'melanoplus', 'sanguinipes', 'm.', 'sanguinipes', 'm', 'msepv', 'bovine', 'adenovirus', 'b.', 'adenovirus', 'b', 'adeb4', 'symbiodinium', 'microadriaticum', 's.', 'microadriaticum', 's', 'symmi', 'cephalotus', 'follicularis', 'c.', 'follicularis', 'c', 'cepfo', 'zancudomyces', 'culisetae', 'z.', 'culisetae', 'z', 'zancu', 'euroglyphus', 'maynei', 'e.', 'maynei', 'e', 'eurma', 'leucania', 'separata', 'l.', 'separata', 'l', 'npvls', 'paramecium', 'bursaria', 'p.', 'bursaria', 'p', 'pbcvn', 'pyrobaculum', 'filamentous', 'p.', 'filamentous', 'p', 'pfv1', 'epiphyas', 'postvittana', 'e.', 'postvittana', 'e', 'npvep', 'cryptophlebia', 'leucotreta', 'c.', 'leucotreta', 'c', 'gvcl', 'pea', 'enation', 'p.', 'enation', 'p', 'pemv2', 'paramecium', 'bursaria', 'p.', 'bursaria', 'p', 'pbcva', 'nora', 'virus', 'n.', 'virus', 'n', 'norav', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpk21', 'chrysochromulina', 'ericina', 'c.', 'ericina', 'c', 'cev01', 'lymantria', 'dispar', 'l.', 'dispar', 'l', 'npvld', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bppam', 'paramecium', 'bursaria', 'p.', 'bursaria', 'p', 'pbcvf', 'pseudomonas', 'phage', 'p.', 'phage', 'p', 'bpkp2', 'staphylococcus', 'phage', 's.', 'phage', 's', 'bps25', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bps10', 'satellite', 'panicum', 's.', 'panicum', 's', 'spmv', 'avonheathcote', 'estuary', 'a.', 'estuary', 'a', 'ahebv', 'helianthus', 'annuus', 'h.', 'annuus', 'h', 'helan', 'armillaria', 'gallica', 'a.', 'gallica', 'a', 'armga', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpgo3', 'thermus', 'phage', 't.', 'phage', 't', 'bpg20', 'sulfolobus', 'polyhedral', 's.', 'polyhedral', 's', 'spv1', 'lithobates', 'catesbeianus', 'l.', 'catesbeianus', 'l', 'litct', 'teladorsagia', 'circumcincta', 't.', 'circumcincta', 't', 'telci', 'punica', 'granatum', 'p.', 'granatum', 'p', 'pungr', 'trifolium', 'pratense', 't.', 'pratense', 't', 'tripr', 'trema', 'orientale', 't.', 'orientale', 't', 'treoi', 'parasponia', 'andersonii', 'p.', 'andersonii', 'p', 'parad', 'salmonella', 'phage', 's.', 'phage', 's', 'bppmb', 'acinetobacter', 'phage', 'a.', 'phage', 'a', 'bpsha', 'picea', 'glauca', 'p.', 'glauca', 'p', 'picgl', 'choristoneura', 'fumiferana', 'c.', 'fumiferana', 'c', 'gvcf', 'blattella', 'germanica', 'b.', 'germanica', 'b', 'blage', 'synechococcus', 'phage', 's.', 'phage', 's', 'bpsyp', 'paramecium', 'bursaria', 'p.', 'bursaria', 'p', 'pbcvm', 'ancylostoma', 'caninum', 'a.', 'caninum', 'a', 'ancca', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpbsp', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpt6', 'bacteroides', 'phage', 'b.', 'phage', 'b', 'bpca1', 'sulfolobus', 'filamentous', 's.', 'filamentous', 's', 'sufv1', 'thalassiosira', 'oceanica', 't.', 'oceanica', 't', 'thaoc', 'anisakis', 'simplex', 'a.', 'simplex', 'a', 'anisi', 'haemonchus', 'placei', 'h.', 'placei', 'h', 'haepc', 'strongylus', 'vulgaris', 's.', 'vulgaris', 's', 'strvu', 'nippostrongylus', 'brasiliensis', 'n.', 'brasiliensis', 'n', 'nipbr', 'cylicostephanus', 'goldi', 'c.', 'goldi', 'c', 'cylgo', 'schistocephalus', 'solidus', 's.', 'solidus', 's', 'schso', 'brachionus', 'plicatilis', 'b.', 'plicatilis', 'b', 'brapc', 'halobacterium', 'phage', 'h.', 'phage', 'h', 'bpphh', 'trichobilharzia', 'regenti', 't.', 'regenti', 't', 'trire', 'dibothriocephalus', 'latus', 'd.', 'latus', 'd', 'dibla', 'chiloscyllium', 'punctatum', 'c.', 'punctatum', 'c', 'chipu', 'armadillidium', 'vulgare', 'a.', 'vulgare', 'a', 'armvu', 'ensete', 'ventricosum', 'e.', 'ventricosum', 'e', 'ensve', 'metamycoplasma', 'salivarium', 'm.', 'salivarium', 'm', 'metsv', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpvt1', 'escherichia', 'phage', 'e.', 'phage', 'e', 'bpgos', 'dendrothele', 'bispora', 'd.', 'bispora', 'd', 'denbc', 'eumeta', 'variegata', 'e.', 'variegata', 'e', 'eumva', 'spodoptera', 'litura', 's.', 'litura', 's', 'spolt', 'escherichia', 'virus', 'e.', 'virus', 'e', 'bpqbe', 'schistosoma', 'japonicum', 's.', 'japonicum', 's', 'schja', 'giardia', 'muris', 'g.', 'muris', 'g', 'giamu', 'pseudomonas', 'sp', 'p.', 'sp', 'p', 'psesp', 'sphingomonas', 'sp', 's.', 'sp', 's', 'sphsx', 'bacillus', 'phage', 'b.', 'phage', 'b', 'bpgo7', 'fowl', 'adenovirus', 'f.', 'adenovirus', 'f', 'adegx', 'portunus', 'trituberculatus', 'p.', 'trituberculatus', 'p', 'portr', 'gigaspora', 'margarita', 'g.', 'margarita', 'g', 'gigma', 'planktothrix', 'agardhii', 'p.', 'agardhii', 'p', 'plaag', 'aphis', 'craccivora', 'a.', 'craccivora', 'a', 'aphcr', 'haematococcus', 'lacustris', 'h.', 'lacustris', 'h', 'haela', 'araneus', 'ventricosus', 'a.', 'ventricosus', 'a', 'arave', 'pyrobaculum', 'filamentous', 'p.', 'filamentous', 'p', 'pfv2', 'saccharolobus', 'solfataricus', 's.', 'solfataricus', 's', 'ssrv1', 'red', 'sea', 'r.', 'sea', 'r', 'rsiv', 'enterobacteria', 'phage', 'e.', 'phage', 'e', 'bpt2', 'chrysochloris', 'asiatica', 'c.', 'asiatica', 'c', 'chras', 'mytilus', 'coruscus', 'm.', 'coruscus', 'm', 'mytco', 'spirometra', 'erinaceieuropaei', 's.', 'erinaceieuropaei', 's', 'spier', 'perkinsus', 'olseni', 'p.', 'olseni', 'p', 'perol', 'thalictrum', 'thalictroides', 't.', 'thalictroides', 't', 'thath', 'bugula', 'neritina', 'b.', 'neritina', 'b', 'bugne', 'caligus', 'rogercresseyi', 'c.', 'rogercresseyi', 'c', 'calro', 'cyanophage', 's2l', 'c.', 's2l', 'c', 'bps2l', 'sepia', 'pharaonis', 's.', 'pharaonis', 's', 'sepph', 'phytophthora', 'infestans', 'p.', 'infestans', 'p', 'phyin', 'ceratitis', 'capitata', 'c.', 'capitata', 'c', 'cerca', 'symbiodinium', 'pilosum', 's.', 'pilosum', 's', 'sympi', 'colocasia', 'esculenta', 'c.', 'esculenta', 'c', 'coles', 'polarella', 'glacialis', 'p.', 'glacialis', 'p', 'polgl', 'erwinia', 'phage', 'e.', 'phage', 'e', 'bpfbb', 'lepeophtheirus', 'salmonis', 'l.', 'salmonis', 'l', 'lepsm', 'mytilus', 'edulis', 'm.', 'edulis', 'm', 'myted', 'paramecium', 'octaurelia', 'p.', 'octaurelia', 'p', 'parot', 'paramecium', 'primaurelia', 'p.', 'primaurelia', 'p', 'parpr', 'parnassius', 'apollo', 'p.', 'apollo', 'p', 'parao', 'brassica', 'cretica', 'b.', 'cretica', 'b', 'bracr', 'thorarchaeota', 'archaeon', 't.', 'archaeon', 't', 'thoar', 'homarus', 'americanus', 'h.', 'americanus', 'h', 'homam', 'chionoecetes', 'opilio', 'c.', 'opilio', 'c', 'chiop', 'halteria', 'grandinella', 'h.', 'grandinella', 'h', 'halgn', 'alicyclobacillus', 'acidoterrestris', 'a.', 'acidoterrestris', 'a', 'aliag', 'nephila', 'pilipes', 'n.', 'pilipes', 'n', 'neppi', 'trichonephila', 'clavata', 't.', 'clavata', 't', 'tricu', 'trichonephila', 'clavipes', 't.', 'clavipes', 't', 'tricx', 'trichomonas', 'vaginalis', 't.', 'vaginalis', 't', 'triv3']
    # now go through it to get out the useful components
    organism_ids={'83333': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'ecoli'}, '559292': {'common_names': ['saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's', 'budding', 'bakers'], 'shortname': 'yeast'}, '10090': {'common_names': ['mus', 'musculus', 'm.', 'musculus', 'm', 'mouse'], 'shortname': 'mouse'}, '7227': {'common_names': ['drosophila', 'melanogaster', 'd.', 'melanogaster', 'd', 'fruit', 'fly'], 'shortname': 'drome'}, '224308': {'common_names': ['bacillus', 'subtilis', 'b.', 'subtilis', 'b'], 'shortname': 'bacsu'}, '10116': {'common_names': ['rattus', 'norvegicus', 'r.', 'norvegicus', 'r', 'rat'], 'shortname': 'rat'}, '9606': {'common_names': ['homo', 'sapiens', 'h.', 'sapiens', 'h', 'sapien', 'human', 'humans'], 'shortname': 'human'}, '3702': {'common_names': ['arabidopsis', 'thaliana', 'a.', 'thaliana', 'a', 'arath'], 'shortname': 'arath'}, '9913': {'common_names': ['bos', 'taurus', 'b.', 'taurus', 'b'], 'shortname': 'bovin'}, '7955': {'common_names': ['danio', 'rerio', 'd.', 'rerio', 'd', 'zebrafish', 'zebra', 'fish'], 'shortname': 'danre'}, '6239': {'common_names': ['caenorhabditis', 'elegans', 'c.', 'elegans', 'c', 'nematode', 'nematodes', 'worm'], 'shortname': 'caeel'}, '44689': {'common_names': ['dictyostelium', 'discoideum', 'd.', 'discoideum', 'd', 'slime', 'mold', 'dictyo'], 'shortname': 'dicdi'}, '39947': {'common_names': ['oryza', 'sativa', 'o.', 'sativa', 'o', 'rice'], 'shortname': 'orysj'}, '766194': {'common_names': ['dugbe', 'virus', 'd.', 'virus', 'd'], 'shortname': 'dugba'}, '10433': {'common_names': ['woodchuck', 'hepatitis', 'w.', 'hepatitis', 'w'], 'shortname': 'whv5'}, '299386': {'common_names': ['equine', 'arteritis', 'e.', 'arteritis', 'e'], 'shortname': 'eavbu'}, '694009': {'common_names': ['severe', 'acute', 's.', 'acute', 's'], 'shortname': 'sars'}, '360393': {'common_names': ['breda', 'virus', 'b.', 'virus', 'b'], 'shortname': 'brv1'}, '12081': {'common_names': ['poliovirus', 'type', 'p.', 'type', 'p'], 'shortname': 'pol1m'}, '475778': {'common_names': ['avian', 'encephalomyelitis', 'a.', 'encephalomyelitis', 'a'], 'shortname': 'aevca'}, '11090': {'common_names': ['yellow', 'fever', 'y.', 'fever', 'y'], 'shortname': 'yefv1'}, '12154': {'common_names': ['turnip', 'yellow', 't.', 'yellow', 't'], 'shortname': 'tymv'}, '649895': {'common_names': ['broad', 'bean', 'b.', 'bean', 'b'], 'shortname': 'bbwvs'}, '314536': {'common_names': ['rabbit', 'hemorrhagic', 'r.', 'hemorrhagic', 'r'], 'shortname': 'rhdvf'}, '654931': {'common_names': ['drosophila', 'x', 'd.', 'x', 'd'], 'shortname': 'dxv96'}, '63746': {'common_names': ['hepatitis', 'c', 'h.', 'c', 'h'], 'shortname': 'hcv77'}, '12219': {'common_names': ['potato', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pvyn'}, '117138': {'common_names': ['brome', 'streak', 'b.', 'streak', 'b'], 'shortname': 'bstv1'}, '12243': {'common_names': ['tobacco', 'mosaic', 't.', 'mosaic', 't'], 'shortname': 'tmv'}, '652106': {'common_names': ['ryegrass', 'mosaic', 'r.', 'mosaic', 'r'], 'shortname': 'rgmvd'}, '371094': {'common_names': ['chikungunya', 'virus', 'c.', 'virus', 'c'], 'shortname': 'chiks'}, '11033': {'common_names': ['semliki', 'forest', 's.', 'forest', 's'], 'shortname': 'sfv'}, '11045': {'common_names': ['rubella', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rubvt'}, '122962': {'common_names': ['human', 'parechovirus', 'h.', 'parechovirus', 'h'], 'shortname': 'hpe2w'}, '686944': {'common_names': ['seneca', 'valley', 's.', 'valley', 's'], 'shortname': 'svv1'}, '766180': {'common_names': ['white', 'bream', 'w.', 'bream', 'w'], 'shortname': 'wbv24'}, '649897': {'common_names': ['footandmouth', 'disease', 'f.', 'disease', 'f'], 'shortname': 'fmdvp'}, '524364': {'common_names': ['norwalk', 'virus', 'n.', 'virus', 'n'], 'shortname': 'nvn68'}, '11927': {'common_names': ['human', 'tcell', 'h.', 'tcell', 'h'], 'shortname': 'htl1c'}, '298339': {'common_names': ['simian', 'foamy', 's.', 'foamy', 's'], 'shortname': 'sfvcp'}, '292349': {'common_names': ['feline', 'calicivirus', 'f.', 'calicivirus', 'f'], 'shortname': 'fcvur'}, '11151': {'common_names': ['porcine', 'transmissible', 'p.', 'transmissible', 'p'], 'shortname': 'cvppu'}, '12456': {'common_names': ['human', 'astrovirus1', 'h.', 'astrovirus1', 'h'], 'shortname': 'hasv1'}, '12327': {'common_names': ['barley', 'stripe', 'b.', 'stripe', 'b'], 'shortname': 'bsmv'}, '2928746': {'common_names': ['spiroplasma', 'virus', 's.', 'virus', 's'], 'shortname': 'spv4'}, '363745': {'common_names': ['avian', 'leukosis', 'a.', 'leukosis', 'a'], 'shortname': 'alva'}, '373193': {'common_names': ['xenotropic', 'mulvrelated', 'x.', 'mulvrelated', 'x'], 'shortname': 'xmrv6'}, '11706': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1h2'}, '11714': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv2be'}, '11100': {'common_names': ['bovine', 'viral', 'b.', 'viral', 'b'], 'shortname': 'bvdvn'}, '2870365': {'common_names': ['encephalomyocarditis', 'virus', 'e.', 'virus', 'e'], 'shortname': 'emcvr'}, '11285': {'common_names': ['vesicular', 'stomatitis', 'v.', 'stomatitis', 'v'], 'shortname': 'vsiva'}, '652953': {'common_names': ['newcastle', 'disease', 'n.', 'disease', 'n'], 'shortname': 'ndvb1'}, '11622': {'common_names': ['lassa', 'virus', 'l.', 'virus', 'l'], 'shortname': 'lassj'}, '11624': {'common_names': ['lymphocytic', 'choriomeningitis', 'l.', 'choriomeningitis', 'l'], 'shortname': 'lycva'}, '35304': {'common_names': ['bunyamwera', 'virus', 'b.', 'virus', 'b'], 'shortname': 'bunyw'}, '11589': {'common_names': ['rift', 'valley', 'r.', 'valley', 'r'], 'shortname': 'rvfvz'}, '11059': {'common_names': ['dengue', 'virus', 'd.', 'virus', 'd'], 'shortname': 'den1w'}, '28285': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade05'}, '1217067': {'common_names': ['acute', 'bee', 'a.', 'bee', 'a'], 'shortname': 'abpvr'}, '11759': {'common_names': ['mouse', 'mammary', 'm.', 'mammary', 'm'], 'shortname': 'mmtvc'}, '694007': {'common_names': ['bat', 'coronavirus', 'b.', 'coronavirus', 'b'], 'shortname': 'bchk4'}, '694006': {'common_names': ['bat', 'coronavirus', 'b.', 'coronavirus', 'b'], 'shortname': 'bchk9'}, '648237': {'common_names': ['human', 'parvovirus', 'h.', 'parvovirus', 'h'], 'shortname': 'pavhv'}, '928306': {'common_names': ['moloney', 'murine', 'm.', 'murine', 'm'], 'shortname': 'mlvms'}, '36413': {'common_names': ['tomato', 'spotted', 't.', 'spotted', 't'], 'shortname': 'tswv1'}, '31762': {'common_names': ['hepatitis', 'delta', 'h.', 'delta', 'h'], 'shortname': 'hdvd3'}, '11049': {'common_names': ['porcine', 'reproductive', 'p.', 'reproductive', 'p'], 'shortname': 'prrsl'}, '686949': {'common_names': ['blackberry', 'virus', 'b.', 'virus', 'b'], 'shortname': 'bvy3'}, '652104': {'common_names': ['barley', 'yellow', 'b.', 'yellow', 'b'], 'shortname': 'baymy'}, '11034': {'common_names': ['sindbis', 'virus', 's.', 'virus', 's'], 'shortname': 'sindv'}, '11137': {'common_names': ['human', 'coronavirus', 'h.', 'coronavirus', 'h'], 'shortname': 'cvh22'}, '11122': {'common_names': ['avian', 'infectious', 'a.', 'infectious', 'a'], 'shortname': 'ibvb'}, '12046': {'common_names': ['potato', 'leafroll', 'p.', 'leafroll', 'p'], 'shortname': 'plrv1'}, '12098': {'common_names': ['human', 'hepatitis', 'h.', 'hepatitis', 'h'], 'shortname': 'havhm'}, '12223': {'common_names': ['soybean', 'mosaic', 's.', 'mosaic', 's'], 'shortname': 'sbmvn'}, '650130': {'common_names': ['human', 'rhinovirus', 'h.', 'rhinovirus', 'h'], 'shortname': 'hrv8a'}, '652105': {'common_names': ['sweet', 'potato', 's.', 'potato', 's'], 'shortname': 'spmmv'}, '337081': {'common_names': ['rice', 'tungro', 'r.', 'tungro', 'r'], 'shortname': 'rtsva'}, '33762': {'common_names': ['parsnip', 'yellow', 'p.', 'yellow', 'p'], 'shortname': 'pyfv1'}, '11043': {'common_names': ['rubella', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rubvm'}, '11142': {'common_names': ['murine', 'coronavirus', 'm.', 'coronavirus', 'm'], 'shortname': 'cvma5'}, '11144': {'common_names': ['murine', 'coronavirus', 'm.', 'coronavirus', 'm'], 'shortname': 'cvmjh'}, '489543': {'common_names': ['duck', 'hepatitis', 'd.', 'hepatitis', 'd'], 'shortname': 'dhbv1'}, '386032': {'common_names': ['reston', 'ebolavirus', 'r.', 'ebolavirus', 'r'], 'shortname': 'eborr'}, '128952': {'common_names': ['zaire', 'ebolavirus', 'z.', 'ebolavirus', 'z'], 'shortname': 'ebozm'}, '11733': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivm1'}, '11738': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivsp'}, '388910': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivtn'}, '12478': {'common_names': ['cryphonectria', 'hypovirus', 'c.', 'hypovirus', 'c'], 'shortname': 'chpve'}, '223341': {'common_names': ['tomato', 'golden', 't.', 'golden', 't'], 'shortname': 'tgmvy'}, '388813': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1vi'}, '388818': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1yf'}, '388821': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv2eh'}, '645118': {'common_names': ['avian', 'infectious', 'a.', 'infectious', 'a'], 'shortname': 'ibdvb'}, '389230': {'common_names': ['bat', 'coronavirus', 'b.', 'coronavirus', 'b'], 'shortname': 'bc133'}, '694008': {'common_names': ['bat', 'coronavirus', 'b.', 'coronavirus', 'b'], 'shortname': 'bchk5'}, '11247': {'common_names': ['bovine', 'respiratory', 'b.', 'respiratory', 'b'], 'shortname': 'brsva'}, '11127': {'common_names': ['avian', 'infectious', 'a.', 'infectious', 'a'], 'shortname': 'ibvm'}, '11926': {'common_names': ['human', 'tcell', 'h.', 'tcell', 'h'], 'shortname': 'htl1a'}, '406769': {'common_names': ['human', 'tcell', 'h.', 'tcell', 'h'], 'shortname': 'htl3p'}, '388826': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv190'}, '11685': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1a2'}, '327105': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1an'}, '401671': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1b9'}, '11686': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1br'}, '11689': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1el'}, '11688': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1jr'}, '11697': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1ma'}, '11701': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1rh'}, '1891767': {'common_names': ['simian', 'virus', 's.', 'virus', 's'], 'shortname': 'sv40'}, '11721': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv2st'}, '388819': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1yb'}, '928296': {'common_names': ['borna', 'disease', 'b.', 'disease', 'b'], 'shortname': 'bdvv'}, '482133': {'common_names': ['hepatitis', 'b', 'h.', 'b', 'h'], 'shortname': 'hbvc1'}, '10411': {'common_names': ['hepatitis', 'b', 'h.', 'b', 'h'], 'shortname': 'hbvd2'}, '490133': {'common_names': ['hepatitis', 'b', 'h.', 'b', 'h'], 'shortname': 'hbvd3'}, '928313': {'common_names': ['tacaribe', 'virus', 't.', 'virus', 't'], 'shortname': 'tacvf'}, '402036': {'common_names': ['human', 'tcell', 'h.', 'tcell', 'h'], 'shortname': 'htl32'}, '31510': {'common_names': ['duck', 'hepatitis', 'd.', 'hepatitis', 'd'], 'shortname': 'hpbdc'}, '518987': {'common_names': ['influenza', 'b', 'i.', 'b', 'i'], 'shortname': 'inble'}, '10515': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade02'}, '11737': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivs4'}, '1289472': {'common_names': ['triticum', 'mosaic', 't.', 'mosaic', 't'], 'shortname': 'trmvu'}, '376264': {'common_names': ['rubella', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rubvv'}, '388912': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivek'}, '928299': {'common_names': ['cowpea', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'cpmvs'}, '928300': {'common_names': ['cricket', 'paralysis', 'c.', 'paralysis', 'c'], 'shortname': 'crpvc'}, '928302': {'common_names': ['hepatitis', 'b', 'h.', 'b', 'h'], 'shortname': 'hbvcj'}, '487099': {'common_names': ['uukuniemi', 'virus', 'u.', 'virus', 'u'], 'shortname': 'uuks'}, '11602': {'common_names': ['hantaan', 'virus', 'h.', 'virus', 'h'], 'shortname': 'hantv'}, '652961': {'common_names': ['crimeancongo', 'hemorrhagic', 'c.', 'hemorrhagic', 'c'], 'shortname': 'cchfi'}, '388911': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'sivmb'}, '10406': {'common_names': ['ground', 'squirrel', 'g.', 'squirrel', 'g'], 'shortname': 'gshv'}, '333760': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv16'}, '11909': {'common_names': ['human', 'tcell', 'h.', 'tcell', 'h'], 'shortname': 'htlv2'}, '211044': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i34a1'}, '45221': {'common_names': ['latino', 'mammarenavirus', 'l.', 'mammarenavirus', 'l'], 'shortname': 'latvb'}, '11628': {'common_names': ['machupo', 'virus', 'm.', 'virus', 'm'], 'shortname': 'machu'}, '651733': {'common_names': ['salivirus', 'a', 's.', 'a', 's'], 'shortname': 'salva'}, '1554483': {'common_names': ['cosavirus', 'a', 'c.', 'a', 'c'], 'shortname': 'cosaa'}, '1554494': {'common_names': ['pegivirus', 'a', 'p.', 'a', 'p'], 'shortname': 'pegia'}, '31722': {'common_names': ['blueberry', 'scorch', 'b.', 'scorch', 'b'], 'shortname': 'bbscv'}, '64320': {'common_names': ['zika', 'virus', 'z.', 'virus', 'z'], 'shortname': 'zikv'}, '650132': {'common_names': ['aichi', 'virus', 'a.', 'virus', 'a'], 'shortname': 'aiva8'}, '11703': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv1u4'}, '11963': {'common_names': ['human', 'spumaretrovirus', 'h.', 'spumaretrovirus', 'h'], 'shortname': 'foamv'}, '1263720': {'common_names': ['middle', 'east', 'm.', 'east', 'm'], 'shortname': 'mers1'}, '381517': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i72a2'}, '31631': {'common_names': ['human', 'coronavirus', 'h.', 'coronavirus', 'h'], 'shortname': 'cvhoc'}, '11676': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': '9hiv1'}, '33727': {'common_names': ['lake', 'victoria', 'l.', 'victoria', 'l'], 'shortname': 'mabvm'}, '11198': {'common_names': ['sendai', 'virus', 's.', 'virus', 's'], 'shortname': 'sendz'}, '1714621': {'common_names': ['borna', 'disease', 'b.', 'disease', 'b'], 'shortname': 'bdv1'}, '12230': {'common_names': ['turnip', 'mosaic', 't.', 'mosaic', 't'], 'shortname': 'tumvj'}, '992212': {'common_names': ['sfts', 'phlebovirus', 's.', 'phlebovirus', 's'], 'shortname': 'sftsv'}, '1980467': {'common_names': ['dobravabelgrade', 'orthohantavirus', 'd.', 'orthohantavirus', 'd'], 'shortname': 'dobv'}, '11590': {'common_names': ['toscana', 'virus', 't.', 'virus', 't'], 'shortname': 'tosv'}, '631345': {'common_names': ['solenopsis', 'invicta', 's.', 'invicta', 's'], 'shortname': 'sinv3'}, '11758': {'common_names': ['mouse', 'mammary', 'm.', 'mammary', 'm'], 'shortname': 'mmtvb'}, '1980494': {'common_names': ['tula', 'orthohantavirus', 't.', 'orthohantavirus', 't'], 'shortname': 'tulv'}, '2697049': {'common_names': ['severe', 'acute', 's.', 'acute', 's'], 'shortname': 'sars2'}, '478555': {'common_names': ['beet', 'yellows', 'b.', 'yellows', 'b'], 'shortname': 'byvu'}, '36402': {'common_names': ['apple', 'stem', 'a.', 'stem', 'a'], 'shortname': 'asgvp'}, '650131': {'common_names': ['equine', 'rhinitis', 'e.', 'rhinitis', 'e'], 'shortname': 'erbv1'}, '1002921': {'common_names': ['porcine', 'sapelovirus', 'p.', 'sapelovirus', 'p'], 'shortname': 'psv13'}, '12281': {'common_names': ['tomato', 'ringspot', 't.', 'ringspot', 't'], 'shortname': 'torvr'}, '11214': {'common_names': ['human', 'parainfluenza', 'h.', 'parainfluenza', 'h'], 'shortname': 'pi2ht'}, '331642': {'common_names': ['bovine', 'enteric', 'b.', 'enteric', 'b'], 'shortname': 'becn1'}, '650481': {'common_names': ['satsuma', 'dwarf', 's.', 'dwarf', 's'], 'shortname': 'sdvs5'}, '364370': {'common_names': ['turkey', 'astrovirus', 't.', 'astrovirus', 't'], 'shortname': 'tasv1'}, '33734': {'common_names': ['feline', 'coronavirus', 'f.', 'coronavirus', 'f'], 'shortname': 'fipv'}, '450149': {'common_names': ['rotavirus', 'a', 'r.', 'a', 'r'], 'shortname': 'rotsh'}, '2884424': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpph2'}, '694067': {'common_names': ['human', 'metapneumovirus', 'h.', 'metapneumovirus', 'h'], 'shortname': 'hmpvc'}, '12252': {'common_names': ['tomato', 'mosaic', 't.', 'mosaic', 't'], 'shortname': 'toml'}, '12302': {'common_names': ['brome', 'mosaic', 'b.', 'mosaic', 'b'], 'shortname': 'bmv'}, '652938': {'common_names': ['southern', 'bean', 's.', 'bean', 's'], 'shortname': 'sbmva'}, '12022': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpms2'}, '492094': {'common_names': ['petunia', 'vein', 'p.', 'vein', 'p'], 'shortname': 'pvcv1'}, '11171': {'common_names': ['mumps', 'virus', 'm.', 'virus', 'm'], 'shortname': 'mumpm'}, '79692': {'common_names': ['human', 'respiratory', 'h.', 'respiratory', 'h'], 'shortname': 'hrsvb'}, '284812': {'common_names': ['schizosaccharomyces', 'pombe', 's.', 'pombe', 's', 'fission'], 'shortname': 'schpo'}, '12307': {'common_names': ['cucumber', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'cmvfn'}, '1217068': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpphs'}, '10583': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv1'}, '652839': {'common_names': ['potato', 'moptop', 'p.', 'moptop', 'p'], 'shortname': 'pmtvs'}, '12538': {'common_names': ['mokola', 'virus', 'm.', 'virus', 'm'], 'shortname': 'mokv'}, '10816': {'common_names': ['abutilon', 'mosaic', 'a.', 'mosaic', 'a'], 'shortname': 'abmvw'}, '650137': {'common_names': ['cherry', 'rasp', 'c.', 'rasp', 'c'], 'shortname': 'crlvp'}, '446561': {'common_names': ['australian', 'bat', 'a.', 'bat', 'a'], 'shortname': 'ablvb'}, '654915': {'common_names': ['mastomys', 'natalensis', 'm.', 'natalensis', 'm'], 'shortname': 'mnpva'}, '291175': {'common_names': ['sapporo', 'virus', 's.', 'virus', 's'], 'shortname': 'svsap'}, '39720': {'common_names': ['walleye', 'dermal', 'w.', 'dermal', 'w'], 'shortname': 'wdsv'}, '37137': {'common_names': ['rotavirus', 'a', 'r.', 'a', 'r'], 'shortname': 'rots1'}, '453116': {'common_names': ['european', 'bat', 'e.', 'bat', 'e'], 'shortname': 'eblv2'}, '11644': {'common_names': ['simian', 'foamy', 's.', 'foamy', 's'], 'shortname': 'sfv3l'}, '12240': {'common_names': ['sunnhemp', 'mosaic', 's.', 'mosaic', 's'], 'shortname': 'shmv'}, '268781': {'common_names': ['sugarcane', 'streak', 's.', 'streak', 's'], 'shortname': 'ssvn'}, '11208': {'common_names': ['parainfluenza', 'virus', 'p.', 'virus', 'p'], 'shortname': 'piv5'}, '11003': {'common_names': ['infectious', 'pancreatic', 'i.', 'pancreatic', 'i'], 'shortname': 'ipnvj'}, '644440': {'common_names': ['avian', 'infectious', 'a.', 'infectious', 'a'], 'shortname': 'ibdvu'}, '311176': {'common_names': ['blotched', 'snakehead', 'b.', 'snakehead', 'b'], 'shortname': 'bsnv'}, '10884': {'common_names': ['reovirus', 'type', 'r.', 'type', 'r'], 'shortname': 'reovl'}, '11720': {'common_names': ['human', 'immunodeficiency', 'h.', 'immunodeficiency', 'h'], 'shortname': 'hv2ro'}, '57119': {'common_names': ['bean', 'yellow', 'b.', 'yellow', 'b'], 'shortname': 'beydv'}, '696863': {'common_names': ['spring', 'viremia', 's.', 'viremia', 's'], 'shortname': 'svcv'}, '12043': {'common_names': ['turnip', 'yellows', 't.', 'yellows', 't'], 'shortname': 'tyyvf'}, '142661': {'common_names': ['canary', 'circovirus', 'c.', 'circovirus', 'c'], 'shortname': 'cacv'}, '11283': {'common_names': ['vesicular', 'stomatitis', 'v.', 'stomatitis', 'v'], 'shortname': 'vsnjo'}, '268780': {'common_names': ['panicum', 'streak', 'p.', 'streak', 'p'], 'shortname': 'pasvk'}, '196398': {'common_names': ['southern', 'cowpea', 's.', 'cowpea', 's'], 'shortname': 'scpmv'}, '261996': {'common_names': ['hepatitis', 'delta', 'h.', 'delta', 'h'], 'shortname': 'hdvp1'}, '11553': {'common_names': ['influenza', 'c', 'i.', 'c', 'i'], 'shortname': 'incaa'}, '10644': {'common_names': ['cauliflower', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'camvc'}, '321609': {'common_names': ['cryphonectria', 'hypovirus', 'c.', 'hypovirus', 'c'], 'shortname': 'chpvu'}, '10783': {'common_names': ['aleutian', 'mink', 'a.', 'mink', 'a'], 'shortname': 'advg'}, '1891762': {'common_names': ['bk', 'polyomavirus', 'b.', 'polyomavirus', 'b'], 'shortname': 'povbk'}, '10636': {'common_names': ['murine', 'polyomavirus', 'm.', 'polyomavirus', 'm'], 'shortname': 'povma'}, '103929': {'common_names': ['rabies', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rabvp'}, '645098': {'common_names': ['measles', 'virus', 'm.', 'virus', 'm'], 'shortname': 'measc'}, '53182': {'common_names': ['feline', 'foamy', 'f.', 'foamy', 'f'], 'shortname': 'ffv'}, '796210': {'common_names': ['bunyavirus', 'la', 'b.', 'la', 'b'], 'shortname': 'bunl8'}, '928303': {'common_names': ['hendra', 'virus', 'h.', 'virus', 'h'], 'shortname': 'hendh'}, '10822': {'common_names': ['maize', 'streak', 'm.', 'streak', 'm'], 'shortname': 'msvk'}, '268344': {'common_names': ['maize', 'streak', 'm.', 'streak', 'm'], 'shortname': 'msvse'}, '453115': {'common_names': ['european', 'bat', 'e.', 'bat', 'e'], 'shortname': 'eblv1'}, '333761': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv18'}, '10829': {'common_names': ['squash', 'leaf', 's.', 'leaf', 's'], 'shortname': 'slcv'}, '2169994': {'common_names': ['parana', 'mammarenavirus', 'p.', 'mammarenavirus', 'p'], 'shortname': 'parvp'}, '49891': {'common_names': ['pirital', 'mammarenavirus', 'p.', 'mammarenavirus', 'p'], 'shortname': 'pirvv'}, '10299': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv11'}, '1554474': {'common_names': ['rosavirus', 'a2', 'r.', 'a2', 'r'], 'shortname': 'rosv2'}, '1554479': {'common_names': ['passerivirus', 'a1', 'p.', 'a1', 'p'], 'shortname': 'pasva'}, '1554480': {'common_names': ['oscivirus', 'a1', 'o.', 'a1', 'o'], 'shortname': 'oscv1'}, '980964': {'common_names': ['megrivirus', 'a', 'm.', 'a', 'm'], 'shortname': 'megr1'}, '1554484': {'common_names': ['avisivirus', 'a', 'a.', 'a', 'a'], 'shortname': 'avisv'}, '1755588': {'common_names': ['sicinivirus', 'a', 's.', 'a', 's'], 'shortname': 'siva1'}, '440266': {'common_names': ['wu', 'polyomavirus', 'w.', 'polyomavirus', 'w'], 'shortname': 'povwu'}, '93838': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i96a0'}, '452475': {'common_names': ['squirrel', 'monkey', 's.', 'monkey', 's'], 'shortname': 'povsm'}, '76344': {'common_names': ['murine', 'coronavirus', 'm.', 'coronavirus', 'm'], 'shortname': 'cvm2'}, '689403': {'common_names': ['primate', 'bocaparvovirus', 'p.', 'bocaparvovirus', 'p'], 'shortname': 'hboc1'}, '290028': {'common_names': ['human', 'coronavirus', 'h.', 'coronavirus', 'h'], 'shortname': 'cvhk1'}, '11588': {'common_names': ['rift', 'valley', 'r.', 'valley', 'r'], 'shortname': 'rvfv'}, '11041': {'common_names': ['rubella', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rubv'}, '387243': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i88a4'}, '11597': {'common_names': ['hazara', 'virus', 'h.', 'virus', 'h'], 'shortname': 'hazvj'}, '45223': {'common_names': ['tamiami', 'mammarenavirus', 't.', 'mammarenavirus', 't'], 'shortname': 'tamvu'}, '133704': {'common_names': ['porcine', 'circovirus', 'p.', 'circovirus', 'p'], 'shortname': 'pcv1'}, '2491661': {'common_names': ['bovine', 'papillomavirus', 'b.', 'papillomavirus', 'b'], 'shortname': 'bpv5'}, '2169993': {'common_names': ['pichinde', 'mammarenavirus', 'p.', 'mammarenavirus', 'p'], 'shortname': 'piarv'}, '11661': {'common_names': ['caprine', 'arthritis', 'c.', 'arthritis', 'c'], 'shortname': 'caevc'}, '10820': {'common_names': ['chloris', 'striate', 'c.', 'striate', 'c'], 'shortname': 'csmv'}, '11674': {'common_names': ['feline', 'immunodeficiency', 'f.', 'immunodeficiency', 'f'], 'shortname': 'fivpe'}, '12450': {'common_names': ['saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's'], 'shortname': 'scvm1'}, '12251': {'common_names': ['tobacco', 'mosaic', 't.', 'mosaic', 't'], 'shortname': 'tmvom'}, '12241': {'common_names': ['tobacco', 'mild', 't.', 'mild', 't'], 'shortname': 'tmgmv'}, '10254': {'common_names': ['vaccinia', 'virus', 'v.', 'virus', 'v'], 'shortname': 'vaccw'}, '649893': {'common_names': ['giardia', 'lamblia', 'g.', 'lamblia', 'g'], 'shortname': 'glvwb'}, '11008': {'common_names': ['saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's'], 'shortname': 'scvla'}, '12322': {'common_names': ['alfalfa', 'mosaic', 'a.', 'mosaic', 'a'], 'shortname': 'amvle'}, '10867': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpike'}, '10869': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpi22'}, '651357': {'common_names': ['indian', 'citrus', 'i.', 'citrus', 'i'], 'shortname': 'icrsv'}, '686987': {'common_names': ['sclerotinia', 'sclerotiorum', 's.', 'sclerotiorum', 's'], 'shortname': 'ssdrv'}, '73472': {'common_names': ['apple', 'chlorotic', 'a.', 'chlorotic', 'a'], 'shortname': 'aclsa'}, '686946': {'common_names': ['botrytis', 'virus', 'b.', 'virus', 'b'], 'shortname': 'botvf'}, '652669': {'common_names': ['maize', 'rayado', 'm.', 'rayado', 'm'], 'shortname': 'mrfvc'}, '239720': {'common_names': ['heterosigma', 'akashiwo', 'h.', 'akashiwo', 'h'], 'shortname': 'harna'}, '693992': {'common_names': ['duck', 'hepatitis', 'd.', 'hepatitis', 'd'], 'shortname': 'dhav'}, '650136': {'common_names': ['porcine', 'teschovirus', 'p.', 'teschovirus', 'p'], 'shortname': 'ptv1f'}, '650488': {'common_names': ['pelargonium', 'zonate', 'p.', 'zonate', 'p'], 'shortname': 'pzsvt'}, '10576': {'common_names': ['pygmy', 'chimpanzee', 'p.', 'chimpanzee', 'p'], 'shortname': 'pcpv1'}, '85708': {'common_names': ['porcine', 'circovirus', 'p.', 'circovirus', 'p'], 'shortname': 'pcv2'}, '12181': {'common_names': ['papaya', 'mosaic', 'p.', 'mosaic', 'p'], 'shortname': 'pmv'}, '903503': {'common_names': ['moranella', 'endobia', 'm.', 'endobia', 'm'], 'shortname': 'morep'}, '693989': {'common_names': ['pea', 'enation', 'p.', 'enation', 'p'], 'shortname': 'pemvw'}, '237561': {'common_names': ['candida', 'albicans', 'c.', 'albicans', 'c'], 'shortname': 'canal'}, '36870': {'common_names': ['wigglesworthia', 'glossinidia', 'w.', 'glossinidia', 'w'], 'shortname': 'wigbr'}, '71421': {'common_names': ['haemophilus', 'influenzae', 'h.', 'influenzae', 'h'], 'shortname': 'haein'}, '10383': {'common_names': ['saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's'], 'shortname': 'shv21'}, '224915': {'common_names': ['buchnera', 'aphidicola', 'b.', 'aphidicola', 'b'], 'shortname': 'bucbp'}, '10498': {'common_names': ['african', 'swine', 'a.', 'swine', 'a'], 'shortname': 'asfb7'}, '372461': {'common_names': ['buchnera', 'aphidicola', 'b.', 'aphidicola', 'b'], 'shortname': 'buccc'}, '12168': {'common_names': ['potato', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pvmr'}, '651356': {'common_names': ['apple', 'stem', 'a.', 'stem', 'a'], 'shortname': 'aspvp'}, '12027': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpsp'}, '243273': {'common_names': ['mycoplasma', 'genitalium', 'm.', 'genitalium', 'm'], 'shortname': 'mycge'}, '686948': {'common_names': ['tomato', 'torrado', 't.', 'torrado', 't'], 'shortname': 'totv'}, '652108': {'common_names': ['nudaurelia', 'capensis', 'n.', 'capensis', 'n'], 'shortname': 'ncbvs'}, '11235': {'common_names': ['measles', 'virus', 'm.', 'virus', 'm'], 'shortname': 'mease'}, '10760': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt7'}, '295027': {'common_names': ['human', 'cytomegalovirus', 'h.', 'cytomegalovirus', 'h'], 'shortname': 'hcmvm'}, '868565': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv8p'}, '651355': {'common_names': ['lettuce', 'infectious', 'l.', 'infectious', 'l'], 'shortname': 'liyv9'}, '652670': {'common_names': ['beet', 'necrotic', 'b.', 'necrotic', 'b'], 'shortname': 'bnyvs'}, '186772': {'common_names': ['saccharomyces', '2s', 's.', '2s', 's'], 'shortname': 'scv20'}, '186769': {'common_names': ['cryphonectria', 'parasitica', 'c.', 'parasitica', 'c'], 'shortname': 'cpmv1'}, '31520': {'common_names': ['equine', 'herpesvirus', 'e.', 'herpesvirus', 'e'], 'shortname': 'ehv1b'}, '1005059': {'common_names': ['cocksfoot', 'mottle', 'c.', 'mottle', 'c'], 'shortname': 'cfmvn'}, '7739': {'common_names': ['branchiostoma', 'floridae', 'b.', 'floridae', 'b'], 'shortname': 'brafl'}, '83332': {'common_names': ['mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm'], 'shortname': 'myctu'}, '31770': {'common_names': ['shallot', 'virus', 's.', 'virus', 's'], 'shortname': 'shvx'}, '12147': {'common_names': ['tomato', 'bushy', 't.', 'bushy', 't'], 'shortname': 'tbsvc'}, '652837': {'common_names': ['peanut', 'clump', 'p.', 'clump', 'p'], 'shortname': 'pcv87'}, '652939': {'common_names': ['tobacco', 'rattle', 't.', 'rattle', 't'], 'shortname': 'trvpp'}, '686943': {'common_names': ['poinsettia', 'latent', 'p.', 'latent', 'p'], 'shortname': 'pnlv'}, '648234': {'common_names': ['aquareovirus', 'g', 'a.', 'g', 'a'], 'shortname': 'aqrvg'}, '2681611': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'lambd'}, '107806': {'common_names': ['buchnera', 'aphidicola', 'b.', 'aphidicola', 'b'], 'shortname': 'bucai'}, '2789016': {'common_names': ['qbeta', 'virus', 'q.', 'virus', 'q'], 'shortname': 'bpmx1'}, '10868': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpif1'}, '2847073': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpfd'}, '10315': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv2h'}, '1977402': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpm13'}, '10848': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpphk'}, '10849': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpal3'}, '10658': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpprd'}, '142804': {'common_names': ['rice', 'dwarf', 'r.', 'dwarf', 'r'], 'shortname': 'rdvf'}, '10655': {'common_names': ['rice', 'tungro', 'r.', 'tungro', 'r'], 'shortname': 'rtbvp'}, '223303': {'common_names': ['pepper', 'huasteco', 'p.', 'huasteco', 'p'], 'shortname': 'phuv'}, '123735': {'common_names': ['tomato', 'yellow', 't.', 'yellow', 't'], 'shortname': 'tycsv'}, '59380': {'common_names': ['rice', 'yellow', 'r.', 'yellow', 'r'], 'shortname': 'rysv'}, '11307': {'common_names': ['sonchus', 'yellow', 's.', 'yellow', 's'], 'shortname': 'synv'}, '645099': {'common_names': ['banana', 'bunchy', 'b.', 'bunchy', 'b'], 'shortname': 'bbtva'}, '374463': {'common_names': ['baumannia', 'cicadellinicola', 'b.', 'cicadellinicola', 'b'], 'shortname': 'bauch'}, '652954': {'common_names': ['avian', 'metapneumovirus', 'a.', 'metapneumovirus', 'a'], 'shortname': 'ampv1'}, '10648': {'common_names': ['cauliflower', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'camvs'}, '12017': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpfr'}, '10338': {'common_names': ['varicellazoster', 'virus', 'v.', 'virus', 'v'], 'shortname': 'vzvd'}, '2928686': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpph6'}, '2681603': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpmu'}, '10589': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv41'}, '10824': {'common_names': ['maize', 'streak', 'm.', 'streak', 'm'], 'shortname': 'msvs'}, '268960': {'common_names': ['beet', 'curly', 'b.', 'curly', 'b'], 'shortname': 'bctvc'}, '291607': {'common_names': ['subterranean', 'clover', 's.', 'clover', 's'], 'shortname': 'scsvf'}, '222448': {'common_names': ['bean', 'golden', 'b.', 'golden', 'b'], 'shortname': 'bgymv'}, '1980426': {'common_names': ['european', 'mountain', 'e.', 'mountain', 'e'], 'shortname': 'emarv'}, '36394': {'common_names': ['rice', 'stripe', 'r.', 'stripe', 'r'], 'shortname': 'rsvt'}, '652674': {'common_names': ['hepatitis', 'e', 'h.', 'e', 'h'], 'shortname': 'hevch'}, '652111': {'common_names': ['carnation', 'mottle', 'c.', 'mottle', 'c'], 'shortname': 'carms'}, '37206': {'common_names': ['helicoverpa', 'armigera', 'h.', 'armigera', 'h'], 'shortname': 'hasv'}, '2169986': {'common_names': ['barley', 'yellow', 'b.', 'yellow', 'b'], 'shortname': 'bydvp'}, '670426': {'common_names': ['psittacid', 'herpesvirus', 'p.', 'herpesvirus', 'p'], 'shortname': 'pshv1'}, '686981': {'common_names': ['citrus', 'leaf', 'c.', 'leaf', 'c'], 'shortname': 'clbvs'}, '648235': {'common_names': ['murine', 'minute', 'm.', 'minute', 'm'], 'shortname': 'mumip'}, '648243': {'common_names': ['bovine', 'parvovirus', 'b.', 'parvovirus', 'b'], 'shortname': 'pavbp'}, '73473': {'common_names': ['apple', 'chlorotic', 'a.', 'chlorotic', 'a'], 'shortname': 'aclsp'}, '49267': {'common_names': ['tomato', 'pseudocurly', 't.', 'pseudocurly', 't'], 'shortname': 'tpctv'}, '10933': {'common_names': ['rotavirus', 'a', 'r.', 'a', 'r'], 'shortname': 'rotrf'}, '31600': {'common_names': ['indian', 'cassava', 'i.', 'cassava', 'i'], 'shortname': 'icmv'}, '429314': {'common_names': ['infectious', 'hematopoietic', 'i.', 'hematopoietic', 'i'], 'shortname': 'ihnvw'}, '103603': {'common_names': ['snakehead', 'rhabdovirus', 's.', 'rhabdovirus', 's'], 'shortname': 'shrv'}, '12187': {'common_names': ['strawberry', 'mild', 's.', 'mild', 's'], 'shortname': 'smyea'}, '647332': {'common_names': ['human', 'picobirnavirus', 'h.', 'picobirnavirus', 'h'], 'shortname': 'hpbvh'}, '302272': {'common_names': ['sendai', 'virus', 's.', 'virus', 's'], 'shortname': 'sendo'}, '12315': {'common_names': ['tomato', 'aspermy', 't.', 'aspermy', 't'], 'shortname': 'tav'}, '11988': {'common_names': ['turnip', 'crinkle', 't.', 'crinkle', 't'], 'shortname': 'tcv'}, '73475': {'common_names': ['chicken', 'anemia', 'c.', 'anemia', 'c'], 'shortname': 'cavc1'}, '2749935': {'common_names': ['taro', 'vein', 't.', 'vein', 't'], 'shortname': 'tavcv'}, '66366': {'common_names': ['tomato', 'yellow', 't.', 'yellow', 't'], 'shortname': 'tylci'}, '28365': {'common_names': ['xanthomonas', 'phage', 'x.', 'phage', 'x'], 'shortname': 'bpphl'}, '12189': {'common_names': ['white', 'clover', 'w.', 'clover', 'w'], 'shortname': 'wcmvm'}, '268789': {'common_names': ['wheat', 'dwarf', 'w.', 'dwarf', 'w'], 'shortname': 'wdvs'}, '82830': {'common_names': ['epsteinbarr', 'virus', 'e.', 'virus', 'e'], 'shortname': 'ebva8'}, '85617': {'common_names': ['vesicular', 'exanthema', 'v.', 'exanthema', 'v'], 'shortname': 'vesva'}, '10900': {'common_names': ['bluetongue', 'virus', 'b.', 'virus', 'b'], 'shortname': 'btv10'}, '335103': {'common_names': ['rotavirus', 'x', 'r.', 'x', 'r'], 'shortname': 'rotj1'}, '31567': {'common_names': ['rotavirus', 'c', 'r.', 'c', 'r'], 'shortname': 'rothc'}, '10596': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv56'}, '333753': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv57'}, '10599': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv5b'}, '37116': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv61'}, '28311': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv63'}, '37119': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv66'}, '37121': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv69'}, '10587': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv35'}, '268331': {'common_names': ['maize', 'streak', 'm.', 'streak', 'm'], 'shortname': 'msvpa'}, '268343': {'common_names': ['maize', 'streak', 'm.', 'streak', 'm'], 'shortname': 'msvra'}, '223295': {'common_names': ['mungbean', 'yellow', 'm.', 'yellow', 'm'], 'shortname': 'mymvv'}, '291272': {'common_names': ['blochmannia', 'pennsylvanicus', 'b.', 'pennsylvanicus', 'b'], 'shortname': 'blopb'}, '12318': {'common_names': ['tobacco', 'streak', 't.', 'streak', 't'], 'shortname': 'tobsv'}, '2779844': {'common_names': ['macaca', 'mulata', 'm.', 'mulata', 'm'], 'shortname': 'mmpv1'}, '10916': {'common_names': ['rotavirus', 'c', 'r.', 'c', 'r'], 'shortname': 'rotpc'}, '10580': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv11'}, '10606': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv15'}, '291605': {'common_names': ['milk', 'vetch', 'm.', 'vetch', 'm'], 'shortname': 'mdv1'}, '223353': {'common_names': ['tomato', 'leaf', 't.', 'leaf', 't'], 'shortname': 'tlcva'}, '185793': {'common_names': ['tomato', 'yellow', 't.', 'yellow', 't'], 'shortname': 'tylcc'}, '46015': {'common_names': ['autographa', 'californica', 'a.', 'californica', 'a'], 'shortname': 'npvac'}, '648250': {'common_names': ['junonia', 'coenia', 'j.', 'coenia', 'j'], 'shortname': 'jdnvp'}, '73478': {'common_names': ['chicken', 'anemia', 'c.', 'anemia', 'c'], 'shortname': 'cavci'}, '12303': {'common_names': ['cowpea', 'chlorotic', 'c.', 'chlorotic', 'c'], 'shortname': 'ccmv'}, '10640': {'common_names': ['carnation', 'etched', 'c.', 'etched', 'c'], 'shortname': 'cerv'}, '12236': {'common_names': ['cucumber', 'green', 'c.', 'green', 'c'], 'shortname': 'cgmvs'}, '11273': {'common_names': ['chandipura', 'virus', 'c.', 'virus', 'c'], 'shortname': 'chav'}, '222073': {'common_names': ['african', 'cassava', 'a.', 'cassava', 'a'], 'shortname': 'clvn'}, '12310': {'common_names': ['cucumber', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'cmvq'}, '648330': {'common_names': ['aedes', 'albopictus', 'a.', 'albopictus', 'a'], 'shortname': 'aadnv'}, '1891754': {'common_names': ['bovine', 'polyomavirus', 'b.', 'polyomavirus', 'b'], 'shortname': 'povbo'}, '1891729': {'common_names': ['hamster', 'polyomavirus', 'h.', 'polyomavirus', 'h'], 'shortname': 'povha'}, '130763': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i97a1'}, '928304': {'common_names': ['lettuce', 'necrotic', 'l.', 'necrotic', 'l'], 'shortname': 'lnyv3'}, '928305': {'common_names': ['maize', 'mosaic', 'm.', 'mosaic', 'm'], 'shortname': 'mmvr'}, '228578': {'common_names': ['youcai', 'mosaic', 'y.', 'mosaic', 'y'], 'shortname': 'yomv'}, '12184': {'common_names': ['potato', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pvxcp'}, '12179': {'common_names': ['foxtail', 'mosaic', 'f.', 'mosaic', 'f'], 'shortname': 'fxmv'}, '12267': {'common_names': ['red', 'clover', 'r.', 'clover', 'r'], 'shortname': 'rcnmv'}, '36409': {'common_names': ['rinderpest', 'virus', 'r.', 'virus', 'r'], 'shortname': 'rindr'}, '291603': {'common_names': ['faba', 'bean', 'f.', 'bean', 'f'], 'shortname': 'fbny1'}, '12185': {'common_names': ['potato', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pvxx3'}, '686945': {'common_names': ['lolium', 'latent', 'l.', 'latent', 'l'], 'shortname': 'lolv'}, '222449': {'common_names': ['bean', 'golden', 'b.', 'golden', 'b'], 'shortname': 'bgymj'}, '652965': {'common_names': ['infectious', 'salmon', 'i.', 'salmon', 'i'], 'shortname': 'isav8'}, '10367': {'common_names': ['murid', 'herpesvirus', 'm.', 'herpesvirus', 'm'], 'shortname': 'muhvs'}, '31553': {'common_names': ['cottontail', 'rabbit', 'c.', 'rabbit', 'c'], 'shortname': 'crpvk'}, '766192': {'common_names': ['canine', 'oral', 'c.', 'oral', 'c'], 'shortname': 'copv6'}, '654916': {'common_names': ['phocoena', 'spinipinnis', 'p.', 'spinipinnis', 'p'], 'shortname': 'pspvp'}, '654918': {'common_names': ['equus', 'caballus', 'e.', 'caballus', 'e'], 'shortname': 'ecpvo'}, '12180': {'common_names': ['narcissus', 'mosaic', 'n.', 'mosaic', 'n'], 'shortname': 'nmv'}, '268776': {'common_names': ['miscanthus', 'streak', 'm.', 'streak', 'm'], 'shortname': 'misv9'}, '126796': {'common_names': ['thogoto', 'virus', 't.', 'virus', 't'], 'shortname': 'thogv'}, '10360': {'common_names': ['human', 'cytomegalovirus', 'h.', 'cytomegalovirus', 'h'], 'shortname': 'hcmva'}, '10665': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt4'}, '10872': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppf3'}, '644639': {'common_names': ['duck', 'hepatitis', 'd.', 'hepatitis', 'd'], 'shortname': 'dhbvq'}, '10621': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv09'}, '10573': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv13'}, '10605': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv14'}, '37954': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv22'}, '37955': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv23'}, '37112': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv29'}, '10585': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv31'}, '10615': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv40'}, '10590': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv42'}, '333765': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv53'}, '10611': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv30'}, '37111': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv28'}, '31548': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv21'}, '37959': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv38'}, '28354': {'common_names': ['plantago', 'asiatica', 'p.', 'asiatica', 'p'], 'shortname': 'p1amv'}, '333923': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv05'}, '10617': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv04'}, '652673': {'common_names': ['soilborne', 'wheat', 's.', 'wheat', 's'], 'shortname': 'sbwmn'}, '10370': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv6u'}, '1554498': {'common_names': ['pasivirus', 'a1', 'p.', 'a1', 'p'], 'shortname': 'pasi1'}, '1554481': {'common_names': ['mosavirus', 'a2', 'm.', 'a2', 'm'], 'shortname': 'mova2'}, '1195365': {'common_names': ['mischivirus', 'a', 'm.', 'a', 'm'], 'shortname': 'misv1'}, '1168173': {'common_names': ['hunnivirus', 'a', 'h.', 'a', 'h'], 'shortname': 'hunvo'}, '1560035': {'common_names': ['gallivirus', 'a', 'g.', 'a', 'g'], 'shortname': 'galiv'}, '1554492': {'common_names': ['aquamavirus', 'a', 'a.', 'a', 'a'], 'shortname': 'aquav'}, '666363': {'common_names': ['drosophila', 'melanogaster', 'd.', 'melanogaster', 'd'], 'shortname': 'dmsva'}, '1559361': {'common_names': ['tibrogargan', 'virus', 't.', 'virus', 't'], 'shortname': 'tibvc'}, '1560034': {'common_names': ['tupaia', 'virus', 't.', 'virus', 't'], 'shortname': 'tupvt'}, '118110': {'common_names': ['buchnera', 'aphidicola', 'b.', 'aphidicola', 'b'], 'shortname': 'bucsc'}, '249584': {'common_names': ['west', 'caucasian', 'w.', 'caucasian', 'w'], 'shortname': 'wcbv'}, '46922': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade17'}, '334210': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv62'}, '385617': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i83a6'}, '10995': {'common_names': ['avian', 'infectious', 'a.', 'infectious', 'a'], 'shortname': 'ibdv'}, '333763': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv32'}, '2560766': {'common_names': ['simian', 'virus', 's.', 'virus', 's'], 'shortname': 'sv41'}, '1671798': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv54'}, '40538': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv48'}, '410078': {'common_names': ['human', 'respiratory', 'h.', 'respiratory', 'h'], 'shortname': 'hrss2'}, '10591': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv43'}, '40540': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv60'}, '37115': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv59'}, '416674': {'common_names': ['influenza', 'b', 'i.', 'b', 'i'], 'shortname': 'inbyb'}, '296738': {'common_names': ['murine', 'pneumonia', 'm.', 'pneumonia', 'm'], 'shortname': 'mpv15'}, '1891747': {'common_names': ['budgerigar', 'fledgling', 'b.', 'fledgling', 'b'], 'shortname': 'bfpyv'}, '10618': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv52'}, '1223562': {'common_names': ['alethinophid', '1', 'a.', '1', 'a'], 'shortname': 'gogv'}, '92129': {'common_names': ['tupaia', 'paramyxovirus', 't.', 'paramyxovirus', 't'], 'shortname': 'tpmv'}, '189830': {'common_names': ['snake', 'adenovirus', 's.', 'adenovirus', 's'], 'shortname': 'ades1'}, '1129345': {'common_names': ['influenza', 'a', 'i.', 'a', 'i'], 'shortname': 'i09a8'}, '100673': {'common_names': ['influenza', 'c', 'i.', 'c', 'i'], 'shortname': 'incjh'}, '10563': {'common_names': ['bos', 'taurus', 'b.', 'taurus', 'b'], 'shortname': 'bpv6'}, '338478': {'common_names': ['simian', 'foamy', 's.', 'foamy', 's'], 'shortname': 'sfv1'}, '129724': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv82'}, '10598': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv58'}, '10568': {'common_names': ['micromys', 'minutus', 'm.', 'minutus', 'm'], 'shortname': 'mmpv'}, '37114': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv55'}, '10377': {'common_names': ['epsteinbarr', 'virus', 'e.', 'virus', 'e'], 'shortname': 'ebvb9'}, '333764': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv34'}, '664730': {'common_names': ['rattus', 'norvegicus', 'r.', 'norvegicus', 'r'], 'shortname': 'rnpv1'}, '37956': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv24'}, '490134': {'common_names': ['woolly', 'monkey', 'w.', 'monkey', 'w'], 'shortname': 'wmhbv'}, '914672': {'common_names': ['nodamura', 'virus', 'n.', 'virus', 'n'], 'shortname': 'nodam'}, '40539': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv50'}, '1335626': {'common_names': ['middle', 'east', 'm.', 'east', 'm'], 'shortname': 'mers'}, '126070': {'common_names': ['pigeon', 'circovirus', 'p.', 'circovirus', 'p'], 'shortname': 'picv'}, '648242': {'common_names': ['adenoassociated', 'virus', 'a.', 'virus', 'a'], 'shortname': 'aav2s'}, '31604': {'common_names': ['pestedespetitsruminants', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pprv'}, '2758957': {'common_names': ['bovine', 'papillomavirus', 'b.', 'papillomavirus', 'b'], 'shortname': 'bpv3'}, '146032': {'common_names': ['goose', 'circovirus', 'g.', 'circovirus', 'g'], 'shortname': 'gocv'}, '11612': {'common_names': ['impatiens', 'necrotic', 'i.', 'necrotic', 'i'], 'shortname': 'insv'}, '11987': {'common_names': ['melon', 'necrotic', 'm.', 'necrotic', 'm'], 'shortname': 'mnsv'}, '1213620': {'common_names': ['bhanja', 'virus', 'b.', 'virus', 'b'], 'shortname': 'bhav'}, '290008': {'common_names': ['isfahan', 'virus', 'i.', 'virus', 'i'], 'shortname': 'isfv'}, '42478': {'common_names': ['saccharomyces', 'cerevisiae', 's.', 'cerevisiae', 's'], 'shortname': 'scvlb'}, '12445': {'common_names': ['satellite', 'tobacco', 's.', 'tobacco', 's'], 'shortname': 'stnv1'}, '11587': {'common_names': ['punta', 'toro', 'p.', 'toro', 'p'], 'shortname': 'ptpv'}, '11577': {'common_names': ['bunyavirus', 'la', 'b.', 'la', 'b'], 'shortname': 'bunlc'}, '35883': {'common_names': ['ipomoea', 'nil', 'i.', 'nil', 'i'], 'shortname': 'iponi'}, '51033': {'common_names': ['human', 'papillomavirus', 'h.', 'papillomavirus', 'h'], 'shortname': 'hpv73'}, '36370': {'common_names': ['jembrana', 'disease', 'j.', 'disease', 'j'], 'shortname': 'jembr'}, '10244': {'common_names': ['monkeypox', 'virus', 'm.', 'virus', 'm'], 'shortname': 'monpv'}, '3885': {'common_names': ['phaseolus', 'vulgaris', 'p.', 'vulgaris', 'p'], 'shortname': 'phavu'}, '312153': {'common_names': ['polynucleobacter', 'asymbioticus', 'p.', 'asymbioticus', 'p'], 'shortname': 'polaq'}, '379731': {'common_names': ['stutzerimonas', 'stutzeri', 's.', 'stutzeri', 's'], 'shortname': 'stus1'}, '369723': {'common_names': ['salinispora', 'tropica', 's.', 'tropica', 's'], 'shortname': 'salto'}, '349521': {'common_names': ['hahella', 'chejuensis', 'h.', 'chejuensis', 'h'], 'shortname': 'hahch'}, '290398': {'common_names': ['chromohalobacter', 'salexigens', 'c.', 'salexigens', 'c'], 'shortname': 'chrsd'}, '399549': {'common_names': ['metallosphaera', 'sedula', 'm.', 'sedula', 'm'], 'shortname': 'mets5'}, '349163': {'common_names': ['acidiphilium', 'cryptum', 'a.', 'cryptum', 'a'], 'shortname': 'acicj'}, '412965': {'common_names': ['vesicomyosocius', 'okutanii', 'v.', 'okutanii', 'v'], 'shortname': 'vesoh'}, '246195': {'common_names': ['dichelobacter', 'nodosus', 'd.', 'nodosus', 'd'], 'shortname': 'dicnv'}, '399550': {'common_names': ['staphylothermus', 'marinus', 's.', 'marinus', 's'], 'shortname': 'stamf'}, '290339': {'common_names': ['cronobacter', 'sakazakii', 'c.', 'sakazakii', 'c'], 'shortname': 'cros8'}, '453591': {'common_names': ['ignicoccus', 'hospitalis', 'i.', 'hospitalis', 'i'], 'shortname': 'ignh4'}, '436907': {'common_names': ['vanderwaltozyma', 'polyspora', 'v.', 'polyspora', 'v'], 'shortname': 'vanpo'}, '329726': {'common_names': ['acaryochloris', 'marina', 'a.', 'marina', 'a'], 'shortname': 'acam1'}, '350688': {'common_names': ['alkaliphilus', 'oremlandii', 'a.', 'oremlandii', 'a'], 'shortname': 'alkoo'}, '438753': {'common_names': ['azorhizobium', 'caulinodans', 'a.', 'caulinodans', 'a'], 'shortname': 'azoc5'}, '555079': {'common_names': ['thermosediminibacter', 'oceani', 't.', 'oceani', 't'], 'shortname': 'theoj'}, '681645': {'common_names': ['corynebacterium', 'pseudotuberculosis', 'c.', 'pseudotuberculosis', 'c'], 'shortname': 'corp2'}, '7240': {'common_names': ['drosophila', 'simulans', 'd.', 'simulans', 'd'], 'shortname': 'drosi'}, '6669': {'common_names': ['daphnia', 'pulex', 'd.', 'pulex', 'd'], 'shortname': 'dappu'}, '762903': {'common_names': ['pseudopedobacter', 'saltans', 'p.', 'saltans', 'p'], 'shortname': 'psesl'}, '104421': {'common_names': ['camponotus', 'floridanus', 'c.', 'floridanus', 'c'], 'shortname': 'camfo'}, '644223': {'common_names': ['komagataella', 'phaffii', 'k.', 'phaffii', 'k'], 'shortname': 'kompg'}, '287752': {'common_names': ['aurantimonas', 'manganoxydans', 'a.', 'manganoxydans', 'a'], 'shortname': 'aurms'}, '446469': {'common_names': ['sanguibacter', 'keddieii', 's.', 'keddieii', 's'], 'shortname': 'sanks'}, '525904': {'common_names': ['thermobaculum', 'terrenum', 't.', 'terrenum', 't'], 'shortname': 'thet1'}, '757424': {'common_names': ['herbaspirillum', 'seropedicae', 'h.', 'seropedicae', 'h'], 'shortname': 'herss'}, '759914': {'common_names': ['brachyspira', 'pilosicoli', 'b.', 'pilosicoli', 'b'], 'shortname': 'brap9'}, '633147': {'common_names': ['olsenella', 'uli', 'o.', 'uli', 'o'], 'shortname': 'olsuv'}, '1198114': {'common_names': ['granulicella', 'tundricola', 'g.', 'tundricola', 'g'], 'shortname': 'gratm'}, '666510': {'common_names': ['acidilobus', 'saccharovorans', 'a.', 'saccharovorans', 'a'], 'shortname': 'acis3'}, '649603': {'common_names': ['rice', 'ragged', 'r.', 'ragged', 'r'], 'shortname': 'rrsvt'}, '649596': {'common_names': ['micromonas', 'pusilla', 'm.', 'pusilla', 'm'], 'shortname': 'mprvn'}, '45237': {'common_names': ['helminthosporium', 'victoriae', 'h.', 'victoriae', 'h'], 'shortname': 'hv19s'}, '318586': {'common_names': ['paracoccus', 'denitrificans', 'p.', 'denitrificans', 'p'], 'shortname': 'pardp'}, '420662': {'common_names': ['methylibium', 'petroleiphilum', 'm.', 'petroleiphilum', 'm'], 'shortname': 'metpp'}, '29252': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bp186'}, '357809': {'common_names': ['lachnoclostridium', 'phytofermentans', 'l.', 'phytofermentans', 'l'], 'shortname': 'lacp7'}, '391735': {'common_names': ['verminephrobacter', 'eiseniae', 'v.', 'eiseniae', 'v'], 'shortname': 'verei'}, '644284': {'common_names': ['arcanobacterium', 'haemolyticum', 'a.', 'haemolyticum', 'a'], 'shortname': 'archd'}, '749414': {'common_names': ['streptomyces', 'bingchenggensis', 's.', 'bingchenggensis', 's'], 'shortname': 'strbb'}, '643648': {'common_names': ['syntrophothermus', 'lipocalidus', 's.', 'lipocalidus', 's'], 'shortname': 'synlt'}, '649638': {'common_names': ['truepera', 'radiovictrix', 't.', 'radiovictrix', 't'], 'shortname': 'trurr'}, '666681': {'common_names': ['methylotenera', 'versatilis', 'm.', 'versatilis', 'm'], 'shortname': 'metv0'}, '644295': {'common_names': ['methanohalobium', 'evestigatum', 'm.', 'evestigatum', 'm'], 'shortname': 'metez'}, '652668': {'common_names': ['grapevine', 'fleck', 'g.', 'fleck', 'g'], 'shortname': 'gfkvm'}, '649894': {'common_names': ['gillassociated', 'virus', 'g.', 'virus', 'g'], 'shortname': 'gavau'}, '650489': {'common_names': ['olive', 'latent', 'o.', 'latent', 'o'], 'shortname': 'olv2i'}, '35297': {'common_names': ['striped', 'jack', 's.', 'jack', 's'], 'shortname': 'sjnnv'}, '292459': {'common_names': ['symbiobacterium', 'thermophilum', 's.', 'thermophilum', 's'], 'shortname': 'symth'}, '273121': {'common_names': ['wolinella', 'succinogenes', 'w.', 'succinogenes', 'w'], 'shortname': 'wolsu'}, '273119': {'common_names': ['ureaplasma', 'parvum', 'u.', 'parvum', 'u'], 'shortname': 'urepa'}, '122586': {'common_names': ['neisseria', 'meningitidis', 'n.', 'meningitidis', 'n'], 'shortname': 'neimb'}, '227882': {'common_names': ['streptomyces', 'avermitilis', 's.', 'avermitilis', 's'], 'shortname': 'straw'}, '85962': {'common_names': ['helicobacter', 'pylori', 'h.', 'pylori', 'h'], 'shortname': 'helpy'}, '62977': {'common_names': ['acinetobacter', 'baylyi', 'a.', 'baylyi', 'a'], 'shortname': 'aciad'}, '272561': {'common_names': ['chlamydia', 'trachomatis', 'c.', 'trachomatis', 'c'], 'shortname': 'chltr'}, '220668': {'common_names': ['lactiplantibacillus', 'plantarum', 'l.', 'plantarum', 'l'], 'shortname': 'lacpl'}, '263820': {'common_names': ['picrophilus', 'torridus', 'p.', 'torridus', 'p'], 'shortname': 'picto'}, '206672': {'common_names': ['bifidobacterium', 'longum', 'b.', 'longum', 'b'], 'shortname': 'biflo'}, '197221': {'common_names': ['thermosynechococcus', 'vestitus', 't.', 'vestitus', 't'], 'shortname': 'thevb'}, '177437': {'common_names': ['desulforapulum', 'autotrophicum', 'd.', 'autotrophicum', 'd'], 'shortname': 'desah'}, '218495': {'common_names': ['streptococcus', 'uberis', 's.', 'uberis', 's'], 'shortname': 'stru0'}, '1117647': {'common_names': ['simiduia', 'agarivorans', 's.', 'agarivorans', 's'], 'shortname': 'simas'}, '1089553': {'common_names': ['thermacetogenium', 'phaeum', 't.', 'phaeum', 't'], 'shortname': 'theps'}, '880072': {'common_names': ['desulfobacca', 'acetoxidans', 'd.', 'acetoxidans', 'd'], 'shortname': 'desar'}, '593907': {'common_names': ['cellulomonas', 'gilvus', 'c.', 'gilvus', 'c'], 'shortname': 'celga'}, '662755': {'common_names': ['corynebacterium', 'resistens', 'c.', 'resistens', 'c'], 'shortname': 'corrg'}, '761193': {'common_names': ['runella', 'slithyformis', 'r.', 'slithyformis', 'r'], 'shortname': 'runsl'}, '717785': {'common_names': ['hyphomicrobium', 'sp', 'h.', 'sp', 'h'], 'shortname': 'hypsm'}, '765952': {'common_names': ['parachlamydia', 'acanthamoebae', 'p.', 'acanthamoebae', 'p'], 'shortname': 'parav'}, '331113': {'common_names': ['simkania', 'negevensis', 's.', 'negevensis', 's'], 'shortname': 'simnz'}, '744872': {'common_names': ['gracilinema', 'caldarium', 'g.', 'caldarium', 'g'], 'shortname': 'grac1'}, '654911': {'common_names': ['acidianus', 'bottleshaped', 'a.', 'bottleshaped', 'a'], 'shortname': 'abvp'}, '654909': {'common_names': ['acidianus', 'filamentous', 'a.', 'filamentous', 'a'], 'shortname': 'afv1y'}, '654922': {'common_names': ['lymphocystis', 'disease', 'l.', 'disease', 'l'], 'shortname': 'lcdv1'}, '272635': {'common_names': ['mycoplasmopsis', 'pulmonis', 'm.', 'pulmonis', 'm'], 'shortname': 'mycpu'}, '264201': {'common_names': ['protochlamydia', 'amoebophila', 'p.', 'amoebophila', 'p'], 'shortname': 'paruw'}, '176279': {'common_names': ['staphylococcus', 'epidermidis', 's.', 'epidermidis', 's'], 'shortname': 'staeq'}, '300852': {'common_names': ['thermus', 'thermophilus', 't.', 'thermophilus', 't'], 'shortname': 'thet8'}, '242231': {'common_names': ['neisseria', 'gonorrhoeae', 'n.', 'gonorrhoeae', 'n'], 'shortname': 'neig1'}, '69014': {'common_names': ['thermococcus', 'kodakarensis', 't.', 'kodakarensis', 't'], 'shortname': 'theko'}, '312309': {'common_names': ['aliivibrio', 'fischeri', 'a.', 'fischeri', 'a'], 'shortname': 'alif1'}, '9031': {'common_names': ['gallus', 'gallus', 'g.', 'gallus', 'g'], 'shortname': 'chick'}, '5664': {'common_names': ['leishmania', 'major', 'l.', 'major', 'l'], 'shortname': 'leima'}, '279808': {'common_names': ['staphylococcus', 'haemolyticus', 's.', 'haemolyticus', 's'], 'shortname': 'stahj'}, '306537': {'common_names': ['corynebacterium', 'jeikeium', 'c.', 'jeikeium', 'c'], 'shortname': 'corjk'}, '259536': {'common_names': ['psychrobacter', 'arcticus', 'p.', 'arcticus', 'p'], 'shortname': 'psya2'}, '262723': {'common_names': ['mycoplasmopsis', 'synoviae', 'm.', 'synoviae', 'm'], 'shortname': 'mycs5'}, '64091': {'common_names': ['halobacterium', 'salinarum', 'h.', 'salinarum', 'h'], 'shortname': 'halsa'}, '273068': {'common_names': ['caldanaerobacter', 'subterraneus', 'c.', 'subterraneus', 'c'], 'shortname': 'cals4'}, '160488': {'common_names': ['pseudomonas', 'putida', 'p.', 'putida', 'p'], 'shortname': 'psepk'}, '251221': {'common_names': ['gloeobacter', 'violaceus', 'g.', 'violaceus', 'g'], 'shortname': 'glovi'}, '83334': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco57'}, '227321': {'common_names': ['emericella', 'nidulans', 'e.', 'nidulans', 'e'], 'shortname': 'emeni'}, '237631': {'common_names': ['ustilago', 'maydis', 'u.', 'maydis', 'u'], 'shortname': 'ustma'}, '435591': {'common_names': ['parabacteroides', 'distasonis', 'p.', 'distasonis', 'p'], 'shortname': 'pard8'}, '652109': {'common_names': ['pothos', 'latent', 'p.', 'latent', 'p'], 'shortname': 'polvp'}, '652110': {'common_names': ['oat', 'chlorotic', 'o.', 'chlorotic', 'o'], 'shortname': 'ocsvu'}, '652597': {'common_names': ['carnation', 'ringspot', 'c.', 'ringspot', 'c'], 'shortname': 'crsvl'}, '12055': {'common_names': ['tobacco', 'necrosis', 't.', 'necrosis', 't'], 'shortname': 'tnva'}, '243231': {'common_names': ['geobacter', 'sulfurreducens', 'g.', 'sulfurreducens', 'g'], 'shortname': 'geosl'}, '228908': {'common_names': ['nanoarchaeum', 'equitans', 'n.', 'equitans', 'n'], 'shortname': 'naneq'}, '262316': {'common_names': ['mycolicibacterium', 'paratuberculosis', 'm.', 'paratuberculosis', 'm'], 'shortname': 'mycpa'}, '257314': {'common_names': ['lactobacillus', 'johnsonii', 'l.', 'johnsonii', 'l'], 'shortname': 'lacjo'}, '196627': {'common_names': ['corynebacterium', 'glutamicum', 'c.', 'glutamicum', 'c'], 'shortname': 'corgl'}, '243277': {'common_names': ['vibrio', 'cholerae', 'v.', 'cholerae', 'v'], 'shortname': 'vibch'}, '170187': {'common_names': ['streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's'], 'shortname': 'strpn'}, '171101': {'common_names': ['streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's'], 'shortname': 'strr6'}, '242619': {'common_names': ['porphyromonas', 'gingivalis', 'p.', 'gingivalis', 'p'], 'shortname': 'porgi'}, '267377': {'common_names': ['methanococcus', 'maripaludis', 'm.', 'maripaludis', 'm'], 'shortname': 'metmp'}, '284811': {'common_names': ['ashbya', 'gossypii', 'a.', 'gossypii', 'a'], 'shortname': 'ashgo'}, '298386': {'common_names': ['photobacterium', 'profundum', 'p.', 'profundum', 'p'], 'shortname': 'phopr'}, '1392': {'common_names': ['bacillus', 'anthracis', 'b.', 'anthracis', 'b'], 'shortname': 'bacan'}, '284590': {'common_names': ['kluyveromyces', 'lactis', 'k.', 'lactis', 'k'], 'shortname': 'klula'}, '284592': {'common_names': ['debaryomyces', 'hansenii', 'd.', 'hansenii', 'd'], 'shortname': 'debha'}, '177439': {'common_names': ['desulfotalea', 'psychrophila', 'd.', 'psychrophila', 'd'], 'shortname': 'desps'}, '272560': {'common_names': ['burkholderia', 'pseudomallei', 'b.', 'pseudomallei', 'b'], 'shortname': 'burps'}, '279010': {'common_names': ['bacillus', 'licheniformis', 'b.', 'licheniformis', 'b'], 'shortname': 'bacld'}, '272624': {'common_names': ['legionella', 'pneumophila', 'l.', 'pneumophila', 'l'], 'shortname': 'legph'}, '471856': {'common_names': ['jonesia', 'denitrificans', 'j.', 'denitrificans', 'j'], 'shortname': 'jondd'}, '292414': {'common_names': ['ruegeria', 'sp', 'r.', 'sp', 'r'], 'shortname': 'ruest'}, '357804': {'common_names': ['psychromonas', 'ingrahamii', 'p.', 'ingrahamii', 'p'], 'shortname': 'psyin'}, '196162': {'common_names': ['nocardioides', 'sp', 'n.', 'sp', 'n'], 'shortname': 'nocsj'}, '368408': {'common_names': ['thermofilum', 'pendens', 't.', 'pendens', 't'], 'shortname': 'thepd'}, '360095': {'common_names': ['bartonella', 'bacilliformis', 'b.', 'bacilliformis', 'b'], 'shortname': 'barbk'}, '365044': {'common_names': ['polaromonas', 'naphthalenivorans', 'p.', 'naphthalenivorans', 'p'], 'shortname': 'polna'}, '349124': {'common_names': ['halorhodospira', 'halophila', 'h.', 'halophila', 'h'], 'shortname': 'halhl'}, '326424': {'common_names': ['frankia', 'alni', 'f.', 'alni', 'f'], 'shortname': 'fraaa'}, '351160': {'common_names': ['methanocella', 'arvoryzae', 'm.', 'arvoryzae', 'm'], 'shortname': 'metar'}, '43151': {'common_names': ['anopheles', 'darlingi', 'a.', 'darlingi', 'a'], 'shortname': 'anoda'}, '349307': {'common_names': ['methanothrix', 'thermoacetophila', 'm.', 'thermoacetophila', 'm'], 'shortname': 'mettp'}, '651358': {'common_names': ['grapevine', 'virus', 'g.', 'virus', 'g'], 'shortname': 'gvais'}, '649896': {'common_names': ['infectious', 'flacherie', 'i.', 'flacherie', 'i'], 'shortname': 'ifvs'}, '318167': {'common_names': ['shewanella', 'frigidimarina', 's.', 'frigidimarina', 's'], 'shortname': 'shefn'}, '743720': {'common_names': ['pseudomonas', 'fulva', 'p.', 'fulva', 'p'], 'shortname': 'psef1'}, '1071378': {'common_names': ['naumovozyma', 'dairenensis', 'n.', 'dairenensis', 'n'], 'shortname': 'naudc'}, '759362': {'common_names': ['ketogulonicigenium', 'vulgare', 'k.', 'vulgare', 'k'], 'shortname': 'ketvw'}, '590646': {'common_names': ['candida', 'tenuis', 'c.', 'tenuis', 'c'], 'shortname': 'cantc'}, '619300': {'common_names': ['spathaspora', 'passalidarum', 's.', 'passalidarum', 's'], 'shortname': 'spapn'}, '9669': {'common_names': ['mustela', 'putorius', 'm.', 'putorius', 'm'], 'shortname': 'muspf'}, '289376': {'common_names': ['thermodesulfovibrio', 'yellowstonii', 't.', 'yellowstonii', 't'], 'shortname': 'theyd'}, '373903': {'common_names': ['halothermothrix', 'orenii', 'h.', 'orenii', 'h'], 'shortname': 'haloh'}, '511995': {'common_names': ['azobacteroides', 'pseudotrichonymphae', 'a.', 'pseudotrichonymphae', 'a'], 'shortname': 'azopc'}, '500485': {'common_names': ['penicillium', 'rubens', 'p.', 'rubens', 'p'], 'shortname': 'penrw'}, '155148': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bphk6'}, '313612': {'common_names': ['lyngbya', 'sp', 'l.', 'sp', 'l'], 'shortname': 'lynsp'}, '465515': {'common_names': ['micrococcus', 'luteus', 'm.', 'luteus', 'm'], 'shortname': 'miclc'}, '218208': {'common_names': ['desulfatibacillum', 'aliphaticivorans', 'd.', 'aliphaticivorans', 'd'], 'shortname': 'desal'}, '10753': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpnf'}, '585055': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco55'}, '585035': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco45'}, '301447': {'common_names': ['streptococcus', 'pyogenes', 's.', 'pyogenes', 's'], 'shortname': 'strp1'}, '290399': {'common_names': ['arthrobacter', 'sp', 'a.', 'sp', 'a'], 'shortname': 'arts2'}, '380703': {'common_names': ['aeromonas', 'hydrophila', 'a.', 'hydrophila', 'a'], 'shortname': 'aerhh'}, '246196': {'common_names': ['mycolicibacterium', 'smegmatis', 'm.', 'smegmatis', 'm'], 'shortname': 'mycs2'}, '414004': {'common_names': ['cenarchaeum', 'symbiosum', 'c.', 'symbiosum', 'c'], 'shortname': 'censy'}, '556484': {'common_names': ['phaeodactylum', 'tricornutum', 'p.', 'tricornutum', 'p'], 'shortname': 'phatc'}, '360106': {'common_names': ['campylobacter', 'fetus', 'c.', 'fetus', 'c'], 'shortname': 'camff'}, '4558': {'common_names': ['sorghum', 'bicolor', 's.', 'bicolor', 's'], 'shortname': 'sorbi'}, '525909': {'common_names': ['acidimicrobium', 'ferrooxidans', 'a.', 'ferrooxidans', 'a'], 'shortname': 'acifd'}, '203123': {'common_names': ['oenococcus', 'oeni', 'o.', 'oeni', 'o'], 'shortname': 'oenob'}, '398578': {'common_names': ['delftia', 'acidovorans', 'd.', 'acidovorans', 'd'], 'shortname': 'delas'}, '93059': {'common_names': ['prochlorococcus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'prom4'}, '436308': {'common_names': ['nitrosopumilus', 'maritimus', 'n.', 'maritimus', 'n'], 'shortname': 'nitms'}, '224324': {'common_names': ['aquifex', 'aeolicus', 'a.', 'aeolicus', 'a'], 'shortname': 'aquae'}, '192222': {'common_names': ['campylobacter', 'jejuni', 'c.', 'jejuni', 'c'], 'shortname': 'camje'}, '243232': {'common_names': ['methanocaldococcus', 'jannaschii', 'm.', 'jannaschii', 'm'], 'shortname': 'metja'}, '272631': {'common_names': ['mycobacterium', 'leprae', 'm.', 'leprae', 'm'], 'shortname': 'mycle'}, '272634': {'common_names': ['mycoplasma', 'pneumoniae', 'm.', 'pneumoniae', 'm'], 'shortname': 'mycpn'}, '272843': {'common_names': ['pasteurella', 'multocida', 'p.', 'multocida', 'p'], 'shortname': 'pasmu'}, '243276': {'common_names': ['treponema', 'pallidum', 't.', 'pallidum', 't'], 'shortname': 'trepa'}, '176299': {'common_names': ['agrobacterium', 'fabrum', 'a.', 'fabrum', 'a'], 'shortname': 'agrfc'}, '272562': {'common_names': ['clostridium', 'acetobutylicum', 'c.', 'acetobutylicum', 'c'], 'shortname': 'cloab'}, '632': {'common_names': ['yersinia', 'pestis', 'y.', 'pestis', 'y'], 'shortname': 'yerpe'}, '169963': {'common_names': ['listeria', 'monocytogenes', 'l.', 'monocytogenes', 'l'], 'shortname': 'lismo'}, '195102': {'common_names': ['clostridium', 'perfringens', 'c.', 'perfringens', 'c'], 'shortname': 'clope'}, '284813': {'common_names': ['encephalitozoon', 'cuniculi', 'e.', 'cuniculi', 'e'], 'shortname': 'enccu'}, '208435': {'common_names': ['streptococcus', 'agalactiae', 's.', 'agalactiae', 's'], 'shortname': 'stra5'}, '221109': {'common_names': ['oceanobacillus', 'iheyensis', 'o.', 'iheyensis', 'o'], 'shortname': 'oceih'}, '649604': {'common_names': ['banna', 'virus', 'b.', 'virus', 'b'], 'shortname': 'bavjk'}, '2905675': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bplsk'}, '471857': {'common_names': ['saccharomonospora', 'viridis', 's.', 'viridis', 's'], 'shortname': 'sacvd'}, '204270': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpkmv'}, '446470': {'common_names': ['stackebrandtia', 'nassauensis', 's.', 'nassauensis', 's'], 'shortname': 'stanl'}, '526218': {'common_names': ['sebaldella', 'termitidis', 's.', 'termitidis', 's'], 'shortname': 'sebte'}, '446466': {'common_names': ['cellulomonas', 'flavigena', 'c.', 'flavigena', 'c'], 'shortname': 'celfn'}, '479433': {'common_names': ['catenulispora', 'acidiphila', 'c.', 'acidiphila', 'c'], 'shortname': 'catad'}, '485917': {'common_names': ['pedobacter', 'heparinus', 'p.', 'heparinus', 'p'], 'shortname': 'pedhd'}, '2682836': {'common_names': ['acyrthosiphon', 'pisum', 'a.', 'pisum', 'a'], 'shortname': 'bpaps'}, '244589': {'common_names': ['sulfolobus', 'spindleshape', 's.', 'spindleshape', 's'], 'shortname': 'ssv1'}, '305674': {'common_names': ['deerpox', 'virus', 'd.', 'virus', 'd'], 'shortname': 'dpv83'}, '31530': {'common_names': ['myxoma', 'virus', 'm.', 'virus', 'm'], 'shortname': 'myxvl'}, '10272': {'common_names': ['rabbit', 'fibroma', 'r.', 'fibroma', 'r'], 'shortname': 'rfvka'}, '10280': {'common_names': ['molluscum', 'contagiosum', 'm.', 'contagiosum', 'm'], 'shortname': 'mcv1'}, '647330': {'common_names': ['orf', 'virus', 'o.', 'virus', 'o'], 'shortname': 'orfsa'}, '300880': {'common_names': ['swinepox', 'virus', 's.', 'virus', 's'], 'shortname': 'swpv1'}, '583355': {'common_names': ['coraliomargarita', 'akajimensis', 'c.', 'akajimensis', 'c'], 'shortname': 'corad'}, '264731': {'common_names': ['prevotella', 'ruminicola', 'p.', 'ruminicola', 'p'], 'shortname': 'prer2'}, '1236608': {'common_names': ['moraxella', 'catarrhalis', 'm.', 'catarrhalis', 'm'], 'shortname': 'morcb'}, '545693': {'common_names': ['priestia', 'megaterium', 'p.', 'megaterium', 'p'], 'shortname': 'prim1'}, '754252': {'common_names': ['propionibacterium', 'freudenreichii', 'p.', 'freudenreichii', 'p'], 'shortname': 'profc'}, '572480': {'common_names': ['arcobacter', 'nitrofigilis', 'a.', 'nitrofigilis', 'a'], 'shortname': 'arcnc'}, '654901': {'common_names': ['alcelaphine', 'herpesvirus', 'a.', 'herpesvirus', 'a'], 'shortname': 'alhv1'}, '469378': {'common_names': ['cryptobacterium', 'curtum', 'c.', 'curtum', 'c'], 'shortname': 'crycd'}, '521095': {'common_names': ['lancefieldella', 'parvula', 'l.', 'parvula', 'l'], 'shortname': 'lanp1'}, '623': {'common_names': ['shigella', 'flexneri', 's.', 'flexneri', 's'], 'shortname': 'shifl'}, '194439': {'common_names': ['chlorobaculum', 'tepidum', 'c.', 'tepidum', 'c'], 'shortname': 'chlte'}, '190485': {'common_names': ['xanthomonas', 'campestris', 'x.', 'campestris', 'x'], 'shortname': 'xancp'}, '186497': {'common_names': ['pyrococcus', 'furiosus', 'p.', 'furiosus', 'p'], 'shortname': 'pyrfu'}, '99287': {'common_names': ['salmonella', 'typhimurium', 's.', 'typhimurium', 's'], 'shortname': 'salty'}, '273063': {'common_names': ['sulfurisphaera', 'tokodaii', 's.', 'tokodaii', 's'], 'shortname': 'sulto'}, '272632': {'common_names': ['mycoplasma', 'mycoides', 'm.', 'mycoides', 'm'], 'shortname': 'mycms'}, '330779': {'common_names': ['sulfolobus', 'acidocaldarius', 's.', 'acidocaldarius', 's'], 'shortname': 'sulac'}, '83331': {'common_names': ['mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm'], 'shortname': 'mycto'}, '233412': {'common_names': ['haemophilus', 'ducreyi', 'h.', 'ducreyi', 'h'], 'shortname': 'haedu'}, '246200': {'common_names': ['ruegeria', 'pomeroyi', 'r.', 'pomeroyi', 'r'], 'shortname': 'ruepo'}, '273075': {'common_names': ['thermoplasma', 'acidophilum', 't.', 'acidophilum', 't'], 'shortname': 'theac'}, '243090': {'common_names': ['rhodopirellula', 'baltica', 'r.', 'baltica', 'r'], 'shortname': 'rhoba'}, '445932': {'common_names': ['elusimicrobium', 'minutum', 'e.', 'minutum', 'e'], 'shortname': 'elump'}, '344609': {'common_names': ['shigella', 'boydii', 's.', 'boydii', 's'], 'shortname': 'shib3'}, '349741': {'common_names': ['akkermansia', 'muciniphila', 'a.', 'muciniphila', 'a'], 'shortname': 'akkm8'}, '498211': {'common_names': ['cellvibrio', 'japonicus', 'c.', 'japonicus', 'c'], 'shortname': 'celju'}, '694429': {'common_names': ['pyrolobus', 'fumarii', 'p.', 'fumarii', 'p'], 'shortname': 'pyrf1'}, '8090': {'common_names': ['oryzias', 'latipes', 'o.', 'latipes', 'o'], 'shortname': 'oryla'}, '485915': {'common_names': ['desulfohalobium', 'retbaense', 'd.', 'retbaense', 'd'], 'shortname': 'desrd'}, '394': {'common_names': ['sinorhizobium', 'fredii', 's.', 'fredii', 's'], 'shortname': 'sinfn'}, '321614': {'common_names': ['phaeosphaeria', 'nodorum', 'p.', 'nodorum', 'p'], 'shortname': 'phano'}, '306901': {'common_names': ['chaetomium', 'globosum', 'c.', 'globosum', 'c'], 'shortname': 'chagb'}, '547558': {'common_names': ['methanohalophilus', 'mahii', 'm.', 'mahii', 'm'], 'shortname': 'metms'}, '717774': {'common_names': ['marinomonas', 'mediterranea', 'm.', 'mediterranea', 'm'], 'shortname': 'marm1'}, '5786': {'common_names': ['dictyostelium', 'purpureum', 'd.', 'purpureum', 'd'], 'shortname': 'dicpu'}, '10651': {'common_names': ['soybean', 'chlorotic', 's.', 'chlorotic', 's'], 'shortname': 'socmv'}, '861557': {'common_names': ['pyrenophora', 'teres', 'p.', 'teres', 'p'], 'shortname': 'pyrtt'}, '765177': {'common_names': ['desulfurococcus', 'mucosus', 'd.', 'mucosus', 'd'], 'shortname': 'desm0'}, '7222': {'common_names': ['drosophila', 'grimshawi', 'd.', 'grimshawi', 'd'], 'shortname': 'drogr'}, '747676': {'common_names': ['melampsora', 'laricipopulina', 'm.', 'laricipopulina', 'm'], 'shortname': 'mellp'}, '61853': {'common_names': ['nomascus', 'leucogenys', 'n.', 'leucogenys', 'n'], 'shortname': 'nomle'}, '59463': {'common_names': ['myotis', 'lucifugus', 'm.', 'lucifugus', 'm'], 'shortname': 'myolu'}, '10029': {'common_names': ['cricetulus', 'griseus', 'c.', 'griseus', 'c'], 'shortname': 'crigr'}, '686950': {'common_names': ['citrus', 'leprosis', 'c.', 'leprosis', 'c'], 'shortname': 'cilvc'}, '652675': {'common_names': ['raspberry', 'bushy', 'r.', 'bushy', 'r'], 'shortname': 'rbdvr'}, '652838': {'common_names': ['ourmia', 'melon', 'o.', 'melon', 'o'], 'shortname': 'oumvv'}, '339671': {'common_names': ['actinobacillus', 'succinogenes', 'a.', 'succinogenes', 'a'], 'shortname': 'actsz'}, '316278': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synr3'}, '266940': {'common_names': ['kineococcus', 'radiotolerans', 'k.', 'radiotolerans', 'k'], 'shortname': 'kinrd'}, '387092': {'common_names': ['nitratiruptor', 'sp', 'n.', 'sp', 'n'], 'shortname': 'nitsb'}, '331111': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco24'}, '331112': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'ecohs'}, '467705': {'common_names': ['streptococcus', 'gordonii', 's.', 'gordonii', 's'], 'shortname': 'strgc'}, '212035': {'common_names': ['acanthamoeba', 'polyphaga', 'a.', 'polyphaga', 'a'], 'shortname': 'mimiv'}, '367737': {'common_names': ['aliarcobacter', 'butzleri', 'a.', 'butzleri', 'a'], 'shortname': 'alib4'}, '397948': {'common_names': ['caldivirga', 'maquilingensis', 'c.', 'maquilingensis', 'c'], 'shortname': 'calmq'}, '66692': {'common_names': ['alkalihalobacillus', 'clausii', 'a.', 'clausii', 'a'], 'shortname': 'alkck'}, '272569': {'common_names': ['haloarcula', 'marismortui', 'h.', 'marismortui', 'h'], 'shortname': 'halma'}, '264199': {'common_names': ['streptococcus', 'thermophilus', 's.', 'thermophilus', 's'], 'shortname': 'strt2'}, '283942': {'common_names': ['idiomarina', 'loihiensis', 'i.', 'loihiensis', 'i'], 'shortname': 'idilo'}, '235909': {'common_names': ['geobacillus', 'kaustophilus', 'g.', 'kaustophilus', 'g'], 'shortname': 'geoka'}, '264203': {'common_names': ['zymomonas', 'mobilis', 'z.', 'mobilis', 'z'], 'shortname': 'zymmo'}, '177416': {'common_names': ['francisella', 'tularensis', 'f.', 'tularensis', 'f'], 'shortname': 'fratt'}, '269084': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synp6'}, '272568': {'common_names': ['gluconacetobacter', 'diazotrophicus', 'g.', 'diazotrophicus', 'g'], 'shortname': 'gluda'}, '216594': {'common_names': ['mycobacterium', 'marinum', 'm.', 'marinum', 'm'], 'shortname': 'mycmm'}, '63737': {'common_names': ['nostoc', 'punctiforme', 'n.', 'punctiforme', 'n'], 'shortname': 'nosp7'}, '391038': {'common_names': ['paraburkholderia', 'phymatum', 'p.', 'phymatum', 'p'], 'shortname': 'parp8'}, '515849': {'common_names': ['podospora', 'anserina', 'p.', 'anserina', 'p'], 'shortname': 'podan'}, '43989': {'common_names': ['crocosphaera', 'subtropica', 'c.', 'subtropica', 'c'], 'shortname': 'cros5'}, '517418': {'common_names': ['chloroherpeton', 'thalassium', 'c.', 'thalassium', 'c'], 'shortname': 'chlt3'}, '521096': {'common_names': ['tsukamurella', 'paurometabola', 't.', 'paurometabola', 't'], 'shortname': 'tsupd'}, '526226': {'common_names': ['gordonia', 'bronchialis', 'g.', 'bronchialis', 'g'], 'shortname': 'gorb4'}, '452471': {'common_names': ['amoebophilus', 'asiaticus', 'a.', 'asiaticus', 'a'], 'shortname': 'amoa5'}, '523791': {'common_names': ['kangiella', 'koreensis', 'k.', 'koreensis', 'k'], 'shortname': 'kankd'}, '395494': {'common_names': ['gallionella', 'capsiferriformans', 'g.', 'capsiferriformans', 'g'], 'shortname': 'galcs'}, '10854': {'common_names': ['spiroplasma', 'virus', 's.', 'virus', 's'], 'shortname': 'spv1r'}, '272558': {'common_names': ['halalkalibacterium', 'halodurans', 'h.', 'halodurans', 'h'], 'shortname': 'halh5'}, '390333': {'common_names': ['lactobacillus', 'delbrueckii', 'l.', 'delbrueckii', 'l'], 'shortname': 'lacda'}, '246410': {'common_names': ['coccidioides', 'immitis', 'c.', 'immitis', 'c'], 'shortname': 'cocim'}, '748280': {'common_names': ['pseudogulbenkiania', 'sp', 'p.', 'sp', 'p'], 'shortname': 'pseul'}, '627192': {'common_names': ['sphingobium', 'sp', 's.', 'sp', 's'], 'shortname': 'sphsk'}, '1069534': {'common_names': ['ligilactobacillus', 'ruminis', 'l.', 'ruminis', 'l'], 'shortname': 'ligr2'}, '714313': {'common_names': ['fructilactobacillus', 'sanfranciscensis', 'f.', 'sanfranciscensis', 'f'], 'shortname': 'frust'}, '7238': {'common_names': ['drosophila', 'sechellia', 'd.', 'sechellia', 'd'], 'shortname': 'drose'}, '441960': {'common_names': ['talaromyces', 'marneffei', 't.', 'marneffei', 't'], 'shortname': 'talmq'}, '766189': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvt1'}, '515622': {'common_names': ['butyrivibrio', 'proteoclasticus', 'b.', 'proteoclasticus', 'b'], 'shortname': 'butpb'}, '284591': {'common_names': ['yarrowia', 'lipolytica', 'y.', 'lipolytica', 'y'], 'shortname': 'yarli'}, '314260': {'common_names': ['parvularcula', 'bermudensis', 'p.', 'bermudensis', 'p'], 'shortname': 'parbh'}, '871271': {'common_names': ['zinderia', 'insecticola', 'z.', 'insecticola', 'z'], 'shortname': 'zinic'}, '583356': {'common_names': ['ignisphaera', 'aggregans', 'i.', 'aggregans', 'i'], 'shortname': 'ignaa'}, '281090': {'common_names': ['leifsonia', 'xyli', 'l.', 'xyli', 'l'], 'shortname': 'leixx'}, '34765': {'common_names': ['oikopleura', 'dioica', 'o.', 'dioica', 'o'], 'shortname': 'oikdi'}, '665079': {'common_names': ['sclerotinia', 'sclerotiorum', 's.', 'sclerotiorum', 's'], 'shortname': 'scls1'}, '334413': {'common_names': ['finegoldia', 'magna', 'f.', 'magna', 'f'], 'shortname': 'finm2'}, '394503': {'common_names': ['ruminiclostridium', 'cellulolyticum', 'r.', 'cellulolyticum', 'r'], 'shortname': 'rumch'}, '81824': {'common_names': ['monosiga', 'brevicollis', 'm.', 'brevicollis', 'm'], 'shortname': 'monbe'}, '345201': {'common_names': ['invertebrate', 'iridescent', 'i.', 'iridescent', 'i'], 'shortname': 'iiv3'}, '243159': {'common_names': ['acidithiobacillus', 'ferrooxidans', 'a.', 'ferrooxidans', 'a'], 'shortname': 'acif2'}, '565050': {'common_names': ['caulobacter', 'vibrioides', 'c.', 'vibrioides', 'c'], 'shortname': 'cauvn'}, '123214': {'common_names': ['persephonella', 'marina', 'p.', 'marina', 'p'], 'shortname': 'permh'}, '204536': {'common_names': ['sulfurihydrogenibium', 'azorense', 's.', 'azorense', 's'], 'shortname': 'sulaa'}, '479437': {'common_names': ['eggerthella', 'lenta', 'e.', 'lenta', 'e'], 'shortname': 'eggle'}, '526225': {'common_names': ['geodermatophilus', 'obscurus', 'g.', 'obscurus', 'g'], 'shortname': 'geoog'}, '458233': {'common_names': ['macrococcus', 'caseolyticus', 'm.', 'caseolyticus', 'm'], 'shortname': 'maccj'}, '670386': {'common_names': ['heterostelium', 'pallidum', 'h.', 'pallidum', 'h'], 'shortname': 'hetp5'}, '862751': {'common_names': ['streptomyces', 'sp', 's.', 'sp', 's'], 'shortname': 'strek'}, '648757': {'common_names': ['rhodomicrobium', 'vannielii', 'r.', 'vannielii', 'r'], 'shortname': 'rhovt'}, '439481': {'common_names': ['aciduliprofundum', 'boonei', 'a.', 'boonei', 'a'], 'shortname': 'acib4'}, '649639': {'common_names': ['evansella', 'cellulosilytica', 'e.', 'cellulosilytica', 'e'], 'shortname': 'evac2'}, '1453429': {'common_names': ['atelocyanobacterium', 'thalassa', 'a.', 'thalassa', 'a'], 'shortname': 'ateth'}, '189518': {'common_names': ['leptospira', 'interrogans', 'l.', 'interrogans', 'l'], 'shortname': 'lepin'}, '196164': {'common_names': ['corynebacterium', 'efficiens', 'c.', 'efficiens', 'c'], 'shortname': 'coref'}, '199310': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'ecol6'}, '212717': {'common_names': ['clostridium', 'tetani', 'c.', 'tetani', 'c'], 'shortname': 'clote'}, '226186': {'common_names': ['bacteroides', 'thetaiotaomicron', 'b.', 'thetaiotaomicron', 'b'], 'shortname': 'bactn'}, '226185': {'common_names': ['enterococcus', 'faecalis', 'e.', 'faecalis', 'e'], 'shortname': 'entfa'}, '228410': {'common_names': ['nitrosomonas', 'europaea', 'n.', 'europaea', 'n'], 'shortname': 'niteu'}, '226900': {'common_names': ['bacillus', 'cereus', 'b.', 'cereus', 'b'], 'shortname': 'baccr'}, '710127': {'common_names': ['mycoplasmoides', 'gallisepticum', 'm.', 'gallisepticum', 'm'], 'shortname': 'mycga'}, '233413': {'common_names': ['mycobacterium', 'bovis', 'm.', 'bovis', 'm'], 'shortname': 'mycbo'}, '167539': {'common_names': ['prochlorococcus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'proma'}, '84588': {'common_names': ['parasynechococcus', 'marenigrum', 'p.', 'marenigrum', 'p'], 'shortname': 'parmw'}, '74547': {'common_names': ['prochlorococcus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'promm'}, '243365': {'common_names': ['chromobacterium', 'violaceum', 'c.', 'violaceum', 'c'], 'shortname': 'chrvo'}, '1111708': {'common_names': ['synechocystis', 'sp', 's.', 'sp', 's'], 'shortname': 'syny3'}, '258594': {'common_names': ['rhodopseudomonas', 'palustris', 'r.', 'palustris', 'r'], 'shortname': 'rhopa'}, '416269': {'common_names': ['actinobacillus', 'pleuropneumoniae', 'a.', 'pleuropneumoniae', 'a'], 'shortname': 'actp2'}, '572477': {'common_names': ['allochromatium', 'vinosum', 'a.', 'vinosum', 'a'], 'shortname': 'allvd'}, '680198': {'common_names': ['streptomyces', 'scabiei', 's.', 'scabiei', 's'], 'shortname': 'strsw'}, '35128': {'common_names': ['thalassiosira', 'pseudonana', 't.', 'pseudonana', 't'], 'shortname': 'thaps'}, '36329': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p'], 'shortname': 'plaf7'}, '373153': {'common_names': ['streptococcus', 'pneumoniae', 's.', 'pneumoniae', 's'], 'shortname': 'strp2'}, '441375': {'common_names': ['cryptosporidium', 'muris', 'c.', 'muris', 'c'], 'shortname': 'crymr'}, '426418': {'common_names': ['pyrenophora', 'triticirepentis', 'p.', 'triticirepentis', 'p'], 'shortname': 'pyrtr'}, '645127': {'common_names': ['corynebacterium', 'kroppenstedtii', 'c.', 'kroppenstedtii', 'c'], 'shortname': 'cork4'}, '515620': {'common_names': ['lachnospira', 'eligens', 'l.', 'eligens', 'l'], 'shortname': 'lace2'}, '572263': {'common_names': ['mesomycoplasma', 'conjunctivae', 'm.', 'conjunctivae', 'm'], 'shortname': 'mesch'}, '716544': {'common_names': ['waddlia', 'chondrophila', 'w.', 'chondrophila', 'w'], 'shortname': 'wadcw'}, '589865': {'common_names': ['desulfurivibrio', 'alkaliphilus', 'd.', 'alkaliphilus', 'd'], 'shortname': 'desat'}, '551115': {'common_names': ['nostoc', 'azollae', 'n.', 'azollae', 'n'], 'shortname': 'nosa0'}, '531844': {'common_names': ['flavobacteriaceae', 'bacterium', 'f.', 'bacterium', 'f'], 'shortname': 'flab3'}, '88036': {'common_names': ['selaginella', 'moellendorffii', 's.', 'moellendorffii', 's'], 'shortname': 'selml'}, '9595': {'common_names': ['gorilla', 'gorilla', 'g.', 'gorilla', 'g'], 'shortname': 'gorgo'}, '639282': {'common_names': ['deferribacter', 'desulfuricans', 'd.', 'desulfuricans', 'd'], 'shortname': 'defds'}, '679897': {'common_names': ['helicobacter', 'mustelae', 'h.', 'mustelae', 'h'], 'shortname': 'helm1'}, '344021': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpk1f'}, '398511': {'common_names': ['alkalihalophilus', 'pseudofirmus', 'a.', 'pseudofirmus', 'a'], 'shortname': 'alkpo'}, '184922': {'common_names': ['giardia', 'intestinalis', 'g.', 'intestinalis', 'g'], 'shortname': 'giaic'}, '663278': {'common_names': ['ethanoligenens', 'harbinense', 'e.', 'harbinense', 'e'], 'shortname': 'ethhy'}, '6945': {'common_names': ['ixodes', 'scapularis', 'i.', 'scapularis', 'i'], 'shortname': 'ixosc'}, '349161': {'common_names': ['desulforamulus', 'reducens', 'd.', 'reducens', 'd'], 'shortname': 'desrm'}, '323850': {'common_names': ['shewanella', 'loihica', 's.', 'loihica', 's'], 'shortname': 'shelp'}, '443906': {'common_names': ['clavibacter', 'michiganensis', 'c.', 'michiganensis', 'c'], 'shortname': 'clam3'}, '357244': {'common_names': ['orientia', 'tsutsugamushi', 'o.', 'tsutsugamushi', 'o'], 'shortname': 'oritb'}, '32051': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synpw'}, '436017': {'common_names': ['ostreococcus', 'lucimarinus', 'o.', 'lucimarinus', 'o'], 'shortname': 'ostlu'}, '293826': {'common_names': ['alkaliphilus', 'metalliredigens', 'a.', 'metalliredigens', 'a'], 'shortname': 'alkmq'}, '46014': {'common_names': ['acholeplasma', 'phage', 'a.', 'phage', 'a'], 'shortname': 'bpl2'}, '167542': {'common_names': ['prochlorococcus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'prom5'}, '414684': {'common_names': ['rhodospirillum', 'centenum', 'r.', 'centenum', 'r'], 'shortname': 'rhocs'}, '45351': {'common_names': ['nematostella', 'vectensis', 'n.', 'vectensis', 'n'], 'shortname': 'nemve'}, '10553': {'common_names': ['fowl', 'adenovirus', 'f.', 'adenovirus', 'f'], 'shortname': 'adeg1'}, '9601': {'common_names': ['pongo', 'abelii', 'p.', 'abelii', 'p'], 'shortname': 'ponab'}, '311402': {'common_names': ['agrobacterium', 'vitis', 'a.', 'vitis', 'a'], 'shortname': 'agrvs'}, '398720': {'common_names': ['leeuwenhoekiella', 'blandensis', 'l.', 'blandensis', 'l'], 'shortname': 'leebm'}, '313603': {'common_names': ['maribacter', 'sp', 'm.', 'sp', 'm'], 'shortname': 'marsh'}, '983644': {'common_names': ['cordyceps', 'militaris', 'c.', 'militaris', 'c'], 'shortname': 'cormm'}, '498257': {'common_names': ['verticillium', 'dahliae', 'v.', 'dahliae', 'v'], 'shortname': 'verdv'}, '580332': {'common_names': ['sideroxydans', 'lithotrophicus', 's.', 'lithotrophicus', 's'], 'shortname': 'sidle'}, '580327': {'common_names': ['thermoanaerobacterium', 'thermosaccharolyticum', 't.', 'thermosaccharolyticum', 't'], 'shortname': 'thetc'}, '502780': {'common_names': ['paracoccidioides', 'brasiliensis', 'p.', 'brasiliensis', 'p'], 'shortname': 'parbd'}, '447093': {'common_names': ['ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a'], 'shortname': 'ajecg'}, '880070': {'common_names': ['cyclobacterium', 'marinum', 'c.', 'marinum', 'c'], 'shortname': 'cycms'}, '1029718': {'common_names': ['arthromitus', 'sp', 'a.', 'sp', 'a'], 'shortname': 'artss'}, '1064592': {'common_names': ['naumovozyma', 'castellii', 'n.', 'castellii', 'n'], 'shortname': 'naucc'}, '9103': {'common_names': ['meleagris', 'gallopavo', 'm.', 'gallopavo', 'm'], 'shortname': 'melga'}, '28377': {'common_names': ['anolis', 'carolinensis', 'a.', 'carolinensis', 'a'], 'shortname': 'anoca'}, '321967': {'common_names': ['lacticaseibacillus', 'paracasei', 'l.', 'paracasei', 'l'], 'shortname': 'lacp3'}, '387344': {'common_names': ['levilactobacillus', 'brevis', 'l.', 'brevis', 'l'], 'shortname': 'levba'}, '574087': {'common_names': ['acetohalobium', 'arabaticum', 'a.', 'arabaticum', 'a'], 'shortname': 'aceaz'}, '610130': {'common_names': ['lacrimispora', 'saccharolytica', 'l.', 'saccharolytica', 'l'], 'shortname': 'lacsw'}, '686947': {'common_names': ['botrytis', 'virus', 'b.', 'virus', 'b'], 'shortname': 'botvx'}, '652599': {'common_names': ['panicum', 'mosaic', 'p.', 'mosaic', 'p'], 'shortname': 'pmvk'}, '654934': {'common_names': ['white', 'clover', 'w.', 'clover', 'w'], 'shortname': 'wccvb'}, '647331': {'common_names': ['atkinsonella', 'hypoxylon', 'a.', 'hypoxylon', 'a'], 'shortname': 'ahv2h'}, '648168': {'common_names': ['colorado', 'tick', 'c.', 'tick', 'c'], 'shortname': 'ctfvl'}, '648170': {'common_names': ['aedes', 'pseudoscutellaris', 'a.', 'pseudoscutellaris', 'a'], 'shortname': 'aprvf'}, '648172': {'common_names': ['fiji', 'disease', 'f.', 'disease', 'f'], 'shortname': 'fdvs'}, '262543': {'common_names': ['exiguobacterium', 'sibiricum', 'e.', 'sibiricum', 'e'], 'shortname': 'exis2'}, '457570': {'common_names': ['natranaerobius', 'thermophilus', 'n.', 'thermophilus', 'n'], 'shortname': 'nattj'}, '374847': {'common_names': ['korarchaeum', 'cryptofilum', 'k.', 'cryptofilum', 'k'], 'shortname': 'korco'}, '32049': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synp2'}, '395495': {'common_names': ['leptothrix', 'cholodnii', 'l.', 'cholodnii', 'l'], 'shortname': 'lepcp'}, '395963': {'common_names': ['beijerinckia', 'indica', 'b.', 'indica', 'b'], 'shortname': 'beii9'}, '706191': {'common_names': ['pantoea', 'ananatis', 'p.', 'ananatis', 'p'], 'shortname': 'panam'}, '1289570': {'common_names': ['haemophilus', 'phage', 'h.', 'phage', 'h'], 'shortname': 'bphc1'}, '465817': {'common_names': ['erwinia', 'tasmaniensis', 'e.', 'tasmaniensis', 'e'], 'shortname': 'erwt9'}, '504474': {'common_names': ['corynebacterium', 'urealyticum', 'c.', 'urealyticum', 'c'], 'shortname': 'coru7'}, '309798': {'common_names': ['coprothermobacter', 'proteolyticus', 'c.', 'proteolyticus', 'c'], 'shortname': 'coppd'}, '402676': {'common_names': ['schizosaccharomyces', 'japonicus', 's.', 'japonicus', 's'], 'shortname': 'schjy'}, '441959': {'common_names': ['talaromyces', 'stipitatus', 't.', 'stipitatus', 't'], 'shortname': 'talsn'}, '485914': {'common_names': ['halomicrobium', 'mukohataei', 'h.', 'mukohataei', 'h'], 'shortname': 'halmd'}, '185959': {'common_names': ['spiroplasma', 'virus', 's.', 'virus', 's'], 'shortname': 'spv1c'}, '335543': {'common_names': ['syntrophobacter', 'fumaroxidans', 's.', 'fumaroxidans', 's'], 'shortname': 'synfm'}, '10754': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpp22'}, '332648': {'common_names': ['botryotinia', 'fuckeliana', 'b.', 'fuckeliana', 'b'], 'shortname': 'botfb'}, '367110': {'common_names': ['neurospora', 'crassa', 'n.', 'crassa', 'n'], 'shortname': 'neucr'}, '224326': {'common_names': ['borreliella', 'burgdorferi', 'b.', 'burgdorferi', 'b'], 'shortname': 'borbu'}, '9986': {'common_names': ['oryctolagus', 'cuniculus', 'o.', 'cuniculus', 'o'], 'shortname': 'rabit'}, '10255': {'common_names': ['variola', 'virus', 'v.', 'virus', 'v'], 'shortname': 'varv'}, '190650': {'common_names': ['caulobacter', 'vibrioides', 'c.', 'vibrioides', 'c'], 'shortname': 'cauvc'}, '266265': {'common_names': ['paraburkholderia', 'xenovorans', 'p.', 'xenovorans', 'p'], 'shortname': 'parxl'}, '46245': {'common_names': ['drosophila', 'pseudoobscura', 'd.', 'pseudoobscura', 'd'], 'shortname': 'drops'}, '269798': {'common_names': ['cytophaga', 'hutchinsonii', 'c.', 'hutchinsonii', 'c'], 'shortname': 'cyth3'}, '190192': {'common_names': ['methanopyrus', 'kandleri', 'm.', 'kandleri', 'm'], 'shortname': 'metka'}, '472759': {'common_names': ['nitrosococcus', 'halophilus', 'n.', 'halophilus', 'n'], 'shortname': 'nithn'}, '512564': {'common_names': ['mycoplasma', 'crocodyli', 'm.', 'crocodyli', 'm'], 'shortname': 'myccm'}, '456481': {'common_names': ['leptospira', 'biflexa', 'l.', 'biflexa', 'l'], 'shortname': 'lepbp'}, '240176': {'common_names': ['coprinopsis', 'cinerea', 'c.', 'cinerea', 'c'], 'shortname': 'copc7'}, '543939': {'common_names': ['sputnik', 'virophage', 's.', 'virophage', 's'], 'shortname': 'sptnk'}, '450851': {'common_names': ['phenylobacterium', 'zucineum', 'p.', 'zucineum', 'p'], 'shortname': 'phezh'}, '564608': {'common_names': ['micromonas', 'pusilla', 'm.', 'pusilla', 'm'], 'shortname': 'micpc'}, '358681': {'common_names': ['brevibacillus', 'brevis', 'b.', 'brevis', 'b'], 'shortname': 'brebn'}, '547559': {'common_names': ['natrialba', 'magadii', 'n.', 'magadii', 'n'], 'shortname': 'natmm'}, '502025': {'common_names': ['haliangium', 'ochraceum', 'h.', 'ochraceum', 'h'], 'shortname': 'halo1'}, '771870': {'common_names': ['sordaria', 'macrospora', 's.', 'macrospora', 's'], 'shortname': 'sormk'}, '680646': {'common_names': ['rothia', 'mucilaginosa', 'r.', 'mucilaginosa', 'r'], 'shortname': 'rotmd'}, '530564': {'common_names': ['pirellula', 'staleyi', 'p.', 'staleyi', 'p'], 'shortname': 'pirsd'}, '637910': {'common_names': ['citrobacter', 'rodentium', 'c.', 'rodentium', 'c'], 'shortname': 'citri'}, '380358': {'common_names': ['xanthomonas', 'albilineans', 'x.', 'albilineans', 'x'], 'shortname': 'xanap'}, '572546': {'common_names': ['archaeoglobus', 'profundus', 'a.', 'profundus', 'a'], 'shortname': 'arcpa'}, '591001': {'common_names': ['acidaminococcus', 'fermentans', 'a.', 'fermentans', 'a'], 'shortname': 'acifv'}, '644283': {'common_names': ['micromonospora', 'aurantiaca', 'm.', 'aurantiaca', 'm'], 'shortname': 'micai'}, '526227': {'common_names': ['meiothermus', 'silvanus', 'm.', 'silvanus', 'm'], 'shortname': 'meisd'}, '521098': {'common_names': ['alicyclobacillus', 'acidocaldarius', 'a.', 'acidocaldarius', 'a'], 'shortname': 'aliad'}, '471852': {'common_names': ['thermomonospora', 'curvata', 't.', 'curvata', 't'], 'shortname': 'thecd'}, '446465': {'common_names': ['brachybacterium', 'faecium', 'b.', 'faecium', 'b'], 'shortname': 'brafd'}, '294381': {'common_names': ['entamoeba', 'histolytica', 'e.', 'histolytica', 'e'], 'shortname': 'enth1'}, '269796': {'common_names': ['rhodospirillum', 'rubrum', 'r.', 'rubrum', 'r'], 'shortname': 'rhort'}, '339860': {'common_names': ['methanosphaera', 'stadtmanae', 'm.', 'stadtmanae', 'm'], 'shortname': 'metst'}, '56780': {'common_names': ['syntrophus', 'aciditrophicus', 's.', 'aciditrophicus', 's'], 'shortname': 'synas'}, '290397': {'common_names': ['anaeromyxobacter', 'dehalogenans', 'a.', 'dehalogenans', 'a'], 'shortname': 'anade'}, '347834': {'common_names': ['rhizobium', 'etli', 'r.', 'etli', 'r'], 'shortname': 'rhiec'}, '106370': {'common_names': ['frankia', 'casuarinae', 'f.', 'casuarinae', 'f'], 'shortname': 'fracc'}, '321332': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synjb'}, '323259': {'common_names': ['methanospirillum', 'hungatei', 'm.', 'hungatei', 'm'], 'shortname': 'methj'}, '138119': {'common_names': ['desulfitobacterium', 'hafniense', 'd.', 'hafniense', 'd'], 'shortname': 'deshy'}, '203122': {'common_names': ['saccharophagus', 'degradans', 's.', 'degradans', 's'], 'shortname': 'sacd2'}, '5874': {'common_names': ['theileria', 'annulata', 't.', 'annulata', 't'], 'shortname': 'thean'}, '323097': {'common_names': ['nitrobacter', 'hamburgensis', 'n.', 'hamburgensis', 'n'], 'shortname': 'nithx'}, '630626': {'common_names': ['shimwellia', 'blattae', 's.', 'blattae', 's'], 'shortname': 'shibc'}, '228405': {'common_names': ['hyphomonas', 'neptunium', 'h.', 'neptunium', 'h'], 'shortname': 'hypna'}, '64471': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'syns3'}, '187272': {'common_names': ['alkalilimnicola', 'ehrlichii', 'a.', 'ehrlichii', 'a'], 'shortname': 'alkeh'}, '391165': {'common_names': ['granulibacter', 'bethesdensis', 'g.', 'bethesdensis', 'g'], 'shortname': 'grabc'}, '394221': {'common_names': ['maricaulis', 'maris', 'm.', 'maris', 'm'], 'shortname': 'marmm'}, '335541': {'common_names': ['syntrophomonas', 'wolfei', 's.', 'wolfei', 's'], 'shortname': 'synww'}, '100226': {'common_names': ['streptomyces', 'coelicolor', 's.', 'coelicolor', 's'], 'shortname': 'strco'}, '273057': {'common_names': ['saccharolobus', 'solfataricus', 's.', 'solfataricus', 's'], 'shortname': 'sacs2'}, '362976': {'common_names': ['haloquadratum', 'walsbyi', 'h.', 'walsbyi', 'h'], 'shortname': 'halwd'}, '266834': {'common_names': ['rhizobium', 'meliloti', 'r.', 'meliloti', 'r'], 'shortname': 'rhime'}, '360910': {'common_names': ['bordetella', 'avium', 'b.', 'avium', 'b'], 'shortname': 'bora1'}, '272563': {'common_names': ['clostridioides', 'difficile', 'c.', 'difficile', 'c'], 'shortname': 'clod6'}, '318161': {'common_names': ['shewanella', 'denitrificans', 's.', 'denitrificans', 's'], 'shortname': 'shedo'}, '296591': {'common_names': ['polaromonas', 'sp', 'p.', 'sp', 'p'], 'shortname': 'polsj'}, '441771': {'common_names': ['clostridium', 'botulinum', 'c.', 'botulinum', 'c'], 'shortname': 'clobh'}, '419947': {'common_names': ['mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm'], 'shortname': 'mycta'}, '557436': {'common_names': ['limosilactobacillus', 'reuteri', 'l.', 'reuteri', 'l'], 'shortname': 'limrd'}, '114615': {'common_names': ['bradyrhizobium', 'sp', 'b.', 'sp', 'b'], 'shortname': 'braso'}, '379508': {'common_names': ['lodderomyces', 'elongisporus', 'l.', 'elongisporus', 'l'], 'shortname': 'lodel'}, '294746': {'common_names': ['meyerozyma', 'guilliermondii', 'm.', 'guilliermondii', 'm'], 'shortname': 'picgu'}, '288705': {'common_names': ['renibacterium', 'salmoninarum', 'r.', 'salmoninarum', 'r'], 'shortname': 'rensm'}, '324602': {'common_names': ['chloroflexus', 'aurantiacus', 'c.', 'aurantiacus', 'c'], 'shortname': 'chlaa'}, '296587': {'common_names': ['micromonas', 'commoda', 'm.', 'commoda', 'm'], 'shortname': 'miccc'}, '557598': {'common_names': ['laribacter', 'hongkongensis', 'l.', 'hongkongensis', 'l'], 'shortname': 'larhh'}, '471854': {'common_names': ['dyadobacter', 'fermentans', 'd.', 'fermentans', 'd'], 'shortname': 'dyafd'}, '522772': {'common_names': ['denitrovibrio', 'acetiphilus', 'd.', 'acetiphilus', 'd'], 'shortname': 'dena2'}, '425104': {'common_names': ['shewanella', 'sediminis', 's.', 'sediminis', 's'], 'shortname': 'shesh'}, '416591': {'common_names': ['pseudothermotoga', 'lettingae', 'p.', 'lettingae', 'p'], 'shortname': 'pselt'}, '459349': {'common_names': ['cloacimonas', 'acidaminovorans', 'c.', 'acidaminovorans', 'c'], 'shortname': 'cloai'}, '482235': {'common_names': ['phytoplasma', 'mali', 'p.', 'mali', 'p'], 'shortname': 'phymt'}, '471855': {'common_names': ['slackia', 'heliotrinireducens', 's.', 'heliotrinireducens', 's'], 'shortname': 'slahd'}, '479434': {'common_names': ['sphaerobacter', 'thermophilus', 's.', 'thermophilus', 's'], 'shortname': 'sphtd'}, '479432': {'common_names': ['streptosporangium', 'roseum', 's.', 'roseum', 's'], 'shortname': 'strrd'}, '525903': {'common_names': ['thermanaerovibrio', 'acidaminovorans', 't.', 'acidaminovorans', 't'], 'shortname': 'theas'}, '469008': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'ecobd'}, '582899': {'common_names': ['hyphomicrobium', 'denitrificans', 'h.', 'denitrificans', 'h'], 'shortname': 'hypda'}, '554155': {'common_names': ['arthroderma', 'otae', 'a.', 'otae', 'a'], 'shortname': 'artoc'}, '559295': {'common_names': ['lachancea', 'thermotolerans', 'l.', 'thermotolerans', 'l'], 'shortname': 'lactc'}, '294747': {'common_names': ['candida', 'tropicalis', 'c.', 'tropicalis', 'c'], 'shortname': 'cantt'}, '559298': {'common_names': ['blastomyces', 'gilchristii', 'b.', 'gilchristii', 'b'], 'shortname': 'blags'}, '638303': {'common_names': ['thermocrinis', 'albus', 't.', 'albus', 't'], 'shortname': 'theah'}, '3880': {'common_names': ['medicago', 'truncatula', 'm.', 'truncatula', 'm'], 'shortname': 'medtr'}, '336963': {'common_names': ['uncinocarpus', 'reesii', 'u.', 'reesii', 'u'], 'shortname': 'uncre'}, '502779': {'common_names': ['paracoccidioides', 'lutzii', 'p.', 'lutzii', 'p'], 'shortname': 'parba'}, '587200': {'common_names': ['variola', 'virus', 'v.', 'virus', 'v'], 'shortname': 'var67'}, '519441': {'common_names': ['streptobacillus', 'moniliformis', 's.', 'moniliformis', 's'], 'shortname': 'strm9'}, '548476': {'common_names': ['corynebacterium', 'aurimucosum', 'c.', 'aurimucosum', 'c'], 'shortname': 'cora7'}, '41514': {'common_names': ['salmonella', 'arizonae', 's.', 'arizonae', 's'], 'shortname': 'salar'}, '10759': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt3'}, '2695836': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt5'}, '2011081': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppf1'}, '31757': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpml5'}, '2003327': {'common_names': ['chlamydia', 'phage', 'c.', 'phage', 'c'], 'shortname': 'bpchp'}, '12018': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpga'}, '28369': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmd2'}, '1604876': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpn15'}, '10730': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bp933'}, '2905728': {'common_names': ['pseudoalteromonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppm2'}, '448385': {'common_names': ['sorangium', 'cellulosum', 's.', 'cellulosum', 's'], 'shortname': 'sorc5'}, '10843': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpg4'}, '203119': {'common_names': ['acetivibrio', 'thermocellus', 'a.', 'thermocellus', 'a'], 'shortname': 'acet2'}, '388919': {'common_names': ['streptococcus', 'sanguinis', 's.', 'sanguinis', 's'], 'shortname': 'strsv'}, '214684': {'common_names': ['cryptococcus', 'neoformans', 'c.', 'neoformans', 'c'], 'shortname': 'crynj'}, '315953': {'common_names': ['acidianus', 'twotailed', 'a.', 'twotailed', 'a'], 'shortname': 'atv'}, '340099': {'common_names': ['thermoanaerobacter', 'pseudethanolicus', 't.', 'pseudethanolicus', 't'], 'shortname': 'thep3'}, '207954': {'common_names': ['neptuniibacter', 'caesariensis', 'n.', 'caesariensis', 'n'], 'shortname': 'nepce'}, '156586': {'common_names': ['flavobacteria', 'bacterium', 'f.', 'bacterium', 'f'], 'shortname': 'flabb'}, '5865': {'common_names': ['babesia', 'bovis', 'b.', 'bovis', 'b'], 'shortname': 'babbo'}, '85643': {'common_names': ['thauera', 'sp', 't.', 'sp', 't'], 'shortname': 'thasp'}, '626418': {'common_names': ['burkholderia', 'glumae', 'b.', 'glumae', 'b'], 'shortname': 'burgb'}, '882': {'common_names': ['desulfovibrio', 'vulgaris', 'd.', 'vulgaris', 'd'], 'shortname': 'desvh'}, '272623': {'common_names': ['lactococcus', 'lactis', 'l.', 'lactis', 'l'], 'shortname': 'lacla'}, '257309': {'common_names': ['corynebacterium', 'diphtheriae', 'c.', 'diphtheriae', 'c'], 'shortname': 'cordi'}, '224325': {'common_names': ['archaeoglobus', 'fulgidus', 'a.', 'fulgidus', 'a'], 'shortname': 'arcfu'}, '203267': {'common_names': ['tropheryma', 'whipplei', 't.', 'whipplei', 't'], 'shortname': 'trowt'}, '240015': {'common_names': ['acidobacterium', 'capsulatum', 'a.', 'capsulatum', 'a'], 'shortname': 'acic5'}, '546414': {'common_names': ['deinococcus', 'deserti', 'd.', 'deserti', 'd'], 'shortname': 'deidv'}, '379066': {'common_names': ['gemmatimonas', 'aurantiaca', 'g.', 'aurantiaca', 'g'], 'shortname': 'gemat'}, '446462': {'common_names': ['actinosynnema', 'mirum', 'a.', 'mirum', 'a'], 'shortname': 'actmd'}, '525897': {'common_names': ['desulfomicrobium', 'baculatum', 'd.', 'baculatum', 'd'], 'shortname': 'desbd'}, '485916': {'common_names': ['desulfofarcimen', 'acetoxidans', 'd.', 'acetoxidans', 'd'], 'shortname': 'desas'}, '479431': {'common_names': ['nakamurella', 'multipartita', 'n.', 'multipartita', 'n'], 'shortname': 'nakmy'}, '446468': {'common_names': ['nocardiopsis', 'dassonvillei', 'n.', 'dassonvillei', 'n'], 'shortname': 'nocdd'}, '521674': {'common_names': ['planctopirus', 'limnophila', 'p.', 'limnophila', 'p'], 'shortname': 'plal2'}, '525898': {'common_names': ['sulfurospirillum', 'deleyianum', 's.', 'deleyianum', 's'], 'shortname': 'suld5'}, '432359': {'common_names': ['toxoplasma', 'gondii', 't.', 'gondii', 't'], 'shortname': 'toxgv'}, '706194': {'common_names': ['karelsulcia', 'muelleri', 'k.', 'muelleri', 'k'], 'shortname': 'karmc'}, '10653': {'common_names': ['commelina', 'yellow', 'c.', 'yellow', 'c'], 'shortname': 'coymv'}, '38062': {'common_names': ['cassava', 'vein', 'c.', 'vein', 'c'], 'shortname': 'csvmv'}, '9615': {'common_names': ['canis', 'lupus', 'c.', 'lupus', 'c'], 'shortname': 'canlf'}, '446471': {'common_names': ['xylanimonas', 'cellulosilytica', 'x.', 'cellulosilytica', 'x'], 'shortname': 'xylcx'}, '395965': {'common_names': ['methylocella', 'silvestris', 'm.', 'silvestris', 'm'], 'shortname': 'metsb'}, '322104': {'common_names': ['scheffersomyces', 'stipitis', 's.', 'stipitis', 's'], 'shortname': 'picst'}, '157898': {'common_names': ['sulfolobus', 'islandicus', 's.', 'islandicus', 's'], 'shortname': 'sirv1'}, '9598': {'common_names': ['pan', 'troglodytes', 'p.', 'troglodytes', 'p'], 'shortname': 'pantr'}, '9258': {'common_names': ['ornithorhynchus', 'anatinus', 'o.', 'anatinus', 'o'], 'shortname': 'ornan'}, '13616': {'common_names': ['monodelphis', 'domestica', 'm.', 'domestica', 'm'], 'shortname': 'mondo'}, '9796': {'common_names': ['equus', 'caballus', 'e.', 'caballus', 'e'], 'shortname': 'horse'}, '269482': {'common_names': ['burkholderia', 'vietnamiensis', 'b.', 'vietnamiensis', 'b'], 'shortname': 'burvg'}, '353153': {'common_names': ['trypanosoma', 'cruzi', 't.', 'cruzi', 't'], 'shortname': 'trycc'}, '216432': {'common_names': ['croceibacter', 'atlanticus', 'c.', 'atlanticus', 'c'], 'shortname': 'croah'}, '439375': {'common_names': ['brucella', 'anthropi', 'b.', 'anthropi', 'b'], 'shortname': 'brua4'}, '523846': {'common_names': ['methanothermus', 'fervidus', 'm.', 'fervidus', 'm'], 'shortname': 'metfv'}, '573413': {'common_names': ['sediminispirochaeta', 'smaragdinae', 's.', 'smaragdinae', 's'], 'shortname': 'sedss'}, '7176': {'common_names': ['culex', 'quinquefasciatus', 'c.', 'quinquefasciatus', 'c'], 'shortname': 'culqu'}, '254252': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bplp2'}, '637905': {'common_names': ['shewanella', 'violacea', 's.', 'violacea', 's'], 'shortname': 'shevd'}, '9940': {'common_names': ['ovis', 'aries', 'o.', 'aries', 'o'], 'shortname': 'sheep'}, '1901': {'common_names': ['streptomyces', 'clavuligerus', 's.', 'clavuligerus', 's'], 'shortname': 'strcl'}, '7425': {'common_names': ['nasonia', 'vitripennis', 'n.', 'vitripennis', 'n'], 'shortname': 'nasvi'}, '272942': {'common_names': ['rhodobacter', 'capsulatus', 'r.', 'capsulatus', 'r'], 'shortname': 'rhocb'}, '572547': {'common_names': ['aminobacterium', 'colombiense', 'a.', 'colombiense', 'a'], 'shortname': 'amicl'}, '426114': {'common_names': ['thiomonas', 'arsenitoxydans', 't.', 'arsenitoxydans', 't'], 'shortname': 'thia3'}, '633148': {'common_names': ['thermosphaera', 'aggregans', 't.', 'aggregans', 't'], 'shortname': 'theam'}, '635013': {'common_names': ['thermincola', 'potens', 't.', 'potens', 't'], 'shortname': 'thepj'}, '521045': {'common_names': ['kosmotoga', 'olearia', 'k.', 'olearia', 'k'], 'shortname': 'kosot'}, '396588': {'common_names': ['thioalkalivibrio', 'sulfidiphilus', 't.', 'sulfidiphilus', 't'], 'shortname': 'thish'}, '65393': {'common_names': ['gloeothece', 'citriformis', 'g.', 'citriformis', 'g'], 'shortname': 'gloc7'}, '246197': {'common_names': ['myxococcus', 'xanthus', 'm.', 'xanthus', 'm'], 'shortname': 'myxxd'}, '360107': {'common_names': ['campylobacter', 'hominis', 'c.', 'hominis', 'c'], 'shortname': 'camhc'}, '456442': {'common_names': ['methanoregula', 'boonei', 'm.', 'boonei', 'm'], 'shortname': 'metb6'}, '431943': {'common_names': ['clostridium', 'kluyveri', 'c.', 'kluyveri', 'c'], 'shortname': 'clok5'}, '381764': {'common_names': ['fervidobacterium', 'nodosum', 'f.', 'nodosum', 'f'], 'shortname': 'fernb'}, '78245': {'common_names': ['xanthobacter', 'autotrophicus', 'x.', 'autotrophicus', 'x'], 'shortname': 'xanp2'}, '145579': {'common_names': ['bdellovibrio', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpphm'}, '398767': {'common_names': ['trichlorobacter', 'lovleyi', 't.', 'lovleyi', 't'], 'shortname': 'tril1'}, '284593': {'common_names': ['candida', 'glabrata', 'c.', 'glabrata', 'c'], 'shortname': 'canga'}, '266264': {'common_names': ['cupriavidus', 'metallidurans', 'c.', 'metallidurans', 'c'], 'shortname': 'cupmc'}, '363253': {'common_names': ['lawsonia', 'intracellularis', 'l.', 'intracellularis', 'l'], 'shortname': 'lawip'}, '319795': {'common_names': ['deinococcus', 'geothermalis', 'd.', 'geothermalis', 'd'], 'shortname': 'deigd'}, '204669': {'common_names': ['koribacter', 'versatilis', 'k.', 'versatilis', 'k'], 'shortname': 'korve'}, '5811': {'common_names': ['toxoplasma', 'gondii', 't.', 'gondii', 't'], 'shortname': 'toxgo'}, '208964': {'common_names': ['pseudomonas', 'aeruginosa', 'p.', 'aeruginosa', 'p'], 'shortname': 'pseae'}, '178306': {'common_names': ['pyrobaculum', 'aerophilum', 'p.', 'aerophilum', 'p'], 'shortname': 'pyrae'}, '265072': {'common_names': ['methylobacillus', 'flagellatus', 'm.', 'flagellatus', 'm'], 'shortname': 'metfk'}, '442563': {'common_names': ['bifidobacterium', 'animalis', 'b.', 'animalis', 'b'], 'shortname': 'bifa0'}, '521011': {'common_names': ['methanosphaerula', 'palustris', 'm.', 'palustris', 'm'], 'shortname': 'metpe'}, '272947': {'common_names': ['rickettsia', 'prowazekii', 'r.', 'prowazekii', 'r'], 'shortname': 'ricpr'}, '643561': {'common_names': ['acidovorax', 'avenae', 'a.', 'avenae', 'a'], 'shortname': 'aciap'}, '103690': {'common_names': ['nostoc', 'sp', 'n.', 'sp', 'n'], 'shortname': 'noss1'}, '298654': {'common_names': ['frankia', 'inefficax', 'f.', 'inefficax', 'f'], 'shortname': 'fraie'}, '188937': {'common_names': ['methanosarcina', 'acetivorans', 'm.', 'acetivorans', 'm'], 'shortname': 'metac'}, '660025': {'common_names': ['fusarium', 'oxysporum', 'f.', 'oxysporum', 'f'], 'shortname': 'fusof'}, '223926': {'common_names': ['vibrio', 'parahaemolyticus', 'v.', 'parahaemolyticus', 'v'], 'shortname': 'vibpa'}, '235279': {'common_names': ['helicobacter', 'hepaticus', 'h.', 'hepaticus', 'h'], 'shortname': 'helhp'}, '443226': {'common_names': ['coccidioides', 'posadasii', 'c.', 'posadasii', 'c'], 'shortname': 'cocps'}, '655827': {'common_names': ['metarhizium', 'acridum', 'm.', 'acridum', 'm'], 'shortname': 'metaq'}, '311424': {'common_names': ['dehalococcoides', 'mccartyi', 'd.', 'mccartyi', 'd'], 'shortname': 'dehmv'}, '210007': {'common_names': ['streptococcus', 'mutans', 's.', 'mutans', 's'], 'shortname': 'strmu'}, '243265': {'common_names': ['photorhabdus', 'laumondii', 'p.', 'laumondii', 'p'], 'shortname': 'pholl'}, '223283': {'common_names': ['pseudomonas', 'syringae', 'p.', 'syringae', 'p'], 'shortname': 'psesm'}, '183190': {'common_names': ['xylella', 'fastidiosa', 'x.', 'fastidiosa', 'x'], 'shortname': 'xylft'}, '272557': {'common_names': ['aeropyrum', 'pernix', 'a.', 'pernix', 'a'], 'shortname': 'aerpe'}, '190304': {'common_names': ['fusobacterium', 'nucleatum', 'f.', 'nucleatum', 'f'], 'shortname': 'fusnn'}, '272633': {'common_names': ['malacoplasma', 'penetrans', 'm.', 'penetrans', 'm'], 'shortname': 'malp2'}, '243230': {'common_names': ['deinococcus', 'radiodurans', 'd.', 'radiodurans', 'd'], 'shortname': 'deira'}, '224911': {'common_names': ['bradyrhizobium', 'diazoefficiens', 'b.', 'diazoefficiens', 'b'], 'shortname': 'bradu'}, '335992': {'common_names': ['pelagibacter', 'ubique', 'p.', 'ubique', 'p'], 'shortname': 'pelub'}, '300269': {'common_names': ['shigella', 'sonnei', 's.', 'sonnei', 's'], 'shortname': 'shiss'}, '330879': {'common_names': ['aspergillus', 'fumigatus', 'a.', 'fumigatus', 'a'], 'shortname': 'aspfu'}, '323098': {'common_names': ['nitrobacter', 'winogradskyi', 'n.', 'winogradskyi', 'n'], 'shortname': 'nitwn'}, '338963': {'common_names': ['syntrophotalea', 'carbinolica', 's.', 'carbinolica', 's'], 'shortname': 'sync1'}, '59920': {'common_names': ['prochlorococcus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'promt'}, '10724': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpspp'}, '653733': {'common_names': ['desulfurispirillum', 'indicum', 'd.', 'indicum', 'd'], 'shortname': 'desis'}, '608538': {'common_names': ['hydrogenobacter', 'thermophilus', 'h.', 'thermophilus', 'h'], 'shortname': 'hydtt'}, '2681617': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bphk7'}, '156889': {'common_names': ['magnetococcus', 'marinus', 'm.', 'marinus', 'm'], 'shortname': 'magmm'}, '418699': {'common_names': ['azoarcus', 'sp', 'a.', 'sp', 'a'], 'shortname': 'azosb'}, '415426': {'common_names': ['hyperthermus', 'butylicus', 'h.', 'butylicus', 'h'], 'shortname': 'hypbu'}, '526222': {'common_names': ['maridesulfovibrio', 'salexigens', 'm.', 'salexigens', 'm'], 'shortname': 'marsd'}, '398579': {'common_names': ['shewanella', 'pealeana', 's.', 'pealeana', 's'], 'shortname': 'shepa'}, '589924': {'common_names': ['ferroglobus', 'placidus', 'f.', 'placidus', 'f'], 'shortname': 'ferpa'}, '429009': {'common_names': ['ammonifex', 'degensii', 'a.', 'degensii', 'a'], 'shortname': 'ammdk'}, '544712': {'common_names': ['ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a'], 'shortname': 'ajech'}, '2880': {'common_names': ['ectocarpus', 'siliculosus', 'e.', 'siliculosus', 'e'], 'shortname': 'ectsi'}, '347256': {'common_names': ['metamycoplasma', 'hominis', 'm.', 'hominis', 'm'], 'shortname': 'meth1'}, '1094619': {'common_names': ['phytophthora', 'sojae', 'p.', 'sojae', 'p'], 'shortname': 'physp'}, '768679': {'common_names': ['thermoproteus', 'tenax', 't.', 'tenax', 't'], 'shortname': 'thetk'}, '945021': {'common_names': ['tetragenococcus', 'halophilus', 't.', 'halophilus', 't'], 'shortname': 'tethn'}, '985895': {'common_names': ['leptosphaeria', 'maculans', 'l.', 'maculans', 'l'], 'shortname': 'lepmj'}, '535722': {'common_names': ['arthroderma', 'gypseum', 'a.', 'gypseum', 'a'], 'shortname': 'artgp'}, '227377': {'common_names': ['coxiella', 'burnetii', 'c.', 'burnetii', 'c'], 'shortname': 'coxbu'}, '257313': {'common_names': ['bordetella', 'pertussis', 'b.', 'pertussis', 'b'], 'shortname': 'borpe'}, '633149': {'common_names': ['brevundimonas', 'subvibrioides', 'b.', 'subvibrioides', 'b'], 'shortname': 'bresc'}, '348780': {'common_names': ['natronomonas', 'pharaonis', 'n.', 'pharaonis', 'n'], 'shortname': 'natpd'}, '272943': {'common_names': ['cereibacter', 'sphaeroides', 'c.', 'sphaeroides', 'c'], 'shortname': 'cers4'}, '246194': {'common_names': ['carboxydothermus', 'hydrogenoformans', 'c.', 'hydrogenoformans', 'c'], 'shortname': 'carhz'}, '314315': {'common_names': ['latilactobacillus', 'sakei', 'l.', 'sakei', 'l'], 'shortname': 'latss'}, '319225': {'common_names': ['chlorobium', 'luteolum', 'c.', 'luteolum', 'c'], 'shortname': 'chll3'}, '207559': {'common_names': ['oleidesulfovibrio', 'alaskensis', 'o.', 'alaskensis', 'o'], 'shortname': 'olea2'}, '326298': {'common_names': ['sulfurimonas', 'denitrificans', 's.', 'denitrificans', 's'], 'shortname': 'suldn'}, '300267': {'common_names': ['shigella', 'dysenteriae', 's.', 'dysenteriae', 's'], 'shortname': 'shids'}, '323848': {'common_names': ['nitrosospira', 'multiformis', 'n.', 'multiformis', 'n'], 'shortname': 'nitmu'}, '359391': {'common_names': ['brucella', 'abortus', 'b.', 'abortus', 'b'], 'shortname': 'brua2'}, '324925': {'common_names': ['pelodictyon', 'phaeoclathratiforme', 'p.', 'phaeoclathratiforme', 'p'], 'shortname': 'pelpb'}, '290512': {'common_names': ['prosthecochloris', 'aestuarii', 'p.', 'aestuarii', 'p'], 'shortname': 'proa2'}, '44056': {'common_names': ['aureococcus', 'anophagefferens', 'a.', 'anophagefferens', 'a'], 'shortname': 'auran'}, '573061': {'common_names': ['clostridium', 'cellulovorans', 'c.', 'cellulovorans', 'c'], 'shortname': 'cloc7'}, '583345': {'common_names': ['methylotenera', 'mobilis', 'm.', 'mobilis', 'm'], 'shortname': 'metml'}, '582744': {'common_names': ['methylovorus', 'glucosetrophus', 'm.', 'glucosetrophus', 'm'], 'shortname': 'metgs'}, '582402': {'common_names': ['hirschia', 'baltica', 'h.', 'baltica', 'h'], 'shortname': 'hirbi'}, '226230': {'common_names': ['saccharomyces', 'kudriavzevii', 's.', 'kudriavzevii', 's'], 'shortname': 'sack1'}, '655819': {'common_names': ['beauveria', 'bassiana', 'b.', 'bassiana', 'b'], 'shortname': 'beab2'}, '457429': {'common_names': ['streptomyces', 'pristinaespiralis', 's.', 'pristinaespiralis', 's'], 'shortname': 'stre2'}, '8083': {'common_names': ['xiphophorus', 'maculatus', 'x.', 'maculatus', 'x'], 'shortname': 'xipma'}, '435590': {'common_names': ['phocaeicola', 'vulgatus', 'p.', 'vulgatus', 'p'], 'shortname': 'phov8'}, '1071380': {'common_names': ['tetrapisispora', 'blattae', 't.', 'blattae', 't'], 'shortname': 'tetbl'}, '935791': {'common_names': ['nematocida', 'parisii', 'n.', 'parisii', 'n'], 'shortname': 'nemp3'}, '768486': {'common_names': ['enterococcus', 'hirae', 'e.', 'hirae', 'e'], 'shortname': 'entha'}, '1133968': {'common_names': ['babesia', 'microti', 'b.', 'microti', 'b'], 'shortname': 'babmr'}, '1206558': {'common_names': ['yersinia', 'phage', 'y.', 'phage', 'y'], 'shortname': 'bppr1'}, '391589': {'common_names': ['roseobacter', 'sp', 'r.', 'sp', 'r'], 'shortname': 'ross0'}, '500633': {'common_names': ['peptacetobacter', 'hiranonis', 'p.', 'hiranonis', 'p'], 'shortname': 'pepht'}, '314256': {'common_names': ['oceanicola', 'granulosus', 'o.', 'granulosus', 'o'], 'shortname': 'ocegh'}, '320771': {'common_names': ['pedosphaera', 'parvula', 'p.', 'parvula', 'p'], 'shortname': 'pedpl'}, '1423757': {'common_names': ['lentilactobacillus', 'hilgardii', 'l.', 'hilgardii', 'l'], 'shortname': 'lenh9'}, '655812': {'common_names': ['aerococcus', 'viridans', 'a.', 'viridans', 'a'], 'shortname': 'aervm'}, '1205910': {'common_names': ['nocardiopsis', 'alba', 'n.', 'alba', 'n'], 'shortname': 'nocaa'}, '865937': {'common_names': ['gillisia', 'limnaea', 'g.', 'limnaea', 'g'], 'shortname': 'gillr'}, '591159': {'common_names': ['streptomyces', 'viridochromogenes', 's.', 'viridochromogenes', 's'], 'shortname': 'strvt'}, '411684': {'common_names': ['hoeflea', 'phototrophica', 'h.', 'phototrophica', 'h'], 'shortname': 'hoepd'}, '553175': {'common_names': ['porphyromonas', 'endodontalis', 'p.', 'endodontalis', 'p'], 'shortname': 'porea'}, '252305': {'common_names': ['pseudooceanicola', 'batsensis', 'p.', 'batsensis', 'p'], 'shortname': 'psebh'}, '411483': {'common_names': ['faecalibacterium', 'prausnitzii', 'f.', 'prausnitzii', 'f'], 'shortname': 'faepa'}, '697282': {'common_names': ['methylobacter', 'tundripaludum', 'm.', 'tundripaludum', 'm'], 'shortname': 'mettv'}, '511051': {'common_names': ['caldisericum', 'exile', 'c.', 'exile', 'c'], 'shortname': 'calea'}, '679197': {'common_names': ['segniliparus', 'rugosus', 's.', 'rugosus', 's'], 'shortname': 'segrc'}, '1156937': {'common_names': ['methylacidiphilum', 'fumariolicum', 'm.', 'fumariolicum', 'm'], 'shortname': 'metfb'}, '638300': {'common_names': ['cardiobacterium', 'hominis', 'c.', 'hominis', 'c'], 'shortname': 'carh6'}, '1078020': {'common_names': ['mycolicibacterium', 'thermoresistibile', 'm.', 'thermoresistibile', 'm'], 'shortname': 'myct3'}, '4081': {'common_names': ['solanum', 'lycopersicum', 's.', 'lycopersicum', 's'], 'shortname': 'sollc'}, '4555': {'common_names': ['setaria', 'italica', 's.', 'italica', 's'], 'shortname': 'setit'}, '1000565': {'common_names': ['methyloversatilis', 'universalis', 'm.', 'universalis', 'm'], 'shortname': 'metuf'}, '396598': {'common_names': ['paraburkholderia', 'graminis', 'p.', 'graminis', 'p'], 'shortname': 'parg4'}, '7460': {'common_names': ['apis', 'mellifera', 'a.', 'mellifera', 'a'], 'shortname': 'apime'}, '7091': {'common_names': ['bombyx', 'mori', 'b.', 'mori', 'b'], 'shortname': 'bommo'}, '12957': {'common_names': ['atta', 'cephalotes', 'a.', 'cephalotes', 'a'], 'shortname': 'attce'}, '660122': {'common_names': ['fusarium', 'vanettenii', 'f.', 'vanettenii', 'f'], 'shortname': 'fusv7'}, '8128': {'common_names': ['oreochromis', 'niloticus', 'o.', 'niloticus', 'o'], 'shortname': 'oreni'}, '43179': {'common_names': ['ictidomys', 'tridecemlineatus', 'i.', 'tridecemlineatus', 'i'], 'shortname': 'icttr'}, '1071382': {'common_names': ['kazachstania', 'africana', 'k.', 'africana', 'k'], 'shortname': 'kazaf'}, '578454': {'common_names': ['candida', 'parapsilosis', 'c.', 'parapsilosis', 'c'], 'shortname': 'canpc'}, '559304': {'common_names': ['pichia', 'sorbitophila', 'p.', 'sorbitophila', 'p'], 'shortname': 'picso'}, '187420': {'common_names': ['methanothermobacter', 'thermautotrophicus', 'm.', 'thermautotrophicus', 'm'], 'shortname': 'metth'}, '30611': {'common_names': ['otolemur', 'garnettii', 'o.', 'garnettii', 'o'], 'shortname': 'otoga'}, '31033': {'common_names': ['takifugu', 'rubripes', 't.', 'rubripes', 't'], 'shortname': 'takru'}, '1041930': {'common_names': ['methanocella', 'conradii', 'm.', 'conradii', 'm'], 'shortname': 'metcz'}, '767434': {'common_names': ['frateuria', 'aurantia', 'f.', 'aurantia', 'f'], 'shortname': 'fraad'}, '164328': {'common_names': ['phytophthora', 'ramorum', 'p.', 'ramorum', 'p'], 'shortname': 'phyrm'}, '54126': {'common_names': ['pristionchus', 'pacificus', 'p.', 'pacificus', 'p'], 'shortname': 'pripa'}, '630390': {'common_names': ['puccinia', 'triticina', 'p.', 'triticina', 'p'], 'shortname': 'puct1'}, '671144': {'common_names': ['wallemia', 'mellicola', 'w.', 'mellicola', 'w'], 'shortname': 'walmc'}, '1110502': {'common_names': ['tistrella', 'mobilis', 't.', 'mobilis', 't'], 'shortname': 'tismk'}, '1184251': {'common_names': ['thermogladius', 'calderae', 't.', 'calderae', 't'], 'shortname': 'thec1'}, '870187': {'common_names': ['thiothrix', 'nivea', 't.', 'nivea', 't'], 'shortname': 'thinj'}, '314266': {'common_names': ['sphingomonas', 'sp', 's.', 'sp', 's'], 'shortname': 'sphss'}, '29159': {'common_names': ['crassostrea', 'gigas', 'c.', 'gigas', 'c'], 'shortname': 'cragi'}, '452589': {'common_names': ['hypocrea', 'atroviridis', 'h.', 'atroviridis', 'h'], 'shortname': 'hypai'}, '720554': {'common_names': ['acetivibrio', 'clariflavus', 'a.', 'clariflavus', 'a'], 'shortname': 'acece'}, '203275': {'common_names': ['tannerella', 'forsythia', 't.', 'forsythia', 't'], 'shortname': 'tanfa'}, '679936': {'common_names': ['sulfobacillus', 'acidophilus', 's.', 'acidophilus', 's'], 'shortname': 'sulad'}, '134676': {'common_names': ['actinoplanes', 'sp', 'a.', 'sp', 'a'], 'shortname': 'acts5'}, '710685': {'common_names': ['mycolicibacterium', 'rhodesiae', 'm.', 'rhodesiae', 'm'], 'shortname': 'mycrn'}, '701521': {'common_names': ['pediococcus', 'claussenii', 'p.', 'claussenii', 'p'], 'shortname': 'pedcp'}, '1104152': {'common_names': ['glarea', 'lozoyensis', 'g.', 'lozoyensis', 'g'], 'shortname': 'glal7'}, '10141': {'common_names': ['cavia', 'porcellus', 'c.', 'porcellus', 'c'], 'shortname': 'cavpo'}, '1913371': {'common_names': ['nematocida', 'ausubeli', 'n.', 'ausubeli', 'n'], 'shortname': 'nema1'}, '11723': {'common_names': ['simian', 'immunodeficiency', 's.', 'immunodeficiency', 's'], 'shortname': 'siv'}, '4950': {'common_names': ['torulaspora', 'delbrueckii', 't.', 'delbrueckii', 't'], 'shortname': 'torde'}, '926562': {'common_names': ['owenweeksia', 'hongkongensis', 'o.', 'hongkongensis', 'o'], 'shortname': 'owehd'}, '158190': {'common_names': ['sphaerochaeta', 'pleomorpha', 's.', 'pleomorpha', 's'], 'shortname': 'sphpg'}, '1041826': {'common_names': ['flavobacterium', 'columnare', 'f.', 'columnare', 'f'], 'shortname': 'flaca'}, '1071381': {'common_names': ['tetrapisispora', 'phaffii', 't.', 'phaffii', 't'], 'shortname': 'tetph'}, '862719': {'common_names': ['azospirillum', 'lipoferum', 'a.', 'lipoferum', 'a'], 'shortname': 'azol4'}, '281689': {'common_names': ['desulfuromonas', 'acetoxidans', 'd.', 'acetoxidans', 'd'], 'shortname': 'desa6'}, '91464': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'syns7'}, '580340': {'common_names': ['thermovirga', 'lienii', 't.', 'lienii', 't'], 'shortname': 'theld'}, '1045855': {'common_names': ['pseudoxanthomonas', 'spadix', 'p.', 'spadix', 'p'], 'shortname': 'pseup'}, '1110509': {'common_names': ['methanothrix', 'harundinacea', 'm.', 'harundinacea', 'm'], 'shortname': 'meth6'}, '342110': {'common_names': ['ralstonia', 'solanacearum', 'r.', 'solanacearum', 'r'], 'shortname': 'ralsu'}, '89187': {'common_names': ['roseovarius', 'nubinhibens', 'r.', 'nubinhibens', 'r'], 'shortname': 'rosni'}, '649764': {'common_names': ['slackia', 'exigua', 's.', 'exigua', 's'], 'shortname': 'slaes'}, '563192': {'common_names': ['bilophila', 'wadsworthia', 'b.', 'wadsworthia', 'b'], 'shortname': 'bilw3'}, '4533': {'common_names': ['oryza', 'brachyantha', 'o.', 'brachyantha', 'o'], 'shortname': 'orybr'}, '644352': {'common_names': ['gaeumannomyces', 'tritici', 'g.', 'tritici', 'g'], 'shortname': 'gaet3'}, '869212': {'common_names': ['turneriella', 'parva', 't.', 'parva', 't'], 'shortname': 'turpd'}, '866536': {'common_names': ['belliella', 'baltica', 'b.', 'baltica', 'b'], 'shortname': 'belbd'}, '867902': {'common_names': ['ornithobacterium', 'rhinotracheale', 'o.', 'rhinotracheale', 'o'], 'shortname': 'ornrl'}, '880071': {'common_names': ['bernardetia', 'litoralis', 'b.', 'litoralis', 'b'], 'shortname': 'berls'}, '706587': {'common_names': ['desulfomonile', 'tiedjei', 'd.', 'tiedjei', 'd'], 'shortname': 'desta'}, '926566': {'common_names': ['terriglobus', 'roseus', 't.', 'roseus', 't'], 'shortname': 'terrk'}, '710421': {'common_names': ['mycolicibacterium', 'chubuense', 'm.', 'chubuense', 'm'], 'shortname': 'myccn'}, '891968': {'common_names': ['acetomicrobium', 'mobile', 'a.', 'mobile', 'a'], 'shortname': 'acemn'}, '765911': {'common_names': ['thiocystis', 'violascens', 't.', 'violascens', 't'], 'shortname': 'thiv6'}, '1189612': {'common_names': ['indibacter', 'alkaliphilus', 'i.', 'alkaliphilus', 'i'], 'shortname': 'indal'}, '1128398': {'common_names': ['gottschalkia', 'acidurici', 'g.', 'acidurici', 'g'], 'shortname': 'gota9'}, '990288': {'common_names': ['acidithiobacillus', 'caldus', 'a.', 'caldus', 'a'], 'shortname': 'acics'}, '713604': {'common_names': ['amycolatopsis', 'mediterranei', 'a.', 'mediterranei', 'a'], 'shortname': 'amyms'}, '1001064': {'common_names': ['rhodosporidium', 'toruloides', 'r.', 'toruloides', 'r'], 'shortname': 'rhot2'}, '120017': {'common_names': ['ustilago', 'hordei', 'u.', 'hordei', 'u'], 'shortname': 'ustho'}, '314265': {'common_names': ['salipiger', 'bermudensis', 's.', 'bermudensis', 's'], 'shortname': 'salbh'}, '1122247': {'common_names': ['mycolicibacterium', 'hassiacum', 'm.', 'hassiacum', 'm'], 'shortname': 'mychd'}, '1179773': {'common_names': ['saccharothrix', 'espanaensis', 's.', 'espanaensis', 's'], 'shortname': 'saces'}, '385025': {'common_names': ['cycloclasticus', 'sp', 'c.', 'sp', 'c'], 'shortname': 'cycsp'}, '930169': {'common_names': ['alcanivorax', 'dieselolei', 'a.', 'dieselolei', 'a'], 'shortname': 'alcdb'}, '698758': {'common_names': ['amphibacillus', 'xylanus', 'a.', 'xylanus', 'a'], 'shortname': 'ampxn'}, '1229758': {'common_names': ['leuconostoc', 'carnosum', 'l.', 'carnosum', 'l'], 'shortname': 'leucj'}, '1071383': {'common_names': ['kazachstania', 'naganishii', 'k.', 'naganishii', 'k'], 'shortname': 'kazna'}, '1120755': {'common_names': ['plasmodium', 'cynomolgi', 'p.', 'cynomolgi', 'p'], 'shortname': 'placd'}, '768706': {'common_names': ['desulfosporosinus', 'orientis', 'd.', 'orientis', 'd'], 'shortname': 'desod'}, '577650': {'common_names': ['desulfobulbus', 'propionicus', 'd.', 'propionicus', 'd'], 'shortname': 'despd'}, '342451': {'common_names': ['staphylococcus', 'saprophyticus', 's.', 'saprophyticus', 's'], 'shortname': 'stas1'}, '290633': {'common_names': ['gluconobacter', 'oxydans', 'g.', 'oxydans', 'g'], 'shortname': 'gluox'}, '402881': {'common_names': ['parvibaculum', 'lavamentivorans', 'p.', 'lavamentivorans', 'p'], 'shortname': 'parl1'}, '387093': {'common_names': ['sulfurovum', 'sp', 's.', 'sp', 's'], 'shortname': 'sulnb'}, '360105': {'common_names': ['campylobacter', 'curvus', 'c.', 'curvus', 'c'], 'shortname': 'camc5'}, '272621': {'common_names': ['lactobacillus', 'acidophilus', 'l.', 'acidophilus', 'l'], 'shortname': 'lacac'}, '404589': {'common_names': ['anaeromyxobacter', 'sp', 'a.', 'sp', 'a'], 'shortname': 'anadf'}, '375286': {'common_names': ['janthinobacterium', 'sp', 'j.', 'sp', 'j'], 'shortname': 'janma'}, '402612': {'common_names': ['flavobacterium', 'psychrophilum', 'f.', 'psychrophilum', 'f'], 'shortname': 'flapj'}, '929558': {'common_names': ['sulfurimonas', 'gotlandica', 's.', 'gotlandica', 's'], 'shortname': 'sulgg'}, '879243': {'common_names': ['porphyromonas', 'asaccharolytica', 'p.', 'asaccharolytica', 'p'], 'shortname': 'porad'}, '906968': {'common_names': ['treponema', 'brennaborense', 't.', 'brennaborense', 't'], 'shortname': 'trebd'}, '76114': {'common_names': ['aromatoleum', 'aromaticum', 'a.', 'aromaticum', 'a'], 'shortname': 'aroae'}, '357808': {'common_names': ['roseiflexus', 'sp', 'r.', 'sp', 'r'], 'shortname': 'ross1'}, '370438': {'common_names': ['pelotomaculum', 'thermopropionicum', 'p.', 'thermopropionicum', 'p'], 'shortname': 'pelts'}, '362948': {'common_names': ['ligilactobacillus', 'salivarius', 'l.', 'salivarius', 'l'], 'shortname': 'ligs1'}, '510516': {'common_names': ['aspergillus', 'oryzae', 'a.', 'oryzae', 'a'], 'shortname': 'aspor'}, '679926': {'common_names': ['methanolacinia', 'petrolearia', 'm.', 'petrolearia', 'm'], 'shortname': 'metp4'}, '317655': {'common_names': ['sphingopyxis', 'alaskensis', 's.', 'alaskensis', 's'], 'shortname': 'sphal'}, '795359': {'common_names': ['thermodesulfobacterium', 'geofontis', 't.', 'geofontis', 't'], 'shortname': 'thegp'}, '426355': {'common_names': ['methylobacterium', 'radiotolerans', 'm.', 'radiotolerans', 'm'], 'shortname': 'metrj'}, '4536': {'common_names': ['oryza', 'nivara', 'o.', 'nivara', 'o'], 'shortname': 'oryni'}, '717231': {'common_names': ['flexistipes', 'sinusarabici', 'f.', 'sinusarabici', 'f'], 'shortname': 'flesm'}, '679901': {'common_names': ['methanosalsum', 'zhilinae', 'm.', 'zhilinae', 'm'], 'shortname': 'metzd'}, '639283': {'common_names': ['starkeya', 'novella', 's.', 'novella', 's'], 'shortname': 'stand'}, '766185': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvd1'}, '266117': {'common_names': ['rubrobacter', 'xylanophilus', 'r.', 'xylanophilus', 'r'], 'shortname': 'rubxd'}, '696127': {'common_names': ['midichloria', 'mitochondrii', 'm.', 'mitochondrii', 'm'], 'shortname': 'midmi'}, '469371': {'common_names': ['thermobispora', 'bispora', 't.', 'bispora', 't'], 'shortname': 'thebd'}, '403677': {'common_names': ['phytophthora', 'infestans', 'p.', 'infestans', 'p'], 'shortname': 'phyit'}, '265311': {'common_names': ['mesoplasma', 'florum', 'm.', 'florum', 'm'], 'shortname': 'mesfl'}, '521097': {'common_names': ['capnocytophaga', 'ochracea', 'c.', 'ochracea', 'c'], 'shortname': 'capod'}, '709991': {'common_names': ['odoribacter', 'splanchnicus', 'o.', 'splanchnicus', 'o'], 'shortname': 'odosd'}, '469382': {'common_names': ['halogeometricum', 'borinquense', 'h.', 'borinquense', 'h'], 'shortname': 'halbp'}, '6279': {'common_names': ['brugia', 'malayi', 'b.', 'malayi', 'b'], 'shortname': 'bruma'}, '572478': {'common_names': ['vulcanisaeta', 'distributa', 'v.', 'distributa', 'v'], 'shortname': 'vuldi'}, '550540': {'common_names': ['ferrimonas', 'balearica', 'f.', 'balearica', 'f'], 'shortname': 'ferbd'}, '1002809': {'common_names': ['solibacillus', 'silvestris', 's.', 'silvestris', 's'], 'shortname': 'solss'}, '351605': {'common_names': ['geotalea', 'uraniireducens', 'g.', 'uraniireducens', 'g'], 'shortname': 'geour'}, '204773': {'common_names': ['herminiimonas', 'arsenicoxydans', 'h.', 'arsenicoxydans', 'h'], 'shortname': 'herar'}, '344612': {'common_names': ['aspergillus', 'clavatus', 'a.', 'clavatus', 'a'], 'shortname': 'aspcl'}, '331117': {'common_names': ['neosartorya', 'fischeri', 'n.', 'fischeri', 'n'], 'shortname': 'neofi'}, '425011': {'common_names': ['aspergillus', 'niger', 'a.', 'niger', 'a'], 'shortname': 'aspnc'}, '651354': {'common_names': ['grapevine', 'leafrollassociated', 'g.', 'leafrollassociated', 'g'], 'shortname': 'glrv3'}, '648169': {'common_names': ['lymantria', 'dispar', 'l.', 'dispar', 'l'], 'shortname': 'ldcpr'}, '185783': {'common_names': ['aquareovirus', 'c', 'a.', 'c', 'a'], 'shortname': 'aqrvc'}, '654932': {'common_names': ['penicillium', 'chrysogenum', 'p.', 'chrysogenum', 'p'], 'shortname': 'pcvc'}, '9544': {'common_names': ['macaca', 'mulatta', 'm.', 'mulatta', 'm'], 'shortname': 'macmu'}, '230407': {'common_names': ['cryphonectria', 'parasitica', 'c.', 'parasitica', 'c'], 'shortname': 'myrv9'}, '10986': {'common_names': ['rice', 'gall', 'r.', 'gall', 'r'], 'shortname': 'rgdv'}, '58103': {'common_names': ['leishmania', 'rna', 'l.', 'rna', 'l'], 'shortname': 'lrvlg'}, '353152': {'common_names': ['cryptosporidium', 'parvum', 'c.', 'parvum', 'c'], 'shortname': 'crypi'}, '3218': {'common_names': ['physcomitrium', 'patens', 'p.', 'patens', 'p'], 'shortname': 'phypa'}, '405948': {'common_names': ['saccharopolyspora', 'erythraea', 's.', 'erythraea', 's'], 'shortname': 'sacen'}, '3694': {'common_names': ['populus', 'trichocarpa', 'p.', 'trichocarpa', 'p'], 'shortname': 'poptr'}, '272559': {'common_names': ['bacteroides', 'fragilis', 'b.', 'fragilis', 'b'], 'shortname': 'bacfn'}, '338966': {'common_names': ['pelobacter', 'propionicus', 'p.', 'propionicus', 'p'], 'shortname': 'pelpd'}, '291331': {'common_names': ['xanthomonas', 'oryzae', 'x.', 'oryzae', 'x'], 'shortname': 'xanor'}, '548479': {'common_names': ['mobiluncus', 'curtisii', 'm.', 'curtisii', 'm'], 'shortname': 'mobcv'}, '557723': {'common_names': ['glaesserella', 'parasuis', 'g.', 'parasuis', 'g'], 'shortname': 'glap5'}, '1072389': {'common_names': ['marssonina', 'brunnea', 'm.', 'brunnea', 'm'], 'shortname': 'marbu'}, '1220162': {'common_names': ['trichosporon', 'asahii', 't.', 'asahii', 't'], 'shortname': 'triac'}, '931890': {'common_names': ['eremothecium', 'cymbalariae', 'e.', 'cymbalariae', 'e'], 'shortname': 'erecy'}, '981222': {'common_names': ['chloracidobacterium', 'thermophilum', 'c.', 'thermophilum', 'c'], 'shortname': 'chltf'}, '667014': {'common_names': ['thermodesulfatator', 'indicus', 't.', 'indicus', 't'], 'shortname': 'theid'}, '797210': {'common_names': ['halopiger', 'xanaduensis', 'h.', 'xanaduensis', 'h'], 'shortname': 'halxs'}, '496833': {'common_names': ['mycoplasmopsis', 'fermentans', 'm.', 'fermentans', 'm'], 'shortname': 'mycfp'}, '10181': {'common_names': ['heterocephalus', 'glaber', 'h.', 'glaber', 'h'], 'shortname': 'hetga'}, '247156': {'common_names': ['nocardia', 'farcinica', 'n.', 'farcinica', 'n'], 'shortname': 'nocfa'}, '243233': {'common_names': ['methylococcus', 'capsulatus', 'm.', 'capsulatus', 'm'], 'shortname': 'metca'}, '650482': {'common_names': ['mushroom', 'bacilliform', 'm.', 'bacilliform', 'm'], 'shortname': 'mbvlf'}, '398580': {'common_names': ['dinoroseobacter', 'shibae', 'd.', 'shibae', 'd'], 'shortname': 'dinsh'}, '323261': {'common_names': ['nitrosococcus', 'oceani', 'n.', 'oceani', 'n'], 'shortname': 'nitoc'}, '326442': {'common_names': ['pseudoalteromonas', 'translucida', 'p.', 'translucida', 'p'], 'shortname': 'pset1'}, '401053': {'common_names': ['terriglobus', 'saanensis', 't.', 'saanensis', 't'], 'shortname': 'terss'}, '700015': {'common_names': ['coriobacterium', 'glomerans', 'c.', 'glomerans', 'c'], 'shortname': 'corgp'}, '869209': {'common_names': ['treponema', 'succinifaciens', 't.', 'succinifaciens', 't'], 'shortname': 'tres6'}, '953739': {'common_names': ['streptomyces', 'venezuelae', 's.', 'venezuelae', 's'], 'shortname': 'strvp'}, '198628': {'common_names': ['dickeya', 'dadantii', 'd.', 'dadantii', 'd'], 'shortname': 'dicd3'}, '756272': {'common_names': ['rubinisphaera', 'brasiliensis', 'r.', 'brasiliensis', 'r'], 'shortname': 'rubbr'}, '572479': {'common_names': ['halanaerobium', 'praevalens', 'h.', 'praevalens', 'h'], 'shortname': 'halpg'}, '886882': {'common_names': ['paenibacillus', 'polymyxa', 'p.', 'polymyxa', 'p'], 'shortname': 'paeps'}, '701347': {'common_names': ['enterobacter', 'lignolyticus', 'e.', 'lignolyticus', 'e'], 'shortname': 'entls'}, '572544': {'common_names': ['ilyobacter', 'polytropus', 'i.', 'polytropus', 'i'], 'shortname': 'ilypc'}, '861360': {'common_names': ['glutamicibacter', 'arilaitensis', 'g.', 'arilaitensis', 'g'], 'shortname': 'gluar'}, '3760': {'common_names': ['prunus', 'persica', 'p.', 'persica', 'p'], 'shortname': 'prupe'}, '632518': {'common_names': ['caldicellulosiruptor', 'owensensis', 'c.', 'owensensis', 'c'], 'shortname': 'calow'}, '3055': {'common_names': ['chlamydomonas', 'reinhardtii', 'c.', 'reinhardtii', 'c'], 'shortname': 'chlre'}, '656061': {'common_names': ['tuber', 'melanosporum', 't.', 'melanosporum', 't'], 'shortname': 'tubmm'}, '10863': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpf1'}, '766191': {'common_names': ['cryptosporidium', 'parvum', 'c.', 'parvum', 'c'], 'shortname': 'cpvks'}, '36351': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv6z'}, '1160507': {'common_names': ['saccharomyces', 'arboricola', 's.', 'arboricola', 's'], 'shortname': 'sacar'}, '452637': {'common_names': ['opitutus', 'terrae', 'o.', 'terrae', 'o'], 'shortname': 'opitp'}, '280699': {'common_names': ['cyanidioschyzon', 'merolae', 'c.', 'merolae', 'c'], 'shortname': 'cyam1'}, '39946': {'common_names': ['oryza', 'sativa', 'o.', 'sativa', 'o'], 'shortname': 'orysi'}, '654908': {'common_names': ['sulfolobus', 'islandicus', 's.', 'islandicus', 's'], 'shortname': 'sifvh'}, '654903': {'common_names': ['ostreid', 'herpesvirus', 'o.', 'herpesvirus', 'o'], 'shortname': 'oshvf'}, '654912': {'common_names': ['his1', 'virus', 'h.', 'virus', 'h'], 'shortname': 'his1i'}, '375451': {'common_names': ['roseobacter', 'denitrificans', 'r.', 'denitrificans', 'r'], 'shortname': 'rosdo'}, '869210': {'common_names': ['marinithermus', 'hydrothermalis', 'm.', 'hydrothermalis', 'm'], 'shortname': 'marht'}, '768670': {'common_names': ['calditerrivibrio', 'nitroreducens', 'c.', 'nitroreducens', 'c'], 'shortname': 'calny'}, '499177': {'common_names': ['acetoanaerobium', 'sticklandii', 'a.', 'sticklandii', 'a'], 'shortname': 'acesd'}, '213810': {'common_names': ['ruminococcus', 'champanellensis', 'r.', 'champanellensis', 'r'], 'shortname': 'rumc1'}, '342108': {'common_names': ['magnetospirillum', 'magneticum', 'm.', 'magneticum', 'm'], 'shortname': 'magsa'}, '7165': {'common_names': ['anopheles', 'gambiae', 'a.', 'gambiae', 'a'], 'shortname': 'anoga'}, '347257': {'common_names': ['mycoplasmopsis', 'agalactiae', 'm.', 'agalactiae', 'm'], 'shortname': 'mycap'}, '882210': {'common_names': ['maize', 'chlorotic', 'm.', 'chlorotic', 'm'], 'shortname': 'mcmvk'}, '269799': {'common_names': ['geobacter', 'metallireducens', 'g.', 'metallireducens', 'g'], 'shortname': 'geomg'}, '452652': {'common_names': ['kitasatospora', 'setae', 'k.', 'setae', 'k'], 'shortname': 'kitsk'}, '766184': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvg1'}, '766190': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvi1'}, '766187': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvz1'}, '82831': {'common_names': ['equine', 'herpesvirus', 'e.', 'herpesvirus', 'e'], 'shortname': 'ehv2'}, '654933': {'common_names': ['oryza', 'sativa', 'o.', 'sativa', 'o'], 'shortname': 'osevj'}, '568816': {'common_names': ['acidaminococcus', 'intestini', 'a.', 'intestini', 'a'], 'shortname': 'aciir'}, '868864': {'common_names': ['desulfurobacterium', 'thermolithotrophum', 'd.', 'thermolithotrophum', 'd'], 'shortname': 'destd'}, '7668': {'common_names': ['strongylocentrotus', 'purpuratus', 's.', 'purpuratus', 's'], 'shortname': 'strpu'}, '682795': {'common_names': ['granulicella', 'mallensis', 'g.', 'mallensis', 'g'], 'shortname': 'gramm'}, '413071': {'common_names': ['hypocrea', 'virens', 'h.', 'virens', 'h'], 'shortname': 'hypvg'}, '1126212': {'common_names': ['macrophomina', 'phaseolina', 'm.', 'phaseolina', 'm'], 'shortname': 'macph'}, '1109443': {'common_names': ['serendipita', 'indica', 's.', 'indica', 's'], 'shortname': 'serid'}, '443254': {'common_names': ['marinitoga', 'piezophila', 'm.', 'piezophila', 'm'], 'shortname': 'marpk'}, '1133850': {'common_names': ['streptomyces', 'hygroscopicus', 's.', 'hygroscopicus', 's'], 'shortname': 'strhj'}, '931626': {'common_names': ['acetobacterium', 'woodii', 'a.', 'woodii', 'a'], 'shortname': 'acewd'}, '684364': {'common_names': ['batrachochytrium', 'dendrobatidis', 'b.', 'dendrobatidis', 'b'], 'shortname': 'batdj'}, '869211': {'common_names': ['spirochaeta', 'thermophila', 's.', 'thermophila', 's'], 'shortname': 'spitz'}, '5660': {'common_names': ['leishmania', 'braziliensis', 'l.', 'braziliensis', 'l'], 'shortname': 'leibr'}, '574566': {'common_names': ['coccomyxa', 'subellipsoidea', 'c.', 'subellipsoidea', 'c'], 'shortname': 'cocsc'}, '7070': {'common_names': ['tribolium', 'castaneum', 't.', 'castaneum', 't'], 'shortname': 'trica'}, '13735': {'common_names': ['pelodiscus', 'sinensis', 'p.', 'sinensis', 'p'], 'shortname': 'pelsi'}, '99883': {'common_names': ['tetraodon', 'nigroviridis', 't.', 'nigroviridis', 't'], 'shortname': 'tetng'}, '858893': {'common_names': ['exophiala', 'dermatitidis', 'e.', 'dermatitidis', 'e'], 'shortname': 'exodn'}, '4577': {'common_names': ['zea', 'mays', 'z.', 'mays', 'z', 'maize', 'corn'], 'shortname': 'maize'}, '320483': {'common_names': ['anaplasma', 'marginale', 'a.', 'marginale', 'a'], 'shortname': 'anamf'}, '573729': {'common_names': ['myceliophthora', 'thermophila', 'm.', 'thermophila', 'm'], 'shortname': 'myctt'}, '651182': {'common_names': ['desulfobacula', 'toluolica', 'd.', 'toluolica', 'd'], 'shortname': 'destt'}, '1162668': {'common_names': ['leptospirillum', 'ferrooxidans', 'l.', 'ferrooxidans', 'l'], 'shortname': 'lepfc'}, '889378': {'common_names': ['spirochaeta', 'africana', 's.', 'africana', 's'], 'shortname': 'spiaz'}, '1163730': {'common_names': ['fervidicoccus', 'fontis', 'f.', 'fontis', 'f'], 'shortname': 'ferfk'}, '945713': {'common_names': ['ignavibacterium', 'album', 'i.', 'album', 'i'], 'shortname': 'ignaj'}, '866895': {'common_names': ['halobacillus', 'halophilus', 'h.', 'halophilus', 'h'], 'shortname': 'halh3'}, '578458': {'common_names': ['schizophyllum', 'commune', 's.', 'commune', 's'], 'shortname': 'schcm'}, '656519': {'common_names': ['halanaerobium', 'hydrogeniformans', 'h.', 'hydrogeniformans', 'h'], 'shortname': 'halhg'}, '649349': {'common_names': ['leadbetterella', 'byssophila', 'l.', 'byssophila', 'l'], 'shortname': 'leab4'}, '488538': {'common_names': ['puniceispirillum', 'marinum', 'p.', 'marinum', 'p'], 'shortname': 'punmi'}, '755732': {'common_names': ['fluviicola', 'taffensis', 'f.', 'taffensis', 'f'], 'shortname': 'flutr'}, '546269': {'common_names': ['filifactor', 'alocis', 'f.', 'alocis', 'f'], 'shortname': 'filad'}, '871585': {'common_names': ['acinetobacter', 'calcoaceticus', 'a.', 'calcoaceticus', 'a'], 'shortname': 'acicp'}, '768700': {'common_names': ['mycoplasma', 'suis', 'm.', 'suis', 'm'], 'shortname': 'mycsl'}, '867900': {'common_names': ['cellulophaga', 'lytica', 'c.', 'lytica', 'c'], 'shortname': 'cellc'}, '645991': {'common_names': ['syntrophobotulus', 'glycolicus', 's.', 'glycolicus', 's'], 'shortname': 'syngf'}, '877455': {'common_names': ['methanobacterium', 'lacus', 'm.', 'lacus', 'm'], 'shortname': 'metla'}, '572307': {'common_names': ['neospora', 'caninum', 'n.', 'caninum', 'n'], 'shortname': 'neocl'}, '1146883': {'common_names': ['blastococcus', 'saxobsidens', 'b.', 'saxobsidens', 'b'], 'shortname': 'blasd'}, '984262': {'common_names': ['saprospira', 'grandis', 's.', 'grandis', 's'], 'shortname': 'sapgl'}, '487067': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvvg'}, '687366': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv6'}, '687343': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv8'}, '652616': {'common_names': ['mycobacterium', 'tuberculosis', 'm.', 'tuberculosis', 'm'], 'shortname': 'mycte'}, '1144275': {'common_names': ['corallococcus', 'coralloides', 'c.', 'coralloides', 'c'], 'shortname': 'corcm'}, '929556': {'common_names': ['solitalea', 'canadensis', 's.', 'canadensis', 's'], 'shortname': 'solcm'}, '1094466': {'common_names': ['flavobacterium', 'indicum', 'f.', 'indicum', 'f'], 'shortname': 'flaig'}, '69293': {'common_names': ['gasterosteus', 'aculeatus', 'g.', 'aculeatus', 'g'], 'shortname': 'gasac'}, '766178': {'common_names': ['ictalurid', 'herpesvirus', 'i.', 'herpesvirus', 'i'], 'shortname': 'ichva'}, '9785': {'common_names': ['loxodonta', 'africana', 'l.', 'africana', 'l'], 'shortname': 'loxaf'}, '9305': {'common_names': ['sarcophilus', 'harrisii', 's.', 'harrisii', 's'], 'shortname': 'sarha'}, '306902': {'common_names': ['clavispora', 'lusitaniae', 'c.', 'lusitaniae', 'c'], 'shortname': 'clal4'}, '693977': {'common_names': ['deinococcus', 'proteolyticus', 'd.', 'proteolyticus', 'd'], 'shortname': 'deipm'}, '515635': {'common_names': ['dictyoglomus', 'turgidum', 'd.', 'turgidum', 'd'], 'shortname': 'dictd'}, '316067': {'common_names': ['geotalea', 'daltonii', 'g.', 'daltonii', 'g'], 'shortname': 'geodf'}, '456320': {'common_names': ['methanococcus', 'voltae', 'm.', 'voltae', 'm'], 'shortname': 'metv3'}, '504832': {'common_names': ['afipia', 'carboxidovorans', 'a.', 'carboxidovorans', 'a'], 'shortname': 'afic5'}, '511062': {'common_names': ['oceanimonas', 'sp', 'o.', 'sp', 'o'], 'shortname': 'ocesg'}, '452662': {'common_names': ['sphingobium', 'indicum', 's.', 'indicum', 's'], 'shortname': 'sphiu'}, '59729': {'common_names': ['taeniopygia', 'guttata', 't.', 'guttata', 't'], 'shortname': 'taegu'}, '103372': {'common_names': ['acromyrmex', 'echinatior', 'a.', 'echinatior', 'a'], 'shortname': 'acrec'}, '175814': {'common_names': ['cestrum', 'yellow', 'c.', 'yellow', 'c'], 'shortname': 'cylcv'}, '1985704': {'common_names': ['northern', 'cereal', 'n.', 'cereal', 'n'], 'shortname': 'ncmv'}, '655863': {'common_names': ['grosmannia', 'clavigera', 'g.', 'clavigera', 'g'], 'shortname': 'grocl'}, '261658': {'common_names': ['cavenderia', 'fasciculata', 'c.', 'fasciculata', 'c'], 'shortname': 'cacfs'}, '7260': {'common_names': ['drosophila', 'willistoni', 'd.', 'willistoni', 'd'], 'shortname': 'drowi'}, '946362': {'common_names': ['salpingoeca', 'rosetta', 's.', 'rosetta', 's'], 'shortname': 'salr5'}, '7217': {'common_names': ['drosophila', 'ananassae', 'd.', 'ananassae', 'd'], 'shortname': 'droan'}, '563040': {'common_names': ['sulfurimonas', 'autotrophica', 's.', 'autotrophica', 's'], 'shortname': 'sulao'}, '990316': {'common_names': ['methanothrix', 'soehngenii', 'm.', 'soehngenii', 'm'], 'shortname': 'metsg'}, '675635': {'common_names': ['pseudonocardia', 'dioxanivorans', 'p.', 'dioxanivorans', 'p'], 'shortname': 'pseux'}, '7029': {'common_names': ['acyrthosiphon', 'pisum', 'a.', 'pisum', 'a'], 'shortname': 'acypi'}, '1125630': {'common_names': ['klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k'], 'shortname': 'kleph'}, '1003195': {'common_names': ['streptantibioticus', 'cattleyicolor', 's.', 'cattleyicolor', 's'], 'shortname': 'stren'}, '51511': {'common_names': ['ciona', 'savignyi', 'c.', 'savignyi', 'c'], 'shortname': 'ciosa'}, '400682': {'common_names': ['amphimedon', 'queenslandica', 'a.', 'queenslandica', 'a'], 'shortname': 'ampqe'}, '926550': {'common_names': ['caldilinea', 'aerophila', 'c.', 'aerophila', 'c'], 'shortname': 'calas'}, '1142394': {'common_names': ['phycisphaera', 'mikurensis', 'p.', 'mikurensis', 'p'], 'shortname': 'phymf'}, '512565': {'common_names': ['actinoplanes', 'missouriensis', 'a.', 'missouriensis', 'a'], 'shortname': 'actm4'}, '983917': {'common_names': ['rubrivivax', 'gelatinosus', 'r.', 'gelatinosus', 'r'], 'shortname': 'rubgi'}, '596154': {'common_names': ['alicycliphilus', 'denitrificans', 'a.', 'denitrificans', 'a'], 'shortname': 'alidk'}, '760011': {'common_names': ['sphaerochaeta', 'coccoides', 's.', 'coccoides', 's'], 'shortname': 'sphcd'}, '981540': {'common_names': ['streptococcus', 'pasteurianus', 's.', 'pasteurianus', 's'], 'shortname': 'strpx'}, '1032480': {'common_names': ['microlunatus', 'phosphovorus', 'm.', 'phosphovorus', 'm'], 'shortname': 'micpn'}, '471853': {'common_names': ['beutenbergia', 'cavernae', 'b.', 'cavernae', 'b'], 'shortname': 'beuc1'}, '341663': {'common_names': ['aspergillus', 'terreus', 'a.', 'terreus', 'a'], 'shortname': 'asptn'}, '218491': {'common_names': ['pectobacterium', 'atrosepticum', 'p.', 'atrosepticum', 'p'], 'shortname': 'pecas'}, '479435': {'common_names': ['kribbella', 'flavida', 'k.', 'flavida', 'k'], 'shortname': 'krifd'}, '1105111': {'common_names': ['rickettsia', 'amblyommatis', 'r.', 'amblyommatis', 'r'], 'shortname': 'ricag'}, '4529': {'common_names': ['oryza', 'rufipogon', 'o.', 'rufipogon', 'o'], 'shortname': 'oryru'}, '654928': {'common_names': ['sheeppox', 'virus', 's.', 'virus', 's'], 'shortname': 'shevt'}, '1214101': {'common_names': ['streptomyces', 'davaonensis', 's.', 'davaonensis', 's'], 'shortname': 'strdj'}, '336722': {'common_names': ['zymoseptoria', 'tritici', 'z.', 'tritici', 'z'], 'shortname': 'zymti'}, '936435': {'common_names': ['serpula', 'lacrymans', 's.', 'lacrymans', 's'], 'shortname': 'serl3'}, '759272': {'common_names': ['chaetomium', 'thermophilum', 'c.', 'thermophilum', 'c'], 'shortname': 'chatd'}, '135651': {'common_names': ['caenorhabditis', 'brenneri', 'c.', 'brenneri', 'c'], 'shortname': 'caebe'}, '10389': {'common_names': ['gallid', 'herpesvirus', 'g.', 'herpesvirus', 'g'], 'shortname': 'gahvm'}, '406817': {'common_names': ['xenorhabdus', 'nematophila', 'x.', 'nematophila', 'x'], 'shortname': 'xenna'}, '264462': {'common_names': ['bdellovibrio', 'bacteriovorus', 'b.', 'bacteriovorus', 'b'], 'shortname': 'bdeba'}, '114430': {'common_names': ['ovine', 'adenovirus', 'o.', 'adenovirus', 'o'], 'shortname': 'adeo7'}, '2886926': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpp1'}, '866775': {'common_names': ['aerococcus', 'urinae', 'a.', 'urinae', 'a'], 'shortname': 'aerua'}, '991905': {'common_names': ['polymorphum', 'gilvum', 'p.', 'gilvum', 'p'], 'shortname': 'polgs'}, '693661': {'common_names': ['archaeoglobus', 'veneficus', 'a.', 'veneficus', 'a'], 'shortname': 'arcvs'}, '760142': {'common_names': ['hippea', 'maritima', 'h.', 'maritima', 'h'], 'shortname': 'hipma'}, '554065': {'common_names': ['chlorella', 'variabilis', 'c.', 'variabilis', 'c'], 'shortname': 'chlva'}, '544711': {'common_names': ['ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a'], 'shortname': 'ajec8'}, '8364': {'common_names': ['xenopus', 'tropicalis', 'x.', 'tropicalis', 'x'], 'shortname': 'xentr'}, '7719': {'common_names': ['ciona', 'intestinalis', 'c.', 'intestinalis', 'c'], 'shortname': 'cioin'}, '290338': {'common_names': ['citrobacter', 'koseri', 'c.', 'koseri', 'c'], 'shortname': 'citk8'}, '652962': {'common_names': ['lettuce', 'bigvein', 'l.', 'bigvein', 'l'], 'shortname': 'lbvav'}, '654919': {'common_names': ['microplitis', 'demolitor', 'm.', 'demolitor', 'm'], 'shortname': 'mdbvw'}, '585394': {'common_names': ['roseburia', 'hominis', 'r.', 'hominis', 'r'], 'shortname': 'rosha'}, '578455': {'common_names': ['thermothielavioides', 'terrestris', 't.', 'terrestris', 't'], 'shortname': 'thett'}, '243274': {'common_names': ['thermotoga', 'maritima', 't.', 'maritima', 't'], 'shortname': 'thema'}, '211586': {'common_names': ['shewanella', 'oneidensis', 's.', 'oneidensis', 's'], 'shortname': 'sheon'}, '1127134': {'common_names': ['nocardia', 'cyriacigeorgica', 'n.', 'cyriacigeorgica', 'n'], 'shortname': 'noccg'}, '41431': {'common_names': ['rippkaea', 'orientalis', 'r.', 'orientalis', 'r'], 'shortname': 'ripo1'}, '574521': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco27'}, '497965': {'common_names': ['gloeothece', 'verrucosa', 'g.', 'verrucosa', 'g'], 'shortname': 'glov7'}, '460265': {'common_names': ['methylobacterium', 'nodulans', 'm.', 'nodulans', 'm'], 'shortname': 'metno'}, '381666': {'common_names': ['cupriavidus', 'necator', 'c.', 'necator', 'c'], 'shortname': 'cupnh'}, '243275': {'common_names': ['treponema', 'denticola', 't.', 'denticola', 't'], 'shortname': 'trede'}, '405955': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'ecok1'}, '386415': {'common_names': ['clostridium', 'novyi', 'c.', 'novyi', 'c'], 'shortname': 'clonn'}, '351607': {'common_names': ['acidothermus', 'cellulolyticus', 'a.', 'cellulolyticus', 'a'], 'shortname': 'acic1'}, '9483': {'common_names': ['callithrix', 'jacchus', 'c.', 'jacchus', 'c'], 'shortname': 'calja'}, '9823': {'common_names': ['sus', 'scrofa', 's.', 'scrofa', 's'], 'shortname': 'pig'}, '469383': {'common_names': ['conexibacter', 'woesei', 'c.', 'woesei', 'c'], 'shortname': 'conwi'}, '699246': {'common_names': ['mageeibacillus', 'indolicus', 'm.', 'indolicus', 'm'], 'shortname': 'magiu'}, '610380': {'common_names': ['harpegnathos', 'saltator', 'h.', 'saltator', 'h'], 'shortname': 'harsa'}, '309800': {'common_names': ['haloferax', 'volcanii', 'h.', 'volcanii', 'h'], 'shortname': 'halvd'}, '486275': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv2'}, '687342': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv3'}, '687345': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv4'}, '486277': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv5'}, '486279': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv7'}, '687364': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvv9'}, '31234': {'common_names': ['caenorhabditis', 'remanei', 'c.', 'remanei', 'c'], 'shortname': 'caere'}, '79700': {'common_names': ['rat', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r'], 'shortname': 'rcmvm'}, '983548': {'common_names': ['dokdonia', 'sp', 'd.', 'sp', 'd'], 'shortname': 'doks4'}, '292415': {'common_names': ['thiobacillus', 'denitrificans', 't.', 'denitrificans', 't'], 'shortname': 'thida'}, '983544': {'common_names': ['lacinutrix', 'sp', 'l.', 'sp', 'l'], 'shortname': 'lacs5'}, '208596': {'common_names': ['carnobacterium', 'sp', 'c.', 'sp', 'c'], 'shortname': 'cars1'}, '263358': {'common_names': ['micromonospora', 'maris', 'm.', 'maris', 'm'], 'shortname': 'micm1'}, '3988': {'common_names': ['ricinus', 'communis', 'r.', 'communis', 'r'], 'shortname': 'ricco'}, '12968': {'common_names': ['blastocystis', 'hominis', 'b.', 'hominis', 'b'], 'shortname': 'blaho'}, '1091494': {'common_names': ['methylotuvimicrobium', 'alcaliphilum', 'm.', 'alcaliphilum', 'm'], 'shortname': 'meta2'}, '205920': {'common_names': ['ehrlichia', 'chaffeensis', 'e.', 'chaffeensis', 'e'], 'shortname': 'ehrcr'}, '59748': {'common_names': ['phytoplasma', 'australiense', 'p.', 'australiense', 'p'], 'shortname': 'phyas'}, '290400': {'common_names': ['jannaschia', 'sp', 'j.', 'sp', 'j'], 'shortname': 'jansc'}, '338969': {'common_names': ['albidiferax', 'ferrireducens', 'a.', 'ferrireducens', 'a'], 'shortname': 'albft'}, '126793': {'common_names': ['plasmodium', 'vivax', 'p.', 'vivax', 'p'], 'shortname': 'plavs'}, '650164': {'common_names': ['phanerochaete', 'carnosa', 'p.', 'carnosa', 'p'], 'shortname': 'phacs'}, '365046': {'common_names': ['ramlibacter', 'tataouinensis', 'r.', 'tataouinensis', 'r'], 'shortname': 'ramtt'}, '1005048': {'common_names': ['collimonas', 'fungivorans', 'c.', 'fungivorans', 'c'], 'shortname': 'colft'}, '10645': {'common_names': ['cauliflower', 'mosaic', 'c.', 'mosaic', 'c'], 'shortname': 'camvd'}, '940190': {'common_names': ['melissococcus', 'plutonius', 'm.', 'plutonius', 'm'], 'shortname': 'melpt'}, '697281': {'common_names': ['mahella', 'australiensis', 'm.', 'australiensis', 'm'], 'shortname': 'maha5'}, '590998': {'common_names': ['cellulomonas', 'fimi', 'c.', 'fimi', 'c'], 'shortname': 'celfa'}, '760192': {'common_names': ['haliscomenobacter', 'hydrossis', 'h.', 'hydrossis', 'h'], 'shortname': 'halh1'}, '158189': {'common_names': ['sphaerochaeta', 'globosa', 's.', 'globosa', 's'], 'shortname': 'sphgb'}, '642492': {'common_names': ['cellulosilyticum', 'lentocellum', 'c.', 'lentocellum', 'c'], 'shortname': 'celld'}, '597362': {'common_names': ['agaricus', 'bisporus', 'a.', 'bisporus', 'a'], 'shortname': 'agabu'}, '510952': {'common_names': ['neurospora', 'tetrasperma', 'n.', 'tetrasperma', 'n'], 'shortname': 'neut9'}, '420890': {'common_names': ['lactococcus', 'garvieae', 'l.', 'garvieae', 'l'], 'shortname': 'lacgl'}, '185431': {'common_names': ['trypanosoma', 'brucei', 't.', 'brucei', 't'], 'shortname': 'tryb2'}, '477974': {'common_names': ['desulforudis', 'audaxviator', 'd.', 'audaxviator', 'd'], 'shortname': 'desap'}, '6238': {'common_names': ['caenorhabditis', 'briggsae', 'c.', 'briggsae', 'c'], 'shortname': 'caebr'}, '498761': {'common_names': ['heliobacterium', 'modesticaldum', 'h.', 'modesticaldum', 'h'], 'shortname': 'helmi'}, '441768': {'common_names': ['acholeplasma', 'laidlawii', 'a.', 'laidlawii', 'a'], 'shortname': 'achli'}, '96561': {'common_names': ['desulfosudis', 'oleivorans', 'd.', 'oleivorans', 'd'], 'shortname': 'desoh'}, '12143': {'common_names': ['cucumber', 'necrosis', 'c.', 'necrosis', 'c'], 'shortname': 'cnv'}, '12144': {'common_names': ['cymbidium', 'ringspot', 'c.', 'ringspot', 'c'], 'shortname': 'crv'}, '928297': {'common_names': ['bovine', 'ephemeral', 'b.', 'ephemeral', 'b'], 'shortname': 'befvb'}, '928314': {'common_names': ['yaba', 'monkey', 'y.', 'monkey', 'y'], 'shortname': 'ymtv5'}, '928301': {'common_names': ['fowlpox', 'virus', 'f.', 'virus', 'f'], 'shortname': 'fowpn'}, '685038': {'common_names': ['escherichia', 'coli', 'e.', 'coli', 'e'], 'shortname': 'eco8n'}, '10650': {'common_names': ['figwort', 'mosaic', 'f.', 'mosaic', 'f'], 'shortname': 'fmvd'}, '693979': {'common_names': ['bacteroides', 'helcogenes', 'b.', 'helcogenes', 'b'], 'shortname': 'bact6'}, '575540': {'common_names': ['isosphaera', 'pallida', 'i.', 'pallida', 'i'], 'shortname': 'isopi'}, '743721': {'common_names': ['pseudoxanthomonas', 'suwonensis', 'p.', 'suwonensis', 'p'], 'shortname': 'pseuu'}, '749222': {'common_names': ['nitratifractor', 'salsuginis', 'n.', 'salsuginis', 'n'], 'shortname': 'nitse'}, '709986': {'common_names': ['deinococcus', 'maricopensis', 'd.', 'maricopensis', 'd'], 'shortname': 'deiml'}, '865938': {'common_names': ['weeksella', 'virosa', 'w.', 'virosa', 'w'], 'shortname': 'weevc'}, '7897': {'common_names': ['latimeria', 'chalumnae', 'l.', 'chalumnae', 'l'], 'shortname': 'latch'}, '871575': {'common_names': ['ogataea', 'parapolymorpha', 'o.', 'parapolymorpha', 'o'], 'shortname': 'ogapd'}, '309807': {'common_names': ['salinibacter', 'ruber', 's.', 'ruber', 's'], 'shortname': 'salrd'}, '634498': {'common_names': ['methanobrevibacter', 'ruminantium', 'm.', 'ruminantium', 'm'], 'shortname': 'metrm'}, '81972': {'common_names': ['arabidopsis', 'lyrata', 'a.', 'lyrata', 'a'], 'shortname': 'arall'}, '526221': {'common_names': ['verticillium', 'alfalfae', 'v.', 'alfalfae', 'v'], 'shortname': 'vera1'}, '290317': {'common_names': ['chlorobium', 'phaeobacteroides', 'c.', 'phaeobacteroides', 'c'], 'shortname': 'chlpd'}, '367928': {'common_names': ['bifidobacterium', 'adolescentis', 'b.', 'adolescentis', 'b'], 'shortname': 'bifaa'}, '694427': {'common_names': ['paludibacter', 'propionicigenes', 'p.', 'propionicigenes', 'p'], 'shortname': 'palpw'}, '643867': {'common_names': ['marivirga', 'tractuosa', 'm.', 'tractuosa', 'm'], 'shortname': 'marth'}, '709032': {'common_names': ['sulfuricurvum', 'kujiense', 's.', 'kujiense', 's'], 'shortname': 'sulky'}, '670487': {'common_names': ['oceanithermus', 'profundus', 'o.', 'profundus', 'o'], 'shortname': 'ocep5'}, '595528': {'common_names': ['capsaspora', 'owczarzaki', 'c.', 'owczarzaki', 'c'], 'shortname': 'capo3'}, '7234': {'common_names': ['drosophila', 'persimilis', 'd.', 'persimilis', 'd'], 'shortname': 'drope'}, '654924': {'common_names': ['frog', 'virus', 'f.', 'virus', 'f'], 'shortname': 'frg3g'}, '766182': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttva1'}, '766183': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvb1'}, '766186': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttve1'}, '766188': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvf1'}, '645133': {'common_names': ['colletotrichum', 'graminicola', 'c.', 'graminicola', 'c'], 'shortname': 'colgm'}, '418459': {'common_names': ['puccinia', 'graminis', 'p.', 'graminis', 'p'], 'shortname': 'pucgt'}, '756982': {'common_names': ['arthrobotrys', 'oligospora', 'a.', 'oligospora', 'a'], 'shortname': 'artoa'}, '654914': {'common_names': ['fringilla', 'coelebs', 'f.', 'coelebs', 'f'], 'shortname': 'fcpvn'}, '654917': {'common_names': ['psittacus', 'erithacus', 'p.', 'erithacus', 'p'], 'shortname': 'pepva'}, '7244': {'common_names': ['drosophila', 'virilis', 'd.', 'virilis', 'd'], 'shortname': 'drovi'}, '634500': {'common_names': ['erwinia', 'billingiae', 'e.', 'billingiae', 'e'], 'shortname': 'erwbe'}, '314225': {'common_names': ['erythrobacter', 'litoralis', 'e.', 'litoralis', 'e'], 'shortname': 'erylh'}, '15368': {'common_names': ['brachypodium', 'distachyon', 'b.', 'distachyon', 'b'], 'shortname': 'bradi'}, '243272': {'common_names': ['metamycoplasma', 'arthritidis', 'm.', 'arthritidis', 'm'], 'shortname': 'meta1'}, '395019': {'common_names': ['burkholderia', 'multivorans', 'b.', 'multivorans', 'b'], 'shortname': 'burm1'}, '93061': {'common_names': ['staphylococcus', 'aureus', 's.', 'aureus', 's'], 'shortname': 'staa8'}, '7159': {'common_names': ['aedes', 'aegypti', 'a.', 'aegypti', 'a'], 'shortname': 'aedae'}, '404380': {'common_names': ['citrifermentans', 'bemidjiense', 'c.', 'bemidjiense', 'c'], 'shortname': 'citbb'}, '3847': {'common_names': ['glycine', 'max', 'g.', 'max', 'g', 'soy', 'soybean', 'bean'], 'shortname': 'soybn'}, '425265': {'common_names': ['malassezia', 'globosa', 'm.', 'globosa', 'm'], 'shortname': 'malgo'}, '378753': {'common_names': ['kocuria', 'rhizophila', 'k.', 'rhizophila', 'k'], 'shortname': 'kocrd'}, '522373': {'common_names': ['stenotrophomonas', 'maltophilia', 's.', 'maltophilia', 's'], 'shortname': 'strmk'}, '290315': {'common_names': ['chlorobium', 'limicola', 'c.', 'limicola', 'c'], 'shortname': 'chll2'}, '1082931': {'common_names': ['pelagibacterium', 'halotolerans', 'p.', 'halotolerans', 'p'], 'shortname': 'pelhb'}, '6183': {'common_names': ['schistosoma', 'mansoni', 's.', 'mansoni', 's'], 'shortname': 'schma'}, '559305': {'common_names': ['trichophyton', 'rubrum', 't.', 'rubrum', 't'], 'shortname': 'trirc'}, '663331': {'common_names': ['arthroderma', 'benhamiae', 'a.', 'benhamiae', 'a'], 'shortname': 'artbc'}, '393595': {'common_names': ['alcanivorax', 'borkumensis', 'a.', 'borkumensis', 'a'], 'shortname': 'alcbs'}, '857087': {'common_names': ['methylomonas', 'methanica', 'm.', 'methanica', 'm'], 'shortname': 'metmm'}, '860228': {'common_names': ['capnocytophaga', 'canimorsus', 'c.', 'canimorsus', 'c'], 'shortname': 'capcc'}, '63186': {'common_names': ['zobellia', 'galactanivorans', 'z.', 'galactanivorans', 'z'], 'shortname': 'zobga'}, '886377': {'common_names': ['muricauda', 'ruestringensis', 'm.', 'ruestringensis', 'm'], 'shortname': 'murrd'}, '9646': {'common_names': ['ailuropoda', 'melanoleuca', 'a.', 'melanoleuca', 'a'], 'shortname': 'ailme'}, '710696': {'common_names': ['intrasporangium', 'calvum', 'i.', 'calvum', 'i'], 'shortname': 'intc7'}, '644966': {'common_names': ['thermaerobacter', 'marianensis', 't.', 'marianensis', 't'], 'shortname': 'them7'}, '595537': {'common_names': ['variovorax', 'paradoxus', 'v.', 'paradoxus', 'v'], 'shortname': 'varpe'}, '926569': {'common_names': ['anaerolinea', 'thermophila', 'a.', 'thermophila', 'a'], 'shortname': 'anatu'}, '1005060': {'common_names': ['groundnut', 'rosette', 'g.', 'rosette', 'g'], 'shortname': 'grvmc'}, '502558': {'common_names': ['eggerthella', 'sp', 'e.', 'sp', 'e'], 'shortname': 'eegsy'}, '1042156': {'common_names': ['clostridium', 'sp', 'c.', 'sp', 'c'], 'shortname': 'closs'}, '649756': {'common_names': ['anaerostipes', 'hadrus', 'a.', 'hadrus', 'a'], 'shortname': 'anaha'}, '862908': {'common_names': ['halobacteriovorax', 'marinus', 'h.', 'marinus', 'h'], 'shortname': 'halms'}, '5932': {'common_names': ['ichthyophthirius', 'multifiliis', 'i.', 'multifiliis', 'i'], 'shortname': 'ichmu'}, '431241': {'common_names': ['hypocrea', 'jecorina', 'h.', 'jecorina', 'h'], 'shortname': 'hypjq'}, '1197325': {'common_names': ['mycoplasma', 'wenyonii', 'm.', 'wenyonii', 'm'], 'shortname': 'mycwm'}, '1201294': {'common_names': ['methanoculleus', 'bourgensis', 'm.', 'bourgensis', 'm'], 'shortname': 'metbm'}, '745277': {'common_names': ['rahnella', 'aquatilis', 'r.', 'aquatilis', 'r'], 'shortname': 'rahac'}, '1191523': {'common_names': ['melioribacter', 'roseus', 'm.', 'roseus', 'm'], 'shortname': 'melrp'}, '10228': {'common_names': ['trichoplax', 'adhaerens', 't.', 'adhaerens', 't'], 'shortname': 'triad'}, '121224': {'common_names': ['pediculus', 'humanus', 'p.', 'humanus', 'p'], 'shortname': 'pedhc'}, '644282': {'common_names': ['desulfarculus', 'baarsii', 'd.', 'baarsii', 'd'], 'shortname': 'desb2'}, '313596': {'common_names': ['robiginitalea', 'biformata', 'r.', 'biformata', 'r'], 'shortname': 'robbh'}, '242507': {'common_names': ['magnaporthe', 'oryzae', 'm.', 'oryzae', 'm'], 'shortname': 'mago7'}, '2885846': {'common_names': ['european', 'elk', 'e.', 'elk', 'e'], 'shortname': 'papve'}, '55884': {'common_names': ['shigella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsf5'}, '267748': {'common_names': ['mesomycoplasma', 'mobile', 'm.', 'mobile', 'm'], 'shortname': 'mesm1'}, '595494': {'common_names': ['tolumonas', 'auensis', 't.', 'auensis', 't'], 'shortname': 'tolat'}, '568814': {'common_names': ['streptococcus', 'suis', 's.', 'suis', 's'], 'shortname': 'strs4'}, '604354': {'common_names': ['thermococcus', 'sibiricus', 't.', 'sibiricus', 't'], 'shortname': 'thesm'}, '377629': {'common_names': ['teredinibacter', 'turnerae', 't.', 'turnerae', 't'], 'shortname': 'tertt'}, '272630': {'common_names': ['methylorubrum', 'extorquens', 'm.', 'extorquens', 'm'], 'shortname': 'metea'}, '578460': {'common_names': ['nosema', 'ceranae', 'n.', 'ceranae', 'n'], 'shortname': 'nosce'}, '10747': {'common_names': ['streptococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpcp1'}, '2932878': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpspb'}, '2905681': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpp2'}, '10680': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpp4'}, '334819': {'common_names': ['gibberella', 'moniliformis', 'g.', 'moniliformis', 'g'], 'shortname': 'gibm7'}, '555778': {'common_names': ['halothiobacillus', 'neapolitanus', 'h.', 'neapolitanus', 'h'], 'shortname': 'halnc'}, '764103': {'common_names': ['mixia', 'osmundae', 'm.', 'osmundae', 'm'], 'shortname': 'mixos'}, '279238': {'common_names': ['novosphingobium', 'aromaticivorans', 'n.', 'aromaticivorans', 'n'], 'shortname': 'novad'}, '1111676': {'common_names': ['mycoplasma', 'haemocanis', 'm.', 'haemocanis', 'm'], 'shortname': 'mychn'}, '246409': {'common_names': ['rhizopus', 'delemar', 'r.', 'delemar', 'r'], 'shortname': 'rhio9'}, '754477': {'common_names': ['methylophaga', 'frappieri', 'm.', 'frappieri', 'm'], 'shortname': 'metfj'}, '1112204': {'common_names': ['gordonia', 'polyisoprenivorans', 'g.', 'polyisoprenivorans', 'g'], 'shortname': 'gorpv'}, '70448': {'common_names': ['ostreococcus', 'tauri', 'o.', 'tauri', 'o'], 'shortname': 'ostta'}, '97195': {'common_names': ['heterosigma', 'akashiwo', 'h.', 'akashiwo', 'h'], 'shortname': 'hav01'}, '326297': {'common_names': ['shewanella', 'amazonensis', 's.', 'amazonensis', 's'], 'shortname': 'sheam'}, '1002672': {'common_names': ['pelagibacter', 'sp', 'p.', 'sp', 'p'], 'shortname': 'pelsm'}, '29760': {'common_names': ['vitis', 'vinifera', 'v.', 'vinifera', 'v'], 'shortname': 'vitvi'}, '1034807': {'common_names': ['flavobacterium', 'branchiophilum', 'f.', 'branchiophilum', 'f'], 'shortname': 'flabf'}, '7230': {'common_names': ['drosophila', 'mojavensis', 'd.', 'mojavensis', 'd'], 'shortname': 'dromo'}, '545695': {'common_names': ['leadbettera', 'azotonutricia', 'l.', 'azotonutricia', 'l'], 'shortname': 'leaaz'}, '545694': {'common_names': ['treponema', 'primitia', 't.', 'primitia', 't'], 'shortname': 'trepz'}, '875328': {'common_names': ['mycolicibacter', 'sinensis', 'm.', 'sinensis', 'm'], 'shortname': 'mycsd'}, '868595': {'common_names': ['desulfotomaculum', 'nigrificans', 'd.', 'nigrificans', 'd'], 'shortname': 'descc'}, '880724': {'common_names': ['methanotorris', 'igneus', 'm.', 'igneus', 'm'], 'shortname': 'metik'}, '717773': {'common_names': ['thiomicrospira', 'cyclica', 't.', 'cyclica', 't'], 'shortname': 'thica'}, '696281': {'common_names': ['desulforamulus', 'ruminis', 'd.', 'ruminis', 'd'], 'shortname': 'desrl'}, '443218': {'common_names': ['hoyosella', 'subflava', 'h.', 'subflava', 'h'], 'shortname': 'hoysd'}, '743718': {'common_names': ['isoptericola', 'variabilis', 'i.', 'variabilis', 'i'], 'shortname': 'isov2'}, '57278': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv7j'}, '114102': {'common_names': ['frog', 'adenovirus', 'f.', 'adenovirus', 'f'], 'shortname': 'adef1'}, '652963': {'common_names': ['citrus', 'psorosis', 'c.', 'psorosis', 'c'], 'shortname': 'cpsvp'}, '1085623': {'common_names': ['glaciecola', 'nitratireducens', 'g.', 'nitratireducens', 'g'], 'shortname': 'glanf'}, '1008459': {'common_names': ['taylorella', 'asinigenitalis', 't.', 'asinigenitalis', 't'], 'shortname': 'tayam'}, '856793': {'common_names': ['micavibrio', 'aeruginosavorus', 'm.', 'aeruginosavorus', 'm'], 'shortname': 'micaa'}, '2059318': {'common_names': ['ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a'], 'shortname': 'ajecn'}, '1206466': {'common_names': ['wickerhamomyces', 'ciferrii', 'w.', 'ciferrii', 'w'], 'shortname': 'wiccf'}, '634168': {'common_names': ['halorubrum', 'pleomorphic', 'h.', 'pleomorphic', 'h'], 'shortname': 'hapv1'}, '1170229': {'common_names': ['penicillium', 'digitatum', 'p.', 'digitatum', 'p'], 'shortname': 'pend2'}, '1235640': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpm'}, '888064': {'common_names': ['enterococcus', 'italicus', 'e.', 'italicus', 'e'], 'shortname': 'enti1'}, '219305': {'common_names': ['micromonospora', 'sp', 'm.', 'sp', 'm'], 'shortname': 'mics3'}, '1173020': {'common_names': ['chamaesiphon', 'minutus', 'c.', 'minutus', 'c'], 'shortname': 'chap6'}, '28072': {'common_names': ['nostoc', 'sp', 'n.', 'sp', 'n'], 'shortname': 'noss7'}, '195253': {'common_names': ['synechococcus', 'sp', 's.', 'sp', 's'], 'shortname': 'synp3'}, '251229': {'common_names': ['chroococcidiopsis', 'thermalis', 'c.', 'thermalis', 'c'], 'shortname': 'chrtp'}, '42068': {'common_names': ['pneumocystis', 'jirovecii', 'p.', 'jirovecii', 'p'], 'shortname': 'pneji'}, '1246955': {'common_names': ['mycoplasmopsis', 'cynos', 'm.', 'cynos', 'm'], 'shortname': 'mycc1'}, '937777': {'common_names': ['deinococcus', 'peraridilitoris', 'd.', 'peraridilitoris', 'd'], 'shortname': 'deipd'}, '797304': {'common_names': ['natronobacterium', 'gregoryi', 'n.', 'gregoryi', 'n'], 'shortname': 'natgs'}, '1056495': {'common_names': ['caldisphaera', 'lagunensis', 'c.', 'lagunensis', 'c'], 'shortname': 'calld'}, '111780': {'common_names': ['stanieria', 'cyanosphaera', 's.', 'cyanosphaera', 's'], 'shortname': 'stac7'}, '755178': {'common_names': ['cyanobacterium', 'aponinum', 'c.', 'aponinum', 'c'], 'shortname': 'cyaap'}, '65093': {'common_names': ['halothece', 'sp', 'h.', 'sp', 'h'], 'shortname': 'halp7'}, '292563': {'common_names': ['cyanobacterium', 'stanieri', 'c.', 'stanieri', 'c'], 'shortname': 'cyasc'}, '9402': {'common_names': ['pteropus', 'alecto', 'p.', 'alecto', 'p'], 'shortname': 'pteal'}, '225400': {'common_names': ['myotis', 'davidii', 'm.', 'davidii', 'm'], 'shortname': 'myods'}, '986075': {'common_names': ['caldalkalibacillus', 'thermarum', 'c.', 'thermarum', 'c'], 'shortname': 'caltt'}, '717605': {'common_names': ['thermobacillus', 'composti', 't.', 'composti', 't'], 'shortname': 'theck'}, '926556': {'common_names': ['echinicola', 'vietnamensis', 'e.', 'vietnamensis', 'e'], 'shortname': 'echvk'}, '871963': {'common_names': ['desulfitobacterium', 'dichloroeliminans', 'd.', 'dichloroeliminans', 'd'], 'shortname': 'desdl'}, '886293': {'common_names': ['singulisphaera', 'acidiphila', 's.', 'acidiphila', 's'], 'shortname': 'sinad'}, '1215343': {'common_names': ['liberibacter', 'crescens', 'l.', 'crescens', 'l'], 'shortname': 'libcb'}, '1209989': {'common_names': ['tepidanaerobacter', 'acetatoxydans', 't.', 'acetatoxydans', 't'], 'shortname': 'tepae'}, '593750': {'common_names': ['methanoregula', 'formicica', 'm.', 'formicica', 'm'], 'shortname': 'metfs'}, '797303': {'common_names': ['natrinema', 'pellirubrum', 'n.', 'pellirubrum', 'n'], 'shortname': 'natp1'}, '797302': {'common_names': ['halovivax', 'ruber', 'h.', 'ruber', 'h'], 'shortname': 'halrx'}, '908937': {'common_names': ['prevotella', 'dentalis', 'p.', 'dentalis', 'p'], 'shortname': 'predd'}, '867904': {'common_names': ['methanomethylovorans', 'hollandica', 'm.', 'hollandica', 'm'], 'shortname': 'methd'}, '748449': {'common_names': ['halobacteroides', 'halobius', 'h.', 'halobius', 'h'], 'shortname': 'halhc'}, '754035': {'common_names': ['mesorhizobium', 'australicum', 'm.', 'australicum', 'm'], 'shortname': 'mesaw'}, '693444': {'common_names': ['enterobacteriaceae', 'bacterium', 'e.', 'bacterium', 'e'], 'shortname': 'entbf'}, '658429': {'common_names': ['pseudogymnoascus', 'destructans', 'p.', 'destructans', 'p'], 'shortname': 'psed2'}, '948595': {'common_names': ['vavraia', 'culicis', 'v.', 'culicis', 'v'], 'shortname': 'vavcu'}, '993615': {'common_names': ['vittaforma', 'corneae', 'v.', 'corneae', 'v'], 'shortname': 'vitco'}, '905079': {'common_names': ['guillardia', 'theta', 'g.', 'theta', 'g'], 'shortname': 'guitc'}, '1213859': {'common_names': ['colletotrichum', 'fructicola', 'c.', 'fructicola', 'c'], 'shortname': 'colfn'}, '4113': {'common_names': ['solanum', 'tuberosum', 's.', 'tuberosum', 's'], 'shortname': 'soltu'}, '112509': {'common_names': ['hordeum', 'vulgare', 'h.', 'vulgare', 'h'], 'shortname': 'horvv'}, '546271': {'common_names': ['selenomonas', 'sputigena', 's.', 'sputigena', 's'], 'shortname': 'sels3'}, '1121335': {'common_names': ['thermoclostridium', 'stercorarium', 't.', 'stercorarium', 't'], 'shortname': 'thes1'}, '1283346': {'common_names': ['atlantic', 'salmon', 'a.', 'salmon', 'a'], 'shortname': 'aspvr'}, '1283347': {'common_names': ['ferdelance', 'paramyxovirus', 'f.', 'paramyxovirus', 'f'], 'shortname': 'fdlv8'}, '1289384': {'common_names': ['rhizosolenia', 'setigera', 'r.', 'setigera', 'r'], 'shortname': 'rset1'}, '1289385': {'common_names': ['aurantiochytrium', 'singlestranded', 'a.', 'singlestranded', 'a'], 'shortname': 'aurn1'}, '1289386': {'common_names': ['potato', 'virus', 'p.', 'virus', 'p'], 'shortname': 'pvt92'}, '1289474': {'common_names': ['heterocapsa', 'circularisquama', 'h.', 'circularisquama', 'h'], 'shortname': 'hcrna'}, '1289468': {'common_names': ['tobacco', 'vein', 't.', 'vein', 't'], 'shortname': 'tvcvl'}, '1289469': {'common_names': ['providence', 'virus', 'p.', 'virus', 'p'], 'shortname': 'prvfl'}, '674953': {'common_names': ['trichomonas', 'vaginalis', 't.', 'vaginalis', 't'], 'shortname': 'ttv1'}, '658904': {'common_names': ['rosellinia', 'necatrix', 'r.', 'necatrix', 'r'], 'shortname': 'rmbv1'}, '1227494': {'common_names': ['natrinema', 'altunense', 'n.', 'altunense', 'n'], 'shortname': 'nata2'}, '246437': {'common_names': ['tupaia', 'chinensis', 't.', 'chinensis', 't'], 'shortname': 'tupch'}, '29540': {'common_names': ['natrialba', 'asiatica', 'n.', 'asiatica', 'n'], 'shortname': 'nata1'}, '1266370': {'common_names': ['nitrospina', 'gracilis', 'n.', 'gracilis', 'n'], 'shortname': 'nitg3'}, '9685': {'common_names': ['felis', 'catus', 'f.', 'catus', 'f'], 'shortname': 'felca'}, '559515': {'common_names': ['hyaloperonospora', 'arabidopsidis', 'h.', 'arabidopsidis', 'h'], 'shortname': 'hyaae'}, '644358': {'common_names': ['magnaporthiopsis', 'poae', 'm.', 'poae', 'm'], 'shortname': 'magp6'}, '1167006': {'common_names': ['desulfocapsa', 'sulfexigens', 'd.', 'sulfexigens', 'd'], 'shortname': 'dessd'}, '1322246': {'common_names': ['pseudodesulfovibrio', 'piezophilus', 'p.', 'piezophilus', 'p'], 'shortname': 'psep2'}, '51351': {'common_names': ['brassica', 'rapa', 'b.', 'rapa', 'b'], 'shortname': 'brarp'}, '717646': {'common_names': ['baudoinia', 'panamericana', 'b.', 'panamericana', 'b'], 'shortname': 'baupa'}, '1245528': {'common_names': ['candida', 'maltosa', 'c.', 'maltosa', 'c'], 'shortname': 'canmx'}, '572290': {'common_names': ['thrush', 'coronavirus', 't.', 'coronavirus', 't'], 'shortname': 'thcov'}, '1313172': {'common_names': ['ilumatobacter', 'coccineus', 'i.', 'coccineus', 'i'], 'shortname': 'ilucy'}, '268739': {'common_names': ['natronomonas', 'moolapensis', 'n.', 'moolapensis', 'n'], 'shortname': 'natm8'}, '1069680': {'common_names': ['pneumocystis', 'murina', 'p.', 'murina', 'p'], 'shortname': 'pnemu'}, '1151754': {'common_names': ['pseudozyma', 'antarctica', 'p.', 'antarctica', 'p'], 'shortname': 'psea3'}, '2769': {'common_names': ['chondrus', 'crispus', 'c.', 'crispus', 'c'], 'shortname': 'chocr'}, '1054217': {'common_names': ['thermoplasmatales', 'archaeon', 't.', 'archaeon', 't'], 'shortname': 'thexx'}, '1287681': {'common_names': ['eutypa', 'lata', 'e.', 'lata', 'e'], 'shortname': 'eutla'}, '1236689': {'common_names': ['methanomethylophilus', 'alvus', 'm.', 'alvus', 'm'], 'shortname': 'metax'}, '214687': {'common_names': ['musa', 'acuminata', 'm.', 'acuminata', 'm'], 'shortname': 'musam'}, '1123367': {'common_names': ['thauera', 'linaloolentis', 't.', 'linaloolentis', 't'], 'shortname': 'thal4'}, '1287680': {'common_names': ['botryosphaeria', 'parva', 'b.', 'parva', 'b'], 'shortname': 'botpv'}, '1097556': {'common_names': ['taphrina', 'deformans', 't.', 'deformans', 't'], 'shortname': 'tapde'}, '2903': {'common_names': ['emiliania', 'huxleyi', 'e.', 'huxleyi', 'e'], 'shortname': 'emihu'}, '1299270': {'common_names': ['wallemia', 'ichthyophaga', 'w.', 'ichthyophaga', 'w'], 'shortname': 'wali9'}, '1295009': {'common_names': ['methanomassiliicoccus', 'intestinalis', 'm.', 'intestinalis', 'm'], 'shortname': 'metii'}, '1305764': {'common_names': ['pseudozyma', 'hubeiensis', 'p.', 'hubeiensis', 'p'], 'shortname': 'psehs'}, '1286976': {'common_names': ['phaeoacremonium', 'minimum', 'p.', 'minimum', 'p'], 'shortname': 'pham7'}, '1303518': {'common_names': ['chthonomonas', 'calidirosea', 'c.', 'calidirosea', 'c'], 'shortname': 'chtct'}, '1220926': {'common_names': ['mucor', 'circinelloides', 'm.', 'circinelloides', 'm'], 'shortname': 'mucc1'}, '1121939': {'common_names': ['halomonas', 'anticariensis', 'h.', 'anticariensis', 'h'], 'shortname': 'halaf'}, '1213857': {'common_names': ['colletotrichum', 'orbiculare', 'c.', 'orbiculare', 'c'], 'shortname': 'color'}, '126957': {'common_names': ['strigamia', 'maritima', 's.', 'maritima', 's'], 'shortname': 'strmm'}, '283909': {'common_names': ['capitella', 'teleta', 'c.', 'teleta', 'c'], 'shortname': 'capte'}, '1284197': {'common_names': ['dactylellina', 'haptotyla', 'd.', 'haptotyla', 'd'], 'shortname': 'dacha'}, '6412': {'common_names': ['helobdella', 'robusta', 'h.', 'robusta', 'h'], 'shortname': 'helro'}, '36166': {'common_names': ['megaselia', 'scalaris', 'm.', 'scalaris', 'm'], 'shortname': 'megsc'}, '13249': {'common_names': ['rhodnius', 'prolixus', 'r.', 'prolixus', 'r'], 'shortname': 'rhopr'}, '32264': {'common_names': ['tetranychus', 'urticae', 't.', 'urticae', 't'], 'shortname': 'tetur'}, '200361': {'common_names': ['aegilops', 'tauschii', 'a.', 'tauschii', 'a'], 'shortname': 'aegts'}, '4572': {'common_names': ['triticum', 'urartu', 't.', 'urartu', 't'], 'shortname': 'triua'}, '743788': {'common_names': ['fomitopsis', 'pinicola', 'f.', 'pinicola', 'f'], 'shortname': 'fompi'}, '1214242': {'common_names': ['streptomyces', 'collinus', 's.', 'collinus', 's'], 'shortname': 'strc3'}, '546991': {'common_names': ['blumeria', 'graminis', 'b.', 'graminis', 'b'], 'shortname': 'blug1'}, '653667': {'common_names': ['schizosaccharomyces', 'cryophilus', 's.', 'cryophilus', 's'], 'shortname': 'schcr'}, '1237896': {'common_names': ['colletotrichum', 'gloeosporioides', 'c.', 'gloeosporioides', 'c'], 'shortname': 'colgc'}, '1163617': {'common_names': ['sulfuricella', 'denitrificans', 's.', 'denitrificans', 's'], 'shortname': 'sulds'}, '1347342': {'common_names': ['formosa', 'agariphila', 'f.', 'agariphila', 'f'], 'shortname': 'forag'}, '1215092': {'common_names': ['pseudomonas', 'alcaligenes', 'p.', 'alcaligenes', 'p'], 'shortname': 'psea4'}, '1121448': {'common_names': ['megalodesulfovibrio', 'gigas', 'm.', 'gigas', 'm'], 'shortname': 'megg1'}, '59894': {'common_names': ['ficedula', 'albicollis', 'f.', 'albicollis', 'f'], 'shortname': 'fical'}, '8840': {'common_names': ['anas', 'platyrhynchos', 'a.', 'platyrhynchos', 'a'], 'shortname': 'anapp'}, '1279085': {'common_names': ['gibberella', 'fujikuroi', 'g.', 'fujikuroi', 'g'], 'shortname': 'gibf5'}, '1111077': {'common_names': ['claviceps', 'purpurea', 'c.', 'purpurea', 'c'], 'shortname': 'clap2'}, '1116229': {'common_names': ['glarea', 'lozoyensis', 'g.', 'lozoyensis', 'g'], 'shortname': 'glal2'}, '1262450': {'common_names': ['ophiostoma', 'piceae', 'o.', 'piceae', 'o'], 'shortname': 'ophp1'}, '1168221': {'common_names': ['coniosporium', 'apollinis', 'c.', 'apollinis', 'c'], 'shortname': 'cona1'}, '1229664': {'common_names': ['fusarium', 'oxysporum', 'f.', 'oxysporum', 'f'], 'shortname': 'fusc1'}, '2502994': {'common_names': ['fusarium', 'oxysporum', 'f.', 'oxysporum', 'f'], 'shortname': 'fusc4'}, '914234': {'common_names': ['ceriporiopsis', 'subvermispora', 'c.', 'subvermispora', 'c'], 'shortname': 'cers8'}, '692275': {'common_names': ['sphaerulina', 'musiva', 's.', 'musiva', 's'], 'shortname': 'sphms'}, '383855': {'common_names': ['pseudocercospora', 'fijiensis', 'p.', 'fijiensis', 'p'], 'shortname': 'psefd'}, '675120': {'common_names': ['dothistroma', 'septosporum', 'd.', 'septosporum', 'd'], 'shortname': 'dotsn'}, '665912': {'common_names': ['cochliobolus', 'sativus', 'c.', 'sativus', 'c'], 'shortname': 'cocsn'}, '671987': {'common_names': ['exserohilum', 'turcicum', 'e.', 'turcicum', 'e'], 'shortname': 'exst2'}, '701091': {'common_names': ['cochliobolus', 'heterostrophus', 'c.', 'heterostrophus', 'c'], 'shortname': 'coch5'}, '683840': {'common_names': ['microbotryum', 'lychnidisdioicae', 'm.', 'lychnidisdioicae', 'm'], 'shortname': 'ustv1'}, '1381753': {'common_names': ['moniliophthora', 'roreri', 'm.', 'roreri', 'm'], 'shortname': 'monro'}, '104623': {'common_names': ['serratia', 'sp', 's.', 'sp', 's'], 'shortname': 'sers3'}, '13333': {'common_names': ['amborella', 'trichopoda', 'a.', 'trichopoda', 'a'], 'shortname': 'ambtc'}, '1356009': {'common_names': ['byssochlamys', 'spectabilis', 'b.', 'spectabilis', 'b'], 'shortname': 'byssn'}, '1391915': {'common_names': ['sporothrix', 'schenckii', 's.', 'schenckii', 's'], 'shortname': 'spos1'}, '762983': {'common_names': ['succinatimonas', 'hippei', 's.', 'hippei', 's'], 'shortname': 'suchy'}, '7994': {'common_names': ['astyanax', 'mexicanus', 'a.', 'mexicanus', 'a'], 'shortname': 'astmx'}, '7918': {'common_names': ['lepisosteus', 'oculatus', 'l.', 'oculatus', 'l'], 'shortname': 'lepoc'}, '761204': {'common_names': ['phytophthora', 'parasitica', 'p.', 'parasitica', 'p'], 'shortname': 'phypn'}, '1236973': {'common_names': ['alkalihalobacillus', 'akibai', 'a.', 'akibai', 'a'], 'shortname': 'alka3'}, '431944': {'common_names': ['magnetospirillum', 'gryphiswaldense', 'm.', 'gryphiswaldense', 'm'], 'shortname': 'maggm'}, '8665': {'common_names': ['ophiophagus', 'hannah', 'o.', 'hannah', 'o'], 'shortname': 'ophha'}, '1247726': {'common_names': ['advenella', 'mimigardefordensis', 'a.', 'mimigardefordensis', 'a'], 'shortname': 'advmd'}, '57270': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p'], 'shortname': 'plafp'}, '4565': {'common_names': ['triticum', 'aestivum', 't.', 'aestivum', 't'], 'shortname': 'wheat'}, '431595': {'common_names': ['globisporangium', 'ultimum', 'g.', 'ultimum', 'g'], 'shortname': 'gloud'}, '6210': {'common_names': ['echinococcus', 'granulosus', 'e.', 'granulosus', 'e'], 'shortname': 'echgr'}, '1263415': {'common_names': ['endocarpon', 'pusillum', 'e.', 'pusillum', 'e'], 'shortname': 'endpu'}, '911162': {'common_names': ['ophiocordyceps', 'sinensis', 'o.', 'sinensis', 'o'], 'shortname': 'ophsc'}, '933388': {'common_names': ['penicillium', 'oxalicum', 'p.', 'oxalicum', 'p'], 'shortname': 'peno1'}, '1365824': {'common_names': ['kalmanozyma', 'brasiliensis', 'k.', 'brasiliensis', 'k'], 'shortname': 'kalbg'}, '1432307': {'common_names': ['sclerotinia', 'borealis', 's.', 'borealis', 's'], 'shortname': 'sclbf'}, '1388766': {'common_names': ['aspergillus', 'ruber', 'a.', 'ruber', 'a'], 'shortname': 'asprc'}, '522306': {'common_names': ['accumulibacter', 'regalis', 'a.', 'regalis', 'a'], 'shortname': 'accre'}, '1219045': {'common_names': ['sphingobium', 'herbicidovorans', 's.', 'herbicidovorans', 's'], 'shortname': 'sphhm'}, '6282': {'common_names': ['onchocerca', 'volvulus', 'o.', 'volvulus', 'o'], 'shortname': 'oncvo'}, '1215338': {'common_names': ['trichophyton', 'interdigitale', 't.', 'interdigitale', 't'], 'shortname': 'triim'}, '1301098': {'common_names': ['pseudomonas', 'knackmussii', 'p.', 'knackmussii', 'p'], 'shortname': 'psekb'}, '3641': {'common_names': ['theobroma', 'cacao', 't.', 'cacao', 't'], 'shortname': 'thecc'}, '1971': {'common_names': ['streptomyces', 'noursei', 's.', 'noursei', 's'], 'shortname': 'strnr'}, '4537': {'common_names': ['oryza', 'punctata', 'o.', 'punctata', 'o'], 'shortname': 'orypu'}, '1159556': {'common_names': ['ustilaginoidea', 'virens', 'u.', 'virens', 'u'], 'shortname': 'ustvr'}, '2711': {'common_names': ['citrus', 'sinensis', 'c.', 'sinensis', 'c'], 'shortname': 'citsi'}, '136037': {'common_names': ['zootermopsis', 'nevadensis', 'z.', 'nevadensis', 'z'], 'shortname': 'zoone'}, '180498': {'common_names': ['jatropha', 'curcas', 'j.', 'curcas', 'j'], 'shortname': 'jatcu'}, '685588': {'common_names': ['galerina', 'marginata', 'g.', 'marginata', 'g'], 'shortname': 'galm3'}, '1173701': {'common_names': ['colletotrichum', 'sublineola', 'c.', 'sublineola', 'c'], 'shortname': 'colsu'}, '28885': {'common_names': ['hydrogenovibrio', 'marinus', 'h.', 'marinus', 'h'], 'shortname': 'hydmr'}, '1037660': {'common_names': ['tilletiaria', 'anomala', 't.', 'anomala', 't'], 'shortname': 'tilau'}, '796606': {'common_names': ['bacillus', 'methanolicus', 'b.', 'methanolicus', 'b'], 'shortname': 'bacmm'}, '1044': {'common_names': ['erythrobacter', 'longus', 'e.', 'longus', 'e'], 'shortname': 'erylo'}, '1304275': {'common_names': ['salinisphaera', 'hydrothermalis', 's.', 'hydrothermalis', 's'], 'shortname': 'salhc'}, '55952': {'common_names': ['streptomyces', 'toyocaensis', 's.', 'toyocaensis', 's'], 'shortname': 'strto'}, '1283841': {'common_names': ['stachybotrys', 'chlorohalonata', 's.', 'chlorohalonata', 's'], 'shortname': 'stac4'}, '563466': {'common_names': ['pseudallescheria', 'apiosperma', 'p.', 'apiosperma', 'p'], 'shortname': 'pseda'}, '246786': {'common_names': ['metabacillus', 'indicus', 'm.', 'indicus', 'm'], 'shortname': 'metid'}, '1517683': {'common_names': ['chryseobacterium', 'sp', 'c.', 'sp', 'c'], 'shortname': 'chrp1'}, '48698': {'common_names': ['poecilia', 'formosa', 'p.', 'formosa', 'p'], 'shortname': 'poefo'}, '9555': {'common_names': ['papio', 'anubis', 'p.', 'anubis', 'p'], 'shortname': 'papan'}, '258533': {'common_names': ['mycolicibacterium', 'cosmeticum', 'm.', 'cosmeticum', 'm'], 'shortname': 'mycco'}, '3075': {'common_names': ['auxenochlorella', 'protothecoides', 'a.', 'protothecoides', 'a'], 'shortname': 'auxpr'}, '885580': {'common_names': ['fukomys', 'damarensis', 'f.', 'damarensis', 'f'], 'shortname': 'fukda'}, '3708': {'common_names': ['brassica', 'napus', 'b.', 'napus', 'b'], 'shortname': 'brana'}, '50452': {'common_names': ['arabis', 'alpina', 'a.', 'alpina', 'a'], 'shortname': 'araal'}, '44252': {'common_names': ['paenibacillus', 'macerans', 'p.', 'macerans', 'p'], 'shortname': 'paema'}, '1907': {'common_names': ['streptomyces', 'glaucescens', 's.', 'glaucescens', 's'], 'shortname': 'strga'}, '5643': {'common_names': ['pycnoporus', 'cinnabarinus', 'p.', 'cinnabarinus', 'p'], 'shortname': 'pycci'}, '1552985': {'common_names': ['alphamesonivirus', '1', 'a.', '1', 'a'], 'shortname': 'amv79'}, '1554482': {'common_names': ['cadicivirus', 'a', 'c.', 'a', 'c'], 'shortname': 'cadiv'}, '1554495': {'common_names': ['furcraea', 'necrotic', 'f.', 'necrotic', 'f'], 'shortname': 'fnsvc'}, '137556': {'common_names': ['maize', 'necrotic', 'm.', 'necrotic', 'm'], 'shortname': 'mnesv'}, '1557032': {'common_names': ['nyamanini', 'virus', 'n.', 'virus', 'n'], 'shortname': 'nymvt'}, '60714': {'common_names': ['galinsoga', 'mosaic', 'g.', 'mosaic', 'g'], 'shortname': 'gamv'}, '1559359': {'common_names': ['perch', 'rhabdovirus', 'p.', 'rhabdovirus', 'p'], 'shortname': 'prvf'}, '1559360': {'common_names': ['spring', 'viraemia', 's.', 'viraemia', 's'], 'shortname': 'svcva'}, '1559363': {'common_names': ['beet', 'curly', 'b.', 'curly', 'b'], 'shortname': 'bctiv'}, '1559364': {'common_names': ['eragrostis', 'curvula', 'e.', 'curvula', 'e'], 'shortname': 'ecsvg'}, '1559365': {'common_names': ['turnip', 'curly', 't.', 'curly', 't'], 'shortname': 'tctvb'}, '1559366': {'common_names': ['lloviu', 'cuevavirus', 'l.', 'cuevavirus', 'l'], 'shortname': 'llova'}, '591166': {'common_names': ['southern', 'tomato', 's.', 'tomato', 's'], 'shortname': 'stv'}, '1559362': {'common_names': ['quaranfil', 'virus', 'q.', 'virus', 'q'], 'shortname': 'qrfve'}, '857340': {'common_names': ['acremonium', 'chrysogenum', 'a.', 'chrysogenum', 'a'], 'shortname': 'acrc1'}, '60711': {'common_names': ['chlorocebus', 'sabaeus', 'c.', 'sabaeus', 'c'], 'shortname': 'chlsb'}, '3659': {'common_names': ['cucumis', 'sativus', 'c.', 'sativus', 'c'], 'shortname': 'cucsa'}, '40296': {'common_names': ['penicillium', 'italicum', 'p.', 'italicum', 'p'], 'shortname': 'penit'}, '36874': {'common_names': ['porphyromonas', 'cangingivalis', 'p.', 'cangingivalis', 'p'], 'shortname': 'porcn'}, '27334': {'common_names': ['penicillium', 'expansum', 'p.', 'expansum', 'p'], 'shortname': 'penen'}, '2045': {'common_names': ['nocardioides', 'simplex', 'n.', 'simplex', 'n'], 'shortname': 'nocsi'}, '1043005': {'common_names': ['aureobasidium', 'subglaciale', 'a.', 'subglaciale', 'a'], 'shortname': 'aurse'}, '1329250': {'common_names': ['weissella', 'oryzae', 'w.', 'oryzae', 'w'], 'shortname': 'weios'}, '1229662': {'common_names': ['pestalotiopsis', 'fici', 'p.', 'fici', 'p'], 'shortname': 'pesfw'}, '1858805': {'common_names': ['dacryopinax', 'primogenitus', 'd.', 'primogenitus', 'd'], 'shortname': 'dacpd'}, '670483': {'common_names': ['gloeophyllum', 'trabeum', 'g.', 'trabeum', 'g'], 'shortname': 'glota'}, '747525': {'common_names': ['heterobasidion', 'irregulare', 'h.', 'irregulare', 'h'], 'shortname': 'hetit'}, '5843': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p', 'malaria'], 'shortname': 'plafo'}, '130081': {'common_names': ['galdieria', 'sulphuraria', 'g.', 'sulphuraria', 'g'], 'shortname': 'galsu'}, '419612': {'common_names': ['camelus', 'ferus', 'c.', 'ferus', 'c'], 'shortname': 'camfr'}, '85681': {'common_names': ['citrus', 'clementina', 'c.', 'clementina', 'c'], 'shortname': 'citcl'}, '72664': {'common_names': ['eutrema', 'salsugineum', 'e.', 'salsugineum', 'e'], 'shortname': 'eutsa'}, '691883': {'common_names': ['fonticula', 'alba', 'f.', 'alba', 'f'], 'shortname': 'fonal'}, '5835': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p'], 'shortname': 'plafc'}, '71139': {'common_names': ['eucalyptus', 'grandis', 'e.', 'grandis', 'e'], 'shortname': 'eucgr'}, '77166': {'common_names': ['dendroctonus', 'ponderosae', 'd.', 'ponderosae', 'd'], 'shortname': 'denpd'}, '695850': {'common_names': ['saprolegnia', 'parasitica', 's.', 'parasitica', 's'], 'shortname': 'sappc'}, '225164': {'common_names': ['lottia', 'gigantea', 'l.', 'gigantea', 'l'], 'shortname': 'lotgi'}, '4155': {'common_names': ['erythranthe', 'guttata', 'e.', 'guttata', 'e'], 'shortname': 'erygu'}, '988480': {'common_names': ['rozella', 'allomycis', 'r.', 'allomycis', 'r'], 'shortname': 'rozac'}, '1156394': {'common_names': ['saprolegnia', 'diclina', 's.', 'diclina', 's'], 'shortname': 'sapdv'}, '74873': {'common_names': ['anopheles', 'sinensis', 'a.', 'sinensis', 'a'], 'shortname': 'anosi'}, '1081103': {'common_names': ['metarhizium', 'album', 'm.', 'album', 'm'], 'shortname': 'metas'}, '52586': {'common_names': ['uncinula', 'necator', 'u.', 'necator', 'u'], 'shortname': 'uncne'}, '2340': {'common_names': ['solemya', 'velum', 's.', 'velum', 's'], 'shortname': 'sovgs'}, '1267021': {'common_names': ['frischella', 'perrara', 'f.', 'perrara', 'f'], 'shortname': 'fripe'}, '6265': {'common_names': ['toxocara', 'canis', 't.', 'canis', 't'], 'shortname': 'toxca'}, '8469': {'common_names': ['chelonia', 'mydas', 'c.', 'mydas', 'c'], 'shortname': 'chemy'}, '1703': {'common_names': ['brevibacterium', 'linens', 'b.', 'linens', 'b'], 'shortname': 'breln'}, '5851': {'common_names': ['plasmodium', 'knowlesi', 'p.', 'knowlesi', 'p'], 'shortname': 'plakh'}, '8897': {'common_names': ['chaetura', 'pelagica', 'c.', 'pelagica', 'c'], 'shortname': 'chape'}, '1081613': {'common_names': ['streptomyces', 'albus', 's.', 'albus', 's'], 'shortname': 'stra4'}, '1221996': {'common_names': ['bacillus', 'thermotolerans', 'b.', 'thermotolerans', 'b'], 'shortname': 'bactr'}, '98228': {'common_names': ['bacillus', 'sp', 'b.', 'sp', 'b'], 'shortname': 'bacsx'}, '41899': {'common_names': ['burkholderia', 'plantarii', 'b.', 'plantarii', 'b'], 'shortname': 'burpl'}, '1455': {'common_names': ['bacillus', 'badius', 'b.', 'badius', 'b'], 'shortname': 'bacba'}, '2064': {'common_names': ['kitasatospora', 'griseola', 'k.', 'griseola', 'k'], 'shortname': 'kitgr'}, '29730': {'common_names': ['gossypium', 'raimondii', 'g.', 'raimondii', 'g'], 'shortname': 'gosra'}, '103808': {'common_names': ['rhodococcus', 'sp', 'r.', 'sp', 'r'], 'shortname': 'rhosx'}, '451': {'common_names': ['tatlockia', 'micdadei', 't.', 'micdadei', 't'], 'shortname': 'tatmi'}, '1076': {'common_names': ['rhodopseudomonas', 'palustris', 'r.', 'palustris', 'r'], 'shortname': 'rhopl'}, '1486262': {'common_names': ['martelella', 'endophytica', 'm.', 'endophytica', 'm'], 'shortname': 'maren'}, '1288970': {'common_names': ['magnetospira', 'sp', 'm.', 'sp', 'm'], 'shortname': 'magsq'}, '1318466': {'common_names': ['alteracholeplasma', 'palmae', 'a.', 'palmae', 'a'], 'shortname': 'altpj'}, '1006576': {'common_names': ['defluviitoga', 'tunisiensis', 'd.', 'tunisiensis', 'd'], 'shortname': 'deftu'}, '1548': {'common_names': ['clostridium', 'scatologenes', 'c.', 'scatologenes', 'c'], 'shortname': 'closl'}, '698492': {'common_names': ['saitoella', 'complicata', 's.', 'complicata', 's'], 'shortname': 'saicn'}, '5866': {'common_names': ['babesia', 'bigemina', 'b.', 'bigemina', 'b'], 'shortname': 'babbi'}, '68170': {'common_names': ['lentzea', 'aerocolonigenes', 'l.', 'aerocolonigenes', 'l'], 'shortname': 'lenae'}, '1403190': {'common_names': ['aspergillus', 'parasiticus', 'a.', 'parasiticus', 'a'], 'shortname': 'asppu'}, '359131': {'common_names': ['streptomyces', 'rubellomurinus', 's.', 'rubellomurinus', 's'], 'shortname': 'strr3'}, '5544': {'common_names': ['trichoderma', 'harzianum', 't.', 'harzianum', 't'], 'shortname': 'triha'}, '47917': {'common_names': ['serratia', 'fonticola', 's.', 'fonticola', 's'], 'shortname': 'serfo'}, '113540': {'common_names': ['scleropages', 'formosus', 's.', 'formosus', 's'], 'shortname': 'sclfo'}, '88771': {'common_names': ['ceratocystis', 'fimbriata', 'c.', 'fimbriata', 'c'], 'shortname': 'cerfi'}, '34073': {'common_names': ['variovorax', 'paradoxus', 'v.', 'paradoxus', 'v'], 'shortname': 'varpd'}, '75913': {'common_names': ['strongyloides', 'venezuelensis', 's.', 'venezuelensis', 's'], 'shortname': 'strvs'}, '6248': {'common_names': ['strongyloides', 'stercoralis', 's.', 'stercoralis', 's'], 'shortname': 'strer'}, '34506': {'common_names': ['strongyloides', 'ratti', 's.', 'ratti', 's'], 'shortname': 'strrb'}, '3555': {'common_names': ['beta', 'vulgaris', 'b.', 'vulgaris', 'b'], 'shortname': 'betvv'}, '1397': {'common_names': ['niallia', 'circulans', 'n.', 'circulans', 'n'], 'shortname': 'niaci'}, '1800': {'common_names': ['mycolicibacterium', 'chubuense', 'm.', 'chubuense', 'm'], 'shortname': 'myccu'}, '61647': {'common_names': ['pluralibacter', 'gergoviae', 'p.', 'gergoviae', 'p'], 'shortname': 'pluge'}, '1473': {'common_names': ['virgibacillus', 'pantothenticus', 'v.', 'pantothenticus', 'v'], 'shortname': 'virpa'}, '1163406': {'common_names': ['tolypocladium', 'ophioglossoides', 't.', 'ophioglossoides', 't'], 'shortname': 'toloc'}, '29655': {'common_names': ['zostera', 'marina', 'z.', 'marina', 'z'], 'shortname': 'zosmr'}, '7375': {'common_names': ['lucilia', 'cuprina', 'l.', 'cuprina', 'l'], 'shortname': 'luccu'}, '268505': {'common_names': ['ophiocordyceps', 'unilateralis', 'o.', 'unilateralis', 'o'], 'shortname': 'ophun'}, '1503': {'common_names': ['gottschalkia', 'purinilytica', 'g.', 'purinilytica', 'g'], 'shortname': 'gotpu'}, '47500': {'common_names': ['aneurinibacillus', 'migulanus', 'a.', 'migulanus', 'a'], 'shortname': 'anemi'}, '1894': {'common_names': ['kitasatospora', 'aureofaciens', 'k.', 'aureofaciens', 'k'], 'shortname': 'kitau'}, '693': {'common_names': ['vibrio', 'nereis', 'v.', 'nereis', 'v'], 'shortname': 'vibne'}, '1547922': {'common_names': ['ideonella', 'sakaiensis', 'i.', 'sakaiensis', 'i'], 'shortname': 'idesa'}, '179993': {'common_names': ['fusarium', 'langsethiae', 'f.', 'langsethiae', 'f'], 'shortname': 'fusla'}, '37360': {'common_names': ['plasmodiophora', 'brassicae', 'p.', 'brassicae', 'p'], 'shortname': 'plabs'}, '5949': {'common_names': ['stylonychia', 'lemnae', 's.', 'lemnae', 's'], 'shortname': 'style'}, '1169540': {'common_names': ['vitrella', 'brassicaformis', 'v.', 'brassicaformis', 'v'], 'shortname': 'vitbc'}, '162': {'common_names': ['treponema', 'phagedenis', 't.', 'phagedenis', 't'], 'shortname': 'treph'}, '104259': {'common_names': ['penicillium', 'brasilianum', 'p.', 'brasilianum', 'p'], 'shortname': 'penbi'}, '8496': {'common_names': ['alligator', 'mississippiensis', 'a.', 'mississippiensis', 'a'], 'shortname': 'allmi'}, '76728': {'common_names': ['wenjunlia', 'vitaminophila', 'w.', 'vitaminophila', 'w'], 'shortname': 'wenvi'}, '29494': {'common_names': ['vibrio', 'furnissii', 'v.', 'furnissii', 'v'], 'shortname': 'vibfu'}, '53501': {'common_names': ['thalassobius', 'gelatinovorus', 't.', 'gelatinovorus', 't'], 'shortname': 'thage'}, '12930': {'common_names': ['amazona', 'aestiva', 'a.', 'aestiva', 'a'], 'shortname': 'amaae'}, '1629': {'common_names': ['weissella', 'viridescens', 'w.', 'viridescens', 'w'], 'shortname': 'weivi'}, '908809': {'common_names': ['caloramator', 'mitchellensis', 'c.', 'mitchellensis', 'c'], 'shortname': 'calmk'}, '2170141': {'common_names': ['chaetoceros', 'protobacilladnavirus', 'c.', 'protobacilladnavirus', 'c'], 'shortname': 'cpbdv'}, '4790': {'common_names': ['phytophthora', 'nicotianae', 'p.', 'nicotianae', 'p'], 'shortname': 'phyni'}, '57421': {'common_names': ['merops', 'nubicus', 'm.', 'nubicus', 'm'], 'shortname': 'mernu'}, '85066': {'common_names': ['corvus', 'brachyrhynchos', 'c.', 'brachyrhynchos', 'c'], 'shortname': 'corbr'}, '109478': {'common_names': ['myotis', 'brandtii', 'm.', 'brandtii', 'm'], 'shortname': 'myobr'}, '188344': {'common_names': ['leptosomus', 'discolor', 'l.', 'discolor', 'l'], 'shortname': 'lepdc'}, '2015173': {'common_names': ['ooceraea', 'biroi', 'o.', 'biroi', 'o'], 'shortname': 'oocbi'}, '188379': {'common_names': ['egretta', 'garzetta', 'e.', 'garzetta', 'e'], 'shortname': 'egrga'}, '3914': {'common_names': ['phaseolus', 'angularis', 'p.', 'angularis', 'p'], 'shortname': 'phaan'}, '645134': {'common_names': ['spizellomyces', 'punctatus', 's.', 'punctatus', 's'], 'shortname': 'spipd'}, '9209': {'common_names': ['phalacrocorax', 'carbo', 'p.', 'carbo', 'p'], 'shortname': 'phaca'}, '76193': {'common_names': ['papilio', 'machaon', 'p.', 'machaon', 'p'], 'shortname': 'papma'}, '66420': {'common_names': ['papilio', 'xuthus', 'p.', 'xuthus', 'p'], 'shortname': 'papxu'}, '1294122': {'common_names': ['nanobsidianus', 'stetteri', 'n.', 'stetteri', 'n'], 'shortname': 'nanst'}, '128390': {'common_names': ['nipponia', 'nippon', 'n.', 'nippon', 'n'], 'shortname': 'nipni'}, '9233': {'common_names': ['aptenodytes', 'forsteri', 'a.', 'forsteri', 'a'], 'shortname': 'aptfo'}, '732165': {'common_names': ['dichomitus', 'squalens', 'd.', 'squalens', 'd'], 'shortname': 'dicsq'}, '2309': {'common_names': ['pyrodictium', 'occultum', 'p.', 'occultum', 'p'], 'shortname': 'pyroc'}, '1408657': {'common_names': ['pneumocystis', 'jirovecii', 'p.', 'jirovecii', 'p'], 'shortname': 'pnej7'}, '37653': {'common_names': ['octopus', 'bimaculoides', 'o.', 'bimaculoides', 'o'], 'shortname': 'octbm'}, '40382': {'common_names': ['aspergillus', 'ustus', 'a.', 'ustus', 'a'], 'shortname': 'asput'}, '741705': {'common_names': ['coniophora', 'puteana', 'c.', 'puteana', 'c'], 'shortname': 'conpw'}, '30419': {'common_names': ['opisthocomus', 'hoazin', 'o.', 'hoazin', 'o'], 'shortname': 'opiho'}, '57412': {'common_names': ['colius', 'striatus', 'c.', 'striatus', 'c'], 'shortname': 'colst'}, '279965': {'common_names': ['antrostomus', 'carolinensis', 'a.', 'carolinensis', 'a'], 'shortname': 'antcr'}, '97097': {'common_names': ['phaethon', 'lepturus', 'p.', 'lepturus', 'p'], 'shortname': 'phalp'}, '94827': {'common_names': ['tinamus', 'guttatus', 't.', 'guttatus', 't'], 'shortname': 'tingu'}, '121530': {'common_names': ['tauraco', 'erythrolophus', 't.', 'erythrolophus', 't'], 'shortname': 'tauer'}, '51031': {'common_names': ['necator', 'americanus', 'n.', 'americanus', 'n'], 'shortname': 'necam'}, '43455': {'common_names': ['cathartes', 'aura', 'c.', 'aura', 'c'], 'shortname': 'catau'}, '84753': {'common_names': ['pseudozyma', 'antarctica', 'p.', 'antarctica', 'p'], 'shortname': 'psea2'}, '29172': {'common_names': ['dictyocaulus', 'viviparus', 'd.', 'viviparus', 'd'], 'shortname': 'dicvi'}, '30455': {'common_names': ['fulmarus', 'glacialis', 'f.', 'glacialis', 'f'], 'shortname': 'fulga'}, '176057': {'common_names': ['nestor', 'notabilis', 'n.', 'notabilis', 'n'], 'shortname': 'nesno'}, '345573': {'common_names': ['podiceps', 'cristatus', 'p.', 'cristatus', 'p'], 'shortname': 'podcr'}, '50402': {'common_names': ['charadrius', 'vociferus', 'c.', 'vociferus', 'c'], 'shortname': 'chavo'}, '8932': {'common_names': ['columba', 'livia', 'c.', 'livia', 'c'], 'shortname': 'colli'}, '118200': {'common_names': ['dryobates', 'pubescens', 'd.', 'pubescens', 'd'], 'shortname': 'drypu'}, '578459': {'common_names': ['rhodotorula', 'graminis', 'r.', 'graminis', 'r'], 'shortname': 'rhogw'}, '9238': {'common_names': ['pygoscelis', 'adeliae', 'p.', 'adeliae', 'p'], 'shortname': 'pygad'}, '3562': {'common_names': ['spinacia', 'oleracea', 's.', 'oleracea', 's'], 'shortname': 'spiol'}, '54380': {'common_names': ['cariama', 'cristata', 'c.', 'cristata', 'c'], 'shortname': 'caric'}, '36300': {'common_names': ['pelecanus', 'crispus', 'p.', 'crispus', 'p'], 'shortname': 'pelcr'}, '56313': {'common_names': ['tyto', 'alba', 't.', 'alba', 't'], 'shortname': 'tytal'}, '741275': {'common_names': ['punctularia', 'strigosozonata', 'p.', 'strigosozonata', 'p'], 'shortname': 'punst'}, '54383': {'common_names': ['eurypyga', 'helias', 'e.', 'helias', 'e'], 'shortname': 'eurhl'}, '57397': {'common_names': ['apaloderma', 'vittatum', 'a.', 'vittatum', 'a'], 'shortname': 'apavi'}, '945553': {'common_names': ['hypholoma', 'sublateritium', 'h.', 'sublateritium', 'h'], 'shortname': 'hypsf'}, '57267': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p'], 'shortname': 'plaf4'}, '137071': {'common_names': ['plasmodium', 'falciparum', 'p.', 'falciparum', 'p'], 'shortname': 'plafx'}, '212818': {'common_names': ['exophiala', 'mesophila', 'e.', 'mesophila', 'e'], 'shortname': 'exome'}, '9244': {'common_names': ['calypte', 'anna', 'c.', 'anna', 'c'], 'shortname': 'calan'}, '37040': {'common_names': ['gavia', 'stellata', 'g.', 'stellata', 'g'], 'shortname': 'gavst'}, '578462': {'common_names': ['allomyces', 'macrogynus', 'a.', 'macrogynus', 'a'], 'shortname': 'allm3'}, '1603295': {'common_names': ['fungal', 'sp', 'f.', 'sp', 'f'], 'shortname': 'blob1'}, '8969': {'common_names': ['haliaeetus', 'albicilla', 'h.', 'albicilla', 'h'], 'shortname': 'halal'}, '28573': {'common_names': ['talaromyces', 'islandicus', 't.', 'islandicus', 't'], 'shortname': 'talis'}, '77044': {'common_names': ['rosellinia', 'necatrix', 'r.', 'necatrix', 'r'], 'shortname': 'rosne'}, '1869': {'common_names': ['actinoplanes', 'utahensis', 'a.', 'utahensis', 'a'], 'shortname': 'actut'}, '578456': {'common_names': ['tremella', 'mesenterica', 't.', 'mesenterica', 't'], 'shortname': 'trems'}, '105231': {'common_names': ['klebsormidium', 'nitens', 'k.', 'nitens', 'k'], 'shortname': 'kleni'}, '45882': {'common_names': ['trichinella', 'britovi', 't.', 'britovi', 't'], 'shortname': 'tribr'}, '454130': {'common_names': ['aspergillus', 'calidoustus', 'a.', 'calidoustus', 'a'], 'shortname': 'aspci'}, '6334': {'common_names': ['trichinella', 'spiralis', 't.', 'spiralis', 't'], 'shortname': 'trisp'}, '6337': {'common_names': ['trichinella', 'pseudospiralis', 't.', 'pseudospiralis', 't'], 'shortname': 'trips'}, '452': {'common_names': ['legionella', 'spiritensis', 'l.', 'spiritensis', 'l'], 'shortname': 'legsp'}, '266149': {'common_names': ['pseudocohnilembus', 'persalinus', 'p.', 'persalinus', 'p'], 'shortname': 'psepj'}, '948': {'common_names': ['anaplasma', 'phagocytophilum', 'a.', 'phagocytophilum', 'a'], 'shortname': 'anaph'}, '46506': {'common_names': ['bacteroides', 'stercoris', 'b.', 'stercoris', 'b'], 'shortname': 'bacse'}, '1766': {'common_names': ['mycolicibacterium', 'fortuitum', 'm.', 'fortuitum', 'm'], 'shortname': 'mycfo'}, '33050': {'common_names': ['sphingopyxis', 'macrogoltabida', 's.', 'macrogoltabida', 's'], 'shortname': 'sphmc'}, '1495144': {'common_names': ['thermoplasmatales', 'archaeon', 't.', 'archaeon', 't'], 'shortname': 'thex5'}, '121290': {'common_names': ['hyphomicrobium', 'sulfonivorans', 'h.', 'sulfonivorans', 'h'], 'shortname': 'hypsl'}, '1108050': {'common_names': ['thanatephorus', 'cucumeris', 't.', 'cucumeris', 't'], 'shortname': 'thacb'}, '85698': {'common_names': ['alcaligenes', 'xylosoxydans', 'a.', 'xylosoxydans', 'a'], 'shortname': 'alcxx'}, '84531': {'common_names': ['lysobacter', 'antibioticus', 'l.', 'antibioticus', 'l'], 'shortname': 'lysan'}, '278992': {'common_names': ['streptomyces', 'ambofaciens', 's.', 'ambofaciens', 's'], 'shortname': 'stra7'}, '292913': {'common_names': ['sphingopyxis', 'sp', 's.', 'sp', 's'], 'shortname': 'sphs1'}, '69': {'common_names': ['lysobacter', 'enzymogenes', 'l.', 'enzymogenes', 'l'], 'shortname': 'lysen'}, '1736': {'common_names': ['eubacterium', 'limosum', 'e.', 'limosum', 'e'], 'shortname': 'eubli'}, '46677': {'common_names': ['pseudomonas', 'agarici', 'p.', 'agarici', 'p'], 'shortname': 'pseaa'}, '1298851': {'common_names': ['thermosulfidibacter', 'takaii', 't.', 'takaii', 't'], 'shortname': 'thet7'}, '36861': {'common_names': ['thiobacillus', 'denitrificans', 't.', 'denitrificans', 't'], 'shortname': 'thide'}, '1079': {'common_names': ['blastochloris', 'viridis', 'b.', 'viridis', 'b'], 'shortname': 'blavi'}, '1555112': {'common_names': ['limnochorda', 'pilosa', 'l.', 'pilosa', 'l'], 'shortname': 'limpi'}, '52': {'common_names': ['chondromyces', 'crocatus', 'c.', 'crocatus', 'c'], 'shortname': 'choco'}, '42253': {'common_names': ['nitrospira', 'moscoviensis', 'n.', 'moscoviensis', 'n'], 'shortname': 'nitmo'}, '5078': {'common_names': ['penicillium', 'patulum', 'p.', 'patulum', 'p'], 'shortname': 'penpa'}, '465721': {'common_names': ['steroidobacter', 'denitrificans', 's.', 'denitrificans', 's'], 'shortname': 'stede'}, '52283': {'common_names': ['sarcoptes', 'scabiei', 's.', 'scabiei', 's'], 'shortname': 'sarsc'}, '796925': {'common_names': ['conidiobolus', 'coronatus', 'c.', 'coronatus', 'c'], 'shortname': 'conc2'}, '1344416': {'common_names': ['gonapodya', 'prolifera', 'g.', 'prolifera', 'g'], 'shortname': 'gonpj'}, '229533': {'common_names': ['gibberella', 'zeae', 'g.', 'zeae', 'g'], 'shortname': 'gibze'}, '1307': {'common_names': ['streptococcus', 'suis', 's.', 'suis', 's'], 'shortname': 'strsu'}, '5823': {'common_names': ['plasmodium', 'berghei', 'p.', 'berghei', 'p'], 'shortname': 'plaba'}, '189385': {'common_names': ['tremblaya', 'princeps', 't.', 'princeps', 't'], 'shortname': 'trepr'}, '959': {'common_names': ['bdellovibrio', 'bacteriovorus', 'b.', 'bacteriovorus', 'b'], 'shortname': 'bdebc'}, '279360': {'common_names': ['roseivirga', 'ehrenbergii', 'r.', 'ehrenbergii', 'r'], 'shortname': 'rosek'}, '33097': {'common_names': ['gonium', 'pectorale', 'g.', 'pectorale', 'g'], 'shortname': 'gonpe'}, '1828': {'common_names': ['rhodococcus', 'fascians', 'r.', 'fascians', 'r'], 'shortname': 'rhofa'}, '361077': {'common_names': ['tieghemostelium', 'lacteum', 't.', 'lacteum', 't'], 'shortname': 'tiela'}, '1855912': {'common_names': ['luteitalea', 'pratensis', 'l.', 'pratensis', 'l'], 'shortname': 'lutpr'}, '39966': {'common_names': ['hypsizygus', 'marmoreus', 'h.', 'marmoreus', 'h'], 'shortname': 'hypma'}, '1794912': {'common_names': ['anaerosporomusa', 'subterranea', 'a.', 'subterranea', 'a'], 'shortname': 'anasb'}, '30069': {'common_names': ['anopheles', 'stephensi', 'a.', 'stephensi', 'a'], 'shortname': 'anost'}, '178035': {'common_names': ['dufourea', 'novaeangliae', 'd.', 'novaeangliae', 'd'], 'shortname': 'dufno'}, '1328760': {'common_names': ['xylona', 'heveae', 'x.', 'heveae', 'x'], 'shortname': 'xylht'}, '1330018': {'common_names': ['calocera', 'viscosa', 'c.', 'viscosa', 'c'], 'shortname': 'calvf'}, '1081104': {'common_names': ['cordyceps', 'fumosorosea', 'c.', 'fumosorosea', 'c'], 'shortname': 'corfa'}, '5454': {'common_names': ['didymella', 'rabiei', 'd.', 'rabiei', 'd'], 'shortname': 'didra'}, '403673': {'common_names': ['batrachochytrium', 'dendrobatidis', 'b.', 'dendrobatidis', 'b'], 'shortname': 'batdl'}, '5599': {'common_names': ['alternaria', 'alternata', 'a.', 'alternata', 'a'], 'shortname': 'altal'}, '763407': {'common_names': ['phycomyces', 'blakesleeanus', 'p.', 'blakesleeanus', 'p'], 'shortname': 'phyb8'}, '1727196': {'common_names': ['methylomonas', 'sp', 'm.', 'sp', 'm'], 'shortname': 'metsd'}, '79200': {'common_names': ['daucus', 'carota', 'd.', 'carota', 'd'], 'shortname': 'daucs'}, '33203': {'common_names': ['purpureocillium', 'lilacinum', 'p.', 'lilacinum', 'p'], 'shortname': 'purli'}, '478820': {'common_names': ['blastocystis', 'sp', 'b.', 'sp', 'b'], 'shortname': 'blahn'}, '36856': {'common_names': ['sinorhizobium', 'saheli', 's.', 'saheli', 's'], 'shortname': 'sinsa'}, '417368': {'common_names': ['enterococcus', 'thailandicus', 'e.', 'thailandicus', 'e'], 'shortname': 'entth'}, '4829': {'common_names': ['absidia', 'glauca', 'a.', 'glauca', 'a'], 'shortname': 'absgl'}, '121845': {'common_names': ['diaphorina', 'citri', 'd.', 'citri', 'd'], 'shortname': 'diaci'}, '9365': {'common_names': ['erinaceus', 'europaeus', 'e.', 'europaeus', 'e'], 'shortname': 'erieu'}, '10020': {'common_names': ['dipodomys', 'ordii', 'd.', 'ordii', 'd'], 'shortname': 'dipor'}, '4097': {'common_names': ['nicotiana', 'tabacum', 'n.', 'tabacum', 'n'], 'shortname': 'tobac'}, '7574': {'common_names': ['lingula', 'unguis', 'l.', 'unguis', 'l'], 'shortname': 'linun'}, '3827': {'common_names': ['cicer', 'arietinum', 'c.', 'arietinum', 'c'], 'shortname': 'cicar'}, '8030': {'common_names': ['salmo', 'salar', 's.', 'salar', 's'], 'shortname': 'salsa'}, '3916': {'common_names': ['vigna', 'radiata', 'v.', 'radiata', 'v'], 'shortname': 'vigrr'}, '3656': {'common_names': ['cucumis', 'melo', 'c.', 'melo', 'c'], 'shortname': 'cucme'}, '36050': {'common_names': ['fusarium', 'poae', 'f.', 'poae', 'f'], 'shortname': 'fuspo'}, '56216': {'common_names': ['neotoma', 'lepida', 'n.', 'lepida', 'n'], 'shortname': 'neole'}, '1915': {'common_names': ['streptomyces', 'lincolnensis', 's.', 'lincolnensis', 's'], 'shortname': 'strln'}, '4615': {'common_names': ['ananas', 'comosus', 'a.', 'comosus', 'a'], 'shortname': 'anaco'}, '478': {'common_names': ['moraxella', 'nonliquefaciens', 'm.', 'nonliquefaciens', 'm'], 'shortname': 'morno'}, '5627': {'common_names': ['grifola', 'frondosa', 'g.', 'frondosa', 'g'], 'shortname': 'grifr'}, '1790': {'common_names': ['mycobacterium', 'asiaticum', 'm.', 'asiaticum', 'm'], 'shortname': 'mycas'}, '683960': {'common_names': ['wickerhamomyces', 'anomalus', 'w.', 'anomalus', 'w'], 'shortname': 'wicaa'}, '983966': {'common_names': ['cyberlindnera', 'jadinii', 'c.', 'jadinii', 'c'], 'shortname': 'cybjn'}, '48709': {'common_names': ['orchesella', 'cincta', 'o.', 'cincta', 'o'], 'shortname': 'orcci'}, '573508': {'common_names': ['aspergillus', 'cristatus', 'a.', 'cristatus', 'a'], 'shortname': 'aspcr'}, '1613': {'common_names': ['limosilactobacillus', 'fermentum', 'l.', 'fermentum', 'l'], 'shortname': 'limfe'}, '28445': {'common_names': ['mycobacterium', 'intermedium', 'm.', 'intermedium', 'm'], 'shortname': 'mycie'}, '1408204': {'common_names': ['endomicrobium', 'trichonymphae', 'e.', 'trichonymphae', 'e'], 'shortname': 'endtx'}, '7209': {'common_names': ['loa', 'loa', 'l.', 'loa', 'l'], 'shortname': 'loalo'}, '29833': {'common_names': ['hanseniaspora', 'uvarum', 'h.', 'uvarum', 'h'], 'shortname': 'hanuv'}, '1267': {'common_names': ['sarcina', 'ventriculi', 's.', 'ventriculi', 's'], 'shortname': 'sarve'}, '33708': {'common_names': ['murid', 'herpesvirus', 'm.', 'herpesvirus', 'm'], 'shortname': 'mhv68'}, '38143': {'common_names': ['simian', 'hemorrhagic', 's.', 'hemorrhagic', 's'], 'shortname': 'shfv'}, '203172': {'common_names': ['camelpox', 'virus', 'c.', 'virus', 'c'], 'shortname': 'camps'}, '10385': {'common_names': ['bovine', 'herpesvirus', 'b.', 'herpesvirus', 'b'], 'shortname': 'bhv4'}, '10529': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade31'}, '10298': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv1'}, '10325': {'common_names': ['cercopithecine', 'herpesvirus', 'c.', 'herpesvirus', 'c'], 'shortname': 'chv1'}, '31545': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade08'}, '10942': {'common_names': ['rotavirus', 'b', 'r.', 'b', 'r'], 'shortname': 'rotga'}, '28344': {'common_names': ['porcine', 'reproductive', 'p.', 'reproductive', 'p'], 'shortname': 'prrsv'}, '50292': {'common_names': ['simian', 'cytomegalovirus', 's.', 'cytomegalovirus', 's'], 'shortname': 'scmvc'}, '10514': {'common_names': ['canine', 'adenovirus', 'c.', 'adenovirus', 'c'], 'shortname': 'adec2'}, '10366': {'common_names': ['murid', 'herpesvirus', 'm.', 'herpesvirus', 'm'], 'shortname': 'muhv1'}, '694015': {'common_names': ['beluga', 'whale', 'b.', 'whale', 'b'], 'shortname': 'bwcov'}, '10353': {'common_names': ['saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's'], 'shortname': 'shv1'}, '1261657': {'common_names': ['rat', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r'], 'shortname': 'rcmve'}, '146015': {'common_names': ['elephantid', 'herpesvirus', 'e.', 'herpesvirus', 'e'], 'shortname': 'elhv1'}, '10258': {'common_names': ['orf', 'virus', 'o.', 'virus', 'o'], 'shortname': 'orfv'}, '10397': {'common_names': ['tupaiid', 'herpesvirus', 't.', 'herpesvirus', 't'], 'shortname': 'tuhv1'}, '46916': {'common_names': ['equine', 'adenovirus', 'e.', 'adenovirus', 'e'], 'shortname': 'adee1'}, '10528': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade18'}, '1003835': {'common_names': ['dabie', 'bandavirus', 'd.', 'bandavirus', 'd'], 'shortname': 'sfts'}, '10386': {'common_names': ['infectious', 'laryngotracheitis', 'i.', 'laryngotracheitis', 'i'], 'shortname': 'iltv'}, '31612': {'common_names': ['adelaide', 'river', 'a.', 'river', 'a'], 'shortname': 'arv'}, '10334': {'common_names': ['feline', 'herpesvirus', 'f.', 'herpesvirus', 'f'], 'shortname': 'fhv1'}, '11660': {'common_names': ['caprine', 'arthritis', 'c.', 'arthritis', 'c'], 'shortname': 'caev'}, '36348': {'common_names': ['cercopithecine', 'herpesvirus', 'c.', 'herpesvirus', 'c'], 'shortname': 'chv9d'}, '10253': {'common_names': ['vaccinia', 'virus', 'v.', 'virus', 'v'], 'shortname': 'vacct'}, '10381': {'common_names': ['saimiriine', 'herpesvirus', 's.', 'herpesvirus', 's'], 'shortname': 'shv2'}, '28280': {'common_names': ['human', 'adenovirus', 'h.', 'adenovirus', 'h'], 'shortname': 'ade04'}, '31519': {'common_names': ['bovine', 'herpesvirus', 'b.', 'herpesvirus', 'b'], 'shortname': 'bhv1k'}, '11048': {'common_names': ['lactate', 'dehydrogenaseelevating', 'l.', 'dehydrogenaseelevating', 'l'], 'shortname': 'ldv'}, '37108': {'common_names': ['meleagrid', 'herpesvirus', 'm.', 'herpesvirus', 'm'], 'shortname': 'mehv1'}, '955': {'common_names': ['wolbachia', 'pipientis', 'w.', 'pipientis', 'w'], 'shortname': 'wolpi'}, '915059': {'common_names': ['flammeovirga', 'pacifica', 'f.', 'pacifica', 'f'], 'shortname': 'flapc'}, '197772': {'common_names': ['psittacus', 'erithacus', 'p.', 'erithacus', 'p'], 'shortname': 'pepv'}, '29542': {'common_names': ['syntrophotalea', 'acetylenica', 's.', 'acetylenica', 's'], 'shortname': 'synac'}, '41': {'common_names': ['stigmatella', 'aurantiaca', 's.', 'aurantiaca', 's'], 'shortname': 'stiau'}, '1525': {'common_names': ['moorella', 'thermoacetica', 'm.', 'thermoacetica', 'm'], 'shortname': 'mooth'}, '971': {'common_names': ['selenomonas', 'ruminantium', 's.', 'ruminantium', 's'], 'shortname': 'selru'}, '1082': {'common_names': ['magnetospirillum', 'fulvum', 'm.', 'fulvum', 'm'], 'shortname': 'magfu'}, '235985': {'common_names': ['streptacidiphilus', 'jiangxiensis', 's.', 'jiangxiensis', 's'], 'shortname': 'strji'}, '211114': {'common_names': ['allokutzneria', 'albata', 'a.', 'albata', 'a'], 'shortname': 'allab'}, '1073325': {'common_names': ['salegentibacter', 'echinorum', 's.', 'echinorum', 's'], 'shortname': 'salec'}, '1137211': {'common_names': ['aspergillus', 'luchuensis', 'a.', 'luchuensis', 'a'], 'shortname': 'asplc'}, '154538': {'common_names': ['trametes', 'pubescens', 't.', 'pubescens', 't'], 'shortname': 'trapu'}, '1848': {'common_names': ['pseudonocardia', 'thermophila', 'p.', 'thermophila', 'p'], 'shortname': 'pseth'}, '767769': {'common_names': ['aspergillus', 'brasiliensis', 'a.', 'brasiliensis', 'a'], 'shortname': 'aspbc'}, '2017': {'common_names': ['streptoalloteichus', 'hindustanus', 's.', 'hindustanus', 's'], 'shortname': 'strhi'}, '690307': {'common_names': ['aspergillus', 'aculeatus', 'a.', 'aculeatus', 'a'], 'shortname': 'aspa1'}, '28028': {'common_names': ['corynebacterium', 'flavescens', 'c.', 'flavescens', 'c'], 'shortname': 'corfl'}, '1230383': {'common_names': ['malassezia', 'sympodialis', 'm.', 'sympodialis', 'm'], 'shortname': 'mals4'}, '526': {'common_names': ['acidiphilium', 'rubrum', 'a.', 'rubrum', 'a'], 'shortname': 'aciru'}, '1326': {'common_names': ['streptococcus', 'acidominimus', 's.', 'acidominimus', 's'], 'shortname': 'strai'}, '1198029': {'common_names': ['neolecta', 'irregularis', 'n.', 'irregularis', 'n'], 'shortname': 'neoid'}, '8355': {'common_names': ['xenopus', 'laevis', 'x.', 'laevis', 'x'], 'shortname': 'xenla'}, '947166': {'common_names': ['ramazzottius', 'varieornatus', 'r.', 'varieornatus', 'r'], 'shortname': 'ramva'}, '49451': {'common_names': ['nicotiana', 'attenuata', 'n.', 'attenuata', 'n'], 'shortname': 'nicat'}, '210143': {'common_names': ['corchorus', 'capsularis', 'c.', 'capsularis', 'c'], 'shortname': 'cocap'}, '602072': {'common_names': ['aspergillus', 'carbonarius', 'a.', 'carbonarius', 'a'], 'shortname': 'aspc5'}, '3871': {'common_names': ['lupinus', 'angustifolius', 'l.', 'angustifolius', 'l'], 'shortname': 'lupan'}, '5353': {'common_names': ['lentinula', 'edodes', 'l.', 'edodes', 'l'], 'shortname': 'lened'}, '435': {'common_names': ['acetobacter', 'aceti', 'a.', 'aceti', 'a'], 'shortname': 'aceac'}, '238': {'common_names': ['elizabethkingia', 'meningoseptica', 'e.', 'meningoseptica', 'e'], 'shortname': 'elime'}, '36022': {'common_names': ['cyberlindnera', 'fabianii', 'c.', 'fabianii', 'c'], 'shortname': 'cybfa'}, '4096': {'common_names': ['nicotiana', 'sylvestris', 'n.', 'sylvestris', 'n'], 'shortname': 'nicsy'}, '3635': {'common_names': ['gossypium', 'hirsutum', 'g.', 'hirsutum', 'g'], 'shortname': 'goshi'}, '4432': {'common_names': ['nelumbo', 'nucifera', 'n.', 'nucifera', 'n'], 'shortname': 'nelnu'}, '1868482': {'common_names': ['carlito', 'syrichta', 'c.', 'syrichta', 'c'], 'shortname': 'carsf'}, '38654': {'common_names': ['alligator', 'sinensis', 'a.', 'sinensis', 'a'], 'shortname': 'allsi'}, '10036': {'common_names': ['mesocricetus', 'auratus', 'm.', 'auratus', 'm'], 'shortname': 'mesau'}, '966': {'common_names': ['oceanospirillum', 'linum', 'o.', 'linum', 'o'], 'shortname': 'oceli'}, '5062': {'common_names': ['aspergillus', 'oryzae', 'a.', 'oryzae', 'a'], 'shortname': 'aspoz'}, '261392': {'common_names': ['treponema', 'porcinum', 't.', 'porcinum', 't'], 'shortname': 'trepo'}, '28066': {'common_names': ['rhodoferax', 'fermentans', 'r.', 'fermentans', 'r'], 'shortname': 'rhofe'}, '4955': {'common_names': ['lachancea', 'fermentati', 'l.', 'fermentati', 'l'], 'shortname': 'lacfm'}, '60169': {'common_names': ['penicillium', 'polonicum', 'p.', 'polonicum', 'p'], 'shortname': 'penpo'}, '69771': {'common_names': ['penicillium', 'decumbens', 'p.', 'decumbens', 'p'], 'shortname': 'pendc'}, '48256': {'common_names': ['ruminiclostridium', 'hungatei', 'r.', 'hungatei', 'r'], 'shortname': 'rumhu'}, '60175': {'common_names': ['penicillium', 'nalgiovense', 'p.', 'nalgiovense', 'p'], 'shortname': 'penna'}, '52670': {'common_names': ['austrofundulus', 'limnaeus', 'a.', 'limnaeus', 'a'], 'shortname': 'ausli'}, '224129': {'common_names': ['agrilus', 'planipennis', 'a.', 'planipennis', 'a'], 'shortname': 'agrpl'}, '692418': {'common_names': ['reichenbachiella', 'faecimaris', 'r.', 'faecimaris', 'r'], 'shortname': 'reifa'}, '53376': {'common_names': ['mycobacterium', 'heidelbergense', 'm.', 'heidelbergense', 'm'], 'shortname': 'myche'}, '687388': {'common_names': ['saccharomonospora', 'piscinae', 's.', 'piscinae', 's'], 'shortname': 'sacpi'}, '929705': {'common_names': ['sulfobacillus', 'thermosulfidooxidans', 's.', 'thermosulfidooxidans', 's'], 'shortname': 'sulta'}, '2030': {'common_names': ['kibdelosporangium', 'aridum', 'k.', 'aridum', 'k'], 'shortname': 'kibar'}, '28094': {'common_names': ['trinickia', 'caryophylli', 't.', 'caryophylli', 't'], 'shortname': 'tricw'}, '105696': {'common_names': ['epicoccum', 'nigrum', 'e.', 'nigrum', 'e'], 'shortname': 'eping'}, '8022': {'common_names': ['oncorhynchus', 'mykiss', 'o.', 'mykiss', 'o'], 'shortname': 'oncmy'}, '1793': {'common_names': ['mycolicibacterium', 'fallax', 'm.', 'fallax', 'm'], 'shortname': 'mycfa'}, '2754530': {'common_names': ['protomyces', 'lactucaedebilis', 'p.', 'lactucaedebilis', 'p'], 'shortname': 'prolt'}, '28045': {'common_names': ['mycobacterium', 'celatum', 'm.', 'celatum', 'm'], 'shortname': 'mycce'}, '56425': {'common_names': ['mycobacterium', 'bohemicum', 'm.', 'bohemicum', 'm'], 'shortname': 'mycbe'}, '2074': {'common_names': ['pseudonocardia', 'autotrophica', 'p.', 'autotrophica', 'p'], 'shortname': 'pseah'}, '107327': {'common_names': ['pseudoalteromonas', 'ulvae', 'p.', 'ulvae', 'p'], 'shortname': 'psedv'}, '33013': {'common_names': ['clavibacter', 'michiganensis', 'c.', 'michiganensis', 'c'], 'shortname': 'clamm'}, '77519': {'common_names': ['plasmodium', 'gonderi', 'p.', 'gonderi', 'p'], 'shortname': 'plago'}, '73868': {'common_names': ['piromyces', 'sp', 'p.', 'sp', 'p'], 'shortname': 'pirse'}, '47858': {'common_names': ['micromonospora', 'echinofusca', 'm.', 'echinofusca', 'm'], 'shortname': 'miceh'}, '158441': {'common_names': ['folsomia', 'candida', 'f.', 'candida', 'f'], 'shortname': 'folca'}, '9009': {'common_names': ['callipepla', 'squamata', 'c.', 'squamata', 'c'], 'shortname': 'calsu'}, '447679': {'common_names': ['ekhidna', 'lutea', 'e.', 'lutea', 'e'], 'shortname': 'ekhlu'}, '63740': {'common_names': ['halorubrum', 'vacuolatum', 'h.', 'vacuolatum', 'h'], 'shortname': 'halvu'}, '1519565': {'common_names': ['fistulifera', 'solaris', 'f.', 'solaris', 'f'], 'shortname': 'fisso'}, '1074': {'common_names': ['rhodoblastus', 'acidophilus', 'r.', 'acidophilus', 'r'], 'shortname': 'rhoac'}, '9014': {'common_names': ['colinus', 'virginianus', 'c.', 'virginianus', 'c'], 'shortname': 'colvi'}, '1038014': {'common_names': ['aquimarina', 'amphilecti', 'a.', 'amphilecti', 'a'], 'shortname': 'aquam'}, '61595': {'common_names': ['allochromatium', 'warmingii', 'a.', 'warmingii', 'a'], 'shortname': 'allwa'}, '1285928': {'common_names': ['niabella', 'drilacis', 'n.', 'drilacis', 'n'], 'shortname': 'niade'}, '152573': {'common_names': ['alkalimonas', 'amylolytica', 'a.', 'amylolytica', 'a'], 'shortname': 'alkam'}, '283786': {'common_names': ['bizionia', 'paragorgiae', 'b.', 'paragorgiae', 'b'], 'shortname': 'bizpa'}, '366584': {'common_names': ['pseudonocardia', 'oroxyli', 'p.', 'oroxyli', 'p'], 'shortname': 'pseor'}, '2741': {'common_names': ['peptococcus', 'niger', 'p.', 'niger', 'p'], 'shortname': 'pepni'}, '5286': {'common_names': ['rhodosporidium', 'toruloides', 'r.', 'toruloides', 'r'], 'shortname': 'rhoto'}, '1732': {'common_names': ['eubacterium', 'oxidoreducens', 'e.', 'oxidoreducens', 'e'], 'shortname': 'eubox'}, '349064': {'common_names': ['thalassotalea', 'agarivorans', 't.', 'agarivorans', 't'], 'shortname': 'thasx'}, '195064': {'common_names': ['ectothiorhodospira', 'mobilis', 'e.', 'mobilis', 'e'], 'shortname': 'ectmo'}, '260086': {'common_names': ['pseudonocardia', 'ammonioxydans', 'p.', 'ammonioxydans', 'p'], 'shortname': 'psuam'}, '63': {'common_names': ['vitreoscilla', 'filiformis', 'v.', 'filiformis', 'v'], 'shortname': 'vitfi'}, '12194': {'common_names': ['lily', 'virus', 'l.', 'virus', 'l'], 'shortname': 'lvx'}, '12294': {'common_names': ['pea', 'early', 'p.', 'early', 'p'], 'shortname': 'pebv'}, '11986': {'common_names': ['carnation', 'mottle', 'c.', 'mottle', 'c'], 'shortname': 'carmv'}, '12182': {'common_names': ['potato', 'aucuba', 'p.', 'aucuba', 'p'], 'shortname': 'pamv'}, '31503': {'common_names': ['maize', 'white', 'm.', 'white', 'm'], 'shortname': 'mwlmv'}, '12142': {'common_names': ['artichoke', 'mottled', 'a.', 'mottled', 'a'], 'shortname': 'amcv'}, '35306': {'common_names': ['simbu', 'virus', 's.', 'virus', 's'], 'shortname': 'simbu'}, '11901': {'common_names': ['bovine', 'leukemia', 'b.', 'leukemia', 'b'], 'shortname': 'blv'}, '12165': {'common_names': ['chrysanthemum', 'virus', 'c.', 'virus', 'c'], 'shortname': 'cvb'}, '31723': {'common_names': ['barley', 'yellow', 'b.', 'yellow', 'b'], 'shortname': 'bydv1'}, '12056': {'common_names': ['tobacco', 'necrosis', 't.', 'necrosis', 't'], 'shortname': 'tnvd'}, '213888': {'common_names': ['dahlia', 'mosaic', 'd.', 'mosaic', 'd'], 'shortname': 'dmv'}, '364030': {'common_names': ['thiomonas', 'delicata', 't.', 'delicata', 't'], 'shortname': 'thidl'}, '1977292': {'common_names': ['paenibacillus', 'xerothermodurans', 'p.', 'xerothermodurans', 'p'], 'shortname': 'paexe'}, '39478': {'common_names': ['streptomyces', 'laurentii', 's.', 'laurentii', 's'], 'shortname': 'strlu'}, '2786': {'common_names': ['porphyra', 'umbilicalis', 'p.', 'umbilicalis', 'p'], 'shortname': 'porum'}, '7102': {'common_names': ['heliothis', 'virescens', 'h.', 'virescens', 'h'], 'shortname': 'helvi'}, '742152': {'common_names': ['wolfiporia', 'cocos', 'w.', 'cocos', 'w'], 'shortname': 'wolco'}, '1052': {'common_names': ['halorhodospira', 'halochloris', 'h.', 'halochloris', 'h'], 'shortname': 'halhr'}, '47428': {'common_names': ['armillaria', 'ostoyae', 'a.', 'ostoyae', 'a'], 'shortname': 'armos'}, '558529': {'common_names': ['natronoarchaeum', 'philippinense', 'n.', 'philippinense', 'n'], 'shortname': 'natpi'}, '5858': {'common_names': ['plasmodium', 'malariae', 'p.', 'malariae', 'p'], 'shortname': 'plama'}, '85471': {'common_names': ['plasmodium', 'relictum', 'p.', 'relictum', 'p'], 'shortname': 'plarl'}, '32013': {'common_names': ['comamonas', 'terrigena', 'c.', 'terrigena', 'c'], 'shortname': 'comtr'}, '36811': {'common_names': ['mycolicibacterium', 'agri', 'm.', 'agri', 'm'], 'shortname': 'mycag'}, '174633': {'common_names': ['kuenenia', 'stuttgartiensis', 'k.', 'stuttgartiensis', 'k'], 'shortname': 'kuest'}, '29539': {'common_names': ['thermoleophilum', 'album', 't.', 'album', 't'], 'shortname': 'theal'}, '53446': {'common_names': ['streptomyces', 'cinnamoneus', 's.', 'cinnamoneus', 's'], 'shortname': 'strcj'}, '4072': {'common_names': ['capsicum', 'annuum', 'c.', 'annuum', 'c'], 'shortname': 'capan'}, '2761530': {'common_names': ['chloroflexi', 'bacterium', 'c.', 'bacterium', 'c'], 'shortname': 'chlb2'}, '1122177': {'common_names': ['flavilitoribacter', 'nigricans', 'f.', 'nigricans', 'f'], 'shortname': 'flan2'}, '80379': {'common_names': ['capsicum', 'chinense', 'c.', 'chinense', 'c'], 'shortname': 'capch'}, '33114': {'common_names': ['capsicum', 'baccatum', 'c.', 'baccatum', 'c'], 'shortname': 'capba'}, '50429': {'common_names': ['stylophora', 'pistillata', 's.', 'pistillata', 's'], 'shortname': 'stypi'}, '42345': {'common_names': ['phoenix', 'dactylifera', 'p.', 'dactylifera', 'p'], 'shortname': 'phodc'}, '6192': {'common_names': ['fasciola', 'hepatica', 'f.', 'hepatica', 'f'], 'shortname': 'fashe'}, '218851': {'common_names': ['aquilegia', 'coerulea', 'a.', 'coerulea', 'a'], 'shortname': 'aquca'}, '498019': {'common_names': ['candida', 'auris', 'c.', 'auris', 'c'], 'shortname': 'canar'}, '307972': {'common_names': ['stichopus', 'japonicus', 's.', 'japonicus', 's'], 'shortname': 'stija'}, '193121': {'common_names': ['pea', 'enation', 'p.', 'enation', 'p'], 'shortname': 'pemv1'}, '650121': {'common_names': ['heterocapsa', 'circularisquama', 'h.', 'circularisquama', 'h'], 'shortname': 'hcv01'}, '11274': {'common_names': ['piry', 'virus', 'p.', 'virus', 'p'], 'shortname': 'piryv'}, '37293': {'common_names': ['aotus', 'nancymaae', 'a.', 'nancymaae', 'a'], 'shortname': 'aotna'}, '2715852': {'common_names': ['cebus', 'imitator', 'c.', 'imitator', 'c'], 'shortname': 'cebim'}, '9531': {'common_names': ['cercocebus', 'atys', 'c.', 'atys', 'c'], 'shortname': 'cerat'}, '336983': {'common_names': ['colobus', 'angolensis', 'c.', 'angolensis', 'c'], 'shortname': 'colap'}, '9541': {'common_names': ['macaca', 'fascicularis', 'm.', 'fascicularis', 'm'], 'shortname': 'macfa'}, '9545': {'common_names': ['macaca', 'nemestrina', 'm.', 'nemestrina', 'm'], 'shortname': 'macne'}, '9568': {'common_names': ['mandrillus', 'leucophaeus', 'm.', 'leucophaeus', 'm'], 'shortname': 'manle'}, '379532': {'common_names': ['propithecus', 'coquereli', 'p.', 'coquereli', 'p'], 'shortname': 'proco'}, '61621': {'common_names': ['rhinopithecus', 'bieti', 'r.', 'bieti', 'r'], 'shortname': 'rhibe'}, '61622': {'common_names': ['rhinopithecus', 'roxellana', 'r.', 'roxellana', 'r'], 'shortname': 'rhiro'}, '39432': {'common_names': ['saimiri', 'boliviensis', 's.', 'boliviensis', 's'], 'shortname': 'saibb'}, '1392255': {'common_names': ['aspergillus', 'novofumigatus', 'a.', 'novofumigatus', 'a'], 'shortname': 'aspn1'}, '41067': {'common_names': ['aspergillus', 'candidus', 'a.', 'candidus', 'a'], 'shortname': 'aspcn'}, '4236': {'common_names': ['lactuca', 'sativa', 'l.', 'sativa', 'l'], 'shortname': 'lacsa'}, '51240': {'common_names': ['juglans', 'regia', 'j.', 'regia', 'j'], 'shortname': 'jugre'}, '960': {'common_names': ['bacteriovorax', 'stolpii', 'b.', 'stolpii', 'b'], 'shortname': 'bactc'}, '176275': {'common_names': ['beauveria', 'bassiana', 'b.', 'bassiana', 'b'], 'shortname': 'beaba'}, '685': {'common_names': ['vibrio', 'diazotrophicus', 'v.', 'diazotrophicus', 'v'], 'shortname': 'vibdi'}, '1564487': {'common_names': ['herbinix', 'hemicellulosilytica', 'h.', 'hemicellulosilytica', 'h'], 'shortname': 'herhm'}, '92644': {'common_names': ['streptomyces', 'malaysiensis', 's.', 'malaysiensis', 's'], 'shortname': 'strmq'}, '37482': {'common_names': ['laceyella', 'sacchari', 'l.', 'sacchari', 'l'], 'shortname': 'lacsh'}, '55188': {'common_names': ['citrus', 'unshiu', 'c.', 'unshiu', 'c'], 'shortname': 'citun'}, '42673': {'common_names': ['gibberella', 'nygamai', 'g.', 'nygamai', 'g'], 'shortname': 'gibny'}, '1664': {'common_names': ['arthrobacter', 'glacialis', 'a.', 'glacialis', 'a'], 'shortname': 'artgl'}, '9083': {'common_names': ['bambusicola', 'thoracicus', 'b.', 'thoracicus', 'b'], 'shortname': 'bamth'}, '1421': {'common_names': ['lysinibacillus', 'sphaericus', 'l.', 'sphaericus', 'l'], 'shortname': 'lyssh'}, '74649': {'common_names': ['rosa', 'chinensis', 'r.', 'chinensis', 'r'], 'shortname': 'rosch'}, '96942': {'common_names': ['vitreoscilla', 'sp', 'v.', 'sp', 'v'], 'shortname': 'vits1'}, '33906': {'common_names': ['actinopolyspora', 'mortivallis', 'a.', 'mortivallis', 'a'], 'shortname': 'actmo'}, '1071': {'common_names': ['rhodopila', 'globiformis', 'r.', 'globiformis', 'r'], 'shortname': 'rhogl'}, '3634': {'common_names': ['gossypium', 'barbadense', 'g.', 'barbadense', 'g'], 'shortname': 'gosba'}, '3076': {'common_names': ['chlorella', 'sorokiniana', 'c.', 'sorokiniana', 'c'], 'shortname': 'chlso'}, '34097': {'common_names': ['brevinema', 'andersonii', 'b.', 'andersonii', 'b'], 'shortname': 'bread'}, '9597': {'common_names': ['pan', 'paniscus', 'p.', 'paniscus', 'p'], 'shortname': 'panpa'}, '2138576': {'common_names': ['vitiosangium', 'sp', 'v.', 'sp', 'v'], 'shortname': 'vitxg'}, '536980': {'common_names': ['chitinophaga', 'niastensis', 'c.', 'niastensis', 'c'], 'shortname': 'china'}, '28320': {'common_names': ['mycoplana', 'dimorpha', 'm.', 'dimorpha', 'm'], 'shortname': 'mycdi'}, '1590841': {'common_names': ['actinidia', 'chinensis', 'a.', 'chinensis', 'a'], 'shortname': 'actcc'}, '5516': {'common_names': ['fusarium', 'culmorum', 'f.', 'culmorum', 'f'], 'shortname': 'fuscu'}, '13706': {'common_names': ['syncephalastrum', 'racemosum', 's.', 'racemosum', 's'], 'shortname': 'synra'}, '6573': {'common_names': ['mizuhopecten', 'yessoensis', 'm.', 'yessoensis', 'm'], 'shortname': 'mizye'}, '58291': {'common_names': ['rhizopus', 'microsporus', 'r.', 'microsporus', 'r'], 'shortname': 'rhizd'}, '46360': {'common_names': ['cervus', 'elaphus', 'c.', 'elaphus', 'c'], 'shortname': 'cereh'}, '675833': {'common_names': ['helicobasidium', 'mompa', 'h.', 'mompa', 'h'], 'shortname': 'hmev'}, '94128': {'common_names': ['apis', 'cerana', 'a.', 'cerana', 'a'], 'shortname': 'apicc'}, '763665': {'common_names': ['coemansia', 'reversa', 'c.', 'reversa', 'c'], 'shortname': 'coern'}, '310749': {'common_names': ['vicia', 'faba', 'v.', 'faba', 'v'], 'shortname': 'vfev'}, '8081': {'common_names': ['poecilia', 'reticulata', 'p.', 'reticulata', 'p'], 'shortname': 'poere'}, '3900': {'common_names': ['trifolium', 'subterraneum', 't.', 'subterraneum', 't'], 'shortname': 'trisu'}, '12041': {'common_names': ['bean', 'leafroll', 'b.', 'leafroll', 'b'], 'shortname': 'blrv'}, '5551': {'common_names': ['trichophyton', 'rubrum', 't.', 'rubrum', 't'], 'shortname': 'triru'}, '1484': {'common_names': ['hydrogenibacillus', 'schlegelii', 'h.', 'schlegelii', 'h'], 'shortname': 'hydsh'}, '2714763': {'common_names': ['cordyceps', 'confragosa', 'c.', 'confragosa', 'c'], 'shortname': 'cordf'}, '9764': {'common_names': ['eschrichtius', 'robustus', 'e.', 'robustus', 'e'], 'shortname': 'escro'}, '4686': {'common_names': ['asparagus', 'officinalis', 'a.', 'officinalis', 'a'], 'shortname': 'aspof'}, '310750': {'common_names': ['phytophthora', 'endornavirus', 'p.', 'endornavirus', 'p'], 'shortname': 'phev1'}, '1081105': {'common_names': ['metarhizium', 'rileyi', 'm.', 'rileyi', 'm'], 'shortname': 'metrr'}, '35243': {'common_names': ['herpesvirus', 'ateles', 'h.', 'ateles', 'h'], 'shortname': 'hsva1'}, '2756': {'common_names': ['brochothrix', 'thermosphacta', 'b.', 'thermosphacta', 'b'], 'shortname': 'broth'}, '98804': {'common_names': ['buchnera', 'aphidicola', 'b.', 'aphidicola', 'b'], 'shortname': 'buctt'}, '59895': {'common_names': ['cynara', 'cardunculus', 'c.', 'cardunculus', 'c'], 'shortname': 'cyncs'}, '3197': {'common_names': ['marchantia', 'polymorpha', 'm.', 'polymorpha', 'm'], 'shortname': 'marpo'}, '42251': {'common_names': ['tuber', 'borchii', 't.', 'borchii', 't'], 'shortname': 'tubbo'}, '400727': {'common_names': ['pomacea', 'canaliculata', 'p.', 'canaliculata', 'p'], 'shortname': 'pomca'}, '428': {'common_names': ['methylosinus', 'sporium', 'm.', 'sporium', 'm'], 'shortname': 'metsr'}, '35608': {'common_names': ['artemisia', 'annua', 'a.', 'annua', 'a'], 'shortname': 'artan'}, '7757': {'common_names': ['petromyzon', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'petma'}, '9739': {'common_names': ['tursiops', 'truncatus', 't.', 'truncatus', 't'], 'shortname': 'turtr'}, '9708': {'common_names': ['odobenus', 'rosmarus', 'o.', 'rosmarus', 'o'], 'shortname': 'odoro'}, '9713': {'common_names': ['leptonychotes', 'weddellii', 'l.', 'weddellii', 'l'], 'shortname': 'lepwe'}, '1765684': {'common_names': ['acidibacillus', 'sulfuroxidans', 'a.', 'sulfuroxidans', 'a'], 'shortname': 'acis4'}, '93369': {'common_names': ['pseudaminobacter', 'salicylatoxidans', 'p.', 'salicylatoxidans', 'p'], 'shortname': 'psese'}, '831': {'common_names': ['butyrivibrio', 'fibrisolvens', 'b.', 'fibrisolvens', 'b'], 'shortname': 'butfi'}, '379075': {'common_names': ['sediminitomix', 'flava', 's.', 'flava', 's'], 'shortname': 'sedfl'}, '52904': {'common_names': ['scophthalmus', 'maximus', 's.', 'maximus', 's'], 'shortname': 'scomx'}, '12585': {'common_names': ['banana', 'bunchy', 'b.', 'bunchy', 'b'], 'shortname': 'bbtv'}, '2026735': {'common_names': ['deltaproteobacteria', 'bacterium', 'd.', 'bacterium', 'd'], 'shortname': 'uncde'}, '2161813': {'common_names': ['glaciecola', 'sp', 'g.', 'sp', 'g'], 'shortname': 'glask'}, '1885': {'common_names': ['streptomyces', 'actuosus', 's.', 'actuosus', 's'], 'shortname': 'stras'}, '1448318': {'common_names': ['aspergillus', 'sclerotiicarbonarius', 'a.', 'sclerotiicarbonarius', 'a'], 'shortname': 'aspsb'}, '9749': {'common_names': ['delphinapterus', 'leucas', 'd.', 'leucas', 'd'], 'shortname': 'delle'}, '9755': {'common_names': ['physeter', 'macrocephalus', 'p.', 'macrocephalus', 'p'], 'shortname': 'phymc'}, '643671': {'common_names': ['larkinella', 'arboricola', 'l.', 'arboricola', 'l'], 'shortname': 'larab'}, '644383': {'common_names': ['thermosporothrix', 'hazakensis', 't.', 'hazakensis', 't'], 'shortname': 'theha'}, '1450537': {'common_names': ['aspergillus', 'homomorphus', 'a.', 'homomorphus', 'a'], 'shortname': 'asphc'}, '1467': {'common_names': ['lederbergia', 'lenta', 'l.', 'lenta', 'l'], 'shortname': 'ledle'}, '4909': {'common_names': ['pichia', 'kudriavzevii', 'p.', 'kudriavzevii', 'p'], 'shortname': 'picku'}, '1450538': {'common_names': ['aspergillus', 'violaceofuscus', 'a.', 'violaceofuscus', 'a'], 'shortname': 'aspv1'}, '7160': {'common_names': ['aedes', 'albopictus', 'a.', 'albopictus', 'a'], 'shortname': 'aedal'}, '33528': {'common_names': ['gambusia', 'affinis', 'g.', 'affinis', 'g'], 'shortname': 'gamaf'}, '1537566': {'common_names': ['balneicella', 'halophila', 'b.', 'halophila', 'b'], 'shortname': 'balha'}, '29313': {'common_names': ['mycobacterium', 'shimoidei', 'm.', 'shimoidei', 'm'], 'shortname': 'mycsh'}, '86630': {'common_names': ['rhizopus', 'azygosporus', 'r.', 'azygosporus', 'r'], 'shortname': 'rhiaz'}, '4846': {'common_names': ['rhizopus', 'stolonifer', 'r.', 'stolonifer', 'r'], 'shortname': 'rhist'}, '1474': {'common_names': ['sporosarcina', 'pasteurii', 's.', 'pasteurii', 's'], 'shortname': 'spopa'}, '549': {'common_names': ['enterobacter', 'agglomerans', 'e.', 'agglomerans', 'e'], 'shortname': 'entag'}, '494': {'common_names': ['bergeriella', 'denitrificans', 'b.', 'denitrificans', 'b'], 'shortname': 'berde'}, '39831': {'common_names': ['klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k'], 'shortname': 'klepr'}, '29486': {'common_names': ['yersinia', 'ruckeri', 'y.', 'ruckeri', 'y'], 'shortname': 'yerru'}, '34062': {'common_names': ['moraxella', 'osloensis', 'm.', 'osloensis', 'm'], 'shortname': 'moros'}, '574': {'common_names': ['klebsiella', 'pneumoniae', 'k.', 'pneumoniae', 'k'], 'shortname': 'klepo'}, '696763': {'common_names': ['thermasporomyces', 'composti', 't.', 'composti', 't'], 'shortname': 'thecx'}, '3088': {'common_names': ['tetradesmus', 'obliquus', 't.', 'obliquus', 't'], 'shortname': 'tetob'}, '80972': {'common_names': ['amphiprion', 'ocellaris', 'a.', 'ocellaris', 'a'], 'shortname': 'ampoc'}, '5539': {'common_names': ['scytalidium', 'lignicola', 's.', 'lignicola', 's'], 'shortname': 'scyli'}, '32507': {'common_names': ['neolamprologus', 'brichardi', 'n.', 'brichardi', 'n'], 'shortname': 'neobr'}, '94237': {'common_names': ['mola', 'mola', 'm.', 'mola', 'm'], 'shortname': 'molml'}, '29073': {'common_names': ['ursus', 'maritimus', 'u.', 'maritimus', 'u'], 'shortname': 'ursma'}, '310752': {'common_names': ['balaenoptera', 'acutorostrata', 'b.', 'acutorostrata', 'b'], 'shortname': 'balas'}, '297': {'common_names': ['hydrogenophilus', 'thermoluteolus', 'h.', 'thermoluteolus', 'h'], 'shortname': 'hydte'}, '2293571': {'common_names': ['streptomyces', 'inhibens', 's.', 'inhibens', 's'], 'shortname': 'strih'}, '3711': {'common_names': ['brassica', 'campestris', 'b.', 'campestris', 'b'], 'shortname': 'bracm'}, '37003': {'common_names': ['kryptolebias', 'marmoratus', 'k.', 'marmoratus', 'k'], 'shortname': 'kryma'}, '8153': {'common_names': ['haplochromis', 'burtoni', 'h.', 'burtoni', 'h'], 'shortname': 'hapbu'}, '28743': {'common_names': ['cyprinodon', 'variegatus', 'c.', 'variegatus', 'c'], 'shortname': 'cypva'}, '64144': {'common_names': ['anabas', 'testudineus', 'a.', 'testudineus', 'a'], 'shortname': 'anate'}, '161767': {'common_names': ['amphiprion', 'percula', 'a.', 'percula', 'a'], 'shortname': 'amppe'}, '244447': {'common_names': ['cynoglossus', 'semilaevis', 'c.', 'semilaevis', 'c'], 'shortname': 'cynse'}, '8010': {'common_names': ['esox', 'lucius', 'e.', 'lucius', 'e'], 'shortname': 'esolu'}, '118797': {'common_names': ['lipotes', 'vexillifer', 'l.', 'vexillifer', 'l'], 'shortname': 'lipve'}, '69332': {'common_names': ['chara', 'braunii', 'c.', 'braunii', 'c'], 'shortname': 'chabu'}, '211228': {'common_names': ['cephus', 'cinctus', 'c.', 'cinctus', 'c'], 'shortname': 'cepcn'}, '5514': {'common_names': ['fusarium', 'sporotrichioides', 'f.', 'sporotrichioides', 'f'], 'shortname': 'fussp'}, '490622': {'common_names': ['trichoderma', 'arundinaceum', 't.', 'arundinaceum', 't'], 'shortname': 'triar'}, '334426': {'common_names': ['angiostrongylus', 'costaricensis', 'a.', 'costaricensis', 'a'], 'shortname': 'angcs'}, '53468': {'common_names': ['mesocestoides', 'corti', 'm.', 'corti', 'm'], 'shortname': 'mesco'}, '66425': {'common_names': ['streptomyces', 'luteoverticillatus', 's.', 'luteoverticillatus', 's'], 'shortname': 'strlt'}, '762': {'common_names': ['avibacterium', 'volantium', 'a.', 'volantium', 'a'], 'shortname': 'avivo'}, '7266': {'common_names': ['drosophila', 'guanche', 'd.', 'guanche', 'd'], 'shortname': 'drogu'}, '718': {'common_names': ['actinobacillus', 'equuli', 'a.', 'equuli', 'a'], 'shortname': 'acteu'}, '1346': {'common_names': ['streptococcus', 'iniae', 's.', 'iniae', 's'], 'shortname': 'strin'}, '6293': {'common_names': ['wuchereria', 'bancrofti', 'w.', 'bancrofti', 'w'], 'shortname': 'wucba'}, '10310': {'common_names': ['human', 'herpesvirus', 'h.', 'herpesvirus', 'h'], 'shortname': 'hhv2'}, '42157': {'common_names': ['onchocerca', 'ochengi', 'o.', 'ochengi', 'o'], 'shortname': 'oncoc'}, '75985': {'common_names': ['mannheimia', 'haemolytica', 'm.', 'haemolytica', 'm'], 'shortname': 'manha'}, '45398': {'common_names': ['streptomyces', 'griseoviridis', 's.', 'griseoviridis', 's'], 'shortname': 'strgd'}, '188477': {'common_names': ['elysia', 'chlorotica', 'e.', 'chlorotica', 'e'], 'shortname': 'elych'}, '54736': {'common_names': ['salmonella', 'bongori', 's.', 'bongori', 's'], 'shortname': 'salbn'}, '135727': {'common_names': ['ziziphus', 'jujuba', 'z.', 'jujuba', 'z'], 'shortname': 'zizju'}, '51028': {'common_names': ['enterobius', 'vermicularis', 'e.', 'vermicularis', 'e'], 'shortname': 'entve'}, '6205': {'common_names': ['hydatigena', 'taeniaeformis', 'h.', 'taeniaeformis', 'h'], 'shortname': 'hydta'}, '6216': {'common_names': ['hymenolepis', 'diminuta', 'h.', 'diminuta', 'h'], 'shortname': 'hymdi'}, '318479': {'common_names': ['dracunculus', 'medinensis', 'd.', 'medinensis', 'd'], 'shortname': 'drame'}, '4540': {'common_names': ['panicum', 'miliaceum', 'p.', 'miliaceum', 'p'], 'shortname': 'panmi'}, '46731': {'common_names': ['pocillopora', 'damicornis', 'p.', 'damicornis', 'p'], 'shortname': 'pocda'}, '2867405': {'common_names': ['blumeria', 'hordei', 'b.', 'hordei', 'b'], 'shortname': 'bluho'}, '2319844': {'common_names': ['sphingomonas', 'paeninsulae', 's.', 'paeninsulae', 's'], 'shortname': 'sphpe'}, '103827': {'common_names': ['thelazia', 'callipaeda', 't.', 'callipaeda', 't'], 'shortname': 'thecl'}, '44316': {'common_names': ['chloebia', 'gouldiae', 'c.', 'gouldiae', 'c'], 'shortname': 'chlgu'}, '91943': {'common_names': ['hortaea', 'werneckii', 'h.', 'werneckii', 'h'], 'shortname': 'horwe'}, '6277': {'common_names': ['acanthocheilonema', 'viteae', 'a.', 'viteae', 'a'], 'shortname': 'acavi'}, '42156': {'common_names': ['litomosoides', 'sigmodontis', 'l.', 'sigmodontis', 'l'], 'shortname': 'litsi'}, '1000373': {'common_names': ['rosellinia', 'necatrix', 'r.', 'necatrix', 'r'], 'shortname': 'rnqv1'}, '6280': {'common_names': ['brugia', 'pahangi', 'b.', 'pahangi', 'b'], 'shortname': 'brupa'}, '47878': {'common_names': ['pseudomonas', 'azotoformans', 'p.', 'azotoformans', 'p'], 'shortname': 'pseaz'}, '102285': {'common_names': ['rodentolepis', 'nana', 'r.', 'nana', 'r'], 'shortname': 'rodna'}, '1791': {'common_names': ['mycolicibacterium', 'aurum', 'm.', 'aurum', 'm'], 'shortname': 'mycau'}, '495550': {'common_names': ['anabarilius', 'grahami', 'a.', 'grahami', 'a'], 'shortname': 'anaga'}, '749': {'common_names': ['pasteurella', 'aerogenes', 'p.', 'aerogenes', 'p'], 'shortname': 'pasae'}, '82996': {'common_names': ['serratia', 'plymuthica', 's.', 'plymuthica', 's'], 'shortname': 'serpl'}, '1792': {'common_names': ['mycolicibacterium', 'chitae', 'm.', 'chitae', 'm'], 'shortname': 'mycci'}, '60517': {'common_names': ['taenia', 'asiatica', 't.', 'asiatica', 't'], 'shortname': 'taeas'}, '168631': {'common_names': ['chilo', 'suppressalis', 'c.', 'suppressalis', 'c'], 'shortname': 'chisp'}, '123683': {'common_names': ['oryzias', 'javanicus', 'o.', 'javanicus', 'o'], 'shortname': 'oryja'}, '93625': {'common_names': ['psilocybe', 'cyanescens', 'p.', 'cyanescens', 'p'], 'shortname': 'psicy'}, '6689': {'common_names': ['penaeus', 'vannamei', 'p.', 'vannamei', 'p'], 'shortname': 'penva'}, '5698': {'common_names': ['trypanosoma', 'rangeli', 't.', 'rangeli', 't'], 'shortname': 'tryra'}, '264951': {'common_names': ['byssochlamys', 'spectabilis', 'b.', 'spectabilis', 'b'], 'shortname': 'byssp'}, '9627': {'common_names': ['vulpes', 'vulpes', 'v.', 'vulpes', 'v'], 'shortname': 'vulvu'}, '34884': {'common_names': ['callorhinus', 'ursinus', 'c.', 'ursinus', 'c'], 'shortname': 'calur'}, '105351': {'common_names': ['aspergillus', 'awamori', 'a.', 'awamori', 'a'], 'shortname': 'aspaw'}, '77856': {'common_names': ['beak', 'and', 'b.', 'and', 'b'], 'shortname': 'bfdv'}, '75743': {'common_names': ['scyliorhinus', 'torazame', 's.', 'torazame', 's'], 'shortname': 'scyto'}, '5217': {'common_names': ['tremella', 'mesenterica', 't.', 'mesenterica', 't'], 'shortname': 'treme'}, '3848': {'common_names': ['glycine', 'soja', 'g.', 'soja', 'g'], 'shortname': 'glyso'}, '3818': {'common_names': ['arachis', 'hypogaea', 'a.', 'hypogaea', 'a'], 'shortname': 'arahy'}, '29552': {'common_names': ['haploplasma', 'axanthum', 'h.', 'axanthum', 'h'], 'shortname': 'hapax'}, '7906': {'common_names': ['acipenser', 'ruthenus', 'a.', 'ruthenus', 'a'], 'shortname': 'acirt'}, '3750': {'common_names': ['malus', 'domestica', 'm.', 'domestica', 'm'], 'shortname': 'maldo'}, '55404': {'common_names': ['streptomyces', 'netropsis', 's.', 'netropsis', 's'], 'shortname': 'strne'}, '2509675': {'common_names': ['ktedonosporobacter', 'rubrisoli', 'k.', 'rubrisoli', 'k'], 'shortname': 'kteru'}, '84645': {'common_names': ['labeo', 'rohita', 'l.', 'rohita', 'l'], 'shortname': 'labro'}, '6184': {'common_names': ['schistosoma', 'bovis', 's.', 'bovis', 's'], 'shortname': 'schbo'}, '13370': {'common_names': ['brettanomyces', 'naardenensis', 'b.', 'naardenensis', 'b'], 'shortname': 'brena'}, '121428': {'common_names': ['sphingobium', 'xenophagum', 's.', 'xenophagum', 's'], 'shortname': 'sphxe'}, '9925': {'common_names': ['capra', 'hircus', 'c.', 'hircus', 'c'], 'shortname': 'caphi'}, '9643': {'common_names': ['ursus', 'americanus', 'u.', 'americanus', 'u'], 'shortname': 'ursam'}, '195883': {'common_names': ['laodelphax', 'striatellus', 'l.', 'striatellus', 'l'], 'shortname': 'laost'}, '2026724': {'common_names': ['chloroflexi', 'bacterium', 'c.', 'bacterium', 'c'], 'shortname': 'uncch'}, '1397368': {'common_names': ['pseudonocardia', 'sediminis', 'p.', 'sediminis', 'p'], 'shortname': 'psest'}, '2026763': {'common_names': ['myxococcales', 'bacterium', 'm.', 'bacterium', 'm'], 'shortname': 'uncmy'}, '433330': {'common_names': ['propioniciclava', 'tarda', 'p.', 'tarda', 'p'], 'shortname': 'protd'}, '1946': {'common_names': ['streptomyces', 'kasugaensis', 's.', 'kasugaensis', 's'], 'shortname': 'strka'}, '73044': {'common_names': ['streptomyces', 'seoulensis', 's.', 'seoulensis', 's'], 'shortname': 'strso'}, '227605': {'common_names': ['methylocella', 'tundrae', 'm.', 'tundrae', 'm'], 'shortname': 'mettu'}, '1082276': {'common_names': ['hydrogenispora', 'ethanolica', 'h.', 'ethanolica', 'h'], 'shortname': 'hydet'}, '8167': {'common_names': ['perca', 'flavescens', 'p.', 'flavescens', 'p'], 'shortname': 'perfv'}, '145285': {'common_names': ['nocardia', 'ignorata', 'n.', 'ignorata', 'n'], 'shortname': 'nocig'}, '304': {'common_names': ['pelomonas', 'saccharophila', 'p.', 'saccharophila', 'p'], 'shortname': 'pelsc'}, '7232': {'common_names': ['drosophila', 'navojoa', 'd.', 'navojoa', 'd'], 'shortname': 'drona'}, '49390': {'common_names': ['coffea', 'canephora', 'c.', 'canephora', 'c'], 'shortname': 'cofca'}, '103600': {'common_names': ['sousa', 'chinensis', 's.', 'chinensis', 's'], 'shortname': 'souch'}, '29443': {'common_names': ['paucimonas', 'lemoignei', 'p.', 'lemoignei', 'p'], 'shortname': 'paule'}, '598644': {'common_names': ['labedaea', 'rhizosphaerae', 'l.', 'rhizosphaerae', 'l'], 'shortname': 'labrh'}, '401976': {'common_names': ['pseudonocardia', 'endophytica', 'p.', 'endophytica', 'p'], 'shortname': 'pseen'}, '5466': {'common_names': ['colletotrichum', 'trifolii', 'c.', 'trifolii', 'c'], 'shortname': 'coltr'}, '35804': {'common_names': ['rhodovulum', 'adriaticum', 'r.', 'adriaticum', 'r'], 'shortname': 'rhoad'}, '8839': {'common_names': ['anas', 'platyrhynchos', 'a.', 'platyrhynchos', 'a'], 'shortname': 'anapl'}, '180675': {'common_names': ['salvia', 'splendens', 's.', 'splendens', 's'], 'shortname': 'salsn'}, '4556': {'common_names': ['setaria', 'viridis', 's.', 'viridis', 's'], 'shortname': 'setvi'}, '34508': {'common_names': ['steinernema', 'carpocapsae', 's.', 'carpocapsae', 's'], 'shortname': 'stecr'}, '240159': {'common_names': ['collichthys', 'lucidus', 'c.', 'lucidus', 'c'], 'shortname': 'collu'}, '9838': {'common_names': ['camelus', 'dromedarius', 'c.', 'dromedarius', 'c'], 'shortname': 'camdr'}, '147828': {'common_names': ['opisthorchis', 'felineus', 'o.', 'felineus', 'o'], 'shortname': 'opife'}, '40151': {'common_names': ['monodon', 'monoceros', 'm.', 'monoceros', 'm'], 'shortname': 'monmo'}, '1498': {'common_names': ['hathewaya', 'histolytica', 'h.', 'histolytica', 'h'], 'shortname': 'hathi'}, '43335': {'common_names': ['populus', 'alba', 'p.', 'alba', 'p'], 'shortname': 'popal'}, '245174': {'common_names': ['wallemia', 'ichthyophaga', 'w.', 'ichthyophaga', 'w'], 'shortname': 'walic'}, '8187': {'common_names': ['lates', 'calcarifer', 'l.', 'calcarifer', 'l'], 'shortname': 'latca'}, '30522': {'common_names': ['bos', 'indicus', 'b.', 'indicus', 'b'], 'shortname': 'bobox'}, '8005': {'common_names': ['electrophorus', 'electricus', 'e.', 'electricus', 'e'], 'shortname': 'eleel'}, '7868': {'common_names': ['callorhinchus', 'milii', 'c.', 'milii', 'c'], 'shortname': 'calmi'}, '29139': {'common_names': ['vombatus', 'ursinus', 'v.', 'ursinus', 'v'], 'shortname': 'vomur'}, '106549': {'common_names': ['malus', 'baccata', 'm.', 'baccata', 'm'], 'shortname': 'malba'}, '13243': {'common_names': ['rarobacter', 'faecitabidus', 'r.', 'faecitabidus', 'r'], 'shortname': 'rarfa'}, '2292766': {'common_names': ['persicimonas', 'caeni', 'p.', 'caeni', 'p'], 'shortname': 'perce'}, '239': {'common_names': ['flavobacterium', 'sp', 'f.', 'sp', 'f'], 'shortname': 'flasp'}, '43667': {'common_names': ['glutamicibacter', 'uratoxydans', 'g.', 'uratoxydans', 'g'], 'shortname': 'gluur'}, '3469': {'common_names': ['papaver', 'somniferum', 'p.', 'somniferum', 'p'], 'shortname': 'papso'}, '46835': {'common_names': ['fasciola', 'gigantica', 'f.', 'gigantica', 'f'], 'shortname': 'fasgi'}, '104662': {'common_names': ['chitinophaga', 'japonensis', 'c.', 'japonensis', 'c'], 'shortname': 'chija'}, '52838': {'common_names': ['musa', 'balbisiana', 'm.', 'balbisiana', 'm'], 'shortname': 'musba'}, '43663': {'common_names': ['paenarthrobacter', 'aurescens', 'p.', 'aurescens', 'p'], 'shortname': 'paeau'}, '1095': {'common_names': ['chlorobium', 'sp', 'c.', 'sp', 'c'], 'shortname': 'chlsq'}, '25': {'common_names': ['shewanella', 'hanedai', 's.', 'hanedai', 's'], 'shortname': 'sheha'}, '350': {'common_names': ['zoogloea', 'ramigera', 'z.', 'ramigera', 'z'], 'shortname': 'zoora'}, '6832': {'common_names': ['tigriopus', 'californicus', 't.', 'californicus', 't'], 'shortname': 'tigca'}, '1168039': {'common_names': ['saccharicrinis', 'carchari', 's.', 'carchari', 's'], 'shortname': 'saccc'}, '1898': {'common_names': ['streptomyces', 'cacaoi', 's.', 'cacaoi', 's'], 'shortname': 'strci'}, '472': {'common_names': ['acinetobacter', 'sp', 'a.', 'sp', 'a'], 'shortname': 'acisp'}, '5098': {'common_names': ['monascus', 'purpureus', 'm.', 'purpureus', 'm'], 'shortname': 'monpu'}, '175774': {'common_names': ['bagarius', 'yarrelli', 'b.', 'yarrelli', 'b'], 'shortname': 'bagya'}, '1880': {'common_names': ['micromonospora', 'olivasterospora', 'm.', 'olivasterospora', 'm'], 'shortname': 'micol'}, '1867': {'common_names': ['actinoplanes', 'teichomyceticus', 'a.', 'teichomyceticus', 'a'], 'shortname': 'actti'}, '10281': {'common_names': ['molluscum', 'contagiosum', 'm.', 'contagiosum', 'm'], 'shortname': 'mcv2'}, '1128664': {'common_names': ['amycolatopsis', 'cihanbeyliensis', 'a.', 'cihanbeyliensis', 'a'], 'shortname': 'amyci'}, '1223518': {'common_names': ['deinococcus', 'cellulosilyticus', 'd.', 'cellulosilyticus', 'd'], 'shortname': 'deic1'}, '1742359': {'common_names': ['bacillus', 'dafuensis', 'b.', 'dafuensis', 'b'], 'shortname': 'bacda'}, '1246': {'common_names': ['leuconostoc', 'lactis', 'l.', 'lactis', 'l'], 'shortname': 'leula'}, '7111': {'common_names': ['trichoplusia', 'ni', 't.', 'ni', 't'], 'shortname': 'trini'}, '38448': {'common_names': ['monilinia', 'fructicola', 'm.', 'fructicola', 'm'], 'shortname': 'monfr'}, '33653': {'common_names': ['cafeteria', 'roenbergensis', 'c.', 'roenbergensis', 'c'], 'shortname': 'cafro'}, '34275': {'common_names': ['gossypium', 'mustelinum', 'g.', 'mustelinum', 'g'], 'shortname': 'gosmu'}, '10266': {'common_names': ['sheeppox', 'virus', 's.', 'virus', 's'], 'shortname': 'shev'}, '35688': {'common_names': ['porphyridium', 'purpureum', 'p.', 'purpureum', 'p'], 'shortname': 'porpp'}, '561879': {'common_names': ['bacillus', 'safensis', 'b.', 'safensis', 'b'], 'shortname': 'bacia'}, '4170': {'common_names': ['striga', 'asiatica', 's.', 'asiatica', 's'], 'shortname': 'straf'}, '492': {'common_names': ['neisseria', 'animalis', 'n.', 'animalis', 'n'], 'shortname': 'neian'}, '132259': {'common_names': ['aspergillus', 'pseudotamarii', 'a.', 'pseudotamarii', 'a'], 'shortname': 'aspps'}, '103733': {'common_names': ['saccharothrix', 'syringae', 's.', 'syringae', 's'], 'shortname': 'sacsy'}, '33899': {'common_names': ['streptomyces', 'galilaeus', 's.', 'galilaeus', 's'], 'shortname': 'strgj'}, '9886': {'common_names': ['muntiacus', 'reevesi', 'm.', 'reevesi', 'm'], 'shortname': 'munre'}, '5067': {'common_names': ['aspergillus', 'parasiticus', 'a.', 'parasiticus', 'a'], 'shortname': 'asppa'}, '61186': {'common_names': ['monilinia', 'laxa', 'm.', 'laxa', 'm'], 'shortname': 'monla'}, '209559': {'common_names': ['petromyces', 'alliaceus', 'p.', 'alliaceus', 'p'], 'shortname': 'petaa'}, '7054': {'common_names': ['photinus', 'pyralis', 'p.', 'pyralis', 'p'], 'shortname': 'phopy'}, '3755': {'common_names': ['prunus', 'dulcis', 'p.', 'dulcis', 'p'], 'shortname': 'prudu'}, '310915': {'common_names': ['pangasianodon', 'hypophthalmus', 'p.', 'hypophthalmus', 'p'], 'shortname': 'panhp'}, '9995': {'common_names': ['marmota', 'monax', 'm.', 'monax', 'm'], 'shortname': 'marmo'}, '2750659': {'common_names': ['pontiella', 'desulfatans', 'p.', 'desulfatans', 'p'], 'shortname': 'ponde'}, '191816': {'common_names': ['lynx', 'pardinus', 'l.', 'pardinus', 'l'], 'shortname': 'lynpa'}, '580': {'common_names': ['kluyvera', 'cryocrescens', 'k.', 'cryocrescens', 'k'], 'shortname': 'klucr'}, '64391': {'common_names': ['callosobruchus', 'maculatus', 'c.', 'maculatus', 'c'], 'shortname': 'calms'}, '1945': {'common_names': ['streptomyces', 'jumonjinensis', 's.', 'jumonjinensis', 's'], 'shortname': 'strju'}, '215358': {'common_names': ['larimichthys', 'crocea', 'l.', 'crocea', 'l'], 'shortname': 'larcr'}, '36863': {'common_names': ['ideonella', 'dechloratans', 'i.', 'dechloratans', 'i'], 'shortname': 'idede'}, '110539': {'common_names': ['mycolicibacterium', 'vanbaalenii', 'm.', 'vanbaalenii', 'm'], 'shortname': 'mycvn'}, '28064': {'common_names': ['heliobacterium', 'mobile', 'h.', 'mobile', 'h'], 'shortname': 'helmo'}, '5025': {'common_names': ['venturia', 'inaequalis', 'v.', 'inaequalis', 'v'], 'shortname': 'venin'}, '106335': {'common_names': ['hibiscus', 'syriacus', 'h.', 'syriacus', 'h'], 'shortname': 'hibsy'}, '9770': {'common_names': ['balaenoptera', 'physalus', 'b.', 'physalus', 'b'], 'shortname': 'balph'}, '1232801': {'common_names': ['amphibalanus', 'amphitrite', 'a.', 'amphitrite', 'a'], 'shortname': 'ampam'}, '5763': {'common_names': ['naegleria', 'fowleri', 'n.', 'fowleri', 'n'], 'shortname': 'naefo'}, '5481': {'common_names': ['diutina', 'rugosa', 'd.', 'rugosa', 'd'], 'shortname': 'diuru'}, '33178': {'common_names': ['aspergillus', 'terreus', 'a.', 'terreus', 'a'], 'shortname': 'aspte'}, '3870': {'common_names': ['lupinus', 'albus', 'l.', 'albus', 'l'], 'shortname': 'lupal'}, '8168': {'common_names': ['perca', 'fluviatilis', 'p.', 'fluviatilis', 'p'], 'shortname': 'perfl'}, '248454': {'common_names': ['apolygus', 'lucorum', 'a.', 'lucorum', 'a'], 'shortname': 'apolu'}, '1973307': {'common_names': ['cyclocybe', 'aegerita', 'c.', 'aegerita', 'c'], 'shortname': 'cycae'}, '3981': {'common_names': ['hevea', 'brasiliensis', 'h.', 'brasiliensis', 'h'], 'shortname': 'hevbr'}, '1765737': {'common_names': ['dissulfurirhabdus', 'thermomarina', 'd.', 'thermomarina', 'd'], 'shortname': 'disth'}, '666': {'common_names': ['vibrio', 'cholerae', 'v.', 'cholerae', 'v'], 'shortname': 'vibcl'}, '59479': {'common_names': ['rhinolophus', 'ferrumequinum', 'r.', 'ferrumequinum', 'r'], 'shortname': 'rhife'}, '61383': {'common_names': ['lynx', 'canadensis', 'l.', 'canadensis', 'l'], 'shortname': 'lynca'}, '9054': {'common_names': ['phasianus', 'colchicus', 'p.', 'colchicus', 'p'], 'shortname': 'phacc'}, '75366': {'common_names': ['sinocyclocheilus', 'grahami', 's.', 'grahami', 's'], 'shortname': 'singr'}, '173247': {'common_names': ['echeneis', 'naucrates', 'e.', 'naucrates', 'e'], 'shortname': 'echna'}, '8175': {'common_names': ['sparus', 'aurata', 's.', 'aurata', 's'], 'shortname': 'spaau'}, '2489341': {'common_names': ['strigops', 'habroptila', 's.', 'habroptila', 's'], 'shortname': 'strhb'}, '181472': {'common_names': ['salarias', 'fasciatus', 's.', 'fasciatus', 's'], 'shortname': 'salfa'}, '37032': {'common_names': ['suricata', 'suricatta', 's.', 'suricatta', 's'], 'shortname': 'sursu'}, '194338': {'common_names': ['athene', 'cunicularia', 'a.', 'cunicularia', 'a'], 'shortname': 'athcn'}, '64176': {'common_names': ['podarcis', 'muralis', 'p.', 'muralis', 'p'], 'shortname': 'podmu'}, '8673': {'common_names': ['pseudonaja', 'textilis', 'p.', 'textilis', 'p'], 'shortname': 'psete'}, '47969': {'common_names': ['oreochromis', 'aureus', 'o.', 'aureus', 'o'], 'shortname': 'oreau'}, '8032': {'common_names': ['salmo', 'trutta', 's.', 'trutta', 's'], 'shortname': 'saltr'}, '9678': {'common_names': ['crocuta', 'crocuta', 'c.', 'crocuta', 'c'], 'shortname': 'crocr'}, '307491': {'common_names': ['aphis', 'glycines', 'a.', 'glycines', 'a'], 'shortname': 'aphgl'}, '5007': {'common_names': ['dekkera', 'bruxellensis', 'd.', 'bruxellensis', 'd'], 'shortname': 'dekbr'}, '6233': {'common_names': ['panagrellus', 'redivivus', 'p.', 'redivivus', 'p'], 'shortname': 'panre'}, '79782': {'common_names': ['cimex', 'lectularius', 'c.', 'lectularius', 'c'], 'shortname': 'cimle'}, '874455': {'common_names': ['arctia', 'plantaginis', 'a.', 'plantaginis', 'a'], 'shortname': 'arcpl'}, '30019': {'common_names': ['drosophila', 'busckii', 'd.', 'busckii', 'd'], 'shortname': 'drobs'}, '36987': {'common_names': ['coptotermes', 'formosanus', 'c.', 'formosanus', 'c'], 'shortname': 'copfo'}, '230844': {'common_names': ['peromyscus', 'maniculatus', 'p.', 'maniculatus', 'p'], 'shortname': 'permb'}, '48883': {'common_names': ['geospiza', 'fortis', 'g.', 'fortis', 'g'], 'shortname': 'geofo'}, '3673': {'common_names': ['momordica', 'charantia', 'm.', 'charantia', 'm'], 'shortname': 'momch'}, '4182': {'common_names': ['sesamum', 'indicum', 's.', 'indicum', 's'], 'shortname': 'sesin'}, '30538': {'common_names': ['vicugna', 'pacos', 'v.', 'pacos', 'v'], 'shortname': 'vicpa'}, '51953': {'common_names': ['elaeis', 'guineensis', 'e.', 'guineensis', 'e'], 'shortname': 'elagv'}, '3661': {'common_names': ['cucurbita', 'maxima', 'c.', 'maxima', 'c'], 'shortname': 'cucma'}, '3726': {'common_names': ['raphanus', 'sativus', 'r.', 'sativus', 'r'], 'shortname': 'rapsa'}, '7137': {'common_names': ['galleria', 'mellonella', 'g.', 'mellonella', 'g'], 'shortname': 'galme'}, '27457': {'common_names': ['bactrocera', 'dorsalis', 'b.', 'dorsalis', 'b'], 'shortname': 'bacdo'}, '110368': {'common_names': ['bicyclus', 'anynana', 'b.', 'anynana', 'b'], 'shortname': 'bican'}, '441921': {'common_names': ['neodiprion', 'lecontei', 'n.', 'lecontei', 'n'], 'shortname': 'neolc'}, '32536': {'common_names': ['acinonyx', 'jubatus', 'a.', 'jubatus', 'a'], 'shortname': 'acijb'}, '56716': {'common_names': ['cottoperca', 'gobio', 'c.', 'gobio', 'c'], 'shortname': 'cotgo'}, '29144': {'common_names': ['chanos', 'chanos', 'c.', 'chanos', 'c'], 'shortname': 'chacn'}, '7225': {'common_names': ['drosophila', 'lebanonensis', 'd.', 'lebanonensis', 'd'], 'shortname': 'drole'}, '7048': {'common_names': ['sitophilus', 'oryzae', 's.', 'oryzae', 's'], 'shortname': 'sitor'}, '219594': {'common_names': ['aythya', 'fuligula', 'a.', 'fuligula', 'a'], 'shortname': 'aytfu'}, '9515': {'common_names': ['sapajus', 'apella', 's.', 'apella', 's'], 'shortname': 'sapap'}, '36596': {'common_names': ['prunus', 'armeniaca', 'p.', 'armeniaca', 'p'], 'shortname': 'pruar'}, '10493': {'common_names': ['frog', 'virus', 'f.', 'virus', 'f'], 'shortname': 'frg3v'}, '42260': {'common_names': ['zygotorulaspora', 'mrakii', 'z.', 'mrakii', 'z'], 'shortname': 'zygmr'}, '2202144': {'common_names': ['spirochaetes', 'bacterium', 's.', 'bacterium', 's'], 'shortname': 'uncsp'}, '66656': {'common_names': ['durio', 'zibethinus', 'd.', 'zibethinus', 'd'], 'shortname': 'durzi'}, '42229': {'common_names': ['prunus', 'avium', 'p.', 'avium', 'p'], 'shortname': 'pruav'}, '7957': {'common_names': ['carassius', 'auratus', 'c.', 'auratus', 'c'], 'shortname': 'carau'}, '9696': {'common_names': ['puma', 'concolor', 'p.', 'concolor', 'p'], 'shortname': 'pumco'}, '9915': {'common_names': ['bos', 'indicus', 'b.', 'indicus', 'b'], 'shortname': 'bosin'}, '7741': {'common_names': ['branchiostoma', 'belcheri', 'b.', 'belcheri', 'b'], 'shortname': 'brabe'}, '38626': {'common_names': ['phascolarctos', 'cinereus', 'p.', 'cinereus', 'p'], 'shortname': 'phaci'}, '6956': {'common_names': ['dermatophagoides', 'pteronyssinus', 'd.', 'pteronyssinus', 'd'], 'shortname': 'derpt'}, '13443': {'common_names': ['coffea', 'arabica', 'c.', 'arabica', 'c'], 'shortname': 'cofar'}, '148305': {'common_names': ['magnaporthe', 'grisea', 'm.', 'grisea', 'm'], 'shortname': 'maggr'}, '6645': {'common_names': ['octopus', 'vulgaris', 'o.', 'vulgaris', 'o'], 'shortname': 'octvu'}, '94885': {'common_names': ['pantherophis', 'guttatus', 'p.', 'guttatus', 'p'], 'shortname': 'pangu'}, '161013': {'common_names': ['thrips', 'palmi', 't.', 'palmi', 't'], 'shortname': 'thrpl'}, '260995': {'common_names': ['geotrypetes', 'seraphini', 'g.', 'seraphini', 'g'], 'shortname': 'geosa'}, '8218': {'common_names': ['gymnodraco', 'acuticeps', 'g.', 'acuticeps', 'g'], 'shortname': 'gymac'}, '6105': {'common_names': ['actinia', 'tenebrosa', 'a.', 'tenebrosa', 'a'], 'shortname': 'actte'}, '30033': {'common_names': ['drosophila', 'kikkawai', 'd.', 'kikkawai', 'd'], 'shortname': 'droki'}, '132908': {'common_names': ['pteropus', 'vampyrus', 'p.', 'vampyrus', 'p'], 'shortname': 'pteva'}, '10160': {'common_names': ['octodon', 'degus', 'o.', 'degus', 'o'], 'shortname': 'octde'}, '609295': {'common_names': ['dinoponera', 'quadriceps', 'd.', 'quadriceps', 'd'], 'shortname': 'dinqu'}, '1041015': {'common_names': ['drosophila', 'rhopaloa', 'd.', 'rhopaloa', 'd'], 'shortname': 'drorh'}, '326968': {'common_names': ['ziziphus', 'jujuba', 'z.', 'jujuba', 'z'], 'shortname': 'zizjj'}, '1712410': {'common_names': ['thermanaerosceptrum', 'fracticalcis', 't.', 'fracticalcis', 't'], 'shortname': 'thefr'}, '2731377': {'common_names': ['alkalicella', 'caledoniensis', 'a.', 'caledoniensis', 'a'], 'shortname': 'alkca'}, '1768': {'common_names': ['mycobacterium', 'kansasii', 'm.', 'kansasii', 'm'], 'shortname': 'mycka'}, '48435': {'common_names': ['steatornis', 'caripensis', 's.', 'caripensis', 's'], 'shortname': 'steca'}, '36200': {'common_names': ['dissostichus', 'mawsoni', 'd.', 'mawsoni', 'd'], 'shortname': 'disma'}, '2099678': {'common_names': ['desulfuromonadales', 'bacterium', 'd.', 'bacterium', 'd'], 'shortname': 'desbx'}, '227228': {'common_names': ['pluvianellus', 'socialis', 'p.', 'socialis', 'p'], 'shortname': 'pluso'}, '159581': {'common_names': ['catharus', 'fuscescens', 'c.', 'fuscescens', 'c'], 'shortname': 'catfu'}, '685828': {'common_names': ['armatimonas', 'rosea', 'a.', 'rosea', 'a'], 'shortname': 'armro'}, '114369': {'common_names': ['piprites', 'chloris', 'p.', 'chloris', 'p'], 'shortname': 'pipcl'}, '127929': {'common_names': ['leucopsar', 'rothschildi', 'l.', 'rothschildi', 'l'], 'shortname': 'leuro'}, '99882': {'common_names': ['toxostoma', 'redivivum', 't.', 'redivivum', 't'], 'shortname': 'toxre'}, '36275': {'common_names': ['leiothrix', 'lutea', 'l.', 'lutea', 'l'], 'shortname': 'leilu'}, '287016': {'common_names': ['chroicocephalus', 'maculipennis', 'c.', 'maculipennis', 'c'], 'shortname': 'chrmc'}, '240209': {'common_names': ['smutsornis', 'africanus', 's.', 'africanus', 's'], 'shortname': 'smuaf'}, '110676': {'common_names': ['cochlearius', 'cochlearius', 'c.', 'cochlearius', 'c'], 'shortname': 'cocco'}, '227184': {'common_names': ['rynchops', 'niger', 'r.', 'niger', 'r'], 'shortname': 'rynni'}, '38397': {'common_names': ['orthonyx', 'spaldingii', 'o.', 'spaldingii', 'o'], 'shortname': 'ortsp'}, '103956': {'common_names': ['corythaixoides', 'concolor', 'c.', 'concolor', 'c'], 'shortname': 'corcn'}, '79633': {'common_names': ['oceanodroma', 'tethys', 'o.', 'tethys', 'o'], 'shortname': 'ocete'}, '51298': {'common_names': ['myotis', 'myotis', 'm.', 'myotis', 'm'], 'shortname': 'myomy'}, '33584': {'common_names': ['balaeniceps', 'rex', 'b.', 'rex', 'b'], 'shortname': 'balrx'}, '13245': {'common_names': ['regulus', 'satrapa', 'r.', 'satrapa', 'r'], 'shortname': 'regsa'}, '37610': {'common_names': ['erithacus', 'rubecula', 'e.', 'rubecula', 'e'], 'shortname': 'eriru'}, '115618': {'common_names': ['columbina', 'picui', 'c.', 'picui', 'c'], 'shortname': 'colpi'}, '175120': {'common_names': ['irena', 'cyanogastra', 'i.', 'cyanogastra', 'i'], 'shortname': 'irecy'}, '8947': {'common_names': ['geococcyx', 'californianus', 'g.', 'californianus', 'g'], 'shortname': 'geoca'}, '45807': {'common_names': ['motacilla', 'alba', 'm.', 'alba', 'm'], 'shortname': 'motal'}, '125297': {'common_names': ['bombycilla', 'garrulus', 'b.', 'garrulus', 'b'], 'shortname': 'bomga'}, '54059': {'common_names': ['stercorarius', 'parasiticus', 's.', 'parasiticus', 's'], 'shortname': 'stepr'}, '8805': {'common_names': ['eudromia', 'elegans', 'e.', 'elegans', 'e'], 'shortname': 'eudel'}, '181099': {'common_names': ['oriolus', 'oriolus', 'o.', 'oriolus', 'o'], 'shortname': 'orior'}, '182897': {'common_names': ['pycnonotus', 'jocosus', 'p.', 'jocosus', 'p'], 'shortname': 'pycjo'}, '28689': {'common_names': ['alca', 'torda', 'a.', 'torda', 'a'], 'shortname': 'alcto'}, '5476': {'common_names': ['candida', 'albicans', 'c.', 'albicans', 'c'], 'shortname': 'canax'}, '30388': {'common_names': ['chauna', 'torquata', 'c.', 'torquata', 'c'], 'shortname': 'chato'}, '137541': {'common_names': ['tyrannus', 'savana', 't.', 'savana', 't'], 'shortname': 'tyrsa'}, '73324': {'common_names': ['sylvia', 'borin', 's.', 'borin', 's'], 'shortname': 'sylbo'}, '33581': {'common_names': ['scopus', 'umbretta', 's.', 'umbretta', 's'], 'shortname': 'scoum'}, '56258': {'common_names': ['sagittarius', 'serpentarius', 's.', 'serpentarius', 's'], 'shortname': 'sagse'}, '48891': {'common_names': ['poecile', 'atricapillus', 'p.', 'atricapillus', 'p'], 'shortname': 'poeat'}, '75485': {'common_names': ['rissa', 'tridactyla', 'r.', 'tridactyla', 'r'], 'shortname': 'ristr'}, '58351': {'common_names': ['kitasatospora', 'kifunensis', 'k.', 'kifunensis', 'k'], 'shortname': 'kitki'}, '2508778': {'common_names': ['aspergillus', 'burnettii', 'a.', 'burnettii', 'a'], 'shortname': 'aspbu'}, '54971': {'common_names': ['arenaria', 'interpres', 'a.', 'interpres', 'a'], 'shortname': 'arein'}, '8790': {'common_names': ['dromaius', 'novaehollandiae', 'd.', 'novaehollandiae', 'd'], 'shortname': 'drono'}, '114276': {'common_names': ['cephalopterus', 'ornatus', 'c.', 'ornatus', 'c'], 'shortname': 'cepor'}, '57439': {'common_names': ['upupa', 'epops', 'u.', 'epops', 'u'], 'shortname': 'upuep'}, '189': {'common_names': ['novispirillum', 'itersonii', 'n.', 'itersonii', 'n'], 'shortname': 'novit'}, '181101': {'common_names': ['panurus', 'biarmicus', 'p.', 'biarmicus', 'p'], 'shortname': 'panbi'}, '187106': {'common_names': ['caloenas', 'nicobarica', 'c.', 'nicobarica', 'c'], 'shortname': 'calni'}, '28713': {'common_names': ['lanius', 'ludovicianus', 'l.', 'ludovicianus', 'l'], 'shortname': 'lanlu'}, '42677': {'common_names': ['gibberella', 'subglutinans', 'g.', 'subglutinans', 'g'], 'shortname': 'gibsu'}, '69962': {'common_names': ['azomonas', 'macrocytogenes', 'a.', 'macrocytogenes', 'a'], 'shortname': 'azoma'}, '33598': {'common_names': ['crotophaga', 'sulcirostris', 'c.', 'sulcirostris', 'c'], 'shortname': 'crosl'}, '39621': {'common_names': ['acrocephalus', 'arundinaceus', 'a.', 'arundinaceus', 'a'], 'shortname': 'acrar'}, '298831': {'common_names': ['setophaga', 'kirtlandii', 's.', 'kirtlandii', 's'], 'shortname': 'setkr'}, '54508': {'common_names': ['jacana', 'jacana', 'j.', 'jacana', 'j'], 'shortname': 'jacjc'}, '360224': {'common_names': ['onychorhynchus', 'coronatus', 'o.', 'coronatus', 'o'], 'shortname': 'onyco'}, '56311': {'common_names': ['trogon', 'melanurus', 't.', 'melanurus', 't'], 'shortname': 'troml'}, '27622': {'common_names': ['molossus', 'molossus', 'm.', 'molossus', 'm'], 'shortname': 'molmo'}, '153643': {'common_names': ['bucorvus', 'abyssinicus', 'b.', 'abyssinicus', 'b'], 'shortname': 'bucab'}, '77932': {'common_names': ['diceros', 'bicornis', 'd.', 'bicornis', 'd'], 'shortname': 'dicbm'}, '64278': {'common_names': ['quiscalus', 'mexicanus', 'q.', 'mexicanus', 'q'], 'shortname': 'quime'}, '84834': {'common_names': ['molothrus', 'ater', 'm.', 'ater', 'm'], 'shortname': 'molat'}, '156561': {'common_names': ['anthoscopus', 'minutus', 'a.', 'minutus', 'a'], 'shortname': 'antmn'}, '9252': {'common_names': ['podilymbus', 'podiceps', 'p.', 'podiceps', 'p'], 'shortname': 'podpo'}, '37079': {'common_names': ['pelecanoides', 'urinatrix', 'p.', 'urinatrix', 'p'], 'shortname': 'pelur'}, '56343': {'common_names': ['herpetotheres', 'cachinnans', 'h.', 'cachinnans', 'h'], 'shortname': 'herca'}, '2026887': {'common_names': ['nitrospirae', 'bacterium', 'n.', 'bacterium', 'n'], 'shortname': 'uncnt'}, '54017': {'common_names': ['thalassarche', 'chlororhynchos', 't.', 'chlororhynchos', 't'], 'shortname': 'thach'}, '227182': {'common_names': ['chionis', 'minor', 'c.', 'minor', 'c'], 'shortname': 'chimn'}, '59472': {'common_names': ['pipistrellus', 'kuhlii', 'p.', 'kuhlii', 'p'], 'shortname': 'pipku'}, '74200': {'common_names': ['thryothorus', 'ludovicianus', 't.', 'ludovicianus', 't'], 'shortname': 'thrlu'}, '5507': {'common_names': ['fusarium', 'oxysporum', 'f.', 'oxysporum', 'f'], 'shortname': 'fusox'}, '44397': {'common_names': ['melospiza', 'melodia', 'm.', 'melodia', 'm'], 'shortname': 'melmo'}, '1708': {'common_names': ['cellulomonas', 'fimi', 'c.', 'fimi', 'c'], 'shortname': 'celfi'}, '81907': {'common_names': ['alectura', 'lathami', 'a.', 'lathami', 'a'], 'shortname': 'alela'}, '1999': {'common_names': ['planomonospora', 'venezuelensis', 'p.', 'venezuelensis', 'p'], 'shortname': 'plave'}, '141839': {'common_names': ['probosciger', 'aterrimus', 'p.', 'aterrimus', 'p'], 'shortname': 'proar'}, '79628': {'common_names': ['fregetta', 'grallaria', 'f.', 'grallaria', 'f'], 'shortname': 'frega'}, '64802': {'common_names': ['loxia', 'curvirostra', 'l.', 'curvirostra', 'l'], 'shortname': 'loxcu'}, '227192': {'common_names': ['pedionomus', 'torquatus', 'p.', 'torquatus', 'p'], 'shortname': 'pedto'}, '1330551': {'common_names': ['paenibacillus', 'lemnae', 'p.', 'lemnae', 'p'], 'shortname': 'paele'}, '279966': {'common_names': ['oenanthe', 'oenanthe', 'o.', 'oenanthe', 'o'], 'shortname': 'oenon'}, '113115': {'common_names': ['rhinopomastus', 'cyanomelas', 'r.', 'cyanomelas', 'r'], 'shortname': 'rhicy'}, '54356': {'common_names': ['aramus', 'guarauna', 'a.', 'guarauna', 'a'], 'shortname': 'araga'}, '48427': {'common_names': ['nyctibius', 'grandis', 'n.', 'grandis', 'n'], 'shortname': 'nycgr'}, '8851': {'common_names': ['anseranas', 'semipalmata', 'a.', 'semipalmata', 'a'], 'shortname': 'ansse'}, '42747': {'common_names': ['fusarium', 'heterosporum', 'f.', 'heterosporum', 'f'], 'shortname': 'fushe'}, '118183': {'common_names': ['chordeiles', 'acutipennis', 'c.', 'acutipennis', 'c'], 'shortname': 'choac'}, '79653': {'common_names': ['oceanites', 'oceanicus', 'o.', 'oceanicus', 'o'], 'shortname': 'oceoc'}, '225398': {'common_names': ['himantopus', 'himantopus', 'h.', 'himantopus', 'h'], 'shortname': 'himhi'}, '182080': {'common_names': ['actinomadura', 'namibiensis', 'a.', 'namibiensis', 'a'], 'shortname': 'actnm'}, '66707': {'common_names': ['polioptila', 'caerulea', 'p.', 'caerulea', 'p'], 'shortname': 'polce'}, '39617': {'common_names': ['aphelocoma', 'coerulescens', 'a.', 'coerulescens', 'a'], 'shortname': 'aphce'}, '371919': {'common_names': ['pheucticus', 'melanocephalus', 'p.', 'melanocephalus', 'p'], 'shortname': 'pheme'}, '176943': {'common_names': ['baryphthengus', 'martii', 'b.', 'martii', 'b'], 'shortname': 'barma'}, '161653': {'common_names': ['phainopepla', 'nitens', 'p.', 'nitens', 'p'], 'shortname': 'phani'}, '9132': {'common_names': ['gymnorhina', 'tibicen', 'g.', 'tibicen', 'g'], 'shortname': 'gymti'}, '56262': {'common_names': ['pandion', 'haliaetus', 'p.', 'haliaetus', 'p'], 'shortname': 'panha'}, '43316': {'common_names': ['glareola', 'pratincola', 'g.', 'pratincola', 'g'], 'shortname': 'glapt'}, '9176': {'common_names': ['pomatostomus', 'ruficeps', 'p.', 'ruficeps', 'p'], 'shortname': 'pomru'}, '98964': {'common_names': ['cardinalis', 'cardinalis', 'c.', 'cardinalis', 'c'], 'shortname': 'carcd'}, '50251': {'common_names': ['sitta', 'europaea', 's.', 'europaea', 's'], 'shortname': 'siteu'}, '3483': {'common_names': ['cannabis', 'sativa', 'c.', 'sativa', 'c'], 'shortname': 'cansa'}, '8905': {'common_names': ['podargus', 'strigoides', 'p.', 'strigoides', 'p'], 'shortname': 'podst'}, '546': {'common_names': ['citrobacter', 'freundii', 'c.', 'freundii', 'c'], 'shortname': 'citfr'}, '28724': {'common_names': ['ptilonorhynchus', 'violaceus', 'p.', 'violaceus', 'p'], 'shortname': 'ptivi'}, '43150': {'common_names': ['hirundo', 'rustica', 'h.', 'rustica', 'h'], 'shortname': 'hirru'}, '2026769': {'common_names': ['nitrospinae', 'bacterium', 'n.', 'bacterium', 'n'], 'shortname': 'uncni'}, '1066': {'common_names': ['rhodocyclus', 'tenuis', 'r.', 'tenuis', 'r'], 'shortname': 'rhote'}, '1970': {'common_names': ['streptomyces', 'morookaense', 's.', 'morookaense', 's'], 'shortname': 'strmo'}, '34956': {'common_names': ['vireo', 'altiloquus', 'v.', 'altiloquus', 'v'], 'shortname': 'viral'}, '161649': {'common_names': ['cinclus', 'mexicanus', 'c.', 'mexicanus', 'c'], 'shortname': 'cinmu'}, '78217': {'common_names': ['glaucidium', 'brasilianum', 'g.', 'brasilianum', 'g'], 'shortname': 'glabr'}, '330153': {'common_names': ['perkinsus', 'chesapeaki', 'p.', 'chesapeaki', 'p'], 'shortname': 'perch'}, '2026780': {'common_names': ['planctomycetota', 'bacterium', 'p.', 'bacterium', 'p'], 'shortname': 'uncpl'}, '34287': {'common_names': ['gossypium', 'davidsonii', 'g.', 'davidsonii', 'g'], 'shortname': 'gosdv'}, '458696': {'common_names': ['tripterygium', 'wilfordii', 't.', 'wilfordii', 't'], 'shortname': 'triwf'}, '4045': {'common_names': ['apium', 'graveolens', 'a.', 'graveolens', 'a'], 'shortname': 'apigr'}, '4442': {'common_names': ['camellia', 'sinensis', 'c.', 'sinensis', 'c'], 'shortname': 'camsi'}, '219545': {'common_names': ['ameiurus', 'melas', 'a.', 'melas', 'a'], 'shortname': 'ameme'}, '9407': {'common_names': ['rousettus', 'aegyptiacus', 'r.', 'aegyptiacus', 'r'], 'shortname': 'rouae'}, '34291': {'common_names': ['gossypium', 'schwendimanii', 'g.', 'schwendimanii', 'g'], 'shortname': 'gossc'}, '34290': {'common_names': ['gossypium', 'aridum', 'g.', 'aridum', 'g'], 'shortname': 'gosai'}, '34282': {'common_names': ['gossypium', 'gossypioides', 'g.', 'gossypioides', 'g'], 'shortname': 'gosgo'}, '42881': {'common_names': ['streptomyces', 'chromofuscus', 's.', 'chromofuscus', 's'], 'shortname': 'strcw'}, '10497': {'common_names': ['african', 'swine', 'a.', 'swine', 'a'], 'shortname': 'asf'}, '8502': {'common_names': ['crocodylus', 'porosus', 'c.', 'porosus', 'c'], 'shortname': 'cropo'}, '109461': {'common_names': ['varroa', 'destructor', 'v.', 'destructor', 'v'], 'shortname': 'varde'}, '97700': {'common_names': ['quercus', 'lobata', 'q.', 'lobata', 'q'], 'shortname': 'quelo'}, '63787': {'common_names': ['kalanchoe', 'fedtschenkoi', 'k.', 'fedtschenkoi', 'k'], 'shortname': 'kalfe'}, '877507': {'common_names': ['epichloe', 'festucae', 'e.', 'festucae', 'e'], 'shortname': 'epiff'}, '343691': {'common_names': ['hermetia', 'illucens', 'h.', 'illucens', 'h'], 'shortname': 'heril'}, '2847778': {'common_names': ['atribacter', 'laminatus', 'a.', 'laminatus', 'a'], 'shortname': 'atrlm'}, '10511': {'common_names': ['bovine', 'adenovirus', 'b.', 'adenovirus', 'b'], 'shortname': 'adeb7'}, '63459': {'common_names': ['chenopodium', 'quinoa', 'c.', 'quinoa', 'c'], 'shortname': 'cheqi'}, '29158': {'common_names': ['mytilus', 'galloprovincialis', 'm.', 'galloprovincialis', 'm'], 'shortname': 'mytga'}, '30213': {'common_names': ['vespula', 'pensylvanica', 'v.', 'pensylvanica', 'v'], 'shortname': 'vespe'}, '198940': {'common_names': ['calcarius', 'ornatus', 'c.', 'ornatus', 'c'], 'shortname': 'calor'}, '1196302': {'common_names': ['corvus', 'moneduloides', 'c.', 'moneduloides', 'c'], 'shortname': 'cormo'}, '175797': {'common_names': ['silurus', 'meridionalis', 's.', 'meridionalis', 's'], 'shortname': 'silme'}, '73333': {'common_names': ['certhia', 'familiaris', 'c.', 'familiaris', 'c'], 'shortname': 'cerfa'}, '474922': {'common_names': ['colletotrichum', 'gloeosporioides', 'c.', 'gloeosporioides', 'c'], 'shortname': 'colgl'}, '658473': {'common_names': ['mycena', 'chlorophos', 'm.', 'chlorophos', 'm'], 'shortname': 'myccl'}, '7454': {'common_names': ['vespula', 'vulgaris', 'v.', 'vulgaris', 'v'], 'shortname': 'vesvu'}, '29856': {'common_names': ['bionectria', 'ochroleuca', 'b.', 'ochroleuca', 'b'], 'shortname': 'biooc'}, '30212': {'common_names': ['vespula', 'germanica', 'v.', 'germanica', 'v'], 'shortname': 'vesge'}, '40210': {'common_names': ['spizella', 'passerina', 's.', 'passerina', 's'], 'shortname': 'spipa'}, '56068': {'common_names': ['sula', 'dactylatra', 's.', 'dactylatra', 's'], 'shortname': 'sulda'}, '103954': {'common_names': ['corythaeola', 'cristata', 'c.', 'cristata', 'c'], 'shortname': 'corcr'}, '5322': {'common_names': ['pleurotus', 'ostreatus', 'p.', 'ostreatus', 'p'], 'shortname': 'pleos'}, '45130': {'common_names': ['cochliobolus', 'sativus', 'c.', 'sativus', 'c'], 'shortname': 'cocsa'}, '142471': {'common_names': ['passerina', 'amoena', 'p.', 'amoena', 'p'], 'shortname': 'pasaf'}, '354439': {'common_names': ['rhynchophorus', 'ferrugineus', 'r.', 'ferrugineus', 'r'], 'shortname': 'rhyfe'}, '118357': {'common_names': ['rhododendron', 'simsii', 'r.', 'simsii', 'r'], 'shortname': 'rhoss'}, '73327': {'common_names': ['aegithalos', 'caudatus', 'a.', 'caudatus', 'a'], 'shortname': 'aegca'}, '135441': {'common_names': ['peucedramus', 'taeniatus', 'p.', 'taeniatus', 'p'], 'shortname': 'peuta'}, '175131': {'common_names': ['picathartes', 'gymnocephalus', 'p.', 'gymnocephalus', 'p'], 'shortname': 'picgy'}, '614051': {'common_names': ['tychaedon', 'coryphoeus', 't.', 'coryphoeus', 't'], 'shortname': 'tycco'}, '37042': {'common_names': ['fregata', 'magnificens', 'f.', 'magnificens', 'f'], 'shortname': 'frema'}, '9163': {'common_names': ['pitta', 'sordida', 'p.', 'sordida', 'p'], 'shortname': 'pitso'}, '81927': {'common_names': ['vidua', 'chalybeata', 'v.', 'chalybeata', 'v'], 'shortname': 'vidch'}, '51239': {'common_names': ['vanilla', 'planifolia', 'v.', 'planifolia', 'v'], 'shortname': 'vanpl'}, '182096': {'common_names': ['aspergillus', 'chevalieri', 'a.', 'chevalieri', 'a'], 'shortname': 'aspch'}, '176039': {'common_names': ['eolophus', 'roseicapilla', 'e.', 'roseicapilla', 'e'], 'shortname': 'eolro'}, '9117': {'common_names': ['grus', 'americana', 'g.', 'americana', 'g'], 'shortname': 'gruam'}, '135972': {'common_names': ['calyptomena', 'viridis', 'c.', 'viridis', 'c'], 'shortname': 'calvr'}, '34880': {'common_names': ['nyctereutes', 'procyonoides', 'n.', 'procyonoides', 'n'], 'shortname': 'nycpr'}, '30732': {'common_names': ['oryzias', 'melastigma', 'o.', 'melastigma', 'o'], 'shortname': 'oryme'}, '7107': {'common_names': ['spodoptera', 'exigua', 's.', 'exigua', 's'], 'shortname': 'spoex'}, '51695': {'common_names': ['chlamydomonas', 'incerta', 'c.', 'incerta', 'c'], 'shortname': 'chlin'}, '33601': {'common_names': ['piaya', 'cayana', 'p.', 'cayana', 'p'], 'shortname': 'piaca'}, '51655': {'common_names': ['plutella', 'xylostella', 'p.', 'xylostella', 'p'], 'shortname': 'pluxy'}, '91625': {'common_names': ['mortierella', 'isabellina', 'm.', 'isabellina', 'm'], 'shortname': 'moris'}, '458196': {'common_names': ['urocolius', 'indicus', 'u.', 'indicus', 'u'], 'shortname': 'uroin'}, '35762': {'common_names': ['planobispora', 'rosea', 'p.', 'rosea', 'p'], 'shortname': 'plaro'}, '187451': {'common_names': ['vidua', 'macroura', 'v.', 'macroura', 'v'], 'shortname': 'vidma'}, '56067': {'common_names': ['anhinga', 'anhinga', 'a.', 'anhinga', 'a'], 'shortname': 'anhan'}, '6326': {'common_names': ['bursaphelenchus', 'xylophilus', 'b.', 'xylophilus', 'b'], 'shortname': 'burxy'}, '135184': {'common_names': ['todus', 'mexicanus', 't.', 'mexicanus', 't'], 'shortname': 'todme'}, '1069201': {'common_names': ['aspergillus', 'kawachii', 'a.', 'kawachii', 'a'], 'shortname': 'aspka'}, '13502': {'common_names': ['eeniella', 'nana', 'e.', 'nana', 'e'], 'shortname': 'eenna'}, '101028': {'common_names': ['fusarium', 'pseudograminearum', 'f.', 'pseudograminearum', 'f'], 'shortname': 'fusps'}, '51605': {'common_names': ['spirodela', 'intermedia', 's.', 'intermedia', 's'], 'shortname': 'spiin'}, '249248': {'common_names': ['adineta', 'ricciae', 'a.', 'ricciae', 'a'], 'shortname': 'adiri'}, '2818388': {'common_names': ['sulfidibacter', 'corallicola', 's.', 'corallicola', 's'], 'shortname': 'sulco'}, '181762': {'common_names': ['psilocybe', 'cubensis', 'p.', 'cubensis', 'p'], 'shortname': 'psicu'}, '5037': {'common_names': ['ajellomyces', 'capsulatus', 'a.', 'capsulatus', 'a'], 'shortname': 'ajeca'}, '74533': {'common_names': ['panthera', 'tigris', 'p.', 'tigris', 'p'], 'shortname': 'panta'}, '36772': {'common_names': ['subterranean', 'clover', 's.', 'clover', 's'], 'shortname': 'scsv'}, '8478': {'common_names': ['chrysemys', 'picta', 'c.', 'picta', 'c'], 'shortname': 'chrpi'}, '1026970': {'common_names': ['nannospalax', 'galili', 'n.', 'galili', 'n'], 'shortname': 'nanga'}, '87175': {'common_names': ['geospiza', 'parvula', 'g.', 'parvula', 'g'], 'shortname': 'geopr'}, '7962': {'common_names': ['cyprinus', 'carpio', 'c.', 'carpio', 'c'], 'shortname': 'cypca'}, '51337': {'common_names': ['jaculus', 'jaculus', 'j.', 'jaculus', 'j'], 'shortname': 'jacja'}, '7764': {'common_names': ['eptatretus', 'burgeri', 'e.', 'burgeri', 'e'], 'shortname': 'eptbu'}, '13489': {'common_names': ['dicentrarchus', 'labrax', 'd.', 'labrax', 'd'], 'shortname': 'dicla'}, '8508': {'common_names': ['sphenodon', 'punctatus', 's.', 'punctatus', 's'], 'shortname': 'sphpu'}, '30608': {'common_names': ['microcebus', 'murinus', 'm.', 'murinus', 'm'], 'shortname': 'micmu'}, '34839': {'common_names': ['chinchilla', 'lanigera', 'c.', 'lanigera', 'c'], 'shortname': 'chila'}, '9689': {'common_names': ['panthera', 'leo', 'p.', 'leo', 'p'], 'shortname': 'panle'}, '74940': {'common_names': ['oncorhynchus', 'tshawytscha', 'o.', 'tshawytscha', 'o'], 'shortname': 'oncts'}, '8475': {'common_names': ['chelydra', 'serpentina', 'c.', 'serpentina', 'c'], 'shortname': 'chese'}, '106734': {'common_names': ['chelonoidis', 'abingdonii', 'c.', 'abingdonii', 'c'], 'shortname': 'cheab'}, '13146': {'common_names': ['melopsittacus', 'undulatus', 'm.', 'undulatus', 'm'], 'shortname': 'melud'}, '8630': {'common_names': ['laticauda', 'laticaudata', 'l.', 'laticaudata', 'l'], 'shortname': 'latla'}, '9994': {'common_names': ['marmota', 'marmota', 'm.', 'marmota', 'm'], 'shortname': 'marma'}, '40217': {'common_names': ['junco', 'hyemalis', 'j.', 'hyemalis', 'j'], 'shortname': 'junhy'}, '9135': {'common_names': ['serinus', 'canaria', 's.', 'canaria', 's'], 'shortname': 'serca'}, '156563': {'common_names': ['cyanistes', 'caeruleus', 'c.', 'caeruleus', 'c'], 'shortname': 'cyacu'}, '9565': {'common_names': ['theropithecus', 'gelada', 't.', 'gelada', 't'], 'shortname': 'thege'}, '93934': {'common_names': ['coturnix', 'japonica', 'c.', 'japonica', 'c'], 'shortname': 'cotja'}, '44394': {'common_names': ['zonotrichia', 'albicollis', 'z.', 'albicollis', 'z'], 'shortname': 'zonal'}, '1328070': {'common_names': ['prolemur', 'simus', 'p.', 'simus', 'p'], 'shortname': 'pross'}, '10103': {'common_names': ['mus', 'spicilegus', 'm.', 'spicilegus', 'm'], 'shortname': 'mussi'}, '9999': {'common_names': ['urocitellus', 'parryii', 'u.', 'parryii', 'u'], 'shortname': 'uropr'}, '30464': {'common_names': ['nothoprocta', 'perdicaria', 'n.', 'perdicaria', 'n'], 'shortname': 'notpe'}, '96440': {'common_names': ['salvator', 'merianae', 's.', 'merianae', 's'], 'shortname': 'salmn'}, '99837': {'common_names': ['spermophilus', 'dauricus', 's.', 'dauricus', 's'], 'shortname': 'speda'}, '8824': {'common_names': ['apteryx', 'owenii', 'a.', 'owenii', 'a'], 'shortname': 'aptow'}, '452646': {'common_names': ['neovison', 'vison', 'n.', 'vison', 'n'], 'shortname': 'neovi'}, '9049': {'common_names': ['pavo', 'cristatus', 'p.', 'cristatus', 'p'], 'shortname': 'pavcr'}, '30521': {'common_names': ['bos', 'mutus', 'b.', 'mutus', 'b'], 'shortname': 'bosmu'}, '8845': {'common_names': ['anser', 'cygnoides', 'a.', 'cygnoides', 'a'], 'shortname': 'anscy'}, '9089': {'common_names': ['chrysolophus', 'pictus', 'c.', 'pictus', 'c'], 'shortname': 'chrpc'}, '68415': {'common_names': ['moschus', 'moschiferus', 'm.', 'moschiferus', 'm'], 'shortname': 'mosmo'}, '61221': {'common_names': ['varanus', 'komodoensis', 'v.', 'komodoensis', 'v'], 'shortname': 'varko'}, '8049': {'common_names': ['gadus', 'morhua', 'g.', 'morhua', 'g'], 'shortname': 'gadmo'}, '105023': {'common_names': ['nothobranchius', 'furzeri', 'n.', 'furzeri', 'n'], 'shortname': 'notfu'}, '42100': {'common_names': ['phocoena', 'sinus', 'p.', 'sinus', 'p'], 'shortname': 'phoss'}, '8019': {'common_names': ['oncorhynchus', 'kisutch', 'o.', 'kisutch', 'o'], 'shortname': 'oncki'}, '35670': {'common_names': ['naja', 'naja', 'n.', 'naja', 'n'], 'shortname': 'najna'}, '100819': {'common_names': ['falco', 'tinnunculus', 'f.', 'tinnunculus', 'f'], 'shortname': 'falti'}, '91951': {'common_names': ['catharus', 'ustulatus', 'c.', 'ustulatus', 'c'], 'shortname': 'catus'}, '55149': {'common_names': ['sciurus', 'vulgaris', 's.', 'vulgaris', 's'], 'shortname': 'scivu'}, '8103': {'common_names': ['cyclopterus', 'lumpus', 'c.', 'lumpus', 'c'], 'shortname': 'cyclu'}, '30461': {'common_names': ['bubo', 'bubo', 'b.', 'bubo', 'b'], 'shortname': 'bubbb'}, '283035': {'common_names': ['sander', 'lucioperca', 's.', 'lucioperca', 's'], 'shortname': 'sanlu'}, '27687': {'common_names': ['erpetoichthys', 'calabaricus', 'e.', 'calabaricus', 'e'], 'shortname': 'erpca'}, '6087': {'common_names': ['hydra', 'vulgaris', 'h.', 'vulgaris', 'h'], 'shortname': 'hydvu'}, '294128': {'common_names': ['hyalella', 'azteca', 'h.', 'azteca', 'h'], 'shortname': 'hyaaz'}, '6565': {'common_names': ['crassostrea', 'virginica', 'c.', 'virginica', 'c'], 'shortname': 'cravi'}, '133434': {'common_names': ['acanthaster', 'planci', 'a.', 'planci', 'a'], 'shortname': 'acapl'}, '334116': {'common_names': ['vanessa', 'tameamea', 'v.', 'tameamea', 'v'], 'shortname': 'vanta'}, '186990': {'common_names': ['hipposideros', 'armiger', 'h.', 'armiger', 'h'], 'shortname': 'hipar'}, '51338': {'common_names': ['castor', 'canadensis', 'c.', 'canadensis', 'c'], 'shortname': 'cascn'}, '3816': {'common_names': ['abrus', 'precatorius', 'a.', 'precatorius', 'a'], 'shortname': 'abrpr'}, '9771': {'common_names': ['balaenoptera', 'musculus', 'b.', 'musculus', 'b'], 'shortname': 'balmu'}, '202257': {'common_names': ['galemys', 'pyrenaicus', 'g.', 'pyrenaicus', 'g'], 'shortname': 'galpy'}, '79684': {'common_names': ['microtus', 'ochrogaster', 'm.', 'ochrogaster', 'm'], 'shortname': 'micoh'}, '79626': {'common_names': ['eudyptes', 'chrysocome', 'e.', 'chrysocome', 'e'], 'shortname': 'eudch'}, '7067': {'common_names': ['tenebrio', 'molitor', 't.', 'molitor', 't'], 'shortname': 'tenmo'}, '1594786': {'common_names': ['clarias', 'magur', 'c.', 'magur', 'c'], 'shortname': 'clamg'}, '103762': {'common_names': ['zizania', 'palustris', 'z.', 'palustris', 'z'], 'shortname': 'zizpa'}, '94328': {'common_names': ['zingiber', 'officinale', 'z.', 'officinale', 'z'], 'shortname': 'zinof'}, '7917': {'common_names': ['atractosteus', 'spatula', 'a.', 'spatula', 'a'], 'shortname': 'atrsp'}, '6347': {'common_names': ['owenia', 'fusiformis', 'o.', 'fusiformis', 'o'], 'shortname': 'owefu'}, '9234': {'common_names': ['aptenodytes', 'patagonicus', 'a.', 'patagonicus', 'a'], 'shortname': 'aptpa'}, '2081491': {'common_names': ['diacronema', 'lutheri', 'd.', 'lutheri', 'd'], 'shortname': 'dialt'}, '57060': {'common_names': ['eleutherodactylus', 'coqui', 'e.', 'coqui', 'e'], 'shortname': 'elecq'}, '37083': {'common_names': ['eudyptula', 'minor', 'e.', 'minor', 'e'], 'shortname': 'eudmi'}, '51543': {'common_names': ['cotesia', 'congregata', 'c.', 'congregata', 'c'], 'shortname': 'cotcn'}, '123851': {'common_names': ['ladona', 'fulva', 'l.', 'fulva', 'l'], 'shortname': 'ladfu'}, '41045': {'common_names': ['pythium', 'oligandrum', 'p.', 'oligandrum', 'p'], 'shortname': 'pytol'}, '13894': {'common_names': ['cocos', 'nucifera', 'c.', 'nucifera', 'c'], 'shortname': 'cocnu'}, '505711': {'common_names': ['andalucia', 'godoyi', 'a.', 'godoyi', 'a'], 'shortname': 'andgo'}, '3696': {'common_names': ['populus', 'deltoides', 'p.', 'deltoides', 'p'], 'shortname': 'popde'}, '94029': {'common_names': ['argiope', 'bruennichi', 'a.', 'bruennichi', 'a'], 'shortname': 'argbr'}, '8040': {'common_names': ['salvelinus', 'namaycush', 's.', 'namaycush', 's'], 'shortname': 'salnm'}, '32201': {'common_names': ['carya', 'illinoinensis', 'c.', 'illinoinensis', 'c'], 'shortname': 'caril'}, '3225': {'common_names': ['ceratodon', 'purpureus', 'c.', 'purpureus', 'c'], 'shortname': 'cerpu'}, '38727': {'common_names': ['panicum', 'virgatum', 'p.', 'virgatum', 'p'], 'shortname': 'panvg'}, '49495': {'common_names': ['ceratopteris', 'richardii', 'c.', 'richardii', 'c'], 'shortname': 'cerri'}, '94219': {'common_names': ['dendrobium', 'nobile', 'd.', 'nobile', 'd'], 'shortname': 'denno'}, '7740': {'common_names': ['branchiostoma', 'lanceolatum', 'b.', 'lanceolatum', 'b'], 'shortname': 'brala'}, '52824': {'common_names': ['brassica', 'carinata', 'b.', 'carinata', 'b'], 'shortname': 'braci'}, '55291': {'common_names': ['polypterus', 'senegalus', 'p.', 'senegalus', 'p'], 'shortname': 'polse'}, '118781': {'common_names': ['populus', 'tomentosa', 'p.', 'tomentosa', 'p'], 'shortname': 'popto'}, '1140': {'common_names': ['synechococcus', 'elongatus', 's.', 'elongatus', 's'], 'shortname': 'syne7'}, '399742': {'common_names': ['enterobacter', 'sp', 'e.', 'sp', 'e'], 'shortname': 'ent38'}, '654913': {'common_names': ['white', 'spot', 'w.', 'spot', 'w'], 'shortname': 'wssvs'}, '1987993': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsav'}, '85154': {'common_names': ['streptococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpo12'}, '582345': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpkpp'}, '5888': {'common_names': ['paramecium', 'tetraurelia', 'p.', 'tetraurelia', 'p'], 'shortname': 'parte'}, '232721': {'common_names': ['acidovorax', 'sp', 'a.', 'sp', 'a'], 'shortname': 'acisj'}, '1068625': {'common_names': ['trypanosoma', 'congolense', 't.', 'congolense', 't'], 'shortname': 'tryci'}, '205870': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmb2'}, '205877': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmbz'}, '244590': {'common_names': ['sulfolobus', 'viruslike', 's.', 'viruslike', 's'], 'shortname': 'ssv2'}, '554373': {'common_names': ['moniliophthora', 'perniciosa', 'm.', 'perniciosa', 'm'], 'shortname': 'monpe'}, '10761': {'common_names': ['shigella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsfv'}, '10506': {'common_names': ['paramecium', 'bursaria', 'p.', 'bursaria', 'p'], 'shortname': 'pbcv1'}, '654925': {'common_names': ['emiliania', 'huxleyi', 'e.', 'huxleyi', 'e'], 'shortname': 'ehv8u'}, '654926': {'common_names': ['ectocarpus', 'siliculosus', 'e.', 'siliculosus', 'e'], 'shortname': 'esv1k'}, '28321': {'common_names': ['amsacta', 'moorei', 'a.', 'moorei', 'a'], 'shortname': 'amepv'}, '2907964': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpd31'}, '12353': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpr69'}, '50948': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bprb4'}, '382359': {'common_names': ['synechococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsys'}, '83129': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bplp0'}, '268747': {'common_names': ['prochlorococcus', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpprs'}, '2907835': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmom'}, '205875': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmco'}, '268746': {'common_names': ['prochlorococcus', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpprm'}, '504346': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppaj'}, '2914006': {'common_names': ['thermus', 'virus', 't.', 'virus', 't'], 'shortname': 'bp234'}, '442493': {'common_names': ['enterococcus', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpphe'}, '2492962': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt1'}, '173443': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpst6'}, '43685': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bpr1t'}, '379501': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpmr1'}, '1283337': {'common_names': ['halomonas', 'phage', 'h.', 'phage', 'h'], 'shortname': 'bpha1'}, '486041': {'common_names': ['laccaria', 'bicolor', 'l.', 'bicolor', 'l'], 'shortname': 'lacbs'}, '12336': {'common_names': ['clostridium', 'botulinum', 'c.', 'botulinum', 'c'], 'shortname': 'cbcp'}, '221915': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bppgk'}, '328615': {'common_names': ['trichoplusia', 'ni', 't.', 'ni', 't'], 'shortname': 'tnavc'}, '260797': {'common_names': ['heliothis', 'virescens', 'h.', 'virescens', 'h'], 'shortname': 'hvave'}, '176652': {'common_names': ['invertebrate', 'iridescent', 'i.', 'iridescent', 'i'], 'shortname': 'iiv6'}, '1283338': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bptwo'}, '35241': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bptu2'}, '2884427': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpsp1'}, '2907955': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpsp6'}, '10704': {'common_names': ['rhizobium', 'phage', 'r.', 'phage', 'r'], 'shortname': 'bp163'}, '481877': {'common_names': ['enterocytozoon', 'bieneusi', 'e.', 'bieneusi', 'e'], 'shortname': 'entbh'}, '561896': {'common_names': ['postia', 'placenta', 'p.', 'placenta', 'p'], 'shortname': 'pospm'}, '2885909': {'common_names': ['bordetella', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpbpp'}, '215158': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpe15'}, '75320': {'common_names': ['vibrio', 'phage', 'v.', 'phage', 'v'], 'shortname': 'bpkvm'}, '2886925': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpn4'}, '2681624': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bplc2'}, '12348': {'common_names': ['lactococcus', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bpllh'}, '5875': {'common_names': ['theileria', 'parva', 't.', 'parva', 't'], 'shortname': 'thepa'}, '342610': {'common_names': ['pseudoalteromonas', 'atlantica', 'p.', 'atlantica', 'p'], 'shortname': 'psea6'}, '392499': {'common_names': ['rhizorhabdus', 'wittichii', 'r.', 'wittichii', 'r'], 'shortname': 'rhiwr'}, '2679905': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpe32'}, '484895': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpluz'}, '462590': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppyu'}, '2905945': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpdpk'}, '186153': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpphd'}, '10719': {'common_names': ['streptomyces', 'phage', 's.', 'phage', 's'], 'shortname': 'bpphc'}, '88870': {'common_names': ['mycobacterium', 'phage', 'm.', 'phage', 'm'], 'shortname': 'bpmt4'}, '12023': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppp7'}, '128710': {'common_names': ['his', '2', 'h.', '2', 'h'], 'shortname': 'his2v'}, '198110': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bp201'}, '487152': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpmr2'}, '236750': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bp35c'}, '2679898': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpga1'}, '97081': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpvt2'}, '40521': {'common_names': ['listeria', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bpa18'}, '1208236': {'common_names': ['helicobacter', 'pylori', 'h.', 'pylori', 'h'], 'shortname': 'bpkhp'}, '1003232': {'common_names': ['edhazardia', 'aedis', 'e.', 'aedis', 'e'], 'shortname': 'edhae'}, '1072681': {'common_names': ['haloredivivus', 'sp', 'h.', 'sp', 'h'], 'shortname': 'halsg'}, '10689': {'common_names': ['vibrio', 'phage', 'v.', 'phage', 'v'], 'shortname': 'bpcpt'}, '281687': {'common_names': ['caenorhabditis', 'japonica', 'c.', 'japonica', 'c'], 'shortname': 'caeja'}, '654910': {'common_names': ['acidianus', 'filamentous', 'a.', 'filamentous', 'a'], 'shortname': 'afv2p'}, '1212765': {'common_names': ['mycoplasma', 'haemolamae', 'm.', 'haemolamae', 'm'], 'shortname': 'mycha'}, '717982': {'common_names': ['auricularia', 'subglabra', 'a.', 'subglabra', 'a'], 'shortname': 'aurst'}, '654920': {'common_names': ['campoletis', 'sonorensis', 'c.', 'sonorensis', 'c'], 'shortname': 'csivt'}, '645993': {'common_names': ['culex', 'nigripalpus', 'c.', 'nigripalpus', 'c'], 'shortname': 'npvco'}, '1283341': {'common_names': ['clostridium', 'phage', 'c.', 'phage', 'c'], 'shortname': 'bppcd'}, '12024': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpprr'}, '5762': {'common_names': ['naegleria', 'gruberi', 'n.', 'gruberi', 'n'], 'shortname': 'naegr'}, '648333': {'common_names': ['periplaneta', 'fuliginosa', 'p.', 'fuliginosa', 'p'], 'shortname': 'pfdng'}, '654904': {'common_names': ['rachiplusia', 'ou', 'r.', 'ou', 'r'], 'shortname': 'npvr1'}, '645664': {'common_names': ['shigella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsp8'}, '648251': {'common_names': ['bombyx', 'mori', 'b.', 'mori', 'b'], 'shortname': 'bmdns'}, '204086': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bp44a'}, '423536': {'common_names': ['perkinsus', 'marinus', 'p.', 'marinus', 'p'], 'shortname': 'perm5'}, '113370': {'common_names': ['spodoptera', 'frugiperda', 's.', 'frugiperda', 's'], 'shortname': 'sfava'}, '1237085': {'common_names': ['nitrososphaera', 'gargensis', 'n.', 'gargensis', 'n'], 'shortname': 'nitgg'}, '311458': {'common_names': ['caldiarchaeum', 'subterraneum', 'c.', 'subterraneum', 'c'], 'shortname': 'cals0'}, '1283339': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpppb'}, '40522': {'common_names': ['listeria', 'phage', 'l.', 'phage', 'l'], 'shortname': 'bpa50'}, '5671': {'common_names': ['leishmania', 'infantum', 'l.', 'infantum', 'l'], 'shortname': 'leiin'}, '999810': {'common_names': ['botryotinia', 'fuckeliana', 'b.', 'fuckeliana', 'b'], 'shortname': 'botf4'}, '10717': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpph1'}, '998086': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppa3'}, '73239': {'common_names': ['plasmodium', 'yoelii', 'p.', 'yoelii', 'p'], 'shortname': 'playo'}, '762660': {'common_names': ['acinetobacter', 'phage', 'a.', 'phage', 'a'], 'shortname': 'bpac4'}, '654923': {'common_names': ['infectious', 'spleen', 'i.', 'spleen', 'i'], 'shortname': 'isknn'}, '654906': {'common_names': ['neodiprion', 'lecontei', 'n.', 'lecontei', 'n'], 'shortname': 'npvnc'}, '654907': {'common_names': ['pyrobaculum', 'spherical', 'p.', 'spherical', 'p'], 'shortname': 'psvy'}, '1076759': {'common_names': ['vibrio', 'phage', 'v.', 'phage', 'v'], 'shortname': 'bpvc8'}, '79923': {'common_names': ['clonorchis', 'sinensis', 'c.', 'sinensis', 'c'], 'shortname': 'closi'}, '1032474': {'common_names': ['aeropyrum', 'pernix', 'a.', 'pernix', 'a'], 'shortname': 'apov1'}, '59241': {'common_names': ['pneumococcus', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpdp1'}, '648412': {'common_names': ['bombyx', 'mori', 'b.', 'mori', 'b'], 'shortname': 'bmdnd'}, '665032': {'common_names': ['delftia', 'phage', 'd.', 'phage', 'd'], 'shortname': 'bpw14'}, '1055687': {'common_names': ['trypanosoma', 'vivax', 't.', 'vivax', 't'], 'shortname': 'tryvy'}, '1141519': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bppkt'}, '1283336': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpfo1'}, '2932880': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpd3'}, '426428': {'common_names': ['fusarium', 'oxysporum', 'f.', 'oxysporum', 'f'], 'shortname': 'fuso4'}, '312017': {'common_names': ['tetrahymena', 'thermophila', 't.', 'thermophila', 't'], 'shortname': 'tetts'}, '654905': {'common_names': ['cydia', 'pomonella', 'c.', 'pomonella', 'c'], 'shortname': 'gvcpm'}, '10480': {'common_names': ['thermoproteus', 'tenax', 't.', 'tenax', 't'], 'shortname': 'ttv1k'}, '1093141': {'common_names': ['nannochloropsis', 'gaditana', 'n.', 'gaditana', 'n'], 'shortname': 'nangc'}, '889948': {'common_names': ['nanosalina', 'sp', 'n.', 'sp', 'n'], 'shortname': 'nans0'}, '889962': {'common_names': ['nanosalinarum', 'sp', 'n.', 'sp', 'n'], 'shortname': 'nansj'}, '72359': {'common_names': ['trachipleistophora', 'hominis', 't.', 'hominis', 't'], 'shortname': 'traho'}, '1283334': {'common_names': ['burkholderia', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpb78'}, '1283335': {'common_names': ['burkholderia', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpbmu'}, '1283342': {'common_names': ['ranid', 'herpesvirus', 'r.', 'herpesvirus', 'r'], 'shortname': 'rahv1'}, '1283343': {'common_names': ['anguillid', 'herpesvirus', 'a.', 'herpesvirus', 'a'], 'shortname': 'anhv1'}, '1239832': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'ttvk2'}, '1289470': {'common_names': ['euprosterna', 'elaeasa', 'e.', 'elaeasa', 'e'], 'shortname': 'eevz'}, '1289471': {'common_names': ['aeropyrum', 'pernix', 'a.', 'pernix', 'a'], 'shortname': 'apbv1'}, '523909': {'common_names': ['musca', 'hytrovirusisolate', 'm.', 'hytrovirusisolate', 'm'], 'shortname': 'mhvb'}, '1218490': {'common_names': ['torque', 'teno', 't.', 'teno', 't'], 'shortname': 'zcttv'}, '1087482': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bps16'}, '1289473': {'common_names': ['nile', 'crocodilepox', 'n.', 'crocodilepox', 'n'], 'shortname': 'cprvz'}, '379529': {'common_names': ['glossina', 'hytrovirus', 'g.', 'hytrovirus', 'g'], 'shortname': 'ghvs'}, '983506': {'common_names': ['thanatephorus', 'cucumeris', 't.', 'cucumeris', 't'], 'shortname': 'thaca'}, '1046081': {'common_names': ['oryctes', 'rhinoceros', 'o.', 'rhinoceros', 'o'], 'shortname': 'ornvm'}, '10713': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpph8'}, '1358809': {'common_names': ['spraguea', 'lophii', 's.', 'lophii', 's'], 'shortname': 'sprlo'}, '66284': {'common_names': ['shigella', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsf2'}, '1292036': {'common_names': ['paeniclostridium', 'sordellii', 'p.', 'sordellii', 'p'], 'shortname': 'paes9'}, '578461': {'common_names': ['nosema', 'bombycis', 'n.', 'bombycis', 'n'], 'shortname': 'nosb1'}, '1406785': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpgra'}, '747089': {'common_names': ['rhizophagus', 'irregularis', 'r.', 'irregularis', 'r'], 'shortname': 'rhiid'}, '110365': {'common_names': ['gregarina', 'niphandrodes', 'g.', 'niphandrodes', 'g'], 'shortname': 'greni'}, '1432141': {'common_names': ['rhizophagus', 'irregularis', 'r.', 'irregularis', 'r'], 'shortname': 'rhiiw'}, '46433': {'common_names': ['reticulomyxa', 'filosa', 'r.', 'filosa', 'r'], 'shortname': 'retfi'}, '10748': {'common_names': ['streptococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpcp7'}, '1554493': {'common_names': ['grapevine', 'leafrollassociated', 'g.', 'leafrollassociated', 'g'], 'shortname': 'glrv7'}, '1554497': {'common_names': ['hibiscus', 'green', 'h.', 'green', 'h'], 'shortname': 'hgsv2'}, '1556324': {'common_names': ['fenneropenaeus', 'chinensis', 'f.', 'chinensis', 'f'], 'shortname': 'fcdnv'}, '1513224': {'common_names': ['infectious', 'hypodermal', 'i.', 'hypodermal', 'i'], 'shortname': 'ihhnv'}, '717641': {'common_names': ['galliform', 'aveparvovirus', 'g.', 'aveparvovirus', 'g'], 'shortname': 'chpv1'}, '1560037': {'common_names': ['eidolon', 'helvum', 'e.', 'helvum', 'e'], 'shortname': 'btpv1'}, '1241371': {'common_names': ['abalone', 'herpesvirus', 'a.', 'herpesvirus', 'a'], 'shortname': 'abhv'}, '1128424': {'common_names': ['helicoverpa', 'zea', 'h.', 'zea', 'h'], 'shortname': 'hznv2'}, '694581': {'common_names': ['marseillevirus', 'marseillevirus', 'm.', 'marseillevirus', 'm'], 'shortname': 'gbmv'}, '693272': {'common_names': ['cafeteria', 'roenbergensis', 'c.', 'roenbergensis', 'c'], 'shortname': 'crovb'}, '69609': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpr27'}, '1559369': {'common_names': ['rosellinia', 'necatrix', 'r.', 'necatrix', 'r'], 'shortname': 'rnqvw'}, '35344': {'common_names': ['streptococcus', 'pyogenes', 's.', 'pyogenes', 's'], 'shortname': 'bpt12'}, '669202': {'common_names': ['thelohanellus', 'kitauei', 't.', 'kitauei', 't'], 'shortname': 'thekt'}, '29729': {'common_names': ['gossypium', 'arboreum', 'g.', 'arboreum', 'g'], 'shortname': 'gosar'}, '6313': {'common_names': ['angiostrongylus', 'cantonensis', 'a.', 'cantonensis', 'a'], 'shortname': 'angca'}, '67767': {'common_names': ['lasius', 'niger', 'l.', 'niger', 'l'], 'shortname': 'lasni'}, '104452': {'common_names': ['operophtera', 'brumata', 'o.', 'brumata', 'o'], 'shortname': 'opebr'}, '157538': {'common_names': ['leptomonas', 'pyrrhocoris', 'l.', 'pyrrhocoris', 'l'], 'shortname': 'leppy'}, '813': {'common_names': ['chlamydia', 'trachomatis', 'c.', 'trachomatis', 'c'], 'shortname': 'chlth'}, '75058': {'common_names': ['bodo', 'saltans', 'b.', 'saltans', 'b'], 'shortname': 'bodsa'}, '694068': {'common_names': ['fomitiporia', 'mediterranea', 'f.', 'mediterranea', 'f'], 'shortname': 'fomme'}, '61180': {'common_names': ['oesophagostomum', 'dentatum', 'o.', 'dentatum', 'o'], 'shortname': 'oesde'}, '721885': {'common_names': ['stereum', 'hirsutum', 's.', 'hirsutum', 's'], 'shortname': 'stehr'}, '765440': {'common_names': ['piloderma', 'croceum', 'p.', 'croceum', 'p'], 'shortname': 'pilcf'}, '990650': {'common_names': ['sphaerobolus', 'stellatus', 's.', 'stellatus', 's'], 'shortname': 'sphs4'}, '717944': {'common_names': ['trametes', 'versicolor', 't.', 'versicolor', 't'], 'shortname': 'travs'}, '407821': {'common_names': ['stegodyphus', 'mimosarum', 's.', 'mimosarum', 's'], 'shortname': 'stemi'}, '946122': {'common_names': ['amanita', 'muscaria', 'a.', 'muscaria', 'a'], 'shortname': 'amamk'}, '4781': {'common_names': ['plasmopara', 'halstedii', 'p.', 'halstedii', 'p'], 'shortname': 'plahl'}, '3821': {'common_names': ['cajanus', 'cajan', 'c.', 'cajan', 'c'], 'shortname': 'cajca'}, '3983': {'common_names': ['manihot', 'esculenta', 'm.', 'esculenta', 'm'], 'shortname': 'manes'}, '68347': {'common_names': ['wiseana', 'iridescent', 'w.', 'iridescent', 'w'], 'shortname': 'irv9'}, '10990': {'common_names': ['rice', 'black', 'r.', 'black', 'r'], 'shortname': 'rbsdv'}, '10989': {'common_names': ['maize', 'rough', 'm.', 'rough', 'm'], 'shortname': 'mrdv'}, '311229': {'common_names': ['rosellinia', 'necatrix', 'r.', 'necatrix', 'r'], 'shortname': 'myrvw'}, '31592': {'common_names': ['orgyia', 'pseudotsugata', 'o.', 'pseudotsugata', 'o'], 'shortname': 'cpvop'}, '103930': {'common_names': ['rhesus', 'cytomegalovirus', 'r.', 'cytomegalovirus', 'r'], 'shortname': 'rhcm6'}, '44088': {'common_names': ['canarypox', 'virus', 'c.', 'virus', 'c'], 'shortname': 'cnpv'}, '83191': {'common_names': ['melanoplus', 'sanguinipes', 'm.', 'sanguinipes', 'm'], 'shortname': 'msepv'}, '70333': {'common_names': ['bovine', 'adenovirus', 'b.', 'adenovirus', 'b'], 'shortname': 'adeb4'}, '2951': {'common_names': ['symbiodinium', 'microadriaticum', 's.', 'microadriaticum', 's'], 'shortname': 'symmi'}, '3775': {'common_names': ['cephalotus', 'follicularis', 'c.', 'follicularis', 'c'], 'shortname': 'cepfo'}, '1213189': {'common_names': ['zancudomyces', 'culisetae', 'z.', 'culisetae', 'z'], 'shortname': 'zancu'}, '6958': {'common_names': ['euroglyphus', 'maynei', 'e.', 'maynei', 'e'], 'shortname': 'eurma'}, '1307956': {'common_names': ['leucania', 'separata', 'l.', 'separata', 'l'], 'shortname': 'npvls'}, '46021': {'common_names': ['paramecium', 'bursaria', 'p.', 'bursaria', 'p'], 'shortname': 'pbcvn'}, '1805492': {'common_names': ['pyrobaculum', 'filamentous', 'p.', 'filamentous', 'p'], 'shortname': 'pfv1'}, '70600': {'common_names': ['epiphyas', 'postvittana', 'e.', 'postvittana', 'e'], 'shortname': 'npvep'}, '35254': {'common_names': ['cryptophlebia', 'leucotreta', 'c.', 'leucotreta', 'c'], 'shortname': 'gvcl'}, '193120': {'common_names': ['pea', 'enation', 'p.', 'enation', 'p'], 'shortname': 'pemv2'}, '380598': {'common_names': ['paramecium', 'bursaria', 'p.', 'bursaria', 'p'], 'shortname': 'pbcva'}, '363716': {'common_names': ['nora', 'virus', 'n.', 'virus', 'n'], 'shortname': 'norav'}, '1678082': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpk21'}, '455364': {'common_names': ['chrysochromulina', 'ericina', 'c.', 'ericina', 'c'], 'shortname': 'cev01'}, '10449': {'common_names': ['lymantria', 'dispar', 'l.', 'dispar', 'l'], 'shortname': 'npvld'}, '1175657': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bppam'}, '399781': {'common_names': ['paramecium', 'bursaria', 'p.', 'bursaria', 'p'], 'shortname': 'pbcvf'}, '1462608': {'common_names': ['pseudomonas', 'phage', 'p.', 'phage', 'p'], 'shortname': 'bpkp2'}, '1041526': {'common_names': ['staphylococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bps25'}, '941058': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bps10'}, '154834': {'common_names': ['satellite', 'panicum', 's.', 'panicum', 's'], 'shortname': 'spmv'}, '2169964': {'common_names': ['avonheathcote', 'estuary', 'a.', 'estuary', 'a'], 'shortname': 'ahebv'}, '4232': {'common_names': ['helianthus', 'annuus', 'h.', 'annuus', 'h'], 'shortname': 'helan'}, '47427': {'common_names': ['armillaria', 'gallica', 'a.', 'gallica', 'a'], 'shortname': 'armga'}, '1933063': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpgo3'}, '1406341': {'common_names': ['thermus', 'phage', 't.', 'phage', 't'], 'shortname': 'bpg20'}, '1982658': {'common_names': ['sulfolobus', 'polyhedral', 's.', 'polyhedral', 's'], 'shortname': 'spv1'}, '8400': {'common_names': ['lithobates', 'catesbeianus', 'l.', 'catesbeianus', 'l'], 'shortname': 'litct'}, '45464': {'common_names': ['teladorsagia', 'circumcincta', 't.', 'circumcincta', 't'], 'shortname': 'telci'}, '22663': {'common_names': ['punica', 'granatum', 'p.', 'granatum', 'p'], 'shortname': 'pungr'}, '57577': {'common_names': ['trifolium', 'pratense', 't.', 'pratense', 't'], 'shortname': 'tripr'}, '63057': {'common_names': ['trema', 'orientale', 't.', 'orientale', 't'], 'shortname': 'treoi'}, '3476': {'common_names': ['parasponia', 'andersonii', 'p.', 'andersonii', 'p'], 'shortname': 'parad'}, '2081904': {'common_names': ['salmonella', 'phage', 's.', 'phage', 's'], 'shortname': 'bppmb'}, '2060946': {'common_names': ['acinetobacter', 'phage', 'a.', 'phage', 'a'], 'shortname': 'bpsha'}, '3330': {'common_names': ['picea', 'glauca', 'p.', 'glauca', 'p'], 'shortname': 'picgl'}, '56947': {'common_names': ['choristoneura', 'fumiferana', 'c.', 'fumiferana', 'c'], 'shortname': 'gvcf'}, '6973': {'common_names': ['blattella', 'germanica', 'b.', 'germanica', 'b'], 'shortname': 'blage'}, '238854': {'common_names': ['synechococcus', 'phage', 's.', 'phage', 's'], 'shortname': 'bpsyp'}, '346932': {'common_names': ['paramecium', 'bursaria', 'p.', 'bursaria', 'p'], 'shortname': 'pbcvm'}, '29170': {'common_names': ['ancylostoma', 'caninum', 'a.', 'caninum', 'a'], 'shortname': 'ancca'}, '2283013': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpbsp'}, '10666': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt6'}, '2301731': {'common_names': ['bacteroides', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpca1'}, '2304198': {'common_names': ['sulfolobus', 'filamentous', 's.', 'filamentous', 's'], 'shortname': 'sufv1'}, '159749': {'common_names': ['thalassiosira', 'oceanica', 't.', 'oceanica', 't'], 'shortname': 'thaoc'}, '6269': {'common_names': ['anisakis', 'simplex', 'a.', 'simplex', 'a'], 'shortname': 'anisi'}, '6290': {'common_names': ['haemonchus', 'placei', 'h.', 'placei', 'h'], 'shortname': 'haepc'}, '40348': {'common_names': ['strongylus', 'vulgaris', 's.', 'vulgaris', 's'], 'shortname': 'strvu'}, '27835': {'common_names': ['nippostrongylus', 'brasiliensis', 'n.', 'brasiliensis', 'n'], 'shortname': 'nipbr'}, '71465': {'common_names': ['cylicostephanus', 'goldi', 'c.', 'goldi', 'c'], 'shortname': 'cylgo'}, '70667': {'common_names': ['schistocephalus', 'solidus', 's.', 'solidus', 's'], 'shortname': 'schso'}, '10195': {'common_names': ['brachionus', 'plicatilis', 'b.', 'plicatilis', 'b'], 'shortname': 'brapc'}, '169684': {'common_names': ['halobacterium', 'phage', 'h.', 'phage', 'h'], 'shortname': 'bpphh'}, '157069': {'common_names': ['trichobilharzia', 'regenti', 't.', 'regenti', 't'], 'shortname': 'trire'}, '60516': {'common_names': ['dibothriocephalus', 'latus', 'd.', 'latus', 'd'], 'shortname': 'dibla'}, '137246': {'common_names': ['chiloscyllium', 'punctatum', 'c.', 'punctatum', 'c'], 'shortname': 'chipu'}, '13347': {'common_names': ['armadillidium', 'vulgare', 'a.', 'vulgare', 'a'], 'shortname': 'armvu'}, '4639': {'common_names': ['ensete', 'ventricosum', 'e.', 'ventricosum', 'e'], 'shortname': 'ensve'}, '2124': {'common_names': ['metamycoplasma', 'salivarium', 'm.', 'salivarium', 'm'], 'shortname': 'metsv'}, '462299': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpvt1'}, '2502409': {'common_names': ['escherichia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpgos'}, '1314807': {'common_names': ['dendrothele', 'bispora', 'd.', 'bispora', 'd'], 'shortname': 'denbc'}, '151549': {'common_names': ['eumeta', 'variegata', 'e.', 'variegata', 'e'], 'shortname': 'eumva'}, '69820': {'common_names': ['spodoptera', 'litura', 's.', 'litura', 's'], 'shortname': 'spolt'}, '39803': {'common_names': ['escherichia', 'virus', 'e.', 'virus', 'e'], 'shortname': 'bpqbe'}, '6182': {'common_names': ['schistosoma', 'japonicum', 's.', 'japonicum', 's'], 'shortname': 'schja'}, '5742': {'common_names': ['giardia', 'muris', 'g.', 'muris', 'g'], 'shortname': 'giamu'}, '306': {'common_names': ['pseudomonas', 'sp', 'p.', 'sp', 'p'], 'shortname': 'psesp'}, '28214': {'common_names': ['sphingomonas', 'sp', 's.', 'sp', 's'], 'shortname': 'sphsx'}, '2593639': {'common_names': ['bacillus', 'phage', 'b.', 'phage', 'b'], 'shortname': 'bpgo7'}, '10547': {'common_names': ['fowl', 'adenovirus', 'f.', 'adenovirus', 'f'], 'shortname': 'adegx'}, '210409': {'common_names': ['portunus', 'trituberculatus', 'p.', 'trituberculatus', 'p'], 'shortname': 'portr'}, '4874': {'common_names': ['gigaspora', 'margarita', 'g.', 'margarita', 'g'], 'shortname': 'gigma'}, '1160': {'common_names': ['planktothrix', 'agardhii', 'p.', 'agardhii', 'p'], 'shortname': 'plaag'}, '307492': {'common_names': ['aphis', 'craccivora', 'a.', 'craccivora', 'a'], 'shortname': 'aphcr'}, '44745': {'common_names': ['haematococcus', 'lacustris', 'h.', 'lacustris', 'h'], 'shortname': 'haela'}, '182803': {'common_names': ['araneus', 'ventricosus', 'a.', 'ventricosus', 'a'], 'shortname': 'arave'}, '2730621': {'common_names': ['pyrobaculum', 'filamentous', 'p.', 'filamentous', 'p'], 'shortname': 'pfv2'}, '2730619': {'common_names': ['saccharolobus', 'solfataricus', 's.', 'solfataricus', 's'], 'shortname': 'ssrv1'}, '65424': {'common_names': ['red', 'sea', 'r.', 'sea', 'r'], 'shortname': 'rsiv'}, '2060721': {'common_names': ['enterobacteria', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpt2'}, '185453': {'common_names': ['chrysochloris', 'asiatica', 'c.', 'asiatica', 'c'], 'shortname': 'chras'}, '42192': {'common_names': ['mytilus', 'coruscus', 'm.', 'coruscus', 'm'], 'shortname': 'mytco'}, '99802': {'common_names': ['spirometra', 'erinaceieuropaei', 's.', 'erinaceieuropaei', 's'], 'shortname': 'spier'}, '32597': {'common_names': ['perkinsus', 'olseni', 'p.', 'olseni', 'p'], 'shortname': 'perol'}, '46969': {'common_names': ['thalictrum', 'thalictroides', 't.', 'thalictroides', 't'], 'shortname': 'thath'}, '10212': {'common_names': ['bugula', 'neritina', 'b.', 'neritina', 'b'], 'shortname': 'bugne'}, '217165': {'common_names': ['caligus', 'rogercresseyi', 'c.', 'rogercresseyi', 'c'], 'shortname': 'calro'}, '260586': {'common_names': ['cyanophage', 's2l', 'c.', 's2l', 'c'], 'shortname': 'bps2l'}, '158019': {'common_names': ['sepia', 'pharaonis', 's.', 'pharaonis', 's'], 'shortname': 'sepph'}, '4787': {'common_names': ['phytophthora', 'infestans', 'p.', 'infestans', 'p'], 'shortname': 'phyin'}, '7213': {'common_names': ['ceratitis', 'capitata', 'c.', 'capitata', 'c'], 'shortname': 'cerca'}, '2952': {'common_names': ['symbiodinium', 'pilosum', 's.', 'pilosum', 's'], 'shortname': 'sympi'}, '4460': {'common_names': ['colocasia', 'esculenta', 'c.', 'esculenta', 'c'], 'shortname': 'coles'}, '89957': {'common_names': ['polarella', 'glacialis', 'p.', 'glacialis', 'p'], 'shortname': 'polgl'}, '2776772': {'common_names': ['erwinia', 'phage', 'e.', 'phage', 'e'], 'shortname': 'bpfbb'}, '72036': {'common_names': ['lepeophtheirus', 'salmonis', 'l.', 'salmonis', 'l'], 'shortname': 'lepsm'}, '6550': {'common_names': ['mytilus', 'edulis', 'm.', 'edulis', 'm'], 'shortname': 'myted'}, '43137': {'common_names': ['paramecium', 'octaurelia', 'p.', 'octaurelia', 'p'], 'shortname': 'parot'}, '5886': {'common_names': ['paramecium', 'primaurelia', 'p.', 'primaurelia', 'p'], 'shortname': 'parpr'}, '110799': {'common_names': ['parnassius', 'apollo', 'p.', 'apollo', 'p'], 'shortname': 'parao'}, '69181': {'common_names': ['brassica', 'cretica', 'b.', 'cretica', 'b'], 'shortname': 'bracr'}, '2053491': {'common_names': ['thorarchaeota', 'archaeon', 't.', 'archaeon', 't'], 'shortname': 'thoar'}, '6706': {'common_names': ['homarus', 'americanus', 'h.', 'americanus', 'h'], 'shortname': 'homam'}, '41210': {'common_names': ['chionoecetes', 'opilio', 'c.', 'opilio', 'c'], 'shortname': 'chiop'}, '5974': {'common_names': ['halteria', 'grandinella', 'h.', 'grandinella', 'h'], 'shortname': 'halgn'}, '1356854': {'common_names': ['alicyclobacillus', 'acidoterrestris', 'a.', 'acidoterrestris', 'a'], 'shortname': 'aliag'}, '299642': {'common_names': ['nephila', 'pilipes', 'n.', 'pilipes', 'n'], 'shortname': 'neppi'}, '2740835': {'common_names': ['trichonephila', 'clavata', 't.', 'clavata', 't'], 'shortname': 'tricu'}, '2585209': {'common_names': ['trichonephila', 'clavipes', 't.', 'clavipes', 't'], 'shortname': 'tricx'}, '412133': {'common_names': ['trichomonas', 'vaginalis', 't.', 'vaginalis', 't'], 'shortname': 'triv3'}}

    # strip out names
    non_organismal = []
    for i in user_input:
        if i not in strip_list:
            non_organismal.append(i)

    # try to get closest taxid if possible
    best_score=0
    taxid=''
    # search all uniprot org IDs and decide on the orgID # 
    for i in organism_ids.keys():
        cur_score=0
        for usrinput in user_input:
            # prioritize orgianism ID first
            if usrinput == i:
                cur_score+=1000
            # prioritize shortnames second
            if usrinput == organism_ids[i]['shortname']:
                cur_score+=100
            # prioritize orgianism common names last
            if usrinput in organism_ids[i]['common_names']:
                cur_score+=1
            if cur_score > best_score:
                best_score=cur_score
                taxid = i
    return {'taxid': taxid, 'gene_info': non_organismal}


def seq_from_uniprot(name):
    '''
    Function to get the uniprot_id of a protein from the name. 

    Parameters
    ----------
    name: string
        A string that carries the details fo the protein to search for. Can 
        contain the name of the protein as well as the name of the organims.
            ex. ARF19
                Arabidopsis ARF19
                p53
                Human p53
                Homo sapiens p53

    Returns
    -------
    top_hit : string
        Returns the amino acid sequence of the top hit on uniprot
        website.
    '''

    # first format name into a url
    # uses only reviewed on first attempt.
    split_name = name.split(' ')
    if len(split_name) == 1:
        use_url=f'https://rest.uniprot.org/uniprotkb/search?size=15&format=fasta&query={split_name[0]}%20AND%20%28reviewed%3Atrue%29'
        top_five = requests.get(use_url).text
        query_keywords=split_name[0]
        
    else:
        # format the search string.
        split_name = parse_input(name)
        # if you don't have a taxid, you're hitting the 'feeling lucky' button on early 2000s Google more or less TBH.
        add_vals = split_name['gene_info']
        query_keywords = split_name['gene_info']
        add_str = ''
        for i in add_vals:
            add_str += i
            add_str += '%20'
        add_str = add_str[0:len(add_str)-3]
        # if no taxid...
        if split_name['taxid']=='':
            # one below filters for the reviewed proteins.
            use_url = f'https://rest.uniprot.org/uniprotkb/search?format=fasta&size=15&query={add_str}%20AND%20%28reviewed%3Atrue%29'
            # pull top 5 fastas
            top_five = requests.get(use_url).text
            if top_five == '':
                # do unreviewed.
                use_url = f'https://rest.uniprot.org/uniprotkb/search?format=fasta&size=15&query={add_str}%20AND%20%28reviewed%3Afalse%29'
                top_five = requests.get(use_url).text
        else:
            # one below filters for the reviewed proteins.
            # trying change to organism_id, no idea if it will work.
            use_url = f"https://rest.uniprot.org/uniprotkb/search?format=fasta&size=15&query={add_str}%20AND%20%28reviewed%3Atrue%29%20AND%20%28organism_id%3A{split_name['taxid']}%29"
            top_five = requests.get(use_url).text
            if top_five == '':
                # do unreviewed.
                use_url = f"https://rest.uniprot.org/uniprotkb/search?format=fasta&size=15&query={add_str}%20AND%20%28reviewed%3Afalse%29%20AND%20%28organism_id%3A{split_name['taxid']}%29"
                top_five = requests.get(use_url).text    

    # if using org id before, take out and try agian.
    if type(split_name)==dict:
        if split_name['taxid']!='':
            if top_five == '':
                use_url = f'https://rest.uniprot.org/uniprotkb/search?format=fasta&size=15&query={add_str}%20AND%20%28reviewed%3Afalse%29'
                top_five = requests.get(use_url).text

    if top_five == '':
        raise Exception('Unable to find sequence.')


    # header placeholder
    header = ''
    final_vals = []
    # now try to get right fasta
    fastas_split = top_five.split('>')[1:]
    
    most_matches = 0
    best_seq=''

    for header_seq in fastas_split:
        temp_seq = ''
        split_by_lines = header_seq.split('\n')
        header = split_by_lines[0].lower()
        temp_header = ''
        for i in header:
            if i == '_':
                temp_header += ' '
            else:
                temp_header += i
        header=temp_header

        if type(query_keywords) == str:

            if query_keywords in header:
                for chars in split_by_lines[1:]:
                    temp_seq+=chars
                final_vals = [header, temp_seq]
                return final_vals
        
        else:
            gene_name = header.split('gn=')[1].split(' ')[0]
            organism_name = header.split('ox=')[1].split(' ')[0]
            cur_matches=0
            for i in query_keywords:
                if i in header:
                    cur_matches += 1
                    if i == gene_name:
                        cur_matches += 2
                    if parse_input(name)['taxid'] != '':
                        if i == parse_input(name)['taxid']:
                            cur_matches += 1
            if cur_matches > most_matches:
                temp_seq=''
                most_matches = cur_matches
                for chars in split_by_lines[1:]:
                    temp_seq+=chars
                best_seq = temp_seq
                final_vals = [header, best_seq]
    

    if final_vals != []:
        return final_vals

    else:
        seq_to_use = fastas_split[0]
        split_by_lines = seq_to_use.split('\n')
        header = split_by_lines[0].lower()
        for chars in split_by_lines[1:]:
            temp_seq+=chars
        final_vals = [header, temp_seq]
        return final_vals

    # if we have still failed... well darn.
    raise Exception('Unable to find sequence.')


